#include "tree_sitter/parser.h"

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#define LANGUAGE_VERSION 14
#define STATE_COUNT 1135
#define LARGE_STATE_COUNT 216
#define SYMBOL_COUNT 324
#define ALIAS_COUNT 0
#define TOKEN_COUNT 167
#define EXTERNAL_TOKEN_COUNT 0
#define FIELD_COUNT 10
#define MAX_ALIAS_SEQUENCE_LENGTH 10
#define PRODUCTION_ID_COUNT 21

enum ts_symbol_identifiers {
  sym_pn_prefix = 1,
  sym_comment = 2,
  anon_sym_SEMI = 3,
  aux_sym_base_declaration_token1 = 4,
  aux_sym_prefix_declaration_token1 = 5,
  aux_sym_select_clause_token1 = 6,
  aux_sym_select_clause_token2 = 7,
  aux_sym_select_clause_token3 = 8,
  anon_sym_LPAREN = 9,
  aux_sym_select_clause_token4 = 10,
  anon_sym_RPAREN = 11,
  anon_sym_STAR = 12,
  aux_sym_construct_query_token1 = 13,
  aux_sym_construct_query_token2 = 14,
  anon_sym_LBRACE = 15,
  anon_sym_RBRACE = 16,
  aux_sym_describe_query_token1 = 17,
  aux_sym_ask_query_token1 = 18,
  aux_sym_dataset_clause_token1 = 19,
  aux_sym_named_graph_clause_token1 = 20,
  aux_sym_group_clause_token1 = 21,
  aux_sym_group_clause_token2 = 22,
  aux_sym_having_clause_token1 = 23,
  aux_sym_order_clause_token1 = 24,
  aux_sym_order_condition_token1 = 25,
  aux_sym_order_condition_token2 = 26,
  aux_sym_limit_clause_token1 = 27,
  aux_sym_offset_clause_token1 = 28,
  aux_sym_values_clause_token1 = 29,
  aux_sym_load_token1 = 30,
  aux_sym_load_token2 = 31,
  aux_sym_load_token3 = 32,
  aux_sym_clear_token1 = 33,
  aux_sym_drop_token1 = 34,
  aux_sym_create_token1 = 35,
  aux_sym_add_token1 = 36,
  aux_sym_add_token2 = 37,
  aux_sym_move_token1 = 38,
  aux_sym_copy_token1 = 39,
  anon_sym_INSERTDATA = 40,
  anon_sym_DELETEDATA = 41,
  anon_sym_DELETEWHERE = 42,
  aux_sym_modify_token1 = 43,
  aux_sym_delete_clause_token1 = 44,
  aux_sym_insert_clause_token1 = 45,
  aux_sym_using_clause_token1 = 46,
  aux_sym_graph_or_default_token1 = 47,
  aux_sym_graph_or_default_token2 = 48,
  aux_sym_graph_ref_all_token1 = 49,
  anon_sym_DOT = 50,
  aux_sym_optional_graph_pattern_token1 = 51,
  aux_sym_service_graph_pattern_token1 = 52,
  aux_sym_bind_token1 = 53,
  aux_sym__data_block_value_token1 = 54,
  aux_sym_minus_graph_pattern_token1 = 55,
  aux_sym_group_or_union_graph_pattern_token1 = 56,
  aux_sym_filter_token1 = 57,
  anon_sym_COMMA = 58,
  anon_sym_a = 59,
  anon_sym_SLASH = 60,
  anon_sym_PIPE = 61,
  anon_sym_CARET = 62,
  sym_path_mod = 63,
  anon_sym_BANG = 64,
  anon_sym_LBRACK = 65,
  anon_sym_RBRACK = 66,
  sym_var = 67,
  anon_sym_PIPE_PIPE = 68,
  anon_sym_AMP_AMP = 69,
  anon_sym_EQ = 70,
  anon_sym_BANG_EQ = 71,
  anon_sym_LT = 72,
  anon_sym_GT = 73,
  anon_sym_LT_EQ = 74,
  anon_sym_GT_EQ = 75,
  aux_sym_binary_expression_token1 = 76,
  aux_sym_binary_expression_token2 = 77,
  anon_sym_PLUS = 78,
  anon_sym_DASH = 79,
  aux_sym_build_in_function_token1 = 80,
  aux_sym_build_in_function_token2 = 81,
  aux_sym_build_in_function_token3 = 82,
  aux_sym__nullary_build_in_function_token1 = 83,
  aux_sym__nullary_build_in_function_token2 = 84,
  aux_sym__nullary_build_in_function_token3 = 85,
  aux_sym__nullary_build_in_function_token4 = 86,
  aux_sym__unary_build_in_function_token1 = 87,
  aux_sym__unary_build_in_function_token2 = 88,
  aux_sym__unary_build_in_function_token3 = 89,
  aux_sym__unary_build_in_function_token4 = 90,
  aux_sym__unary_build_in_function_token5 = 91,
  aux_sym__unary_build_in_function_token6 = 92,
  aux_sym__unary_build_in_function_token7 = 93,
  aux_sym__unary_build_in_function_token8 = 94,
  aux_sym__unary_build_in_function_token9 = 95,
  aux_sym__unary_build_in_function_token10 = 96,
  aux_sym__unary_build_in_function_token11 = 97,
  aux_sym__unary_build_in_function_token12 = 98,
  aux_sym__unary_build_in_function_token13 = 99,
  aux_sym__unary_build_in_function_token14 = 100,
  aux_sym__unary_build_in_function_token15 = 101,
  aux_sym__unary_build_in_function_token16 = 102,
  aux_sym__unary_build_in_function_token17 = 103,
  aux_sym__unary_build_in_function_token18 = 104,
  aux_sym__unary_build_in_function_token19 = 105,
  aux_sym__unary_build_in_function_token20 = 106,
  aux_sym__unary_build_in_function_token21 = 107,
  aux_sym__unary_build_in_function_token22 = 108,
  aux_sym__unary_build_in_function_token23 = 109,
  aux_sym__unary_build_in_function_token24 = 110,
  aux_sym__unary_build_in_function_token25 = 111,
  aux_sym__unary_build_in_function_token26 = 112,
  aux_sym__unary_build_in_function_token27 = 113,
  aux_sym__unary_build_in_function_token28 = 114,
  aux_sym__unary_build_in_function_token29 = 115,
  aux_sym__unary_build_in_function_token30 = 116,
  aux_sym__unary_build_in_function_token31 = 117,
  aux_sym__binary_build_in_function_token1 = 118,
  aux_sym__binary_build_in_function_token2 = 119,
  aux_sym__binary_build_in_function_token3 = 120,
  aux_sym__binary_build_in_function_token4 = 121,
  aux_sym__binary_build_in_function_token5 = 122,
  aux_sym__binary_build_in_function_token6 = 123,
  aux_sym__binary_build_in_function_token7 = 124,
  aux_sym__binary_build_in_function_token8 = 125,
  aux_sym__binary_build_in_function_token9 = 126,
  aux_sym__variadic_build_in_function_token1 = 127,
  aux_sym__variadic_build_in_function_token2 = 128,
  aux_sym_regex_expression_token1 = 129,
  aux_sym_substring_expression_token1 = 130,
  aux_sym_string_replace_expression_token1 = 131,
  aux_sym_exists_func_token1 = 132,
  aux_sym_aggregate_token1 = 133,
  aux_sym_aggregate_token2 = 134,
  aux_sym_aggregate_token3 = 135,
  aux_sym_aggregate_token4 = 136,
  aux_sym_aggregate_token5 = 137,
  aux_sym_aggregate_token6 = 138,
  anon_sym_GROUP_CONCAT = 139,
  aux_sym_aggregate_token7 = 140,
  anon_sym_CARET_CARET = 141,
  anon_sym_true = 142,
  anon_sym_false = 143,
  aux_sym_iri_reference_token1 = 144,
  anon_sym_GT2 = 145,
  anon_sym_COLON = 146,
  anon_sym__COLON = 147,
  aux_sym_blank_node_label_token1 = 148,
  sym_lang_tag = 149,
  sym_integer = 150,
  sym_decimal = 151,
  sym_double = 152,
  anon_sym_SQUOTE = 153,
  aux_sym__string_literal1_token1 = 154,
  anon_sym_DQUOTE = 155,
  aux_sym__string_literal2_token1 = 156,
  anon_sym_SQUOTE_SQUOTE_SQUOTE = 157,
  anon_sym_SQUOTE_SQUOTE = 158,
  aux_sym__string_literal_long1_token1 = 159,
  anon_sym_DQUOTE_DQUOTE_DQUOTE = 160,
  anon_sym_DQUOTE_DQUOTE = 161,
  aux_sym__string_literal_long2_token1 = 162,
  sym_echar = 163,
  sym_nil = 164,
  sym_anon = 165,
  sym_pn_local = 166,
  sym_unit = 167,
  sym__update = 168,
  sym_prologue = 169,
  sym_base_declaration = 170,
  sym_prefix_declaration = 171,
  sym_select_query = 172,
  sym_sub_select = 173,
  sym_select_clause = 174,
  sym_construct_query = 175,
  sym_describe_query = 176,
  sym_ask_query = 177,
  sym_dataset_clause = 178,
  sym_default_graph_clause = 179,
  sym_named_graph_clause = 180,
  sym_where_clause = 181,
  sym_solution_modifier = 182,
  sym_group_clause = 183,
  sym_group_condition = 184,
  sym_having_clause = 185,
  sym_having_condition = 186,
  sym_order_clause = 187,
  sym_order_condition = 188,
  sym_limit_offset_clauses = 189,
  sym_limit_clause = 190,
  sym_offset_clause = 191,
  sym_values_clause = 192,
  sym_load = 193,
  sym_clear = 194,
  sym_drop = 195,
  sym_create = 196,
  sym_add = 197,
  sym_move = 198,
  sym_copy = 199,
  sym_insert_data = 200,
  sym_delete_data = 201,
  sym_delete_where = 202,
  sym_modify = 203,
  sym_delete_clause = 204,
  sym_insert_clause = 205,
  sym_using_clause = 206,
  sym_graph_or_default = 207,
  sym_graph_ref = 208,
  sym_graph_ref_all = 209,
  sym_quads = 210,
  sym_quads_not_triples = 211,
  sym_triples_template = 212,
  sym_group_graph_pattern = 213,
  sym_triples_block = 214,
  sym__graph_pattern_not_triples = 215,
  sym_optional_graph_pattern = 216,
  sym_graph_graph_pattern = 217,
  sym_service_graph_pattern = 218,
  sym_bind = 219,
  sym_inline_data = 220,
  sym_data_block = 221,
  sym__inline_data_one_var = 222,
  sym__inline_data_full = 223,
  sym__data_block_value = 224,
  sym_minus_graph_pattern = 225,
  sym_group_or_union_graph_pattern = 226,
  sym_filter = 227,
  sym__constraint = 228,
  sym_function_call = 229,
  sym_arg_list = 230,
  sym_expression_list = 231,
  sym_construct_template = 232,
  sym_construct_triples = 233,
  sym_triples_same_subject = 234,
  sym_property_list = 235,
  sym_property = 236,
  sym__predicate = 237,
  sym_object_list = 238,
  sym_triples_same_subject_path = 239,
  sym_property_list_path = 240,
  sym_property_path = 241,
  sym_property_path_rest = 242,
  sym__predicate_path = 243,
  sym_object_list_path = 244,
  sym__path = 245,
  sym_binary_path = 246,
  sym_path_element = 247,
  sym_path_inverse = 248,
  sym__primary_path = 249,
  sym_path_negated_property_set = 250,
  sym_path_one_in_property_set = 251,
  sym__triples_node = 252,
  sym_blank_node_property_list = 253,
  sym__triples_node_path = 254,
  sym_blank_node_property_list_path = 255,
  sym_collection = 256,
  sym_collection_path = 257,
  sym__graph_node = 258,
  sym__graph_node_path = 259,
  sym__var_or_term = 260,
  sym__var_or_iri = 261,
  sym__graph_term = 262,
  sym__expression = 263,
  sym_binary_expression = 264,
  sym_unary_expression = 265,
  sym__primary_expression = 266,
  sym_bracketted_expression = 267,
  sym__build_in_call = 268,
  sym_build_in_function = 269,
  sym__nullary_build_in_function = 270,
  sym__unary_build_in_function = 271,
  sym__binary_build_in_function = 272,
  sym__variadic_build_in_function = 273,
  sym_regex_expression = 274,
  sym_substring_expression = 275,
  sym_string_replace_expression = 276,
  sym_exists_func = 277,
  sym_not_exists_func = 278,
  sym_aggregate = 279,
  sym__iri_or_function = 280,
  sym_rdf_literal = 281,
  sym__numeric_literal = 282,
  sym_boolean_literal = 283,
  sym_string = 284,
  sym__iri = 285,
  sym_prefixed_name = 286,
  sym__blank_node = 287,
  sym_iri_reference = 288,
  sym_namespace = 289,
  sym_blank_node_label = 290,
  sym__string_literal1 = 291,
  sym__string_literal2 = 292,
  sym__string_literal_long1 = 293,
  sym__string_literal_long2 = 294,
  aux_sym_unit_repeat1 = 295,
  aux_sym_prologue_repeat1 = 296,
  aux_sym_select_query_repeat1 = 297,
  aux_sym_select_clause_repeat1 = 298,
  aux_sym_describe_query_repeat1 = 299,
  aux_sym_group_clause_repeat1 = 300,
  aux_sym_having_clause_repeat1 = 301,
  aux_sym_order_clause_repeat1 = 302,
  aux_sym_modify_repeat1 = 303,
  aux_sym_quads_repeat1 = 304,
  aux_sym_triples_template_repeat1 = 305,
  aux_sym_group_graph_pattern_repeat1 = 306,
  aux_sym_triples_block_repeat1 = 307,
  aux_sym__inline_data_one_var_repeat1 = 308,
  aux_sym__inline_data_full_repeat1 = 309,
  aux_sym__inline_data_full_repeat2 = 310,
  aux_sym_group_or_union_graph_pattern_repeat1 = 311,
  aux_sym_arg_list_repeat1 = 312,
  aux_sym_property_list_repeat1 = 313,
  aux_sym_object_list_repeat1 = 314,
  aux_sym_property_list_path_repeat1 = 315,
  aux_sym_object_list_path_repeat1 = 316,
  aux_sym_path_negated_property_set_repeat1 = 317,
  aux_sym_collection_repeat1 = 318,
  aux_sym_collection_path_repeat1 = 319,
  aux_sym__string_literal1_repeat1 = 320,
  aux_sym__string_literal2_repeat1 = 321,
  aux_sym__string_literal_long1_repeat1 = 322,
  aux_sym__string_literal_long2_repeat1 = 323,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [sym_pn_prefix] = "pn_prefix",
  [sym_comment] = "comment",
  [anon_sym_SEMI] = ";",
  [aux_sym_base_declaration_token1] = "BASE",
  [aux_sym_prefix_declaration_token1] = "PREFIX",
  [aux_sym_select_clause_token1] = "SELECT",
  [aux_sym_select_clause_token2] = "DISTINCT",
  [aux_sym_select_clause_token3] = "REDUCED",
  [anon_sym_LPAREN] = "(",
  [aux_sym_select_clause_token4] = "AS",
  [anon_sym_RPAREN] = ")",
  [anon_sym_STAR] = "*",
  [aux_sym_construct_query_token1] = "CONSTRUCT",
  [aux_sym_construct_query_token2] = "WHERE",
  [anon_sym_LBRACE] = "{",
  [anon_sym_RBRACE] = "}",
  [aux_sym_describe_query_token1] = "DESCRIBE",
  [aux_sym_ask_query_token1] = "ASK",
  [aux_sym_dataset_clause_token1] = "FROM",
  [aux_sym_named_graph_clause_token1] = "NAMED",
  [aux_sym_group_clause_token1] = "GROUP",
  [aux_sym_group_clause_token2] = "BY",
  [aux_sym_having_clause_token1] = "HAVING",
  [aux_sym_order_clause_token1] = "ORDER",
  [aux_sym_order_condition_token1] = "ASC",
  [aux_sym_order_condition_token2] = "DESC",
  [aux_sym_limit_clause_token1] = "LIMIT",
  [aux_sym_offset_clause_token1] = "OFFSET",
  [aux_sym_values_clause_token1] = "VALUES",
  [aux_sym_load_token1] = "LOAD",
  [aux_sym_load_token2] = "SILENT",
  [aux_sym_load_token3] = "INTO",
  [aux_sym_clear_token1] = "CLEAR",
  [aux_sym_drop_token1] = "DROP",
  [aux_sym_create_token1] = "CREATE",
  [aux_sym_add_token1] = "ADD",
  [aux_sym_add_token2] = "TO",
  [aux_sym_move_token1] = "MOVE",
  [aux_sym_copy_token1] = "COPY",
  [anon_sym_INSERTDATA] = "INSERT DATA",
  [anon_sym_DELETEDATA] = "DELETE DATA",
  [anon_sym_DELETEWHERE] = "DELETE WHERE",
  [aux_sym_modify_token1] = "WITH",
  [aux_sym_delete_clause_token1] = "DELETE",
  [aux_sym_insert_clause_token1] = "INSERT",
  [aux_sym_using_clause_token1] = "USING",
  [aux_sym_graph_or_default_token1] = "DEFAULT",
  [aux_sym_graph_or_default_token2] = "GRAPH",
  [aux_sym_graph_ref_all_token1] = "ALL",
  [anon_sym_DOT] = ".",
  [aux_sym_optional_graph_pattern_token1] = "OPTIONAL",
  [aux_sym_service_graph_pattern_token1] = "SERVICE",
  [aux_sym_bind_token1] = "BIND",
  [aux_sym__data_block_value_token1] = "UNDEF",
  [aux_sym_minus_graph_pattern_token1] = "MINUS",
  [aux_sym_group_or_union_graph_pattern_token1] = "UNION",
  [aux_sym_filter_token1] = "FILTER",
  [anon_sym_COMMA] = ",",
  [anon_sym_a] = "a",
  [anon_sym_SLASH] = "/",
  [anon_sym_PIPE] = "|",
  [anon_sym_CARET] = "^",
  [sym_path_mod] = "path_mod",
  [anon_sym_BANG] = "!",
  [anon_sym_LBRACK] = "[",
  [anon_sym_RBRACK] = "]",
  [sym_var] = "var",
  [anon_sym_PIPE_PIPE] = "||",
  [anon_sym_AMP_AMP] = "&&",
  [anon_sym_EQ] = "=",
  [anon_sym_BANG_EQ] = "!=",
  [anon_sym_LT] = "<",
  [anon_sym_GT] = ">",
  [anon_sym_LT_EQ] = "<=",
  [anon_sym_GT_EQ] = ">=",
  [aux_sym_binary_expression_token1] = "IN",
  [aux_sym_binary_expression_token2] = "NOT",
  [anon_sym_PLUS] = "+",
  [anon_sym_DASH] = "-",
  [aux_sym_build_in_function_token1] = "BOUND",
  [aux_sym_build_in_function_token2] = "BNODE",
  [aux_sym_build_in_function_token3] = "IF",
  [aux_sym__nullary_build_in_function_token1] = "NOW",
  [aux_sym__nullary_build_in_function_token2] = "RAND",
  [aux_sym__nullary_build_in_function_token3] = "STRUUID",
  [aux_sym__nullary_build_in_function_token4] = "UUID",
  [aux_sym__unary_build_in_function_token1] = "ABS",
  [aux_sym__unary_build_in_function_token2] = "CEIL",
  [aux_sym__unary_build_in_function_token3] = "DATATYPE",
  [aux_sym__unary_build_in_function_token4] = "DAY",
  [aux_sym__unary_build_in_function_token5] = "ENCODE_FOR_URI",
  [aux_sym__unary_build_in_function_token6] = "FLOOR",
  [aux_sym__unary_build_in_function_token7] = "HOURS",
  [aux_sym__unary_build_in_function_token8] = "IRI",
  [aux_sym__unary_build_in_function_token9] = "LANG",
  [aux_sym__unary_build_in_function_token10] = "LCASE",
  [aux_sym__unary_build_in_function_token11] = "MD5",
  [aux_sym__unary_build_in_function_token12] = "MINUTES",
  [aux_sym__unary_build_in_function_token13] = "MONTH",
  [aux_sym__unary_build_in_function_token14] = "ROUND",
  [aux_sym__unary_build_in_function_token15] = "SECONDS",
  [aux_sym__unary_build_in_function_token16] = "SHA1",
  [aux_sym__unary_build_in_function_token17] = "SHA256",
  [aux_sym__unary_build_in_function_token18] = "SHA384",
  [aux_sym__unary_build_in_function_token19] = "SHA512",
  [aux_sym__unary_build_in_function_token20] = "STR",
  [aux_sym__unary_build_in_function_token21] = "STRLEN",
  [aux_sym__unary_build_in_function_token22] = "TIMEZONE",
  [aux_sym__unary_build_in_function_token23] = "TZ",
  [aux_sym__unary_build_in_function_token24] = "UCASE",
  [aux_sym__unary_build_in_function_token25] = "URI",
  [aux_sym__unary_build_in_function_token26] = "YEAR",
  [aux_sym__unary_build_in_function_token27] = "isBLANK",
  [aux_sym__unary_build_in_function_token28] = "isIRI",
  [aux_sym__unary_build_in_function_token29] = "isLITERAL",
  [aux_sym__unary_build_in_function_token30] = "isNUMERIC",
  [aux_sym__unary_build_in_function_token31] = "isURI",
  [aux_sym__binary_build_in_function_token1] = "CONTAINS",
  [aux_sym__binary_build_in_function_token2] = "LANGMATCHES",
  [aux_sym__binary_build_in_function_token3] = "STRAFTER",
  [aux_sym__binary_build_in_function_token4] = "STRBEFORE",
  [aux_sym__binary_build_in_function_token5] = "STRDT",
  [aux_sym__binary_build_in_function_token6] = "STRENDS",
  [aux_sym__binary_build_in_function_token7] = "STRLANG",
  [aux_sym__binary_build_in_function_token8] = "STRSTARTS",
  [aux_sym__binary_build_in_function_token9] = "sameTerm",
  [aux_sym__variadic_build_in_function_token1] = "CONCAT",
  [aux_sym__variadic_build_in_function_token2] = "COALESCE",
  [aux_sym_regex_expression_token1] = "REGEX",
  [aux_sym_substring_expression_token1] = "SUBSTR",
  [aux_sym_string_replace_expression_token1] = "REPLACE",
  [aux_sym_exists_func_token1] = "EXISTS",
  [aux_sym_aggregate_token1] = "COUNT",
  [aux_sym_aggregate_token2] = "SUM",
  [aux_sym_aggregate_token3] = "MIN",
  [aux_sym_aggregate_token4] = "MAX",
  [aux_sym_aggregate_token5] = "AVG",
  [aux_sym_aggregate_token6] = "SAMPLE",
  [anon_sym_GROUP_CONCAT] = "GROUP_CONCAT",
  [aux_sym_aggregate_token7] = "SEPARATOR",
  [anon_sym_CARET_CARET] = "^^",
  [anon_sym_true] = "true",
  [anon_sym_false] = "false",
  [aux_sym_iri_reference_token1] = "iri_reference_token1",
  [anon_sym_GT2] = ">",
  [anon_sym_COLON] = ":",
  [anon_sym__COLON] = "_:",
  [aux_sym_blank_node_label_token1] = "blank_node_label_token1",
  [sym_lang_tag] = "lang_tag",
  [sym_integer] = "integer",
  [sym_decimal] = "decimal",
  [sym_double] = "double",
  [anon_sym_SQUOTE] = "'",
  [aux_sym__string_literal1_token1] = "_string_literal1_token1",
  [anon_sym_DQUOTE] = "\"",
  [aux_sym__string_literal2_token1] = "_string_literal2_token1",
  [anon_sym_SQUOTE_SQUOTE_SQUOTE] = "'''",
  [anon_sym_SQUOTE_SQUOTE] = "''",
  [aux_sym__string_literal_long1_token1] = "_string_literal_long1_token1",
  [anon_sym_DQUOTE_DQUOTE_DQUOTE] = "\"\"\"",
  [anon_sym_DQUOTE_DQUOTE] = "\"\"",
  [aux_sym__string_literal_long2_token1] = "_string_literal_long2_token1",
  [sym_echar] = "echar",
  [sym_nil] = "nil",
  [sym_anon] = "anon",
  [sym_pn_local] = "pn_local",
  [sym_unit] = "unit",
  [sym__update] = "_update",
  [sym_prologue] = "prologue",
  [sym_base_declaration] = "base_declaration",
  [sym_prefix_declaration] = "prefix_declaration",
  [sym_select_query] = "select_query",
  [sym_sub_select] = "sub_select",
  [sym_select_clause] = "select_clause",
  [sym_construct_query] = "construct_query",
  [sym_describe_query] = "describe_query",
  [sym_ask_query] = "ask_query",
  [sym_dataset_clause] = "dataset_clause",
  [sym_default_graph_clause] = "default_graph_clause",
  [sym_named_graph_clause] = "named_graph_clause",
  [sym_where_clause] = "where_clause",
  [sym_solution_modifier] = "solution_modifier",
  [sym_group_clause] = "group_clause",
  [sym_group_condition] = "group_condition",
  [sym_having_clause] = "having_clause",
  [sym_having_condition] = "having_condition",
  [sym_order_clause] = "order_clause",
  [sym_order_condition] = "order_condition",
  [sym_limit_offset_clauses] = "limit_offset_clauses",
  [sym_limit_clause] = "limit_clause",
  [sym_offset_clause] = "offset_clause",
  [sym_values_clause] = "values_clause",
  [sym_load] = "load",
  [sym_clear] = "clear",
  [sym_drop] = "drop",
  [sym_create] = "create",
  [sym_add] = "add",
  [sym_move] = "move",
  [sym_copy] = "copy",
  [sym_insert_data] = "insert_data",
  [sym_delete_data] = "delete_data",
  [sym_delete_where] = "delete_where",
  [sym_modify] = "modify",
  [sym_delete_clause] = "delete_clause",
  [sym_insert_clause] = "insert_clause",
  [sym_using_clause] = "using_clause",
  [sym_graph_or_default] = "graph_or_default",
  [sym_graph_ref] = "graph_ref",
  [sym_graph_ref_all] = "graph_ref_all",
  [sym_quads] = "quads",
  [sym_quads_not_triples] = "quads_not_triples",
  [sym_triples_template] = "triples_template",
  [sym_group_graph_pattern] = "group_graph_pattern",
  [sym_triples_block] = "triples_block",
  [sym__graph_pattern_not_triples] = "_graph_pattern_not_triples",
  [sym_optional_graph_pattern] = "optional_graph_pattern",
  [sym_graph_graph_pattern] = "graph_graph_pattern",
  [sym_service_graph_pattern] = "service_graph_pattern",
  [sym_bind] = "bind",
  [sym_inline_data] = "inline_data",
  [sym_data_block] = "data_block",
  [sym__inline_data_one_var] = "_inline_data_one_var",
  [sym__inline_data_full] = "_inline_data_full",
  [sym__data_block_value] = "_data_block_value",
  [sym_minus_graph_pattern] = "minus_graph_pattern",
  [sym_group_or_union_graph_pattern] = "group_or_union_graph_pattern",
  [sym_filter] = "filter",
  [sym__constraint] = "_constraint",
  [sym_function_call] = "function_call",
  [sym_arg_list] = "arg_list",
  [sym_expression_list] = "expression_list",
  [sym_construct_template] = "construct_template",
  [sym_construct_triples] = "construct_triples",
  [sym_triples_same_subject] = "triples_same_subject",
  [sym_property_list] = "property_list",
  [sym_property] = "property",
  [sym__predicate] = "_predicate",
  [sym_object_list] = "object_list",
  [sym_triples_same_subject_path] = "triples_same_subject",
  [sym_property_list_path] = "property_list",
  [sym_property_path] = "property",
  [sym_property_path_rest] = "property",
  [sym__predicate_path] = "_predicate_path",
  [sym_object_list_path] = "object_list",
  [sym__path] = "_path",
  [sym_binary_path] = "binary_path",
  [sym_path_element] = "path_element",
  [sym_path_inverse] = "path_inverse",
  [sym__primary_path] = "_primary_path",
  [sym_path_negated_property_set] = "path_negated_property_set",
  [sym_path_one_in_property_set] = "path_one_in_property_set",
  [sym__triples_node] = "_triples_node",
  [sym_blank_node_property_list] = "blank_node_property_list",
  [sym__triples_node_path] = "_triples_node_path",
  [sym_blank_node_property_list_path] = "blank_node_property_list",
  [sym_collection] = "collection",
  [sym_collection_path] = "collection",
  [sym__graph_node] = "_graph_node",
  [sym__graph_node_path] = "_graph_node_path",
  [sym__var_or_term] = "_var_or_term",
  [sym__var_or_iri] = "_var_or_iri",
  [sym__graph_term] = "_graph_term",
  [sym__expression] = "_expression",
  [sym_binary_expression] = "binary_expression",
  [sym_unary_expression] = "unary_expression",
  [sym__primary_expression] = "_primary_expression",
  [sym_bracketted_expression] = "bracketted_expression",
  [sym__build_in_call] = "_build_in_call",
  [sym_build_in_function] = "build_in_function",
  [sym__nullary_build_in_function] = "_nullary_build_in_function",
  [sym__unary_build_in_function] = "_unary_build_in_function",
  [sym__binary_build_in_function] = "_binary_build_in_function",
  [sym__variadic_build_in_function] = "_variadic_build_in_function",
  [sym_regex_expression] = "regex_expression",
  [sym_substring_expression] = "substring_expression",
  [sym_string_replace_expression] = "string_replace_expression",
  [sym_exists_func] = "exists_func",
  [sym_not_exists_func] = "not_exists_func",
  [sym_aggregate] = "aggregate",
  [sym__iri_or_function] = "_iri_or_function",
  [sym_rdf_literal] = "rdf_literal",
  [sym__numeric_literal] = "_numeric_literal",
  [sym_boolean_literal] = "boolean_literal",
  [sym_string] = "string",
  [sym__iri] = "_iri",
  [sym_prefixed_name] = "prefixed_name",
  [sym__blank_node] = "_blank_node",
  [sym_iri_reference] = "iri_reference",
  [sym_namespace] = "namespace",
  [sym_blank_node_label] = "blank_node_label",
  [sym__string_literal1] = "_string_literal1",
  [sym__string_literal2] = "_string_literal2",
  [sym__string_literal_long1] = "_string_literal_long1",
  [sym__string_literal_long2] = "_string_literal_long2",
  [aux_sym_unit_repeat1] = "unit_repeat1",
  [aux_sym_prologue_repeat1] = "prologue_repeat1",
  [aux_sym_select_query_repeat1] = "select_query_repeat1",
  [aux_sym_select_clause_repeat1] = "select_clause_repeat1",
  [aux_sym_describe_query_repeat1] = "describe_query_repeat1",
  [aux_sym_group_clause_repeat1] = "group_clause_repeat1",
  [aux_sym_having_clause_repeat1] = "having_clause_repeat1",
  [aux_sym_order_clause_repeat1] = "order_clause_repeat1",
  [aux_sym_modify_repeat1] = "modify_repeat1",
  [aux_sym_quads_repeat1] = "quads_repeat1",
  [aux_sym_triples_template_repeat1] = "triples_template_repeat1",
  [aux_sym_group_graph_pattern_repeat1] = "group_graph_pattern_repeat1",
  [aux_sym_triples_block_repeat1] = "triples_block_repeat1",
  [aux_sym__inline_data_one_var_repeat1] = "_inline_data_one_var_repeat1",
  [aux_sym__inline_data_full_repeat1] = "_inline_data_full_repeat1",
  [aux_sym__inline_data_full_repeat2] = "_inline_data_full_repeat2",
  [aux_sym_group_or_union_graph_pattern_repeat1] = "group_or_union_graph_pattern_repeat1",
  [aux_sym_arg_list_repeat1] = "arg_list_repeat1",
  [aux_sym_property_list_repeat1] = "property_list_repeat1",
  [aux_sym_object_list_repeat1] = "object_list_repeat1",
  [aux_sym_property_list_path_repeat1] = "property_list_path_repeat1",
  [aux_sym_object_list_path_repeat1] = "object_list_path_repeat1",
  [aux_sym_path_negated_property_set_repeat1] = "path_negated_property_set_repeat1",
  [aux_sym_collection_repeat1] = "collection_repeat1",
  [aux_sym_collection_path_repeat1] = "collection_path_repeat1",
  [aux_sym__string_literal1_repeat1] = "_string_literal1_repeat1",
  [aux_sym__string_literal2_repeat1] = "_string_literal2_repeat1",
  [aux_sym__string_literal_long1_repeat1] = "_string_literal_long1_repeat1",
  [aux_sym__string_literal_long2_repeat1] = "_string_literal_long2_repeat1",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [sym_pn_prefix] = sym_pn_prefix,
  [sym_comment] = sym_comment,
  [anon_sym_SEMI] = anon_sym_SEMI,
  [aux_sym_base_declaration_token1] = aux_sym_base_declaration_token1,
  [aux_sym_prefix_declaration_token1] = aux_sym_prefix_declaration_token1,
  [aux_sym_select_clause_token1] = aux_sym_select_clause_token1,
  [aux_sym_select_clause_token2] = aux_sym_select_clause_token2,
  [aux_sym_select_clause_token3] = aux_sym_select_clause_token3,
  [anon_sym_LPAREN] = anon_sym_LPAREN,
  [aux_sym_select_clause_token4] = aux_sym_select_clause_token4,
  [anon_sym_RPAREN] = anon_sym_RPAREN,
  [anon_sym_STAR] = anon_sym_STAR,
  [aux_sym_construct_query_token1] = aux_sym_construct_query_token1,
  [aux_sym_construct_query_token2] = aux_sym_construct_query_token2,
  [anon_sym_LBRACE] = anon_sym_LBRACE,
  [anon_sym_RBRACE] = anon_sym_RBRACE,
  [aux_sym_describe_query_token1] = aux_sym_describe_query_token1,
  [aux_sym_ask_query_token1] = aux_sym_ask_query_token1,
  [aux_sym_dataset_clause_token1] = aux_sym_dataset_clause_token1,
  [aux_sym_named_graph_clause_token1] = aux_sym_named_graph_clause_token1,
  [aux_sym_group_clause_token1] = aux_sym_group_clause_token1,
  [aux_sym_group_clause_token2] = aux_sym_group_clause_token2,
  [aux_sym_having_clause_token1] = aux_sym_having_clause_token1,
  [aux_sym_order_clause_token1] = aux_sym_order_clause_token1,
  [aux_sym_order_condition_token1] = aux_sym_order_condition_token1,
  [aux_sym_order_condition_token2] = aux_sym_order_condition_token2,
  [aux_sym_limit_clause_token1] = aux_sym_limit_clause_token1,
  [aux_sym_offset_clause_token1] = aux_sym_offset_clause_token1,
  [aux_sym_values_clause_token1] = aux_sym_values_clause_token1,
  [aux_sym_load_token1] = aux_sym_load_token1,
  [aux_sym_load_token2] = aux_sym_load_token2,
  [aux_sym_load_token3] = aux_sym_load_token3,
  [aux_sym_clear_token1] = aux_sym_clear_token1,
  [aux_sym_drop_token1] = aux_sym_drop_token1,
  [aux_sym_create_token1] = aux_sym_create_token1,
  [aux_sym_add_token1] = aux_sym_add_token1,
  [aux_sym_add_token2] = aux_sym_add_token2,
  [aux_sym_move_token1] = aux_sym_move_token1,
  [aux_sym_copy_token1] = aux_sym_copy_token1,
  [anon_sym_INSERTDATA] = anon_sym_INSERTDATA,
  [anon_sym_DELETEDATA] = anon_sym_DELETEDATA,
  [anon_sym_DELETEWHERE] = anon_sym_DELETEWHERE,
  [aux_sym_modify_token1] = aux_sym_modify_token1,
  [aux_sym_delete_clause_token1] = aux_sym_delete_clause_token1,
  [aux_sym_insert_clause_token1] = aux_sym_insert_clause_token1,
  [aux_sym_using_clause_token1] = aux_sym_using_clause_token1,
  [aux_sym_graph_or_default_token1] = aux_sym_graph_or_default_token1,
  [aux_sym_graph_or_default_token2] = aux_sym_graph_or_default_token2,
  [aux_sym_graph_ref_all_token1] = aux_sym_graph_ref_all_token1,
  [anon_sym_DOT] = anon_sym_DOT,
  [aux_sym_optional_graph_pattern_token1] = aux_sym_optional_graph_pattern_token1,
  [aux_sym_service_graph_pattern_token1] = aux_sym_service_graph_pattern_token1,
  [aux_sym_bind_token1] = aux_sym_bind_token1,
  [aux_sym__data_block_value_token1] = aux_sym__data_block_value_token1,
  [aux_sym_minus_graph_pattern_token1] = aux_sym_minus_graph_pattern_token1,
  [aux_sym_group_or_union_graph_pattern_token1] = aux_sym_group_or_union_graph_pattern_token1,
  [aux_sym_filter_token1] = aux_sym_filter_token1,
  [anon_sym_COMMA] = anon_sym_COMMA,
  [anon_sym_a] = anon_sym_a,
  [anon_sym_SLASH] = anon_sym_SLASH,
  [anon_sym_PIPE] = anon_sym_PIPE,
  [anon_sym_CARET] = anon_sym_CARET,
  [sym_path_mod] = sym_path_mod,
  [anon_sym_BANG] = anon_sym_BANG,
  [anon_sym_LBRACK] = anon_sym_LBRACK,
  [anon_sym_RBRACK] = anon_sym_RBRACK,
  [sym_var] = sym_var,
  [anon_sym_PIPE_PIPE] = anon_sym_PIPE_PIPE,
  [anon_sym_AMP_AMP] = anon_sym_AMP_AMP,
  [anon_sym_EQ] = anon_sym_EQ,
  [anon_sym_BANG_EQ] = anon_sym_BANG_EQ,
  [anon_sym_LT] = anon_sym_LT,
  [anon_sym_GT] = anon_sym_GT,
  [anon_sym_LT_EQ] = anon_sym_LT_EQ,
  [anon_sym_GT_EQ] = anon_sym_GT_EQ,
  [aux_sym_binary_expression_token1] = aux_sym_binary_expression_token1,
  [aux_sym_binary_expression_token2] = aux_sym_binary_expression_token2,
  [anon_sym_PLUS] = anon_sym_PLUS,
  [anon_sym_DASH] = anon_sym_DASH,
  [aux_sym_build_in_function_token1] = aux_sym_build_in_function_token1,
  [aux_sym_build_in_function_token2] = aux_sym_build_in_function_token2,
  [aux_sym_build_in_function_token3] = aux_sym_build_in_function_token3,
  [aux_sym__nullary_build_in_function_token1] = aux_sym__nullary_build_in_function_token1,
  [aux_sym__nullary_build_in_function_token2] = aux_sym__nullary_build_in_function_token2,
  [aux_sym__nullary_build_in_function_token3] = aux_sym__nullary_build_in_function_token3,
  [aux_sym__nullary_build_in_function_token4] = aux_sym__nullary_build_in_function_token4,
  [aux_sym__unary_build_in_function_token1] = aux_sym__unary_build_in_function_token1,
  [aux_sym__unary_build_in_function_token2] = aux_sym__unary_build_in_function_token2,
  [aux_sym__unary_build_in_function_token3] = aux_sym__unary_build_in_function_token3,
  [aux_sym__unary_build_in_function_token4] = aux_sym__unary_build_in_function_token4,
  [aux_sym__unary_build_in_function_token5] = aux_sym__unary_build_in_function_token5,
  [aux_sym__unary_build_in_function_token6] = aux_sym__unary_build_in_function_token6,
  [aux_sym__unary_build_in_function_token7] = aux_sym__unary_build_in_function_token7,
  [aux_sym__unary_build_in_function_token8] = aux_sym__unary_build_in_function_token8,
  [aux_sym__unary_build_in_function_token9] = aux_sym__unary_build_in_function_token9,
  [aux_sym__unary_build_in_function_token10] = aux_sym__unary_build_in_function_token10,
  [aux_sym__unary_build_in_function_token11] = aux_sym__unary_build_in_function_token11,
  [aux_sym__unary_build_in_function_token12] = aux_sym__unary_build_in_function_token12,
  [aux_sym__unary_build_in_function_token13] = aux_sym__unary_build_in_function_token13,
  [aux_sym__unary_build_in_function_token14] = aux_sym__unary_build_in_function_token14,
  [aux_sym__unary_build_in_function_token15] = aux_sym__unary_build_in_function_token15,
  [aux_sym__unary_build_in_function_token16] = aux_sym__unary_build_in_function_token16,
  [aux_sym__unary_build_in_function_token17] = aux_sym__unary_build_in_function_token17,
  [aux_sym__unary_build_in_function_token18] = aux_sym__unary_build_in_function_token18,
  [aux_sym__unary_build_in_function_token19] = aux_sym__unary_build_in_function_token19,
  [aux_sym__unary_build_in_function_token20] = aux_sym__unary_build_in_function_token20,
  [aux_sym__unary_build_in_function_token21] = aux_sym__unary_build_in_function_token21,
  [aux_sym__unary_build_in_function_token22] = aux_sym__unary_build_in_function_token22,
  [aux_sym__unary_build_in_function_token23] = aux_sym__unary_build_in_function_token23,
  [aux_sym__unary_build_in_function_token24] = aux_sym__unary_build_in_function_token24,
  [aux_sym__unary_build_in_function_token25] = aux_sym__unary_build_in_function_token25,
  [aux_sym__unary_build_in_function_token26] = aux_sym__unary_build_in_function_token26,
  [aux_sym__unary_build_in_function_token27] = aux_sym__unary_build_in_function_token27,
  [aux_sym__unary_build_in_function_token28] = aux_sym__unary_build_in_function_token28,
  [aux_sym__unary_build_in_function_token29] = aux_sym__unary_build_in_function_token29,
  [aux_sym__unary_build_in_function_token30] = aux_sym__unary_build_in_function_token30,
  [aux_sym__unary_build_in_function_token31] = aux_sym__unary_build_in_function_token31,
  [aux_sym__binary_build_in_function_token1] = aux_sym__binary_build_in_function_token1,
  [aux_sym__binary_build_in_function_token2] = aux_sym__binary_build_in_function_token2,
  [aux_sym__binary_build_in_function_token3] = aux_sym__binary_build_in_function_token3,
  [aux_sym__binary_build_in_function_token4] = aux_sym__binary_build_in_function_token4,
  [aux_sym__binary_build_in_function_token5] = aux_sym__binary_build_in_function_token5,
  [aux_sym__binary_build_in_function_token6] = aux_sym__binary_build_in_function_token6,
  [aux_sym__binary_build_in_function_token7] = aux_sym__binary_build_in_function_token7,
  [aux_sym__binary_build_in_function_token8] = aux_sym__binary_build_in_function_token8,
  [aux_sym__binary_build_in_function_token9] = aux_sym__binary_build_in_function_token9,
  [aux_sym__variadic_build_in_function_token1] = aux_sym__variadic_build_in_function_token1,
  [aux_sym__variadic_build_in_function_token2] = aux_sym__variadic_build_in_function_token2,
  [aux_sym_regex_expression_token1] = aux_sym_regex_expression_token1,
  [aux_sym_substring_expression_token1] = aux_sym_substring_expression_token1,
  [aux_sym_string_replace_expression_token1] = aux_sym_string_replace_expression_token1,
  [aux_sym_exists_func_token1] = aux_sym_exists_func_token1,
  [aux_sym_aggregate_token1] = aux_sym_aggregate_token1,
  [aux_sym_aggregate_token2] = aux_sym_aggregate_token2,
  [aux_sym_aggregate_token3] = aux_sym_aggregate_token3,
  [aux_sym_aggregate_token4] = aux_sym_aggregate_token4,
  [aux_sym_aggregate_token5] = aux_sym_aggregate_token5,
  [aux_sym_aggregate_token6] = aux_sym_aggregate_token6,
  [anon_sym_GROUP_CONCAT] = anon_sym_GROUP_CONCAT,
  [aux_sym_aggregate_token7] = aux_sym_aggregate_token7,
  [anon_sym_CARET_CARET] = anon_sym_CARET_CARET,
  [anon_sym_true] = anon_sym_true,
  [anon_sym_false] = anon_sym_false,
  [aux_sym_iri_reference_token1] = aux_sym_iri_reference_token1,
  [anon_sym_GT2] = anon_sym_GT,
  [anon_sym_COLON] = anon_sym_COLON,
  [anon_sym__COLON] = anon_sym__COLON,
  [aux_sym_blank_node_label_token1] = aux_sym_blank_node_label_token1,
  [sym_lang_tag] = sym_lang_tag,
  [sym_integer] = sym_integer,
  [sym_decimal] = sym_decimal,
  [sym_double] = sym_double,
  [anon_sym_SQUOTE] = anon_sym_SQUOTE,
  [aux_sym__string_literal1_token1] = aux_sym__string_literal1_token1,
  [anon_sym_DQUOTE] = anon_sym_DQUOTE,
  [aux_sym__string_literal2_token1] = aux_sym__string_literal2_token1,
  [anon_sym_SQUOTE_SQUOTE_SQUOTE] = anon_sym_SQUOTE_SQUOTE_SQUOTE,
  [anon_sym_SQUOTE_SQUOTE] = anon_sym_SQUOTE_SQUOTE,
  [aux_sym__string_literal_long1_token1] = aux_sym__string_literal_long1_token1,
  [anon_sym_DQUOTE_DQUOTE_DQUOTE] = anon_sym_DQUOTE_DQUOTE_DQUOTE,
  [anon_sym_DQUOTE_DQUOTE] = anon_sym_DQUOTE_DQUOTE,
  [aux_sym__string_literal_long2_token1] = aux_sym__string_literal_long2_token1,
  [sym_echar] = sym_echar,
  [sym_nil] = sym_nil,
  [sym_anon] = sym_anon,
  [sym_pn_local] = sym_pn_local,
  [sym_unit] = sym_unit,
  [sym__update] = sym__update,
  [sym_prologue] = sym_prologue,
  [sym_base_declaration] = sym_base_declaration,
  [sym_prefix_declaration] = sym_prefix_declaration,
  [sym_select_query] = sym_select_query,
  [sym_sub_select] = sym_sub_select,
  [sym_select_clause] = sym_select_clause,
  [sym_construct_query] = sym_construct_query,
  [sym_describe_query] = sym_describe_query,
  [sym_ask_query] = sym_ask_query,
  [sym_dataset_clause] = sym_dataset_clause,
  [sym_default_graph_clause] = sym_default_graph_clause,
  [sym_named_graph_clause] = sym_named_graph_clause,
  [sym_where_clause] = sym_where_clause,
  [sym_solution_modifier] = sym_solution_modifier,
  [sym_group_clause] = sym_group_clause,
  [sym_group_condition] = sym_group_condition,
  [sym_having_clause] = sym_having_clause,
  [sym_having_condition] = sym_having_condition,
  [sym_order_clause] = sym_order_clause,
  [sym_order_condition] = sym_order_condition,
  [sym_limit_offset_clauses] = sym_limit_offset_clauses,
  [sym_limit_clause] = sym_limit_clause,
  [sym_offset_clause] = sym_offset_clause,
  [sym_values_clause] = sym_values_clause,
  [sym_load] = sym_load,
  [sym_clear] = sym_clear,
  [sym_drop] = sym_drop,
  [sym_create] = sym_create,
  [sym_add] = sym_add,
  [sym_move] = sym_move,
  [sym_copy] = sym_copy,
  [sym_insert_data] = sym_insert_data,
  [sym_delete_data] = sym_delete_data,
  [sym_delete_where] = sym_delete_where,
  [sym_modify] = sym_modify,
  [sym_delete_clause] = sym_delete_clause,
  [sym_insert_clause] = sym_insert_clause,
  [sym_using_clause] = sym_using_clause,
  [sym_graph_or_default] = sym_graph_or_default,
  [sym_graph_ref] = sym_graph_ref,
  [sym_graph_ref_all] = sym_graph_ref_all,
  [sym_quads] = sym_quads,
  [sym_quads_not_triples] = sym_quads_not_triples,
  [sym_triples_template] = sym_triples_template,
  [sym_group_graph_pattern] = sym_group_graph_pattern,
  [sym_triples_block] = sym_triples_block,
  [sym__graph_pattern_not_triples] = sym__graph_pattern_not_triples,
  [sym_optional_graph_pattern] = sym_optional_graph_pattern,
  [sym_graph_graph_pattern] = sym_graph_graph_pattern,
  [sym_service_graph_pattern] = sym_service_graph_pattern,
  [sym_bind] = sym_bind,
  [sym_inline_data] = sym_inline_data,
  [sym_data_block] = sym_data_block,
  [sym__inline_data_one_var] = sym__inline_data_one_var,
  [sym__inline_data_full] = sym__inline_data_full,
  [sym__data_block_value] = sym__data_block_value,
  [sym_minus_graph_pattern] = sym_minus_graph_pattern,
  [sym_group_or_union_graph_pattern] = sym_group_or_union_graph_pattern,
  [sym_filter] = sym_filter,
  [sym__constraint] = sym__constraint,
  [sym_function_call] = sym_function_call,
  [sym_arg_list] = sym_arg_list,
  [sym_expression_list] = sym_expression_list,
  [sym_construct_template] = sym_construct_template,
  [sym_construct_triples] = sym_construct_triples,
  [sym_triples_same_subject] = sym_triples_same_subject,
  [sym_property_list] = sym_property_list,
  [sym_property] = sym_property,
  [sym__predicate] = sym__predicate,
  [sym_object_list] = sym_object_list,
  [sym_triples_same_subject_path] = sym_triples_same_subject,
  [sym_property_list_path] = sym_property_list,
  [sym_property_path] = sym_property,
  [sym_property_path_rest] = sym_property,
  [sym__predicate_path] = sym__predicate_path,
  [sym_object_list_path] = sym_object_list,
  [sym__path] = sym__path,
  [sym_binary_path] = sym_binary_path,
  [sym_path_element] = sym_path_element,
  [sym_path_inverse] = sym_path_inverse,
  [sym__primary_path] = sym__primary_path,
  [sym_path_negated_property_set] = sym_path_negated_property_set,
  [sym_path_one_in_property_set] = sym_path_one_in_property_set,
  [sym__triples_node] = sym__triples_node,
  [sym_blank_node_property_list] = sym_blank_node_property_list,
  [sym__triples_node_path] = sym__triples_node_path,
  [sym_blank_node_property_list_path] = sym_blank_node_property_list,
  [sym_collection] = sym_collection,
  [sym_collection_path] = sym_collection,
  [sym__graph_node] = sym__graph_node,
  [sym__graph_node_path] = sym__graph_node_path,
  [sym__var_or_term] = sym__var_or_term,
  [sym__var_or_iri] = sym__var_or_iri,
  [sym__graph_term] = sym__graph_term,
  [sym__expression] = sym__expression,
  [sym_binary_expression] = sym_binary_expression,
  [sym_unary_expression] = sym_unary_expression,
  [sym__primary_expression] = sym__primary_expression,
  [sym_bracketted_expression] = sym_bracketted_expression,
  [sym__build_in_call] = sym__build_in_call,
  [sym_build_in_function] = sym_build_in_function,
  [sym__nullary_build_in_function] = sym__nullary_build_in_function,
  [sym__unary_build_in_function] = sym__unary_build_in_function,
  [sym__binary_build_in_function] = sym__binary_build_in_function,
  [sym__variadic_build_in_function] = sym__variadic_build_in_function,
  [sym_regex_expression] = sym_regex_expression,
  [sym_substring_expression] = sym_substring_expression,
  [sym_string_replace_expression] = sym_string_replace_expression,
  [sym_exists_func] = sym_exists_func,
  [sym_not_exists_func] = sym_not_exists_func,
  [sym_aggregate] = sym_aggregate,
  [sym__iri_or_function] = sym__iri_or_function,
  [sym_rdf_literal] = sym_rdf_literal,
  [sym__numeric_literal] = sym__numeric_literal,
  [sym_boolean_literal] = sym_boolean_literal,
  [sym_string] = sym_string,
  [sym__iri] = sym__iri,
  [sym_prefixed_name] = sym_prefixed_name,
  [sym__blank_node] = sym__blank_node,
  [sym_iri_reference] = sym_iri_reference,
  [sym_namespace] = sym_namespace,
  [sym_blank_node_label] = sym_blank_node_label,
  [sym__string_literal1] = sym__string_literal1,
  [sym__string_literal2] = sym__string_literal2,
  [sym__string_literal_long1] = sym__string_literal_long1,
  [sym__string_literal_long2] = sym__string_literal_long2,
  [aux_sym_unit_repeat1] = aux_sym_unit_repeat1,
  [aux_sym_prologue_repeat1] = aux_sym_prologue_repeat1,
  [aux_sym_select_query_repeat1] = aux_sym_select_query_repeat1,
  [aux_sym_select_clause_repeat1] = aux_sym_select_clause_repeat1,
  [aux_sym_describe_query_repeat1] = aux_sym_describe_query_repeat1,
  [aux_sym_group_clause_repeat1] = aux_sym_group_clause_repeat1,
  [aux_sym_having_clause_repeat1] = aux_sym_having_clause_repeat1,
  [aux_sym_order_clause_repeat1] = aux_sym_order_clause_repeat1,
  [aux_sym_modify_repeat1] = aux_sym_modify_repeat1,
  [aux_sym_quads_repeat1] = aux_sym_quads_repeat1,
  [aux_sym_triples_template_repeat1] = aux_sym_triples_template_repeat1,
  [aux_sym_group_graph_pattern_repeat1] = aux_sym_group_graph_pattern_repeat1,
  [aux_sym_triples_block_repeat1] = aux_sym_triples_block_repeat1,
  [aux_sym__inline_data_one_var_repeat1] = aux_sym__inline_data_one_var_repeat1,
  [aux_sym__inline_data_full_repeat1] = aux_sym__inline_data_full_repeat1,
  [aux_sym__inline_data_full_repeat2] = aux_sym__inline_data_full_repeat2,
  [aux_sym_group_or_union_graph_pattern_repeat1] = aux_sym_group_or_union_graph_pattern_repeat1,
  [aux_sym_arg_list_repeat1] = aux_sym_arg_list_repeat1,
  [aux_sym_property_list_repeat1] = aux_sym_property_list_repeat1,
  [aux_sym_object_list_repeat1] = aux_sym_object_list_repeat1,
  [aux_sym_property_list_path_repeat1] = aux_sym_property_list_path_repeat1,
  [aux_sym_object_list_path_repeat1] = aux_sym_object_list_path_repeat1,
  [aux_sym_path_negated_property_set_repeat1] = aux_sym_path_negated_property_set_repeat1,
  [aux_sym_collection_repeat1] = aux_sym_collection_repeat1,
  [aux_sym_collection_path_repeat1] = aux_sym_collection_path_repeat1,
  [aux_sym__string_literal1_repeat1] = aux_sym__string_literal1_repeat1,
  [aux_sym__string_literal2_repeat1] = aux_sym__string_literal2_repeat1,
  [aux_sym__string_literal_long1_repeat1] = aux_sym__string_literal_long1_repeat1,
  [aux_sym__string_literal_long2_repeat1] = aux_sym__string_literal_long2_repeat1,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [sym_pn_prefix] = {
    .visible = true,
    .named = true,
  },
  [sym_comment] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_SEMI] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_base_declaration_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_prefix_declaration_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_select_clause_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_select_clause_token2] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_select_clause_token3] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_select_clause_token4] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_construct_query_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_construct_query_token2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_describe_query_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_ask_query_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_dataset_clause_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_named_graph_clause_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_group_clause_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_group_clause_token2] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_having_clause_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_order_clause_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_order_condition_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_order_condition_token2] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_limit_clause_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_offset_clause_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_values_clause_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_load_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_load_token2] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_load_token3] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_clear_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_drop_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_create_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_add_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_add_token2] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_move_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_copy_token1] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_INSERTDATA] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DELETEDATA] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DELETEWHERE] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_modify_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_delete_clause_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_insert_clause_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_using_clause_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_graph_or_default_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_graph_or_default_token2] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_graph_ref_all_token1] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_optional_graph_pattern_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_service_graph_pattern_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_bind_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__data_block_value_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_minus_graph_pattern_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_group_or_union_graph_pattern_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_filter_token1] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COMMA] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_a] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CARET] = {
    .visible = true,
    .named = false,
  },
  [sym_path_mod] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_BANG] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [sym_var] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_PIPE_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_binary_expression_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_binary_expression_token2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_build_in_function_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_build_in_function_token2] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_build_in_function_token3] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__nullary_build_in_function_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__nullary_build_in_function_token2] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__nullary_build_in_function_token3] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__nullary_build_in_function_token4] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__unary_build_in_function_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__unary_build_in_function_token2] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__unary_build_in_function_token3] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__unary_build_in_function_token4] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__unary_build_in_function_token5] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__unary_build_in_function_token6] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__unary_build_in_function_token7] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__unary_build_in_function_token8] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__unary_build_in_function_token9] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__unary_build_in_function_token10] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__unary_build_in_function_token11] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__unary_build_in_function_token12] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__unary_build_in_function_token13] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__unary_build_in_function_token14] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__unary_build_in_function_token15] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__unary_build_in_function_token16] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__unary_build_in_function_token17] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__unary_build_in_function_token18] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__unary_build_in_function_token19] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__unary_build_in_function_token20] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__unary_build_in_function_token21] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__unary_build_in_function_token22] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__unary_build_in_function_token23] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__unary_build_in_function_token24] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__unary_build_in_function_token25] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__unary_build_in_function_token26] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__unary_build_in_function_token27] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__unary_build_in_function_token28] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__unary_build_in_function_token29] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__unary_build_in_function_token30] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__unary_build_in_function_token31] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__binary_build_in_function_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__binary_build_in_function_token2] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__binary_build_in_function_token3] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__binary_build_in_function_token4] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__binary_build_in_function_token5] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__binary_build_in_function_token6] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__binary_build_in_function_token7] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__binary_build_in_function_token8] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__binary_build_in_function_token9] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__variadic_build_in_function_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__variadic_build_in_function_token2] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_regex_expression_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_substring_expression_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_string_replace_expression_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_exists_func_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_aggregate_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_aggregate_token2] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_aggregate_token3] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_aggregate_token4] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_aggregate_token5] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_aggregate_token6] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GROUP_CONCAT] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_aggregate_token7] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CARET_CARET] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_true] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_false] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_iri_reference_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_GT2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym__COLON] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_blank_node_label_token1] = {
    .visible = false,
    .named = false,
  },
  [sym_lang_tag] = {
    .visible = true,
    .named = true,
  },
  [sym_integer] = {
    .visible = true,
    .named = true,
  },
  [sym_decimal] = {
    .visible = true,
    .named = true,
  },
  [sym_double] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__string_literal1_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__string_literal2_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_SQUOTE_SQUOTE_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SQUOTE_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__string_literal_long1_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_DQUOTE_DQUOTE_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DQUOTE_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [aux_sym__string_literal_long2_token1] = {
    .visible = false,
    .named = false,
  },
  [sym_echar] = {
    .visible = true,
    .named = true,
  },
  [sym_nil] = {
    .visible = true,
    .named = true,
  },
  [sym_anon] = {
    .visible = true,
    .named = true,
  },
  [sym_pn_local] = {
    .visible = true,
    .named = true,
  },
  [sym_unit] = {
    .visible = true,
    .named = true,
  },
  [sym__update] = {
    .visible = false,
    .named = true,
  },
  [sym_prologue] = {
    .visible = true,
    .named = true,
  },
  [sym_base_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_prefix_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_select_query] = {
    .visible = true,
    .named = true,
  },
  [sym_sub_select] = {
    .visible = true,
    .named = true,
  },
  [sym_select_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_construct_query] = {
    .visible = true,
    .named = true,
  },
  [sym_describe_query] = {
    .visible = true,
    .named = true,
  },
  [sym_ask_query] = {
    .visible = true,
    .named = true,
  },
  [sym_dataset_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_default_graph_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_named_graph_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_where_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_solution_modifier] = {
    .visible = true,
    .named = true,
  },
  [sym_group_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_group_condition] = {
    .visible = true,
    .named = true,
  },
  [sym_having_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_having_condition] = {
    .visible = true,
    .named = true,
  },
  [sym_order_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_order_condition] = {
    .visible = true,
    .named = true,
  },
  [sym_limit_offset_clauses] = {
    .visible = true,
    .named = true,
  },
  [sym_limit_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_offset_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_values_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_load] = {
    .visible = true,
    .named = true,
  },
  [sym_clear] = {
    .visible = true,
    .named = true,
  },
  [sym_drop] = {
    .visible = true,
    .named = true,
  },
  [sym_create] = {
    .visible = true,
    .named = true,
  },
  [sym_add] = {
    .visible = true,
    .named = true,
  },
  [sym_move] = {
    .visible = true,
    .named = true,
  },
  [sym_copy] = {
    .visible = true,
    .named = true,
  },
  [sym_insert_data] = {
    .visible = true,
    .named = true,
  },
  [sym_delete_data] = {
    .visible = true,
    .named = true,
  },
  [sym_delete_where] = {
    .visible = true,
    .named = true,
  },
  [sym_modify] = {
    .visible = true,
    .named = true,
  },
  [sym_delete_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_insert_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_using_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_graph_or_default] = {
    .visible = true,
    .named = true,
  },
  [sym_graph_ref] = {
    .visible = true,
    .named = true,
  },
  [sym_graph_ref_all] = {
    .visible = true,
    .named = true,
  },
  [sym_quads] = {
    .visible = true,
    .named = true,
  },
  [sym_quads_not_triples] = {
    .visible = true,
    .named = true,
  },
  [sym_triples_template] = {
    .visible = true,
    .named = true,
  },
  [sym_group_graph_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_triples_block] = {
    .visible = true,
    .named = true,
  },
  [sym__graph_pattern_not_triples] = {
    .visible = false,
    .named = true,
  },
  [sym_optional_graph_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_graph_graph_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_service_graph_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_bind] = {
    .visible = true,
    .named = true,
  },
  [sym_inline_data] = {
    .visible = true,
    .named = true,
  },
  [sym_data_block] = {
    .visible = true,
    .named = true,
  },
  [sym__inline_data_one_var] = {
    .visible = false,
    .named = true,
  },
  [sym__inline_data_full] = {
    .visible = false,
    .named = true,
  },
  [sym__data_block_value] = {
    .visible = false,
    .named = true,
  },
  [sym_minus_graph_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_group_or_union_graph_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_filter] = {
    .visible = true,
    .named = true,
  },
  [sym__constraint] = {
    .visible = false,
    .named = true,
  },
  [sym_function_call] = {
    .visible = true,
    .named = true,
  },
  [sym_arg_list] = {
    .visible = true,
    .named = true,
  },
  [sym_expression_list] = {
    .visible = true,
    .named = true,
  },
  [sym_construct_template] = {
    .visible = true,
    .named = true,
  },
  [sym_construct_triples] = {
    .visible = true,
    .named = true,
  },
  [sym_triples_same_subject] = {
    .visible = true,
    .named = true,
  },
  [sym_property_list] = {
    .visible = true,
    .named = true,
  },
  [sym_property] = {
    .visible = true,
    .named = true,
  },
  [sym__predicate] = {
    .visible = false,
    .named = true,
  },
  [sym_object_list] = {
    .visible = true,
    .named = true,
  },
  [sym_triples_same_subject_path] = {
    .visible = true,
    .named = true,
  },
  [sym_property_list_path] = {
    .visible = true,
    .named = true,
  },
  [sym_property_path] = {
    .visible = true,
    .named = true,
  },
  [sym_property_path_rest] = {
    .visible = true,
    .named = true,
  },
  [sym__predicate_path] = {
    .visible = false,
    .named = true,
  },
  [sym_object_list_path] = {
    .visible = true,
    .named = true,
  },
  [sym__path] = {
    .visible = false,
    .named = true,
  },
  [sym_binary_path] = {
    .visible = true,
    .named = true,
  },
  [sym_path_element] = {
    .visible = true,
    .named = true,
  },
  [sym_path_inverse] = {
    .visible = true,
    .named = true,
  },
  [sym__primary_path] = {
    .visible = false,
    .named = true,
  },
  [sym_path_negated_property_set] = {
    .visible = true,
    .named = true,
  },
  [sym_path_one_in_property_set] = {
    .visible = true,
    .named = true,
  },
  [sym__triples_node] = {
    .visible = false,
    .named = true,
  },
  [sym_blank_node_property_list] = {
    .visible = true,
    .named = true,
  },
  [sym__triples_node_path] = {
    .visible = false,
    .named = true,
  },
  [sym_blank_node_property_list_path] = {
    .visible = true,
    .named = true,
  },
  [sym_collection] = {
    .visible = true,
    .named = true,
  },
  [sym_collection_path] = {
    .visible = true,
    .named = true,
  },
  [sym__graph_node] = {
    .visible = false,
    .named = true,
  },
  [sym__graph_node_path] = {
    .visible = false,
    .named = true,
  },
  [sym__var_or_term] = {
    .visible = false,
    .named = true,
  },
  [sym__var_or_iri] = {
    .visible = false,
    .named = true,
  },
  [sym__graph_term] = {
    .visible = false,
    .named = true,
  },
  [sym__expression] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_binary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_unary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__primary_expression] = {
    .visible = false,
    .named = true,
  },
  [sym_bracketted_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__build_in_call] = {
    .visible = false,
    .named = true,
  },
  [sym_build_in_function] = {
    .visible = true,
    .named = true,
  },
  [sym__nullary_build_in_function] = {
    .visible = false,
    .named = true,
  },
  [sym__unary_build_in_function] = {
    .visible = false,
    .named = true,
  },
  [sym__binary_build_in_function] = {
    .visible = false,
    .named = true,
  },
  [sym__variadic_build_in_function] = {
    .visible = false,
    .named = true,
  },
  [sym_regex_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_substring_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_string_replace_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_exists_func] = {
    .visible = true,
    .named = true,
  },
  [sym_not_exists_func] = {
    .visible = true,
    .named = true,
  },
  [sym_aggregate] = {
    .visible = true,
    .named = true,
  },
  [sym__iri_or_function] = {
    .visible = false,
    .named = true,
  },
  [sym_rdf_literal] = {
    .visible = true,
    .named = true,
  },
  [sym__numeric_literal] = {
    .visible = false,
    .named = true,
  },
  [sym_boolean_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_string] = {
    .visible = true,
    .named = true,
  },
  [sym__iri] = {
    .visible = false,
    .named = true,
  },
  [sym_prefixed_name] = {
    .visible = true,
    .named = true,
  },
  [sym__blank_node] = {
    .visible = false,
    .named = true,
  },
  [sym_iri_reference] = {
    .visible = true,
    .named = true,
  },
  [sym_namespace] = {
    .visible = true,
    .named = true,
  },
  [sym_blank_node_label] = {
    .visible = true,
    .named = true,
  },
  [sym__string_literal1] = {
    .visible = false,
    .named = true,
  },
  [sym__string_literal2] = {
    .visible = false,
    .named = true,
  },
  [sym__string_literal_long1] = {
    .visible = false,
    .named = true,
  },
  [sym__string_literal_long2] = {
    .visible = false,
    .named = true,
  },
  [aux_sym_unit_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_prologue_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_select_query_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_select_clause_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_describe_query_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_group_clause_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_having_clause_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_order_clause_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_modify_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_quads_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_triples_template_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_group_graph_pattern_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_triples_block_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__inline_data_one_var_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__inline_data_full_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__inline_data_full_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_group_or_union_graph_pattern_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_arg_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_property_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_object_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_property_list_path_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_object_list_path_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_path_negated_property_set_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_collection_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_collection_path_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__string_literal1_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__string_literal2_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__string_literal_long1_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__string_literal_long2_repeat1] = {
    .visible = false,
    .named = false,
  },
};

enum ts_field_identifiers {
  field_arguments = 1,
  field_bound_variable = 2,
  field_datatype = 3,
  field_flag = 4,
  field_identifier = 5,
  field_pattern = 6,
  field_source_selector = 7,
  field_subject = 8,
  field_text = 9,
  field_value = 10,
};

static const char * const ts_field_names[] = {
  [0] = NULL,
  [field_arguments] = "arguments",
  [field_bound_variable] = "bound_variable",
  [field_datatype] = "datatype",
  [field_flag] = "flag",
  [field_identifier] = "identifier",
  [field_pattern] = "pattern",
  [field_source_selector] = "source_selector",
  [field_subject] = "subject",
  [field_text] = "text",
  [field_value] = "value",
};

static const TSFieldMapSlice ts_field_map_slices[PRODUCTION_ID_COUNT] = {
  [1] = {.index = 0, .length = 1},
  [2] = {.index = 1, .length = 1},
  [3] = {.index = 2, .length = 1},
  [4] = {.index = 3, .length = 1},
  [5] = {.index = 4, .length = 1},
  [6] = {.index = 5, .length = 2},
  [7] = {.index = 7, .length = 1},
  [8] = {.index = 8, .length = 1},
  [9] = {.index = 9, .length = 1},
  [10] = {.index = 10, .length = 1},
  [11] = {.index = 11, .length = 1},
  [12] = {.index = 12, .length = 1},
  [13] = {.index = 13, .length = 3},
  [14] = {.index = 16, .length = 3},
  [15] = {.index = 19, .length = 1},
  [16] = {.index = 20, .length = 5},
  [17] = {.index = 25, .length = 2},
  [18] = {.index = 27, .length = 1},
  [19] = {.index = 28, .length = 7},
  [20] = {.index = 35, .length = 3},
};

static const TSFieldMapEntry ts_field_map_entries[] = {
  [0] =
    {field_bound_variable, 0},
  [1] =
    {field_bound_variable, 1, .inherited = true},
  [2] =
    {field_bound_variable, 2, .inherited = true},
  [3] =
    {field_arguments, 0, .inherited = true},
  [4] =
    {field_value, 0},
  [5] =
    {field_bound_variable, 0, .inherited = true},
    {field_bound_variable, 1, .inherited = true},
  [7] =
    {field_source_selector, 0},
  [8] =
    {field_bound_variable, 0, .inherited = true},
  [9] =
    {field_arguments, 1},
  [10] =
    {field_identifier, 0},
  [11] =
    {field_source_selector, 1},
  [12] =
    {field_subject, 0},
  [13] =
    {field_datatype, 1},
    {field_datatype, 2},
    {field_value, 0},
  [16] =
    {field_arguments, 1},
    {field_arguments, 2},
    {field_arguments, 3},
  [19] =
    {field_bound_variable, 3},
  [20] =
    {field_arguments, 1},
    {field_arguments, 2},
    {field_arguments, 3},
    {field_arguments, 4},
    {field_arguments, 5},
  [25] =
    {field_pattern, 4},
    {field_text, 2},
  [27] =
    {field_bound_variable, 4},
  [28] =
    {field_arguments, 1},
    {field_arguments, 2},
    {field_arguments, 3},
    {field_arguments, 4},
    {field_arguments, 5},
    {field_arguments, 6},
    {field_arguments, 7},
  [35] =
    {field_flag, 6},
    {field_pattern, 4},
    {field_text, 2},
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
};

static const uint16_t ts_non_terminal_alias_map[] = {
  0,
};

static const TSStateId ts_primary_state_ids[STATE_COUNT] = {
  [0] = 0,
  [1] = 1,
  [2] = 2,
  [3] = 3,
  [4] = 4,
  [5] = 4,
  [6] = 4,
  [7] = 4,
  [8] = 8,
  [9] = 9,
  [10] = 10,
  [11] = 11,
  [12] = 12,
  [13] = 13,
  [14] = 14,
  [15] = 15,
  [16] = 10,
  [17] = 10,
  [18] = 13,
  [19] = 9,
  [20] = 13,
  [21] = 8,
  [22] = 9,
  [23] = 10,
  [24] = 8,
  [25] = 13,
  [26] = 8,
  [27] = 9,
  [28] = 28,
  [29] = 29,
  [30] = 30,
  [31] = 31,
  [32] = 32,
  [33] = 33,
  [34] = 28,
  [35] = 35,
  [36] = 36,
  [37] = 37,
  [38] = 38,
  [39] = 39,
  [40] = 40,
  [41] = 41,
  [42] = 42,
  [43] = 43,
  [44] = 44,
  [45] = 45,
  [46] = 46,
  [47] = 47,
  [48] = 48,
  [49] = 49,
  [50] = 50,
  [51] = 51,
  [52] = 52,
  [53] = 53,
  [54] = 54,
  [55] = 55,
  [56] = 56,
  [57] = 57,
  [58] = 31,
  [59] = 57,
  [60] = 42,
  [61] = 43,
  [62] = 44,
  [63] = 45,
  [64] = 47,
  [65] = 49,
  [66] = 50,
  [67] = 52,
  [68] = 53,
  [69] = 54,
  [70] = 55,
  [71] = 56,
  [72] = 57,
  [73] = 31,
  [74] = 42,
  [75] = 29,
  [76] = 44,
  [77] = 47,
  [78] = 49,
  [79] = 50,
  [80] = 52,
  [81] = 53,
  [82] = 54,
  [83] = 55,
  [84] = 56,
  [85] = 57,
  [86] = 31,
  [87] = 42,
  [88] = 43,
  [89] = 44,
  [90] = 47,
  [91] = 49,
  [92] = 50,
  [93] = 52,
  [94] = 53,
  [95] = 54,
  [96] = 55,
  [97] = 56,
  [98] = 30,
  [99] = 32,
  [100] = 33,
  [101] = 46,
  [102] = 51,
  [103] = 30,
  [104] = 32,
  [105] = 33,
  [106] = 46,
  [107] = 51,
  [108] = 30,
  [109] = 32,
  [110] = 33,
  [111] = 46,
  [112] = 51,
  [113] = 29,
  [114] = 28,
  [115] = 29,
  [116] = 28,
  [117] = 43,
  [118] = 118,
  [119] = 119,
  [120] = 120,
  [121] = 121,
  [122] = 122,
  [123] = 123,
  [124] = 124,
  [125] = 125,
  [126] = 126,
  [127] = 127,
  [128] = 128,
  [129] = 129,
  [130] = 130,
  [131] = 131,
  [132] = 132,
  [133] = 2,
  [134] = 134,
  [135] = 135,
  [136] = 136,
  [137] = 137,
  [138] = 3,
  [139] = 139,
  [140] = 140,
  [141] = 141,
  [142] = 142,
  [143] = 143,
  [144] = 144,
  [145] = 145,
  [146] = 146,
  [147] = 147,
  [148] = 148,
  [149] = 149,
  [150] = 150,
  [151] = 151,
  [152] = 152,
  [153] = 153,
  [154] = 154,
  [155] = 155,
  [156] = 15,
  [157] = 11,
  [158] = 14,
  [159] = 12,
  [160] = 160,
  [161] = 161,
  [162] = 162,
  [163] = 163,
  [164] = 164,
  [165] = 165,
  [166] = 166,
  [167] = 167,
  [168] = 167,
  [169] = 169,
  [170] = 169,
  [171] = 171,
  [172] = 171,
  [173] = 173,
  [174] = 141,
  [175] = 126,
  [176] = 127,
  [177] = 128,
  [178] = 129,
  [179] = 130,
  [180] = 131,
  [181] = 132,
  [182] = 134,
  [183] = 135,
  [184] = 155,
  [185] = 137,
  [186] = 139,
  [187] = 140,
  [188] = 153,
  [189] = 142,
  [190] = 143,
  [191] = 144,
  [192] = 154,
  [193] = 146,
  [194] = 147,
  [195] = 148,
  [196] = 149,
  [197] = 150,
  [198] = 151,
  [199] = 152,
  [200] = 136,
  [201] = 120,
  [202] = 121,
  [203] = 122,
  [204] = 123,
  [205] = 124,
  [206] = 125,
  [207] = 119,
  [208] = 145,
  [209] = 165,
  [210] = 161,
  [211] = 163,
  [212] = 162,
  [213] = 160,
  [214] = 164,
  [215] = 166,
  [216] = 216,
  [217] = 216,
  [218] = 216,
  [219] = 216,
  [220] = 220,
  [221] = 221,
  [222] = 222,
  [223] = 223,
  [224] = 224,
  [225] = 225,
  [226] = 226,
  [227] = 153,
  [228] = 119,
  [229] = 154,
  [230] = 230,
  [231] = 231,
  [232] = 232,
  [233] = 232,
  [234] = 234,
  [235] = 235,
  [236] = 236,
  [237] = 236,
  [238] = 238,
  [239] = 239,
  [240] = 240,
  [241] = 241,
  [242] = 242,
  [243] = 243,
  [244] = 244,
  [245] = 245,
  [246] = 238,
  [247] = 247,
  [248] = 248,
  [249] = 249,
  [250] = 250,
  [251] = 251,
  [252] = 252,
  [253] = 253,
  [254] = 248,
  [255] = 255,
  [256] = 256,
  [257] = 257,
  [258] = 257,
  [259] = 247,
  [260] = 256,
  [261] = 250,
  [262] = 262,
  [263] = 263,
  [264] = 264,
  [265] = 265,
  [266] = 266,
  [267] = 267,
  [268] = 266,
  [269] = 269,
  [270] = 267,
  [271] = 271,
  [272] = 255,
  [273] = 264,
  [274] = 274,
  [275] = 275,
  [276] = 276,
  [277] = 277,
  [278] = 278,
  [279] = 279,
  [280] = 280,
  [281] = 281,
  [282] = 282,
  [283] = 283,
  [284] = 284,
  [285] = 285,
  [286] = 286,
  [287] = 255,
  [288] = 274,
  [289] = 264,
  [290] = 290,
  [291] = 291,
  [292] = 292,
  [293] = 293,
  [294] = 294,
  [295] = 295,
  [296] = 296,
  [297] = 297,
  [298] = 298,
  [299] = 299,
  [300] = 300,
  [301] = 301,
  [302] = 302,
  [303] = 303,
  [304] = 304,
  [305] = 305,
  [306] = 119,
  [307] = 307,
  [308] = 308,
  [309] = 309,
  [310] = 153,
  [311] = 311,
  [312] = 312,
  [313] = 313,
  [314] = 154,
  [315] = 315,
  [316] = 316,
  [317] = 130,
  [318] = 318,
  [319] = 319,
  [320] = 320,
  [321] = 321,
  [322] = 322,
  [323] = 323,
  [324] = 324,
  [325] = 325,
  [326] = 326,
  [327] = 327,
  [328] = 328,
  [329] = 329,
  [330] = 330,
  [331] = 331,
  [332] = 332,
  [333] = 136,
  [334] = 120,
  [335] = 121,
  [336] = 122,
  [337] = 123,
  [338] = 124,
  [339] = 125,
  [340] = 126,
  [341] = 127,
  [342] = 128,
  [343] = 129,
  [344] = 131,
  [345] = 132,
  [346] = 134,
  [347] = 135,
  [348] = 155,
  [349] = 137,
  [350] = 139,
  [351] = 140,
  [352] = 141,
  [353] = 142,
  [354] = 143,
  [355] = 144,
  [356] = 145,
  [357] = 146,
  [358] = 147,
  [359] = 148,
  [360] = 149,
  [361] = 150,
  [362] = 151,
  [363] = 152,
  [364] = 364,
  [365] = 365,
  [366] = 364,
  [367] = 367,
  [368] = 368,
  [369] = 369,
  [370] = 367,
  [371] = 371,
  [372] = 372,
  [373] = 373,
  [374] = 374,
  [375] = 375,
  [376] = 376,
  [377] = 377,
  [378] = 378,
  [379] = 379,
  [380] = 380,
  [381] = 264,
  [382] = 382,
  [383] = 255,
  [384] = 274,
  [385] = 385,
  [386] = 386,
  [387] = 274,
  [388] = 388,
  [389] = 389,
  [390] = 220,
  [391] = 391,
  [392] = 392,
  [393] = 393,
  [394] = 221,
  [395] = 221,
  [396] = 220,
  [397] = 293,
  [398] = 398,
  [399] = 292,
  [400] = 295,
  [401] = 401,
  [402] = 402,
  [403] = 403,
  [404] = 404,
  [405] = 405,
  [406] = 297,
  [407] = 407,
  [408] = 408,
  [409] = 409,
  [410] = 299,
  [411] = 298,
  [412] = 290,
  [413] = 274,
  [414] = 414,
  [415] = 291,
  [416] = 416,
  [417] = 296,
  [418] = 418,
  [419] = 419,
  [420] = 420,
  [421] = 421,
  [422] = 296,
  [423] = 295,
  [424] = 297,
  [425] = 293,
  [426] = 292,
  [427] = 299,
  [428] = 298,
  [429] = 290,
  [430] = 291,
  [431] = 324,
  [432] = 432,
  [433] = 433,
  [434] = 330,
  [435] = 435,
  [436] = 436,
  [437] = 437,
  [438] = 438,
  [439] = 439,
  [440] = 440,
  [441] = 441,
  [442] = 442,
  [443] = 443,
  [444] = 444,
  [445] = 445,
  [446] = 446,
  [447] = 447,
  [448] = 448,
  [449] = 449,
  [450] = 450,
  [451] = 451,
  [452] = 452,
  [453] = 453,
  [454] = 454,
  [455] = 455,
  [456] = 456,
  [457] = 457,
  [458] = 458,
  [459] = 459,
  [460] = 460,
  [461] = 325,
  [462] = 462,
  [463] = 463,
  [464] = 464,
  [465] = 465,
  [466] = 466,
  [467] = 302,
  [468] = 468,
  [469] = 469,
  [470] = 470,
  [471] = 471,
  [472] = 472,
  [473] = 473,
  [474] = 474,
  [475] = 475,
  [476] = 321,
  [477] = 477,
  [478] = 322,
  [479] = 479,
  [480] = 320,
  [481] = 365,
  [482] = 482,
  [483] = 483,
  [484] = 484,
  [485] = 485,
  [486] = 486,
  [487] = 487,
  [488] = 488,
  [489] = 489,
  [490] = 490,
  [491] = 491,
  [492] = 327,
  [493] = 493,
  [494] = 494,
  [495] = 315,
  [496] = 496,
  [497] = 496,
  [498] = 498,
  [499] = 499,
  [500] = 308,
  [501] = 501,
  [502] = 502,
  [503] = 503,
  [504] = 221,
  [505] = 498,
  [506] = 491,
  [507] = 499,
  [508] = 498,
  [509] = 496,
  [510] = 498,
  [511] = 499,
  [512] = 512,
  [513] = 513,
  [514] = 494,
  [515] = 309,
  [516] = 220,
  [517] = 517,
  [518] = 499,
  [519] = 519,
  [520] = 496,
  [521] = 521,
  [522] = 466,
  [523] = 432,
  [524] = 524,
  [525] = 309,
  [526] = 315,
  [527] = 527,
  [528] = 528,
  [529] = 463,
  [530] = 308,
  [531] = 128,
  [532] = 121,
  [533] = 533,
  [534] = 534,
  [535] = 535,
  [536] = 139,
  [537] = 122,
  [538] = 140,
  [539] = 539,
  [540] = 540,
  [541] = 149,
  [542] = 126,
  [543] = 124,
  [544] = 141,
  [545] = 127,
  [546] = 546,
  [547] = 131,
  [548] = 528,
  [549] = 132,
  [550] = 145,
  [551] = 134,
  [552] = 143,
  [553] = 129,
  [554] = 135,
  [555] = 130,
  [556] = 142,
  [557] = 155,
  [558] = 558,
  [559] = 137,
  [560] = 527,
  [561] = 150,
  [562] = 151,
  [563] = 563,
  [564] = 125,
  [565] = 152,
  [566] = 144,
  [567] = 136,
  [568] = 146,
  [569] = 123,
  [570] = 570,
  [571] = 148,
  [572] = 147,
  [573] = 120,
  [574] = 574,
  [575] = 574,
  [576] = 576,
  [577] = 577,
  [578] = 576,
  [579] = 491,
  [580] = 576,
  [581] = 576,
  [582] = 574,
  [583] = 577,
  [584] = 577,
  [585] = 574,
  [586] = 577,
  [587] = 587,
  [588] = 588,
  [589] = 589,
  [590] = 590,
  [591] = 591,
  [592] = 592,
  [593] = 590,
  [594] = 591,
  [595] = 588,
  [596] = 589,
  [597] = 590,
  [598] = 591,
  [599] = 592,
  [600] = 588,
  [601] = 601,
  [602] = 264,
  [603] = 592,
  [604] = 274,
  [605] = 605,
  [606] = 606,
  [607] = 607,
  [608] = 592,
  [609] = 606,
  [610] = 607,
  [611] = 601,
  [612] = 588,
  [613] = 613,
  [614] = 589,
  [615] = 615,
  [616] = 589,
  [617] = 590,
  [618] = 591,
  [619] = 615,
  [620] = 255,
  [621] = 621,
  [622] = 622,
  [623] = 491,
  [624] = 624,
  [625] = 625,
  [626] = 626,
  [627] = 626,
  [628] = 628,
  [629] = 629,
  [630] = 630,
  [631] = 630,
  [632] = 632,
  [633] = 633,
  [634] = 634,
  [635] = 635,
  [636] = 636,
  [637] = 637,
  [638] = 638,
  [639] = 639,
  [640] = 625,
  [641] = 633,
  [642] = 632,
  [643] = 637,
  [644] = 625,
  [645] = 645,
  [646] = 625,
  [647] = 632,
  [648] = 638,
  [649] = 632,
  [650] = 621,
  [651] = 637,
  [652] = 639,
  [653] = 645,
  [654] = 622,
  [655] = 655,
  [656] = 629,
  [657] = 639,
  [658] = 645,
  [659] = 622,
  [660] = 655,
  [661] = 629,
  [662] = 639,
  [663] = 645,
  [664] = 622,
  [665] = 655,
  [666] = 629,
  [667] = 630,
  [668] = 638,
  [669] = 621,
  [670] = 655,
  [671] = 633,
  [672] = 637,
  [673] = 638,
  [674] = 621,
  [675] = 626,
  [676] = 626,
  [677] = 635,
  [678] = 624,
  [679] = 635,
  [680] = 624,
  [681] = 635,
  [682] = 624,
  [683] = 633,
  [684] = 630,
  [685] = 587,
  [686] = 686,
  [687] = 687,
  [688] = 688,
  [689] = 689,
  [690] = 690,
  [691] = 691,
  [692] = 692,
  [693] = 689,
  [694] = 694,
  [695] = 695,
  [696] = 696,
  [697] = 697,
  [698] = 698,
  [699] = 699,
  [700] = 700,
  [701] = 701,
  [702] = 701,
  [703] = 703,
  [704] = 704,
  [705] = 705,
  [706] = 300,
  [707] = 707,
  [708] = 708,
  [709] = 709,
  [710] = 707,
  [711] = 711,
  [712] = 712,
  [713] = 713,
  [714] = 714,
  [715] = 705,
  [716] = 716,
  [717] = 717,
  [718] = 718,
  [719] = 719,
  [720] = 720,
  [721] = 721,
  [722] = 722,
  [723] = 723,
  [724] = 724,
  [725] = 725,
  [726] = 726,
  [727] = 721,
  [728] = 728,
  [729] = 491,
  [730] = 730,
  [731] = 731,
  [732] = 732,
  [733] = 733,
  [734] = 734,
  [735] = 255,
  [736] = 274,
  [737] = 737,
  [738] = 738,
  [739] = 734,
  [740] = 323,
  [741] = 326,
  [742] = 738,
  [743] = 743,
  [744] = 738,
  [745] = 734,
  [746] = 738,
  [747] = 734,
  [748] = 748,
  [749] = 749,
  [750] = 264,
  [751] = 751,
  [752] = 752,
  [753] = 752,
  [754] = 754,
  [755] = 752,
  [756] = 756,
  [757] = 757,
  [758] = 758,
  [759] = 759,
  [760] = 760,
  [761] = 758,
  [762] = 762,
  [763] = 762,
  [764] = 758,
  [765] = 765,
  [766] = 766,
  [767] = 767,
  [768] = 758,
  [769] = 769,
  [770] = 770,
  [771] = 771,
  [772] = 759,
  [773] = 758,
  [774] = 774,
  [775] = 775,
  [776] = 776,
  [777] = 777,
  [778] = 778,
  [779] = 779,
  [780] = 780,
  [781] = 781,
  [782] = 782,
  [783] = 783,
  [784] = 784,
  [785] = 785,
  [786] = 783,
  [787] = 787,
  [788] = 788,
  [789] = 789,
  [790] = 781,
  [791] = 782,
  [792] = 787,
  [793] = 783,
  [794] = 787,
  [795] = 781,
  [796] = 782,
  [797] = 797,
  [798] = 798,
  [799] = 799,
  [800] = 800,
  [801] = 801,
  [802] = 802,
  [803] = 803,
  [804] = 804,
  [805] = 805,
  [806] = 255,
  [807] = 807,
  [808] = 808,
  [809] = 274,
  [810] = 264,
  [811] = 811,
  [812] = 812,
  [813] = 813,
  [814] = 294,
  [815] = 815,
  [816] = 816,
  [817] = 817,
  [818] = 818,
  [819] = 819,
  [820] = 820,
  [821] = 692,
  [822] = 822,
  [823] = 823,
  [824] = 824,
  [825] = 825,
  [826] = 818,
  [827] = 827,
  [828] = 828,
  [829] = 829,
  [830] = 830,
  [831] = 823,
  [832] = 824,
  [833] = 823,
  [834] = 824,
  [835] = 688,
  [836] = 836,
  [837] = 477,
  [838] = 838,
  [839] = 839,
  [840] = 840,
  [841] = 841,
  [842] = 842,
  [843] = 843,
  [844] = 844,
  [845] = 220,
  [846] = 828,
  [847] = 408,
  [848] = 464,
  [849] = 465,
  [850] = 827,
  [851] = 468,
  [852] = 828,
  [853] = 691,
  [854] = 854,
  [855] = 855,
  [856] = 488,
  [857] = 489,
  [858] = 418,
  [859] = 690,
  [860] = 843,
  [861] = 861,
  [862] = 487,
  [863] = 863,
  [864] = 864,
  [865] = 433,
  [866] = 822,
  [867] = 861,
  [868] = 844,
  [869] = 869,
  [870] = 870,
  [871] = 871,
  [872] = 872,
  [873] = 873,
  [874] = 871,
  [875] = 695,
  [876] = 876,
  [877] = 836,
  [878] = 686,
  [879] = 221,
  [880] = 827,
  [881] = 699,
  [882] = 882,
  [883] = 389,
  [884] = 884,
  [885] = 885,
  [886] = 886,
  [887] = 887,
  [888] = 888,
  [889] = 889,
  [890] = 388,
  [891] = 891,
  [892] = 892,
  [893] = 893,
  [894] = 893,
  [895] = 895,
  [896] = 886,
  [897] = 882,
  [898] = 898,
  [899] = 519,
  [900] = 900,
  [901] = 884,
  [902] = 886,
  [903] = 903,
  [904] = 807,
  [905] = 905,
  [906] = 811,
  [907] = 907,
  [908] = 908,
  [909] = 909,
  [910] = 910,
  [911] = 911,
  [912] = 908,
  [913] = 882,
  [914] = 914,
  [915] = 887,
  [916] = 916,
  [917] = 895,
  [918] = 385,
  [919] = 919,
  [920] = 891,
  [921] = 921,
  [922] = 884,
  [923] = 889,
  [924] = 887,
  [925] = 805,
  [926] = 884,
  [927] = 887,
  [928] = 928,
  [929] = 889,
  [930] = 930,
  [931] = 700,
  [932] = 889,
  [933] = 697,
  [934] = 930,
  [935] = 886,
  [936] = 893,
  [937] = 893,
  [938] = 938,
  [939] = 939,
  [940] = 940,
  [941] = 941,
  [942] = 942,
  [943] = 943,
  [944] = 944,
  [945] = 945,
  [946] = 946,
  [947] = 947,
  [948] = 948,
  [949] = 949,
  [950] = 950,
  [951] = 951,
  [952] = 952,
  [953] = 953,
  [954] = 954,
  [955] = 955,
  [956] = 956,
  [957] = 957,
  [958] = 958,
  [959] = 959,
  [960] = 960,
  [961] = 961,
  [962] = 962,
  [963] = 963,
  [964] = 949,
  [965] = 965,
  [966] = 966,
  [967] = 961,
  [968] = 952,
  [969] = 945,
  [970] = 970,
  [971] = 971,
  [972] = 955,
  [973] = 973,
  [974] = 974,
  [975] = 949,
  [976] = 955,
  [977] = 977,
  [978] = 949,
  [979] = 979,
  [980] = 980,
  [981] = 981,
  [982] = 955,
  [983] = 983,
  [984] = 952,
  [985] = 952,
  [986] = 986,
  [987] = 987,
  [988] = 988,
  [989] = 989,
  [990] = 990,
  [991] = 991,
  [992] = 992,
  [993] = 993,
  [994] = 994,
  [995] = 995,
  [996] = 996,
  [997] = 997,
  [998] = 990,
  [999] = 999,
  [1000] = 1000,
  [1001] = 1001,
  [1002] = 1002,
  [1003] = 1003,
  [1004] = 992,
  [1005] = 1005,
  [1006] = 1006,
  [1007] = 993,
  [1008] = 1008,
  [1009] = 987,
  [1010] = 1010,
  [1011] = 1011,
  [1012] = 996,
  [1013] = 990,
  [1014] = 990,
  [1015] = 1015,
  [1016] = 1016,
  [1017] = 1017,
  [1018] = 1018,
  [1019] = 1001,
  [1020] = 1020,
  [1021] = 999,
  [1022] = 1001,
  [1023] = 1010,
  [1024] = 999,
  [1025] = 1025,
  [1026] = 1003,
  [1027] = 1027,
  [1028] = 1005,
  [1029] = 1006,
  [1030] = 1030,
  [1031] = 1031,
  [1032] = 1032,
  [1033] = 989,
  [1034] = 1034,
  [1035] = 1035,
  [1036] = 1036,
  [1037] = 1037,
  [1038] = 1038,
  [1039] = 1039,
  [1040] = 1040,
  [1041] = 1003,
  [1042] = 987,
  [1043] = 1043,
  [1044] = 992,
  [1045] = 1005,
  [1046] = 1017,
  [1047] = 1032,
  [1048] = 1001,
  [1049] = 1003,
  [1050] = 1002,
  [1051] = 988,
  [1052] = 997,
  [1053] = 1053,
  [1054] = 996,
  [1055] = 1055,
  [1056] = 994,
  [1057] = 1032,
  [1058] = 992,
  [1059] = 993,
  [1060] = 1060,
  [1061] = 1027,
  [1062] = 1055,
  [1063] = 1002,
  [1064] = 988,
  [1065] = 997,
  [1066] = 1066,
  [1067] = 1067,
  [1068] = 996,
  [1069] = 990,
  [1070] = 1070,
  [1071] = 996,
  [1072] = 1027,
  [1073] = 1055,
  [1074] = 1002,
  [1075] = 988,
  [1076] = 997,
  [1077] = 1053,
  [1078] = 996,
  [1079] = 1003,
  [1080] = 1080,
  [1081] = 1005,
  [1082] = 1060,
  [1083] = 1027,
  [1084] = 1055,
  [1085] = 1085,
  [1086] = 999,
  [1087] = 1016,
  [1088] = 1020,
  [1089] = 1089,
  [1090] = 1090,
  [1091] = 1067,
  [1092] = 1018,
  [1093] = 1010,
  [1094] = 1094,
  [1095] = 1080,
  [1096] = 1085,
  [1097] = 1097,
  [1098] = 1067,
  [1099] = 1018,
  [1100] = 987,
  [1101] = 1101,
  [1102] = 1006,
  [1103] = 991,
  [1104] = 1104,
  [1105] = 1067,
  [1106] = 1018,
  [1107] = 1094,
  [1108] = 993,
  [1109] = 1109,
  [1110] = 996,
  [1111] = 1010,
  [1112] = 1094,
  [1113] = 986,
  [1114] = 1109,
  [1115] = 1032,
  [1116] = 1053,
  [1117] = 1094,
  [1118] = 986,
  [1119] = 1109,
  [1120] = 1101,
  [1121] = 986,
  [1122] = 1109,
  [1123] = 1123,
  [1124] = 1124,
  [1125] = 1006,
  [1126] = 1126,
  [1127] = 1127,
  [1128] = 995,
  [1129] = 1123,
  [1130] = 995,
  [1131] = 1123,
  [1132] = 995,
  [1133] = 1123,
  [1134] = 1053,
};

static TSCharacterRange sym_var_character_set_1[] = {
  {'0', '9'}, {'A', 'Z'}, {'_', '_'}, {'a', 'z'}, {0xc0, 0xd6}, {0xd8, 0xf6}, {0xf8, 0x2ff}, {0x370, 0x37d},
  {0x37f, 0x1fff}, {0x200c, 0x200d}, {0x2070, 0x218f}, {0x2c00, 0x2fef}, {0x3001, 0xd7ff}, {0xf900, 0xfdcf}, {0xfdf0, 0xfffd}, {0x10000, 0xeffff},
};

static TSCharacterRange sym_var_character_set_2[] = {
  {'0', '9'}, {'A', 'Z'}, {'_', '_'}, {'a', 'z'}, {0xb7, 0xb7}, {0xc0, 0xd6}, {0xd8, 0xf6}, {0xf8, 0x37d},
  {0x37f, 0x1fff}, {0x200c, 0x200d}, {0x203f, 0x2040}, {0x2070, 0x218f}, {0x2c00, 0x2fef}, {0x3001, 0xd7ff}, {0xf900, 0xfdcf}, {0xfdf0, 0xfffd},
  {0x10000, 0xeffff},
};

static TSCharacterRange aux_sym_blank_node_label_token1_character_set_1[] = {
  {'-', '.'}, {'0', '9'}, {'A', 'Z'}, {'_', '_'}, {'a', 'z'}, {0xb7, 0xb7}, {0xc0, 0xd6}, {0xd8, 0xf6},
  {0xf8, 0x37d}, {0x37f, 0x1fff}, {0x200c, 0x200d}, {0x203f, 0x2040}, {0x2070, 0x218f}, {0x2c00, 0x2fef}, {0x3001, 0xd7ff}, {0xf900, 0xfdcf},
  {0xfdf0, 0xfffd}, {0x10000, 0xeffff},
};

static TSCharacterRange sym_pn_prefix_character_set_1[] = {
  {'A', 'Z'}, {'a', 'z'}, {0xc0, 0xd6}, {0xd8, 0xf6}, {0xf8, 0x2ff}, {0x370, 0x37d}, {0x37f, 0x1fff}, {0x200c, 0x200d},
  {0x2070, 0x218f}, {0x2c00, 0x2fef}, {0x3001, 0xd7ff}, {0xf900, 0xfdcf}, {0xfdf0, 0xfffd}, {0x10000, 0xeffff},
};

static TSCharacterRange sym_pn_local_character_set_1[] = {
  {'%', '%'}, {'0', ':'}, {'A', 'Z'}, {'\\', '\\'}, {'_', '_'}, {'a', 'z'}, {0xc0, 0xd6}, {0xd8, 0xf6},
  {0xf8, 0x2ff}, {0x370, 0x37d}, {0x37f, 0x1fff}, {0x200c, 0x200d}, {0x2070, 0x218f}, {0x2c00, 0x2fef}, {0x3001, 0xd7ff}, {0xf900, 0xfdcf},
  {0xfdf0, 0xfffd}, {0x10000, 0xeffff},
};

static TSCharacterRange sym_pn_local_character_set_2[] = {
  {'%', '%'}, {'-', '.'}, {'0', ':'}, {'A', 'Z'}, {'\\', '\\'}, {'_', '_'}, {'a', 'z'}, {0xb7, 0xb7},
  {0xc0, 0xd6}, {0xd8, 0xf6}, {0xf8, 0x37d}, {0x37f, 0x1fff}, {0x200c, 0x200d}, {0x203f, 0x2040}, {0x2070, 0x218f}, {0x2c00, 0x2fef},
  {0x3001, 0xd7ff}, {0xf900, 0xfdcf}, {0xfdf0, 0xfffd}, {0x10000, 0xeffff},
};

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(70);
      ADVANCE_MAP(
        '!', 94,
        '"', 132,
        '#', 71,
        '$', 61,
        '&', 27,
        '\'', 127,
        '(', 74,
        ')', 75,
        '*', 76,
        '+', 108,
        ',', 84,
        '-', 110,
        '.', 83,
        '/', 85,
        ':', 115,
        ';', 72,
        '<', 103,
        '=', 100,
        '>', 104,
        '?', 92,
        '@', 59,
        'D', 149,
        'I', 154,
        '[', 95,
        '\\', 52,
        ']', 96,
        '^', 89,
        '_', 33,
        '{', 77,
        '|', 87,
        '}', 78,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(0);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(122);
      if (set_contains(sym_pn_prefix_character_set_1, 14, lookahead)) ADVANCE(159);
      END_STATE();
    case 1:
      ADVANCE_MAP(
        '!', 93,
        '"', 133,
        '#', 71,
        '\'', 128,
        '(', 73,
        ')', 75,
        '*', 76,
        '+', 108,
        '-', 110,
        '.', 53,
        ':', 115,
        ';', 72,
        '<', 102,
        '@', 59,
        ']', 96,
        '^', 89,
        '{', 77,
        '}', 78,
        '$', 61,
        '?', 61,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(1);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(122);
      if (set_contains(sym_pn_prefix_character_set_1, 14, lookahead)) ADVANCE(159);
      END_STATE();
    case 2:
      ADVANCE_MAP(
        '!', 93,
        '#', 71,
        '%', 58,
        '(', 73,
        ':', 116,
        '<', 102,
        '\\', 56,
        '^', 88,
        '$', 61,
        '?', 61,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(4);
      if (('0' <= lookahead && lookahead <= '9') ||
          lookahead == '_') ADVANCE(166);
      if (set_contains(sym_pn_local_character_set_1, 18, lookahead)) ADVANCE(177);
      END_STATE();
    case 3:
      ADVANCE_MAP(
        '!', 93,
        '#', 71,
        '(', 73,
        ',', 84,
        '.', 82,
        ':', 115,
        ';', 72,
        '<', 102,
        ']', 96,
        '^', 88,
        '{', 77,
        '}', 78,
        '$', 61,
        '?', 61,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(3);
      if (set_contains(sym_pn_prefix_character_set_1, 14, lookahead)) ADVANCE(159);
      END_STATE();
    case 4:
      ADVANCE_MAP(
        '!', 93,
        '#', 71,
        '(', 73,
        ':', 115,
        '<', 102,
        '^', 88,
        '$', 61,
        '?', 61,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(4);
      if (set_contains(sym_pn_prefix_character_set_1, 14, lookahead)) ADVANCE(159);
      END_STATE();
    case 5:
      ADVANCE_MAP(
        '!', 34,
        '#', 71,
        '%', 58,
        '&', 27,
        '(', 74,
        ')', 75,
        '*', 76,
        '+', 107,
        ',', 84,
        '-', 109,
        '.', 82,
        '/', 85,
        ';', 72,
        '<', 103,
        '=', 100,
        '>', 104,
        '\\', 56,
        ']', 96,
        '{', 77,
        '|', 87,
        '}', 78,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(8);
      if (('0' <= lookahead && lookahead <= ':') ||
          lookahead == '_') ADVANCE(166);
      if (set_contains(sym_pn_local_character_set_1, 18, lookahead)) ADVANCE(177);
      END_STATE();
    case 6:
      ADVANCE_MAP(
        '!', 34,
        '#', 71,
        '%', 58,
        '&', 27,
        '(', 74,
        ')', 75,
        '*', 76,
        '+', 107,
        ',', 84,
        '-', 109,
        '/', 85,
        ';', 72,
        '<', 103,
        '=', 100,
        '>', 104,
        '\\', 56,
        '|', 49,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(9);
      if (('0' <= lookahead && lookahead <= ':') ||
          lookahead == '_') ADVANCE(166);
      if (set_contains(sym_pn_local_character_set_1, 18, lookahead)) ADVANCE(177);
      END_STATE();
    case 7:
      ADVANCE_MAP(
        '!', 34,
        '#', 71,
        '&', 27,
        '(', 74,
        ')', 75,
        '*', 76,
        '+', 107,
        ',', 84,
        '-', 109,
        '.', 82,
        '/', 85,
        ';', 72,
        '<', 103,
        '=', 100,
        '>', 104,
        '@', 59,
        ']', 96,
        '^', 48,
        '{', 77,
        '|', 49,
        '}', 78,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(7);
      if (set_contains(sym_pn_prefix_character_set_1, 14, lookahead)) ADVANCE(159);
      END_STATE();
    case 8:
      ADVANCE_MAP(
        '!', 34,
        '#', 71,
        '&', 27,
        '(', 74,
        ')', 75,
        '*', 76,
        '+', 107,
        ',', 84,
        '-', 109,
        '.', 82,
        '/', 85,
        ';', 72,
        '<', 103,
        '=', 100,
        '>', 104,
        ']', 96,
        '{', 77,
        '|', 87,
        '}', 78,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(8);
      if (set_contains(sym_pn_prefix_character_set_1, 14, lookahead)) ADVANCE(159);
      END_STATE();
    case 9:
      ADVANCE_MAP(
        '!', 34,
        '#', 71,
        '&', 27,
        '(', 74,
        ')', 75,
        '*', 76,
        '+', 107,
        ',', 84,
        '-', 109,
        '/', 85,
        ';', 72,
        '<', 103,
        '=', 100,
        '>', 104,
        '|', 49,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(9);
      if (set_contains(sym_pn_prefix_character_set_1, 14, lookahead)) ADVANCE(159);
      END_STATE();
    case 10:
      if (lookahead == '"') ADVANCE(132);
      if (lookahead == '#') ADVANCE(142);
      if (lookahead == '\\') ADVANCE(52);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(143);
      if (lookahead != 0) ADVANCE(142);
      END_STATE();
    case 11:
      if (lookahead == '"') ADVANCE(140);
      END_STATE();
    case 12:
      if (lookahead == '"') ADVANCE(131);
      if (lookahead == '#') ADVANCE(134);
      if (lookahead == '\\') ADVANCE(52);
      if (lookahead == '\n' ||
          lookahead == '\r') SKIP(12);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') ADVANCE(135);
      if (lookahead != 0) ADVANCE(134);
      END_STATE();
    case 13:
      ADVANCE_MAP(
        '"', 133,
        '#', 71,
        '$', 61,
        '%', 58,
        '\'', 128,
        '(', 74,
        ')', 75,
        '*', 90,
        '+', 91,
        '-', 30,
        '.', 53,
        '/', 85,
        ':', 116,
        '<', 102,
        '?', 92,
        '[', 95,
        '\\', 56,
        '_', 163,
        '|', 86,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(15);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(178);
      if (set_contains(sym_pn_local_character_set_1, 18, lookahead)) ADVANCE(177);
      END_STATE();
    case 14:
      ADVANCE_MAP(
        '"', 133,
        '#', 71,
        '$', 61,
        '\'', 128,
        '(', 74,
        ')', 75,
        '*', 90,
        '+', 91,
        '-', 30,
        '.', 83,
        '/', 85,
        ':', 115,
        '<', 102,
        '?', 92,
        '@', 59,
        '[', 95,
        '^', 48,
        '_', 33,
        '{', 77,
        '|', 86,
        '}', 78,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(14);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(122);
      if (set_contains(sym_pn_prefix_character_set_1, 14, lookahead)) ADVANCE(159);
      END_STATE();
    case 15:
      ADVANCE_MAP(
        '"', 133,
        '#', 71,
        '$', 61,
        '\'', 128,
        '(', 74,
        ')', 75,
        '*', 90,
        '+', 91,
        '-', 30,
        '.', 53,
        '/', 85,
        ':', 115,
        '<', 102,
        '?', 92,
        '[', 95,
        '_', 33,
        '|', 86,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(15);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(122);
      if (set_contains(sym_pn_prefix_character_set_1, 14, lookahead)) ADVANCE(159);
      END_STATE();
    case 16:
      ADVANCE_MAP(
        '"', 133,
        '#', 71,
        '%', 58,
        '\'', 128,
        ')', 75,
        '.', 53,
        ':', 116,
        '<', 102,
        '\\', 56,
        '_', 166,
        '}', 78,
        '+', 30,
        '-', 30,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(17);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(178);
      if (set_contains(sym_pn_local_character_set_1, 18, lookahead)) ADVANCE(177);
      END_STATE();
    case 17:
      ADVANCE_MAP(
        '"', 133,
        '#', 71,
        '\'', 128,
        ')', 75,
        '.', 53,
        ':', 115,
        '<', 102,
        '}', 78,
        '+', 30,
        '-', 30,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(17);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(122);
      if (set_contains(sym_pn_prefix_character_set_1, 14, lookahead)) ADVANCE(159);
      END_STATE();
    case 18:
      ADVANCE_MAP(
        '#', 71,
        '%', 58,
        '(', 74,
        ')', 75,
        ',', 84,
        '.', 82,
        '/', 85,
        ';', 72,
        '\\', 56,
        ']', 96,
        '{', 77,
        '|', 86,
        '}', 78,
        '*', 90,
        '+', 90,
        '?', 90,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(19);
      if (('0' <= lookahead && lookahead <= ':') ||
          lookahead == '_') ADVANCE(166);
      if (set_contains(sym_pn_local_character_set_1, 18, lookahead)) ADVANCE(177);
      END_STATE();
    case 19:
      ADVANCE_MAP(
        '#', 71,
        '(', 74,
        ')', 75,
        ',', 84,
        '.', 82,
        '/', 85,
        ';', 72,
        ']', 96,
        '{', 77,
        '|', 86,
        '}', 78,
        '*', 90,
        '+', 90,
        '?', 90,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(19);
      if (set_contains(sym_pn_prefix_character_set_1, 14, lookahead)) ADVANCE(159);
      END_STATE();
    case 20:
      if (lookahead == '#') ADVANCE(71);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(20);
      END_STATE();
    case 21:
      if (lookahead == '#') ADVANCE(71);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(20);
      if (set_contains(sym_var_character_set_1, 16, lookahead)) ADVANCE(119);
      END_STATE();
    case 22:
      if (lookahead == '#') ADVANCE(138);
      if (lookahead == '\'') ADVANCE(127);
      if (lookahead == '\\') ADVANCE(52);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(139);
      if (lookahead != 0) ADVANCE(138);
      END_STATE();
    case 23:
      if (lookahead == '#') ADVANCE(129);
      if (lookahead == '\'') ADVANCE(126);
      if (lookahead == '\\') ADVANCE(52);
      if (lookahead == '\n' ||
          lookahead == '\r') SKIP(23);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') ADVANCE(130);
      if (lookahead != 0) ADVANCE(129);
      END_STATE();
    case 24:
      if (lookahead == '%') ADVANCE(58);
      if (lookahead == '.') ADVANCE(25);
      if (lookahead == '\\') ADVANCE(56);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(162);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(164);
      if (set_contains(sym_pn_local_character_set_2, 20, lookahead)) ADVANCE(166);
      END_STATE();
    case 25:
      if (lookahead == '%') ADVANCE(58);
      if (lookahead == '.') ADVANCE(25);
      if (lookahead == '\\') ADVANCE(56);
      if (set_contains(sym_pn_local_character_set_2, 20, lookahead)) ADVANCE(166);
      END_STATE();
    case 26:
      if (lookahead == '%') ADVANCE(58);
      if (lookahead == '.') ADVANCE(26);
      if (lookahead == ':') ADVANCE(166);
      if (lookahead == '\\') ADVANCE(56);
      if (set_contains(sym_pn_local_character_set_2, 20, lookahead)) ADVANCE(177);
      END_STATE();
    case 27:
      if (lookahead == '&') ADVANCE(99);
      END_STATE();
    case 28:
      if (lookahead == '\'') ADVANCE(136);
      END_STATE();
    case 29:
      if (lookahead == ')') ADVANCE(145);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') ADVANCE(29);
      END_STATE();
    case 30:
      if (lookahead == '.') ADVANCE(53);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(122);
      END_STATE();
    case 31:
      if (lookahead == '.') ADVANCE(31);
      if (set_contains(aux_sym_blank_node_label_token1_character_set_1, 18, lookahead)) ADVANCE(159);
      END_STATE();
    case 32:
      if (lookahead == '.') ADVANCE(32);
      if (set_contains(aux_sym_blank_node_label_token1_character_set_1, 18, lookahead)) ADVANCE(119);
      END_STATE();
    case 33:
      if (lookahead == ':') ADVANCE(117);
      END_STATE();
    case 34:
      if (lookahead == '=') ADVANCE(101);
      END_STATE();
    case 35:
      if (lookahead == 'A') ADVANCE(45);
      END_STATE();
    case 36:
      if (lookahead == 'A') ADVANCE(80);
      END_STATE();
    case 37:
      if (lookahead == 'A') ADVANCE(79);
      END_STATE();
    case 38:
      if (lookahead == 'A') ADVANCE(46);
      END_STATE();
    case 39:
      if (lookahead == 'D') ADVANCE(35);
      if (lookahead == 'W') ADVANCE(43);
      END_STATE();
    case 40:
      if (lookahead == 'D') ADVANCE(38);
      END_STATE();
    case 41:
      if (lookahead == 'E') ADVANCE(44);
      END_STATE();
    case 42:
      if (lookahead == 'E') ADVANCE(81);
      END_STATE();
    case 43:
      if (lookahead == 'H') ADVANCE(41);
      END_STATE();
    case 44:
      if (lookahead == 'R') ADVANCE(42);
      END_STATE();
    case 45:
      if (lookahead == 'T') ADVANCE(36);
      END_STATE();
    case 46:
      if (lookahead == 'T') ADVANCE(37);
      END_STATE();
    case 47:
      if (lookahead == ']') ADVANCE(146);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') ADVANCE(47);
      END_STATE();
    case 48:
      if (lookahead == '^') ADVANCE(111);
      END_STATE();
    case 49:
      if (lookahead == '|') ADVANCE(98);
      END_STATE();
    case 50:
      if (lookahead == '+' ||
          lookahead == '-') ADVANCE(54);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(125);
      END_STATE();
    case 51:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(50);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(124);
      END_STATE();
    case 52:
      ADVANCE_MAP(
        '"', 144,
        '\'', 144,
        '\\', 144,
        'b', 144,
        'f', 144,
        'n', 144,
        'r', 144,
        't', 144,
      );
      END_STATE();
    case 53:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(124);
      END_STATE();
    case 54:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(125);
      END_STATE();
    case 55:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(123);
      END_STATE();
    case 56:
      if (lookahead == '!' ||
          ('#' <= lookahead && lookahead <= '/') ||
          lookahead == ';' ||
          lookahead == '=' ||
          lookahead == '?' ||
          lookahead == '@' ||
          lookahead == '_' ||
          lookahead == '~') ADVANCE(166);
      END_STATE();
    case 57:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(166);
      END_STATE();
    case 58:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(57);
      END_STATE();
    case 59:
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(120);
      END_STATE();
    case 60:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(121);
      END_STATE();
    case 61:
      if (set_contains(sym_var_character_set_1, 16, lookahead)) ADVANCE(97);
      END_STATE();
    case 62:
      if (eof) ADVANCE(70);
      ADVANCE_MAP(
        '!', 34,
        '#', 71,
        '&', 27,
        ')', 75,
        '*', 76,
        '+', 107,
        ',', 84,
        '-', 109,
        '/', 85,
        ';', 72,
        '<', 103,
        '=', 100,
        '>', 104,
        'D', 149,
        'I', 154,
        '|', 49,
        '}', 78,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(62);
      if (set_contains(sym_pn_prefix_character_set_1, 14, lookahead)) ADVANCE(159);
      END_STATE();
    case 63:
      if (eof) ADVANCE(70);
      ADVANCE_MAP(
        '"', 133,
        '#', 71,
        '\'', 128,
        '(', 73,
        ')', 75,
        '*', 76,
        '.', 82,
        '/', 85,
        ':', 115,
        '<', 102,
        '>', 114,
        'D', 149,
        'I', 154,
        '{', 77,
        '|', 86,
        '}', 78,
        '$', 61,
        '?', 61,
        '+', 55,
        '-', 55,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(64);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(123);
      if (set_contains(sym_pn_prefix_character_set_1, 14, lookahead)) ADVANCE(159);
      END_STATE();
    case 64:
      if (eof) ADVANCE(70);
      ADVANCE_MAP(
        '"', 133,
        '#', 71,
        '\'', 128,
        '(', 73,
        ')', 75,
        '*', 76,
        '.', 82,
        '/', 85,
        ':', 115,
        '<', 102,
        'D', 149,
        'I', 154,
        '{', 77,
        '|', 86,
        '}', 78,
        '$', 61,
        '?', 61,
        '+', 55,
        '-', 55,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(64);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(123);
      if (set_contains(sym_pn_prefix_character_set_1, 14, lookahead)) ADVANCE(159);
      END_STATE();
    case 65:
      if (eof) ADVANCE(70);
      ADVANCE_MAP(
        '#', 71,
        '%', 58,
        ')', 75,
        '/', 85,
        ';', 72,
        'D', 167,
        'I', 172,
        '\\', 56,
        '{', 77,
        '|', 86,
        '*', 90,
        '+', 90,
        '?', 90,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(68);
      if (('0' <= lookahead && lookahead <= ':') ||
          lookahead == '_') ADVANCE(166);
      if (set_contains(sym_pn_local_character_set_1, 18, lookahead)) ADVANCE(177);
      END_STATE();
    case 66:
      if (eof) ADVANCE(70);
      ADVANCE_MAP(
        '#', 71,
        '%', 58,
        ':', 116,
        '<', 102,
        'D', 167,
        'I', 172,
        '\\', 56,
        '{', 77,
        '$', 61,
        '?', 61,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(69);
      if (('0' <= lookahead && lookahead <= '9') ||
          lookahead == '_') ADVANCE(166);
      if (set_contains(sym_pn_local_character_set_1, 18, lookahead)) ADVANCE(177);
      END_STATE();
    case 67:
      if (eof) ADVANCE(70);
      ADVANCE_MAP(
        '#', 71,
        '(', 74,
        ')', 75,
        ',', 84,
        '.', 82,
        ':', 115,
        ';', 72,
        '<', 102,
        'D', 149,
        'I', 154,
        ']', 96,
        '{', 77,
        '|', 86,
        '}', 78,
        '$', 61,
        '?', 61,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(67);
      if (set_contains(sym_pn_prefix_character_set_1, 14, lookahead)) ADVANCE(159);
      END_STATE();
    case 68:
      if (eof) ADVANCE(70);
      ADVANCE_MAP(
        '#', 71,
        ')', 75,
        '/', 85,
        ';', 72,
        'D', 149,
        'I', 154,
        '{', 77,
        '|', 86,
        '*', 90,
        '+', 90,
        '?', 90,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(68);
      if (set_contains(sym_pn_prefix_character_set_1, 14, lookahead)) ADVANCE(159);
      END_STATE();
    case 69:
      if (eof) ADVANCE(70);
      ADVANCE_MAP(
        '#', 71,
        ':', 115,
        '<', 102,
        'D', 149,
        'I', 154,
        '{', 77,
        '$', 61,
        '?', 61,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(69);
      if (set_contains(sym_pn_prefix_character_set_1, 14, lookahead)) ADVANCE(159);
      END_STATE();
    case 70:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 71:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(71);
      END_STATE();
    case 72:
      ACCEPT_TOKEN(anon_sym_SEMI);
      END_STATE();
    case 73:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      END_STATE();
    case 74:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      if (lookahead == ')') ADVANCE(145);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') ADVANCE(29);
      END_STATE();
    case 75:
      ACCEPT_TOKEN(anon_sym_RPAREN);
      END_STATE();
    case 76:
      ACCEPT_TOKEN(anon_sym_STAR);
      END_STATE();
    case 77:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      END_STATE();
    case 78:
      ACCEPT_TOKEN(anon_sym_RBRACE);
      END_STATE();
    case 79:
      ACCEPT_TOKEN(anon_sym_INSERTDATA);
      END_STATE();
    case 80:
      ACCEPT_TOKEN(anon_sym_DELETEDATA);
      END_STATE();
    case 81:
      ACCEPT_TOKEN(anon_sym_DELETEWHERE);
      END_STATE();
    case 82:
      ACCEPT_TOKEN(anon_sym_DOT);
      END_STATE();
    case 83:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(124);
      END_STATE();
    case 84:
      ACCEPT_TOKEN(anon_sym_COMMA);
      END_STATE();
    case 85:
      ACCEPT_TOKEN(anon_sym_SLASH);
      END_STATE();
    case 86:
      ACCEPT_TOKEN(anon_sym_PIPE);
      END_STATE();
    case 87:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '|') ADVANCE(98);
      END_STATE();
    case 88:
      ACCEPT_TOKEN(anon_sym_CARET);
      END_STATE();
    case 89:
      ACCEPT_TOKEN(anon_sym_CARET);
      if (lookahead == '^') ADVANCE(111);
      END_STATE();
    case 90:
      ACCEPT_TOKEN(sym_path_mod);
      END_STATE();
    case 91:
      ACCEPT_TOKEN(sym_path_mod);
      if (lookahead == '.') ADVANCE(53);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(122);
      END_STATE();
    case 92:
      ACCEPT_TOKEN(sym_path_mod);
      if (set_contains(sym_var_character_set_1, 16, lookahead)) ADVANCE(97);
      END_STATE();
    case 93:
      ACCEPT_TOKEN(anon_sym_BANG);
      END_STATE();
    case 94:
      ACCEPT_TOKEN(anon_sym_BANG);
      if (lookahead == '=') ADVANCE(101);
      END_STATE();
    case 95:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      if (lookahead == ']') ADVANCE(146);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') ADVANCE(47);
      END_STATE();
    case 96:
      ACCEPT_TOKEN(anon_sym_RBRACK);
      END_STATE();
    case 97:
      ACCEPT_TOKEN(sym_var);
      if (set_contains(sym_var_character_set_2, 17, lookahead)) ADVANCE(97);
      END_STATE();
    case 98:
      ACCEPT_TOKEN(anon_sym_PIPE_PIPE);
      END_STATE();
    case 99:
      ACCEPT_TOKEN(anon_sym_AMP_AMP);
      END_STATE();
    case 100:
      ACCEPT_TOKEN(anon_sym_EQ);
      END_STATE();
    case 101:
      ACCEPT_TOKEN(anon_sym_BANG_EQ);
      END_STATE();
    case 102:
      ACCEPT_TOKEN(anon_sym_LT);
      END_STATE();
    case 103:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '=') ADVANCE(105);
      END_STATE();
    case 104:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '=') ADVANCE(106);
      END_STATE();
    case 105:
      ACCEPT_TOKEN(anon_sym_LT_EQ);
      END_STATE();
    case 106:
      ACCEPT_TOKEN(anon_sym_GT_EQ);
      END_STATE();
    case 107:
      ACCEPT_TOKEN(anon_sym_PLUS);
      END_STATE();
    case 108:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '.') ADVANCE(53);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(122);
      END_STATE();
    case 109:
      ACCEPT_TOKEN(anon_sym_DASH);
      END_STATE();
    case 110:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '.') ADVANCE(53);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(122);
      END_STATE();
    case 111:
      ACCEPT_TOKEN(anon_sym_CARET_CARET);
      END_STATE();
    case 112:
      ACCEPT_TOKEN(aux_sym_iri_reference_token1);
      if (lookahead == '#') ADVANCE(113);
      if (lookahead > ' ' &&
          lookahead != '"' &&
          lookahead != '#' &&
          lookahead != '<' &&
          lookahead != '>' &&
          lookahead != '\\' &&
          lookahead != '^' &&
          lookahead != '`' &&
          (lookahead < '{' || '}' < lookahead)) ADVANCE(113);
      END_STATE();
    case 113:
      ACCEPT_TOKEN(aux_sym_iri_reference_token1);
      if (lookahead > ' ' &&
          lookahead != '"' &&
          lookahead != '<' &&
          lookahead != '>' &&
          lookahead != '\\' &&
          lookahead != '^' &&
          lookahead != '`' &&
          (lookahead < '{' || '}' < lookahead)) ADVANCE(113);
      END_STATE();
    case 114:
      ACCEPT_TOKEN(anon_sym_GT2);
      END_STATE();
    case 115:
      ACCEPT_TOKEN(anon_sym_COLON);
      END_STATE();
    case 116:
      ACCEPT_TOKEN(anon_sym_COLON);
      if (lookahead == '%') ADVANCE(58);
      if (lookahead == '.') ADVANCE(25);
      if (lookahead == '\\') ADVANCE(56);
      if (set_contains(sym_pn_local_character_set_2, 20, lookahead)) ADVANCE(166);
      END_STATE();
    case 117:
      ACCEPT_TOKEN(anon_sym__COLON);
      END_STATE();
    case 118:
      ACCEPT_TOKEN(anon_sym__COLON);
      if (lookahead == '%') ADVANCE(58);
      if (lookahead == '.') ADVANCE(25);
      if (lookahead == '\\') ADVANCE(56);
      if (set_contains(sym_pn_local_character_set_2, 20, lookahead)) ADVANCE(166);
      END_STATE();
    case 119:
      ACCEPT_TOKEN(aux_sym_blank_node_label_token1);
      if (lookahead == '.') ADVANCE(32);
      if (set_contains(aux_sym_blank_node_label_token1_character_set_1, 18, lookahead)) ADVANCE(119);
      END_STATE();
    case 120:
      ACCEPT_TOKEN(sym_lang_tag);
      if (lookahead == '-') ADVANCE(60);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(120);
      END_STATE();
    case 121:
      ACCEPT_TOKEN(sym_lang_tag);
      if (lookahead == '-') ADVANCE(60);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(121);
      END_STATE();
    case 122:
      ACCEPT_TOKEN(sym_integer);
      if (lookahead == '.') ADVANCE(51);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(50);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(122);
      END_STATE();
    case 123:
      ACCEPT_TOKEN(sym_integer);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(123);
      END_STATE();
    case 124:
      ACCEPT_TOKEN(sym_decimal);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(50);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(124);
      END_STATE();
    case 125:
      ACCEPT_TOKEN(sym_double);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(125);
      END_STATE();
    case 126:
      ACCEPT_TOKEN(anon_sym_SQUOTE);
      END_STATE();
    case 127:
      ACCEPT_TOKEN(anon_sym_SQUOTE);
      if (lookahead == '\'') ADVANCE(137);
      END_STATE();
    case 128:
      ACCEPT_TOKEN(anon_sym_SQUOTE);
      if (lookahead == '\'') ADVANCE(28);
      END_STATE();
    case 129:
      ACCEPT_TOKEN(aux_sym__string_literal1_token1);
      END_STATE();
    case 130:
      ACCEPT_TOKEN(aux_sym__string_literal1_token1);
      if (lookahead == '#') ADVANCE(129);
      if (lookahead == '\t' ||
          lookahead == 0x0b ||
          lookahead == '\f' ||
          lookahead == ' ') ADVANCE(130);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != '\'' &&
          lookahead != '\\') ADVANCE(129);
      END_STATE();
    case 131:
      ACCEPT_TOKEN(anon_sym_DQUOTE);
      END_STATE();
    case 132:
      ACCEPT_TOKEN(anon_sym_DQUOTE);
      if (lookahead == '"') ADVANCE(141);
      END_STATE();
    case 133:
      ACCEPT_TOKEN(anon_sym_DQUOTE);
      if (lookahead == '"') ADVANCE(11);
      END_STATE();
    case 134:
      ACCEPT_TOKEN(aux_sym__string_literal2_token1);
      END_STATE();
    case 135:
      ACCEPT_TOKEN(aux_sym__string_literal2_token1);
      if (lookahead == '#') ADVANCE(134);
      if (lookahead == '\t' ||
          lookahead == 0x0b ||
          lookahead == '\f' ||
          lookahead == ' ') ADVANCE(135);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != '"' &&
          lookahead != '#' &&
          lookahead != '\\') ADVANCE(134);
      END_STATE();
    case 136:
      ACCEPT_TOKEN(anon_sym_SQUOTE_SQUOTE_SQUOTE);
      END_STATE();
    case 137:
      ACCEPT_TOKEN(anon_sym_SQUOTE_SQUOTE);
      if (lookahead == '\'') ADVANCE(136);
      END_STATE();
    case 138:
      ACCEPT_TOKEN(aux_sym__string_literal_long1_token1);
      END_STATE();
    case 139:
      ACCEPT_TOKEN(aux_sym__string_literal_long1_token1);
      if (lookahead == '#') ADVANCE(138);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(139);
      if (lookahead != 0 &&
          lookahead != '\'' &&
          lookahead != '\\') ADVANCE(138);
      END_STATE();
    case 140:
      ACCEPT_TOKEN(anon_sym_DQUOTE_DQUOTE_DQUOTE);
      END_STATE();
    case 141:
      ACCEPT_TOKEN(anon_sym_DQUOTE_DQUOTE);
      if (lookahead == '"') ADVANCE(140);
      END_STATE();
    case 142:
      ACCEPT_TOKEN(aux_sym__string_literal_long2_token1);
      END_STATE();
    case 143:
      ACCEPT_TOKEN(aux_sym__string_literal_long2_token1);
      if (lookahead == '#') ADVANCE(142);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(143);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '#' &&
          lookahead != '\\') ADVANCE(142);
      END_STATE();
    case 144:
      ACCEPT_TOKEN(sym_echar);
      END_STATE();
    case 145:
      ACCEPT_TOKEN(sym_nil);
      END_STATE();
    case 146:
      ACCEPT_TOKEN(sym_anon);
      END_STATE();
    case 147:
      ACCEPT_TOKEN(sym_pn_prefix);
      if (lookahead == ' ') ADVANCE(39);
      if (lookahead == '.') ADVANCE(31);
      if (set_contains(aux_sym_blank_node_label_token1_character_set_1, 18, lookahead)) ADVANCE(159);
      END_STATE();
    case 148:
      ACCEPT_TOKEN(sym_pn_prefix);
      if (lookahead == ' ') ADVANCE(40);
      if (lookahead == '.') ADVANCE(31);
      if (set_contains(aux_sym_blank_node_label_token1_character_set_1, 18, lookahead)) ADVANCE(159);
      END_STATE();
    case 149:
      ACCEPT_TOKEN(sym_pn_prefix);
      if (lookahead == '.') ADVANCE(31);
      if (lookahead == 'E') ADVANCE(153);
      if (set_contains(aux_sym_blank_node_label_token1_character_set_1, 18, lookahead)) ADVANCE(159);
      END_STATE();
    case 150:
      ACCEPT_TOKEN(sym_pn_prefix);
      if (lookahead == '.') ADVANCE(31);
      if (lookahead == 'E') ADVANCE(158);
      if (set_contains(aux_sym_blank_node_label_token1_character_set_1, 18, lookahead)) ADVANCE(159);
      END_STATE();
    case 151:
      ACCEPT_TOKEN(sym_pn_prefix);
      if (lookahead == '.') ADVANCE(31);
      if (lookahead == 'E') ADVANCE(155);
      if (set_contains(aux_sym_blank_node_label_token1_character_set_1, 18, lookahead)) ADVANCE(159);
      END_STATE();
    case 152:
      ACCEPT_TOKEN(sym_pn_prefix);
      if (lookahead == '.') ADVANCE(31);
      if (lookahead == 'E') ADVANCE(147);
      if (set_contains(aux_sym_blank_node_label_token1_character_set_1, 18, lookahead)) ADVANCE(159);
      END_STATE();
    case 153:
      ACCEPT_TOKEN(sym_pn_prefix);
      if (lookahead == '.') ADVANCE(31);
      if (lookahead == 'L') ADVANCE(150);
      if (set_contains(aux_sym_blank_node_label_token1_character_set_1, 18, lookahead)) ADVANCE(159);
      END_STATE();
    case 154:
      ACCEPT_TOKEN(sym_pn_prefix);
      if (lookahead == '.') ADVANCE(31);
      if (lookahead == 'N') ADVANCE(156);
      if (set_contains(aux_sym_blank_node_label_token1_character_set_1, 18, lookahead)) ADVANCE(159);
      END_STATE();
    case 155:
      ACCEPT_TOKEN(sym_pn_prefix);
      if (lookahead == '.') ADVANCE(31);
      if (lookahead == 'R') ADVANCE(157);
      if (set_contains(aux_sym_blank_node_label_token1_character_set_1, 18, lookahead)) ADVANCE(159);
      END_STATE();
    case 156:
      ACCEPT_TOKEN(sym_pn_prefix);
      if (lookahead == '.') ADVANCE(31);
      if (lookahead == 'S') ADVANCE(151);
      if (set_contains(aux_sym_blank_node_label_token1_character_set_1, 18, lookahead)) ADVANCE(159);
      END_STATE();
    case 157:
      ACCEPT_TOKEN(sym_pn_prefix);
      if (lookahead == '.') ADVANCE(31);
      if (lookahead == 'T') ADVANCE(148);
      if (set_contains(aux_sym_blank_node_label_token1_character_set_1, 18, lookahead)) ADVANCE(159);
      END_STATE();
    case 158:
      ACCEPT_TOKEN(sym_pn_prefix);
      if (lookahead == '.') ADVANCE(31);
      if (lookahead == 'T') ADVANCE(152);
      if (set_contains(aux_sym_blank_node_label_token1_character_set_1, 18, lookahead)) ADVANCE(159);
      END_STATE();
    case 159:
      ACCEPT_TOKEN(sym_pn_prefix);
      if (lookahead == '.') ADVANCE(31);
      if (set_contains(aux_sym_blank_node_label_token1_character_set_1, 18, lookahead)) ADVANCE(159);
      END_STATE();
    case 160:
      ACCEPT_TOKEN(sym_pn_local);
      if (lookahead == ' ') ADVANCE(39);
      if (lookahead == '%') ADVANCE(58);
      if (lookahead == '.') ADVANCE(26);
      if (lookahead == ':') ADVANCE(166);
      if (lookahead == '\\') ADVANCE(56);
      if (set_contains(sym_pn_local_character_set_2, 20, lookahead)) ADVANCE(177);
      END_STATE();
    case 161:
      ACCEPT_TOKEN(sym_pn_local);
      if (lookahead == ' ') ADVANCE(40);
      if (lookahead == '%') ADVANCE(58);
      if (lookahead == '.') ADVANCE(26);
      if (lookahead == ':') ADVANCE(166);
      if (lookahead == '\\') ADVANCE(56);
      if (set_contains(sym_pn_local_character_set_2, 20, lookahead)) ADVANCE(177);
      END_STATE();
    case 162:
      ACCEPT_TOKEN(sym_pn_local);
      if (lookahead == '%') ADVANCE(58);
      if (lookahead == '+') ADVANCE(54);
      if (lookahead == '-') ADVANCE(165);
      if (lookahead == '.') ADVANCE(25);
      if (lookahead == '\\') ADVANCE(56);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(165);
      if (set_contains(sym_pn_local_character_set_2, 20, lookahead)) ADVANCE(166);
      END_STATE();
    case 163:
      ACCEPT_TOKEN(sym_pn_local);
      if (lookahead == '%') ADVANCE(58);
      if (lookahead == '.') ADVANCE(25);
      if (lookahead == ':') ADVANCE(118);
      if (lookahead == '\\') ADVANCE(56);
      if (set_contains(sym_pn_local_character_set_2, 20, lookahead)) ADVANCE(166);
      END_STATE();
    case 164:
      ACCEPT_TOKEN(sym_pn_local);
      if (lookahead == '%') ADVANCE(58);
      if (lookahead == '.') ADVANCE(25);
      if (lookahead == '\\') ADVANCE(56);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(162);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(164);
      if (set_contains(sym_pn_local_character_set_2, 20, lookahead)) ADVANCE(166);
      END_STATE();
    case 165:
      ACCEPT_TOKEN(sym_pn_local);
      if (lookahead == '%') ADVANCE(58);
      if (lookahead == '.') ADVANCE(25);
      if (lookahead == '\\') ADVANCE(56);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(165);
      if (set_contains(sym_pn_local_character_set_2, 20, lookahead)) ADVANCE(166);
      END_STATE();
    case 166:
      ACCEPT_TOKEN(sym_pn_local);
      if (lookahead == '%') ADVANCE(58);
      if (lookahead == '.') ADVANCE(25);
      if (lookahead == '\\') ADVANCE(56);
      if (set_contains(sym_pn_local_character_set_2, 20, lookahead)) ADVANCE(166);
      END_STATE();
    case 167:
      ACCEPT_TOKEN(sym_pn_local);
      if (lookahead == '%') ADVANCE(58);
      if (lookahead == '.') ADVANCE(26);
      if (lookahead == ':') ADVANCE(166);
      if (lookahead == 'E') ADVANCE(171);
      if (lookahead == '\\') ADVANCE(56);
      if (set_contains(sym_pn_local_character_set_2, 20, lookahead)) ADVANCE(177);
      END_STATE();
    case 168:
      ACCEPT_TOKEN(sym_pn_local);
      if (lookahead == '%') ADVANCE(58);
      if (lookahead == '.') ADVANCE(26);
      if (lookahead == ':') ADVANCE(166);
      if (lookahead == 'E') ADVANCE(176);
      if (lookahead == '\\') ADVANCE(56);
      if (set_contains(sym_pn_local_character_set_2, 20, lookahead)) ADVANCE(177);
      END_STATE();
    case 169:
      ACCEPT_TOKEN(sym_pn_local);
      if (lookahead == '%') ADVANCE(58);
      if (lookahead == '.') ADVANCE(26);
      if (lookahead == ':') ADVANCE(166);
      if (lookahead == 'E') ADVANCE(173);
      if (lookahead == '\\') ADVANCE(56);
      if (set_contains(sym_pn_local_character_set_2, 20, lookahead)) ADVANCE(177);
      END_STATE();
    case 170:
      ACCEPT_TOKEN(sym_pn_local);
      if (lookahead == '%') ADVANCE(58);
      if (lookahead == '.') ADVANCE(26);
      if (lookahead == ':') ADVANCE(166);
      if (lookahead == 'E') ADVANCE(160);
      if (lookahead == '\\') ADVANCE(56);
      if (set_contains(sym_pn_local_character_set_2, 20, lookahead)) ADVANCE(177);
      END_STATE();
    case 171:
      ACCEPT_TOKEN(sym_pn_local);
      if (lookahead == '%') ADVANCE(58);
      if (lookahead == '.') ADVANCE(26);
      if (lookahead == ':') ADVANCE(166);
      if (lookahead == 'L') ADVANCE(168);
      if (lookahead == '\\') ADVANCE(56);
      if (set_contains(sym_pn_local_character_set_2, 20, lookahead)) ADVANCE(177);
      END_STATE();
    case 172:
      ACCEPT_TOKEN(sym_pn_local);
      if (lookahead == '%') ADVANCE(58);
      if (lookahead == '.') ADVANCE(26);
      if (lookahead == ':') ADVANCE(166);
      if (lookahead == 'N') ADVANCE(174);
      if (lookahead == '\\') ADVANCE(56);
      if (set_contains(sym_pn_local_character_set_2, 20, lookahead)) ADVANCE(177);
      END_STATE();
    case 173:
      ACCEPT_TOKEN(sym_pn_local);
      if (lookahead == '%') ADVANCE(58);
      if (lookahead == '.') ADVANCE(26);
      if (lookahead == ':') ADVANCE(166);
      if (lookahead == 'R') ADVANCE(175);
      if (lookahead == '\\') ADVANCE(56);
      if (set_contains(sym_pn_local_character_set_2, 20, lookahead)) ADVANCE(177);
      END_STATE();
    case 174:
      ACCEPT_TOKEN(sym_pn_local);
      if (lookahead == '%') ADVANCE(58);
      if (lookahead == '.') ADVANCE(26);
      if (lookahead == ':') ADVANCE(166);
      if (lookahead == 'S') ADVANCE(169);
      if (lookahead == '\\') ADVANCE(56);
      if (set_contains(sym_pn_local_character_set_2, 20, lookahead)) ADVANCE(177);
      END_STATE();
    case 175:
      ACCEPT_TOKEN(sym_pn_local);
      if (lookahead == '%') ADVANCE(58);
      if (lookahead == '.') ADVANCE(26);
      if (lookahead == ':') ADVANCE(166);
      if (lookahead == 'T') ADVANCE(161);
      if (lookahead == '\\') ADVANCE(56);
      if (set_contains(sym_pn_local_character_set_2, 20, lookahead)) ADVANCE(177);
      END_STATE();
    case 176:
      ACCEPT_TOKEN(sym_pn_local);
      if (lookahead == '%') ADVANCE(58);
      if (lookahead == '.') ADVANCE(26);
      if (lookahead == ':') ADVANCE(166);
      if (lookahead == 'T') ADVANCE(170);
      if (lookahead == '\\') ADVANCE(56);
      if (set_contains(sym_pn_local_character_set_2, 20, lookahead)) ADVANCE(177);
      END_STATE();
    case 177:
      ACCEPT_TOKEN(sym_pn_local);
      if (lookahead == '%') ADVANCE(58);
      if (lookahead == '.') ADVANCE(26);
      if (lookahead == ':') ADVANCE(166);
      if (lookahead == '\\') ADVANCE(56);
      if (set_contains(sym_pn_local_character_set_2, 20, lookahead)) ADVANCE(177);
      END_STATE();
    case 178:
      ACCEPT_TOKEN(sym_pn_local);
      if (lookahead == '%') ADVANCE(58);
      if (lookahead == '.') ADVANCE(24);
      if (lookahead == '\\') ADVANCE(56);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(162);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(178);
      if (set_contains(sym_pn_local_character_set_2, 20, lookahead)) ADVANCE(166);
      END_STATE();
    default:
      return false;
  }
}

static bool ts_lex_keywords(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      ADVANCE_MAP(
        'A', 1,
        'F', 2,
        'G', 3,
        'I', 4,
        'S', 5,
        'T', 6,
        'a', 7,
        'f', 8,
        'g', 9,
        'i', 10,
        's', 11,
        't', 12,
        'B', 13,
        'b', 13,
        'C', 14,
        'c', 14,
        'D', 15,
        'd', 15,
        'E', 16,
        'e', 16,
        'H', 17,
        'h', 17,
        'L', 18,
        'l', 18,
        'M', 19,
        'm', 19,
        'N', 20,
        'n', 20,
        'O', 21,
        'o', 21,
        'P', 22,
        'p', 22,
        'R', 23,
        'r', 23,
        'U', 24,
        'u', 24,
        'V', 25,
        'v', 25,
        'W', 26,
        'w', 26,
        'Y', 27,
        'y', 27,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(0);
      END_STATE();
    case 1:
      ADVANCE_MAP(
        'B', 28,
        'b', 28,
        'D', 29,
        'd', 29,
        'L', 30,
        'l', 30,
        'S', 31,
        's', 31,
        'V', 32,
        'v', 32,
      );
      END_STATE();
    case 2:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(33);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(34);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(35);
      END_STATE();
    case 3:
      if (lookahead == 'R') ADVANCE(36);
      if (lookahead == 'r') ADVANCE(37);
      END_STATE();
    case 4:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(38);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(39);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(40);
      END_STATE();
    case 5:
      ADVANCE_MAP(
        'A', 41,
        'a', 41,
        'E', 42,
        'e', 42,
        'H', 43,
        'h', 43,
        'I', 44,
        'i', 44,
        'T', 45,
        't', 45,
        'U', 46,
        'u', 46,
      );
      END_STATE();
    case 6:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(47);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(48);
      if (lookahead == 'Z' ||
          lookahead == 'z') ADVANCE(49);
      END_STATE();
    case 7:
      ACCEPT_TOKEN(anon_sym_a);
      ADVANCE_MAP(
        'B', 28,
        'b', 28,
        'D', 29,
        'd', 29,
        'L', 30,
        'l', 30,
        'S', 31,
        's', 31,
        'V', 32,
        'v', 32,
      );
      END_STATE();
    case 8:
      if (lookahead == 'a') ADVANCE(50);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(33);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(34);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(35);
      END_STATE();
    case 9:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(37);
      END_STATE();
    case 10:
      if (lookahead == 's') ADVANCE(51);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(38);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(39);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(40);
      END_STATE();
    case 11:
      ADVANCE_MAP(
        'A', 41,
        'a', 52,
        'E', 42,
        'e', 42,
        'H', 43,
        'h', 43,
        'I', 44,
        'i', 44,
        'T', 45,
        't', 45,
        'U', 46,
        'u', 46,
      );
      END_STATE();
    case 12:
      if (lookahead == 'r') ADVANCE(53);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(47);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(48);
      if (lookahead == 'Z' ||
          lookahead == 'z') ADVANCE(49);
      END_STATE();
    case 13:
      ADVANCE_MAP(
        'A', 54,
        'a', 54,
        'I', 55,
        'i', 55,
        'N', 56,
        'n', 56,
        'O', 57,
        'o', 57,
        'Y', 58,
        'y', 58,
      );
      END_STATE();
    case 14:
      ADVANCE_MAP(
        'E', 59,
        'e', 59,
        'L', 60,
        'l', 60,
        'O', 61,
        'o', 61,
        'R', 62,
        'r', 62,
      );
      END_STATE();
    case 15:
      ADVANCE_MAP(
        'A', 63,
        'a', 63,
        'E', 64,
        'e', 64,
        'I', 65,
        'i', 65,
        'R', 66,
        'r', 66,
      );
      END_STATE();
    case 16:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(67);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(68);
      END_STATE();
    case 17:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(69);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(70);
      END_STATE();
    case 18:
      ADVANCE_MAP(
        'A', 71,
        'a', 71,
        'C', 72,
        'c', 72,
        'I', 73,
        'i', 73,
        'O', 74,
        'o', 74,
      );
      END_STATE();
    case 19:
      ADVANCE_MAP(
        'A', 75,
        'a', 75,
        'D', 76,
        'd', 76,
        'I', 77,
        'i', 77,
        'O', 78,
        'o', 78,
      );
      END_STATE();
    case 20:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(79);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(80);
      END_STATE();
    case 21:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(81);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(82);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(83);
      END_STATE();
    case 22:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(84);
      END_STATE();
    case 23:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(85);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(86);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(87);
      END_STATE();
    case 24:
      ADVANCE_MAP(
        'C', 88,
        'c', 88,
        'N', 89,
        'n', 89,
        'R', 90,
        'r', 90,
        'S', 91,
        's', 91,
        'U', 92,
        'u', 92,
      );
      END_STATE();
    case 25:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(93);
      END_STATE();
    case 26:
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(94);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(95);
      END_STATE();
    case 27:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(96);
      END_STATE();
    case 28:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(97);
      END_STATE();
    case 29:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(98);
      END_STATE();
    case 30:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(99);
      END_STATE();
    case 31:
      ACCEPT_TOKEN(aux_sym_select_clause_token4);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(100);
      if (lookahead == 'K' ||
          lookahead == 'k') ADVANCE(101);
      END_STATE();
    case 32:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(102);
      END_STATE();
    case 33:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(103);
      END_STATE();
    case 34:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(104);
      END_STATE();
    case 35:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(105);
      END_STATE();
    case 36:
      if (lookahead == 'O') ADVANCE(106);
      if (lookahead == 'o') ADVANCE(107);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(108);
      END_STATE();
    case 37:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(108);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(107);
      END_STATE();
    case 38:
      ACCEPT_TOKEN(aux_sym_build_in_function_token3);
      END_STATE();
    case 39:
      ACCEPT_TOKEN(aux_sym_binary_expression_token1);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(109);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(110);
      END_STATE();
    case 40:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(111);
      END_STATE();
    case 41:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(112);
      END_STATE();
    case 42:
      ADVANCE_MAP(
        'C', 113,
        'c', 113,
        'L', 114,
        'l', 114,
        'P', 115,
        'p', 115,
        'R', 116,
        'r', 116,
      );
      END_STATE();
    case 43:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(117);
      END_STATE();
    case 44:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(118);
      END_STATE();
    case 45:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(119);
      END_STATE();
    case 46:
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(120);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(121);
      END_STATE();
    case 47:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(122);
      END_STATE();
    case 48:
      ACCEPT_TOKEN(aux_sym_add_token2);
      END_STATE();
    case 49:
      ACCEPT_TOKEN(aux_sym__unary_build_in_function_token23);
      END_STATE();
    case 50:
      if (lookahead == 'l') ADVANCE(123);
      END_STATE();
    case 51:
      ADVANCE_MAP(
        'B', 124,
        'b', 124,
        'I', 125,
        'i', 125,
        'L', 126,
        'l', 126,
        'N', 127,
        'n', 127,
        'U', 128,
        'u', 128,
      );
      END_STATE();
    case 52:
      if (lookahead == 'M') ADVANCE(112);
      if (lookahead == 'm') ADVANCE(129);
      END_STATE();
    case 53:
      if (lookahead == 'u') ADVANCE(130);
      END_STATE();
    case 54:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(131);
      END_STATE();
    case 55:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(132);
      END_STATE();
    case 56:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(133);
      END_STATE();
    case 57:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(134);
      END_STATE();
    case 58:
      ACCEPT_TOKEN(aux_sym_group_clause_token2);
      END_STATE();
    case 59:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(135);
      END_STATE();
    case 60:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(136);
      END_STATE();
    case 61:
      ADVANCE_MAP(
        'A', 137,
        'a', 137,
        'N', 138,
        'n', 138,
        'P', 139,
        'p', 139,
        'U', 140,
        'u', 140,
      );
      END_STATE();
    case 62:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(141);
      END_STATE();
    case 63:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(142);
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(143);
      END_STATE();
    case 64:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(144);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(145);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(146);
      END_STATE();
    case 65:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(147);
      END_STATE();
    case 66:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(148);
      END_STATE();
    case 67:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(149);
      END_STATE();
    case 68:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(150);
      END_STATE();
    case 69:
      if (lookahead == 'V' ||
          lookahead == 'v') ADVANCE(151);
      END_STATE();
    case 70:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(152);
      END_STATE();
    case 71:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(153);
      END_STATE();
    case 72:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(154);
      END_STATE();
    case 73:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(155);
      END_STATE();
    case 74:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(156);
      END_STATE();
    case 75:
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(157);
      END_STATE();
    case 76:
      if (lookahead == '5') ADVANCE(158);
      END_STATE();
    case 77:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(159);
      END_STATE();
    case 78:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(160);
      if (lookahead == 'V' ||
          lookahead == 'v') ADVANCE(161);
      END_STATE();
    case 79:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(162);
      END_STATE();
    case 80:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(163);
      if (lookahead == 'W' ||
          lookahead == 'w') ADVANCE(164);
      END_STATE();
    case 81:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(165);
      END_STATE();
    case 82:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(166);
      END_STATE();
    case 83:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(167);
      END_STATE();
    case 84:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(168);
      END_STATE();
    case 85:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(169);
      END_STATE();
    case 86:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(170);
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(171);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(172);
      END_STATE();
    case 87:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(173);
      END_STATE();
    case 88:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(174);
      END_STATE();
    case 89:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(175);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(176);
      END_STATE();
    case 90:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(177);
      END_STATE();
    case 91:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(178);
      END_STATE();
    case 92:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(179);
      END_STATE();
    case 93:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(180);
      END_STATE();
    case 94:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(181);
      END_STATE();
    case 95:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(182);
      END_STATE();
    case 96:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(183);
      END_STATE();
    case 97:
      ACCEPT_TOKEN(aux_sym__unary_build_in_function_token1);
      END_STATE();
    case 98:
      ACCEPT_TOKEN(aux_sym_add_token1);
      END_STATE();
    case 99:
      ACCEPT_TOKEN(aux_sym_graph_ref_all_token1);
      END_STATE();
    case 100:
      ACCEPT_TOKEN(aux_sym_order_condition_token1);
      END_STATE();
    case 101:
      ACCEPT_TOKEN(aux_sym_ask_query_token1);
      END_STATE();
    case 102:
      ACCEPT_TOKEN(aux_sym_aggregate_token5);
      END_STATE();
    case 103:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(184);
      END_STATE();
    case 104:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(185);
      END_STATE();
    case 105:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(186);
      END_STATE();
    case 106:
      if (lookahead == 'U') ADVANCE(187);
      if (lookahead == 'u') ADVANCE(188);
      END_STATE();
    case 107:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(188);
      END_STATE();
    case 108:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(189);
      END_STATE();
    case 109:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(190);
      END_STATE();
    case 110:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(191);
      END_STATE();
    case 111:
      ACCEPT_TOKEN(aux_sym__unary_build_in_function_token8);
      END_STATE();
    case 112:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(192);
      END_STATE();
    case 113:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(193);
      END_STATE();
    case 114:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(194);
      END_STATE();
    case 115:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(195);
      END_STATE();
    case 116:
      if (lookahead == 'V' ||
          lookahead == 'v') ADVANCE(196);
      END_STATE();
    case 117:
      if (lookahead == '1') ADVANCE(197);
      if (lookahead == '2') ADVANCE(198);
      if (lookahead == '3') ADVANCE(199);
      if (lookahead == '5') ADVANCE(200);
      END_STATE();
    case 118:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(201);
      END_STATE();
    case 119:
      ACCEPT_TOKEN(aux_sym__unary_build_in_function_token20);
      ADVANCE_MAP(
        'A', 202,
        'a', 202,
        'B', 203,
        'b', 203,
        'D', 204,
        'd', 204,
        'E', 205,
        'e', 205,
        'L', 206,
        'l', 206,
        'S', 207,
        's', 207,
        'U', 208,
        'u', 208,
      );
      END_STATE();
    case 120:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(209);
      END_STATE();
    case 121:
      ACCEPT_TOKEN(aux_sym_aggregate_token2);
      END_STATE();
    case 122:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(210);
      END_STATE();
    case 123:
      if (lookahead == 's') ADVANCE(211);
      END_STATE();
    case 124:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(212);
      END_STATE();
    case 125:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(213);
      END_STATE();
    case 126:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(214);
      END_STATE();
    case 127:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(215);
      END_STATE();
    case 128:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(216);
      END_STATE();
    case 129:
      if (lookahead == 'e') ADVANCE(217);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(192);
      END_STATE();
    case 130:
      if (lookahead == 'e') ADVANCE(218);
      END_STATE();
    case 131:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(219);
      END_STATE();
    case 132:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(220);
      END_STATE();
    case 133:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(221);
      END_STATE();
    case 134:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(222);
      END_STATE();
    case 135:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(223);
      END_STATE();
    case 136:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(224);
      END_STATE();
    case 137:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(225);
      END_STATE();
    case 138:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(226);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(227);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(228);
      END_STATE();
    case 139:
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(229);
      END_STATE();
    case 140:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(230);
      END_STATE();
    case 141:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(231);
      END_STATE();
    case 142:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(232);
      END_STATE();
    case 143:
      ACCEPT_TOKEN(aux_sym__unary_build_in_function_token4);
      END_STATE();
    case 144:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(233);
      END_STATE();
    case 145:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(234);
      END_STATE();
    case 146:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(235);
      END_STATE();
    case 147:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(236);
      END_STATE();
    case 148:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(237);
      END_STATE();
    case 149:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(238);
      END_STATE();
    case 150:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(239);
      END_STATE();
    case 151:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(240);
      END_STATE();
    case 152:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(241);
      END_STATE();
    case 153:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(242);
      END_STATE();
    case 154:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(243);
      END_STATE();
    case 155:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(244);
      END_STATE();
    case 156:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(245);
      END_STATE();
    case 157:
      ACCEPT_TOKEN(aux_sym_aggregate_token4);
      END_STATE();
    case 158:
      ACCEPT_TOKEN(aux_sym__unary_build_in_function_token11);
      END_STATE();
    case 159:
      ACCEPT_TOKEN(aux_sym_aggregate_token3);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(246);
      END_STATE();
    case 160:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(247);
      END_STATE();
    case 161:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(248);
      END_STATE();
    case 162:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(249);
      END_STATE();
    case 163:
      ACCEPT_TOKEN(aux_sym_binary_expression_token2);
      END_STATE();
    case 164:
      ACCEPT_TOKEN(aux_sym__nullary_build_in_function_token1);
      END_STATE();
    case 165:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(250);
      END_STATE();
    case 166:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(251);
      END_STATE();
    case 167:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(252);
      END_STATE();
    case 168:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(253);
      END_STATE();
    case 169:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(254);
      END_STATE();
    case 170:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(255);
      END_STATE();
    case 171:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(256);
      END_STATE();
    case 172:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(257);
      END_STATE();
    case 173:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(258);
      END_STATE();
    case 174:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(259);
      END_STATE();
    case 175:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(260);
      END_STATE();
    case 176:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(261);
      END_STATE();
    case 177:
      ACCEPT_TOKEN(aux_sym__unary_build_in_function_token25);
      END_STATE();
    case 178:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(262);
      END_STATE();
    case 179:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(263);
      END_STATE();
    case 180:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(264);
      END_STATE();
    case 181:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(265);
      END_STATE();
    case 182:
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(266);
      END_STATE();
    case 183:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(267);
      END_STATE();
    case 184:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(268);
      END_STATE();
    case 185:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(269);
      END_STATE();
    case 186:
      ACCEPT_TOKEN(aux_sym_dataset_clause_token1);
      END_STATE();
    case 187:
      if (lookahead == 'P') ADVANCE(270);
      if (lookahead == 'p') ADVANCE(271);
      END_STATE();
    case 188:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(271);
      END_STATE();
    case 189:
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(272);
      END_STATE();
    case 190:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(273);
      END_STATE();
    case 191:
      ACCEPT_TOKEN(aux_sym_load_token3);
      END_STATE();
    case 192:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(274);
      END_STATE();
    case 193:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(275);
      END_STATE();
    case 194:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(276);
      END_STATE();
    case 195:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(277);
      END_STATE();
    case 196:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(278);
      END_STATE();
    case 197:
      ACCEPT_TOKEN(aux_sym__unary_build_in_function_token16);
      END_STATE();
    case 198:
      if (lookahead == '5') ADVANCE(279);
      END_STATE();
    case 199:
      if (lookahead == '8') ADVANCE(280);
      END_STATE();
    case 200:
      if (lookahead == '1') ADVANCE(281);
      END_STATE();
    case 201:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(282);
      END_STATE();
    case 202:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(283);
      END_STATE();
    case 203:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(284);
      END_STATE();
    case 204:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(285);
      END_STATE();
    case 205:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(286);
      END_STATE();
    case 206:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(287);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(288);
      END_STATE();
    case 207:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(289);
      END_STATE();
    case 208:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(290);
      END_STATE();
    case 209:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(291);
      END_STATE();
    case 210:
      if (lookahead == 'Z' ||
          lookahead == 'z') ADVANCE(292);
      END_STATE();
    case 211:
      if (lookahead == 'e') ADVANCE(293);
      END_STATE();
    case 212:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(294);
      END_STATE();
    case 213:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(295);
      END_STATE();
    case 214:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(296);
      END_STATE();
    case 215:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(297);
      END_STATE();
    case 216:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(298);
      END_STATE();
    case 217:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(299);
      END_STATE();
    case 218:
      ACCEPT_TOKEN(anon_sym_true);
      END_STATE();
    case 219:
      ACCEPT_TOKEN(aux_sym_base_declaration_token1);
      END_STATE();
    case 220:
      ACCEPT_TOKEN(aux_sym_bind_token1);
      END_STATE();
    case 221:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(300);
      END_STATE();
    case 222:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(301);
      END_STATE();
    case 223:
      ACCEPT_TOKEN(aux_sym__unary_build_in_function_token2);
      END_STATE();
    case 224:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(302);
      END_STATE();
    case 225:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(303);
      END_STATE();
    case 226:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(304);
      END_STATE();
    case 227:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(305);
      END_STATE();
    case 228:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(306);
      END_STATE();
    case 229:
      ACCEPT_TOKEN(aux_sym_copy_token1);
      END_STATE();
    case 230:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(307);
      END_STATE();
    case 231:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(308);
      END_STATE();
    case 232:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(309);
      END_STATE();
    case 233:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(310);
      END_STATE();
    case 234:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(311);
      END_STATE();
    case 235:
      ACCEPT_TOKEN(aux_sym_order_condition_token2);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(312);
      END_STATE();
    case 236:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(313);
      END_STATE();
    case 237:
      ACCEPT_TOKEN(aux_sym_drop_token1);
      END_STATE();
    case 238:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(314);
      END_STATE();
    case 239:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(315);
      END_STATE();
    case 240:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(316);
      END_STATE();
    case 241:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(317);
      END_STATE();
    case 242:
      ACCEPT_TOKEN(aux_sym__unary_build_in_function_token9);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(318);
      END_STATE();
    case 243:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(319);
      END_STATE();
    case 244:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(320);
      END_STATE();
    case 245:
      ACCEPT_TOKEN(aux_sym_load_token1);
      END_STATE();
    case 246:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(321);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(322);
      END_STATE();
    case 247:
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(323);
      END_STATE();
    case 248:
      ACCEPT_TOKEN(aux_sym_move_token1);
      END_STATE();
    case 249:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(324);
      END_STATE();
    case 250:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(325);
      END_STATE();
    case 251:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(326);
      END_STATE();
    case 252:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(327);
      END_STATE();
    case 253:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(328);
      END_STATE();
    case 254:
      ACCEPT_TOKEN(aux_sym__nullary_build_in_function_token2);
      END_STATE();
    case 255:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(329);
      END_STATE();
    case 256:
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(330);
      END_STATE();
    case 257:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(331);
      END_STATE();
    case 258:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(332);
      END_STATE();
    case 259:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(333);
      END_STATE();
    case 260:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(334);
      END_STATE();
    case 261:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(335);
      END_STATE();
    case 262:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(336);
      END_STATE();
    case 263:
      ACCEPT_TOKEN(aux_sym__nullary_build_in_function_token4);
      END_STATE();
    case 264:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(337);
      END_STATE();
    case 265:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(338);
      END_STATE();
    case 266:
      ACCEPT_TOKEN(aux_sym_modify_token1);
      END_STATE();
    case 267:
      ACCEPT_TOKEN(aux_sym__unary_build_in_function_token26);
      END_STATE();
    case 268:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(339);
      END_STATE();
    case 269:
      ACCEPT_TOKEN(aux_sym__unary_build_in_function_token6);
      END_STATE();
    case 270:
      ACCEPT_TOKEN(aux_sym_group_clause_token1);
      if (lookahead == '_') ADVANCE(340);
      END_STATE();
    case 271:
      ACCEPT_TOKEN(aux_sym_group_clause_token1);
      END_STATE();
    case 272:
      ACCEPT_TOKEN(aux_sym_graph_or_default_token2);
      END_STATE();
    case 273:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(341);
      END_STATE();
    case 274:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(342);
      END_STATE();
    case 275:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(343);
      END_STATE();
    case 276:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(344);
      END_STATE();
    case 277:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(345);
      END_STATE();
    case 278:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(346);
      END_STATE();
    case 279:
      if (lookahead == '6') ADVANCE(347);
      END_STATE();
    case 280:
      if (lookahead == '4') ADVANCE(348);
      END_STATE();
    case 281:
      if (lookahead == '2') ADVANCE(349);
      END_STATE();
    case 282:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(350);
      END_STATE();
    case 283:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(351);
      END_STATE();
    case 284:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(352);
      END_STATE();
    case 285:
      ACCEPT_TOKEN(aux_sym__binary_build_in_function_token5);
      END_STATE();
    case 286:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(353);
      END_STATE();
    case 287:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(354);
      END_STATE();
    case 288:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(355);
      END_STATE();
    case 289:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(356);
      END_STATE();
    case 290:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(357);
      END_STATE();
    case 291:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(358);
      END_STATE();
    case 292:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(359);
      END_STATE();
    case 293:
      ACCEPT_TOKEN(anon_sym_false);
      END_STATE();
    case 294:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(360);
      END_STATE();
    case 295:
      ACCEPT_TOKEN(aux_sym__unary_build_in_function_token28);
      END_STATE();
    case 296:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(361);
      END_STATE();
    case 297:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(362);
      END_STATE();
    case 298:
      ACCEPT_TOKEN(aux_sym__unary_build_in_function_token31);
      END_STATE();
    case 299:
      if (lookahead == 'e') ADVANCE(363);
      END_STATE();
    case 300:
      ACCEPT_TOKEN(aux_sym_build_in_function_token2);
      END_STATE();
    case 301:
      ACCEPT_TOKEN(aux_sym_build_in_function_token1);
      END_STATE();
    case 302:
      ACCEPT_TOKEN(aux_sym_clear_token1);
      END_STATE();
    case 303:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(364);
      END_STATE();
    case 304:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(365);
      END_STATE();
    case 305:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(366);
      END_STATE();
    case 306:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(367);
      END_STATE();
    case 307:
      ACCEPT_TOKEN(aux_sym_aggregate_token1);
      END_STATE();
    case 308:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(368);
      END_STATE();
    case 309:
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(369);
      END_STATE();
    case 310:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(370);
      END_STATE();
    case 311:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(371);
      END_STATE();
    case 312:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(372);
      END_STATE();
    case 313:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(373);
      END_STATE();
    case 314:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(374);
      END_STATE();
    case 315:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(375);
      END_STATE();
    case 316:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(376);
      END_STATE();
    case 317:
      ACCEPT_TOKEN(aux_sym__unary_build_in_function_token7);
      END_STATE();
    case 318:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(377);
      END_STATE();
    case 319:
      ACCEPT_TOKEN(aux_sym__unary_build_in_function_token10);
      END_STATE();
    case 320:
      ACCEPT_TOKEN(aux_sym_limit_clause_token1);
      END_STATE();
    case 321:
      ACCEPT_TOKEN(aux_sym_minus_graph_pattern_token1);
      END_STATE();
    case 322:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(378);
      END_STATE();
    case 323:
      ACCEPT_TOKEN(aux_sym__unary_build_in_function_token13);
      END_STATE();
    case 324:
      ACCEPT_TOKEN(aux_sym_named_graph_clause_token1);
      END_STATE();
    case 325:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(379);
      END_STATE();
    case 326:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(380);
      END_STATE();
    case 327:
      ACCEPT_TOKEN(aux_sym_order_clause_token1);
      END_STATE();
    case 328:
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(381);
      END_STATE();
    case 329:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(382);
      END_STATE();
    case 330:
      ACCEPT_TOKEN(aux_sym_regex_expression_token1);
      END_STATE();
    case 331:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(383);
      END_STATE();
    case 332:
      ACCEPT_TOKEN(aux_sym__unary_build_in_function_token14);
      END_STATE();
    case 333:
      ACCEPT_TOKEN(aux_sym__unary_build_in_function_token24);
      END_STATE();
    case 334:
      ACCEPT_TOKEN(aux_sym__data_block_value_token1);
      END_STATE();
    case 335:
      ACCEPT_TOKEN(aux_sym_group_or_union_graph_pattern_token1);
      END_STATE();
    case 336:
      ACCEPT_TOKEN(aux_sym_using_clause_token1);
      END_STATE();
    case 337:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(384);
      END_STATE();
    case 338:
      ACCEPT_TOKEN(aux_sym_construct_query_token2);
      END_STATE();
    case 339:
      ACCEPT_TOKEN(aux_sym_filter_token1);
      END_STATE();
    case 340:
      if (lookahead == 'C') ADVANCE(385);
      END_STATE();
    case 341:
      ACCEPT_TOKEN(aux_sym_insert_clause_token1);
      END_STATE();
    case 342:
      ACCEPT_TOKEN(aux_sym_aggregate_token6);
      END_STATE();
    case 343:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(386);
      END_STATE();
    case 344:
      ACCEPT_TOKEN(aux_sym_select_clause_token1);
      END_STATE();
    case 345:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(387);
      END_STATE();
    case 346:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(388);
      END_STATE();
    case 347:
      ACCEPT_TOKEN(aux_sym__unary_build_in_function_token17);
      END_STATE();
    case 348:
      ACCEPT_TOKEN(aux_sym__unary_build_in_function_token18);
      END_STATE();
    case 349:
      ACCEPT_TOKEN(aux_sym__unary_build_in_function_token19);
      END_STATE();
    case 350:
      ACCEPT_TOKEN(aux_sym_load_token2);
      END_STATE();
    case 351:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(389);
      END_STATE();
    case 352:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(390);
      END_STATE();
    case 353:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(391);
      END_STATE();
    case 354:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(392);
      END_STATE();
    case 355:
      ACCEPT_TOKEN(aux_sym__unary_build_in_function_token21);
      END_STATE();
    case 356:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(393);
      END_STATE();
    case 357:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(394);
      END_STATE();
    case 358:
      ACCEPT_TOKEN(aux_sym_substring_expression_token1);
      END_STATE();
    case 359:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(395);
      END_STATE();
    case 360:
      if (lookahead == 'K' ||
          lookahead == 'k') ADVANCE(396);
      END_STATE();
    case 361:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(397);
      END_STATE();
    case 362:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(398);
      END_STATE();
    case 363:
      if (lookahead == 'r') ADVANCE(399);
      END_STATE();
    case 364:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(400);
      END_STATE();
    case 365:
      ACCEPT_TOKEN(aux_sym__variadic_build_in_function_token1);
      END_STATE();
    case 366:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(401);
      END_STATE();
    case 367:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(402);
      END_STATE();
    case 368:
      ACCEPT_TOKEN(aux_sym_create_token1);
      END_STATE();
    case 369:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(403);
      END_STATE();
    case 370:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(404);
      END_STATE();
    case 371:
      ACCEPT_TOKEN(aux_sym_delete_clause_token1);
      END_STATE();
    case 372:
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(405);
      END_STATE();
    case 373:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(406);
      END_STATE();
    case 374:
      if (lookahead == '_') ADVANCE(407);
      END_STATE();
    case 375:
      ACCEPT_TOKEN(aux_sym_exists_func_token1);
      END_STATE();
    case 376:
      ACCEPT_TOKEN(aux_sym_having_clause_token1);
      END_STATE();
    case 377:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(408);
      END_STATE();
    case 378:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(409);
      END_STATE();
    case 379:
      ACCEPT_TOKEN(aux_sym_offset_clause_token1);
      END_STATE();
    case 380:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(410);
      END_STATE();
    case 381:
      ACCEPT_TOKEN(aux_sym_prefix_declaration_token1);
      END_STATE();
    case 382:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(411);
      END_STATE();
    case 383:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(412);
      END_STATE();
    case 384:
      ACCEPT_TOKEN(aux_sym_values_clause_token1);
      END_STATE();
    case 385:
      if (lookahead == 'O') ADVANCE(413);
      END_STATE();
    case 386:
      ACCEPT_TOKEN(aux_sym__unary_build_in_function_token15);
      END_STATE();
    case 387:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(414);
      END_STATE();
    case 388:
      ACCEPT_TOKEN(aux_sym_service_graph_pattern_token1);
      END_STATE();
    case 389:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(415);
      END_STATE();
    case 390:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(416);
      END_STATE();
    case 391:
      ACCEPT_TOKEN(aux_sym__binary_build_in_function_token6);
      END_STATE();
    case 392:
      ACCEPT_TOKEN(aux_sym__binary_build_in_function_token7);
      END_STATE();
    case 393:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(417);
      END_STATE();
    case 394:
      ACCEPT_TOKEN(aux_sym__nullary_build_in_function_token3);
      END_STATE();
    case 395:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(418);
      END_STATE();
    case 396:
      ACCEPT_TOKEN(aux_sym__unary_build_in_function_token27);
      END_STATE();
    case 397:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(419);
      END_STATE();
    case 398:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(420);
      END_STATE();
    case 399:
      if (lookahead == 'm') ADVANCE(421);
      END_STATE();
    case 400:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(422);
      END_STATE();
    case 401:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(423);
      END_STATE();
    case 402:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(424);
      END_STATE();
    case 403:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(425);
      END_STATE();
    case 404:
      ACCEPT_TOKEN(aux_sym_graph_or_default_token1);
      END_STATE();
    case 405:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(426);
      END_STATE();
    case 406:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(427);
      END_STATE();
    case 407:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(428);
      END_STATE();
    case 408:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(429);
      END_STATE();
    case 409:
      ACCEPT_TOKEN(aux_sym__unary_build_in_function_token12);
      END_STATE();
    case 410:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(430);
      END_STATE();
    case 411:
      ACCEPT_TOKEN(aux_sym_select_clause_token3);
      END_STATE();
    case 412:
      ACCEPT_TOKEN(aux_sym_string_replace_expression_token1);
      END_STATE();
    case 413:
      if (lookahead == 'N') ADVANCE(431);
      END_STATE();
    case 414:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(432);
      END_STATE();
    case 415:
      ACCEPT_TOKEN(aux_sym__binary_build_in_function_token3);
      END_STATE();
    case 416:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(433);
      END_STATE();
    case 417:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(434);
      END_STATE();
    case 418:
      ACCEPT_TOKEN(aux_sym__unary_build_in_function_token22);
      END_STATE();
    case 419:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(435);
      END_STATE();
    case 420:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(436);
      END_STATE();
    case 421:
      ACCEPT_TOKEN(aux_sym__binary_build_in_function_token9);
      END_STATE();
    case 422:
      ACCEPT_TOKEN(aux_sym__variadic_build_in_function_token2);
      END_STATE();
    case 423:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(437);
      END_STATE();
    case 424:
      ACCEPT_TOKEN(aux_sym__binary_build_in_function_token1);
      END_STATE();
    case 425:
      ACCEPT_TOKEN(aux_sym__unary_build_in_function_token3);
      END_STATE();
    case 426:
      ACCEPT_TOKEN(aux_sym_describe_query_token1);
      END_STATE();
    case 427:
      ACCEPT_TOKEN(aux_sym_select_clause_token2);
      END_STATE();
    case 428:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(438);
      END_STATE();
    case 429:
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(439);
      END_STATE();
    case 430:
      ACCEPT_TOKEN(aux_sym_optional_graph_pattern_token1);
      END_STATE();
    case 431:
      if (lookahead == 'C') ADVANCE(440);
      END_STATE();
    case 432:
      ACCEPT_TOKEN(aux_sym_aggregate_token7);
      END_STATE();
    case 433:
      ACCEPT_TOKEN(aux_sym__binary_build_in_function_token4);
      END_STATE();
    case 434:
      ACCEPT_TOKEN(aux_sym__binary_build_in_function_token8);
      END_STATE();
    case 435:
      ACCEPT_TOKEN(aux_sym__unary_build_in_function_token29);
      END_STATE();
    case 436:
      ACCEPT_TOKEN(aux_sym__unary_build_in_function_token30);
      END_STATE();
    case 437:
      ACCEPT_TOKEN(aux_sym_construct_query_token1);
      END_STATE();
    case 438:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(441);
      END_STATE();
    case 439:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(442);
      END_STATE();
    case 440:
      if (lookahead == 'A') ADVANCE(443);
      END_STATE();
    case 441:
      if (lookahead == '_') ADVANCE(444);
      END_STATE();
    case 442:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(445);
      END_STATE();
    case 443:
      if (lookahead == 'T') ADVANCE(446);
      END_STATE();
    case 444:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(447);
      END_STATE();
    case 445:
      ACCEPT_TOKEN(aux_sym__binary_build_in_function_token2);
      END_STATE();
    case 446:
      ACCEPT_TOKEN(anon_sym_GROUP_CONCAT);
      END_STATE();
    case 447:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(448);
      END_STATE();
    case 448:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(449);
      END_STATE();
    case 449:
      ACCEPT_TOKEN(aux_sym__unary_build_in_function_token5);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0},
  [1] = {.lex_state = 0},
  [2] = {.lex_state = 63},
  [3] = {.lex_state = 63},
  [4] = {.lex_state = 1},
  [5] = {.lex_state = 1},
  [6] = {.lex_state = 1},
  [7] = {.lex_state = 1},
  [8] = {.lex_state = 1},
  [9] = {.lex_state = 1},
  [10] = {.lex_state = 1},
  [11] = {.lex_state = 63},
  [12] = {.lex_state = 63},
  [13] = {.lex_state = 1},
  [14] = {.lex_state = 63},
  [15] = {.lex_state = 63},
  [16] = {.lex_state = 1},
  [17] = {.lex_state = 1},
  [18] = {.lex_state = 1},
  [19] = {.lex_state = 1},
  [20] = {.lex_state = 1},
  [21] = {.lex_state = 1},
  [22] = {.lex_state = 1},
  [23] = {.lex_state = 1},
  [24] = {.lex_state = 1},
  [25] = {.lex_state = 1},
  [26] = {.lex_state = 1},
  [27] = {.lex_state = 1},
  [28] = {.lex_state = 1},
  [29] = {.lex_state = 1},
  [30] = {.lex_state = 1},
  [31] = {.lex_state = 1},
  [32] = {.lex_state = 1},
  [33] = {.lex_state = 1},
  [34] = {.lex_state = 1},
  [35] = {.lex_state = 1},
  [36] = {.lex_state = 1},
  [37] = {.lex_state = 1},
  [38] = {.lex_state = 1},
  [39] = {.lex_state = 1},
  [40] = {.lex_state = 1},
  [41] = {.lex_state = 1},
  [42] = {.lex_state = 1},
  [43] = {.lex_state = 1},
  [44] = {.lex_state = 1},
  [45] = {.lex_state = 1},
  [46] = {.lex_state = 1},
  [47] = {.lex_state = 1},
  [48] = {.lex_state = 1},
  [49] = {.lex_state = 1},
  [50] = {.lex_state = 1},
  [51] = {.lex_state = 1},
  [52] = {.lex_state = 1},
  [53] = {.lex_state = 1},
  [54] = {.lex_state = 1},
  [55] = {.lex_state = 1},
  [56] = {.lex_state = 1},
  [57] = {.lex_state = 1},
  [58] = {.lex_state = 1},
  [59] = {.lex_state = 1},
  [60] = {.lex_state = 1},
  [61] = {.lex_state = 1},
  [62] = {.lex_state = 1},
  [63] = {.lex_state = 1},
  [64] = {.lex_state = 1},
  [65] = {.lex_state = 1},
  [66] = {.lex_state = 1},
  [67] = {.lex_state = 1},
  [68] = {.lex_state = 1},
  [69] = {.lex_state = 1},
  [70] = {.lex_state = 1},
  [71] = {.lex_state = 1},
  [72] = {.lex_state = 1},
  [73] = {.lex_state = 1},
  [74] = {.lex_state = 1},
  [75] = {.lex_state = 1},
  [76] = {.lex_state = 1},
  [77] = {.lex_state = 1},
  [78] = {.lex_state = 1},
  [79] = {.lex_state = 1},
  [80] = {.lex_state = 1},
  [81] = {.lex_state = 1},
  [82] = {.lex_state = 1},
  [83] = {.lex_state = 1},
  [84] = {.lex_state = 1},
  [85] = {.lex_state = 1},
  [86] = {.lex_state = 1},
  [87] = {.lex_state = 1},
  [88] = {.lex_state = 1},
  [89] = {.lex_state = 1},
  [90] = {.lex_state = 1},
  [91] = {.lex_state = 1},
  [92] = {.lex_state = 1},
  [93] = {.lex_state = 1},
  [94] = {.lex_state = 1},
  [95] = {.lex_state = 1},
  [96] = {.lex_state = 1},
  [97] = {.lex_state = 1},
  [98] = {.lex_state = 1},
  [99] = {.lex_state = 1},
  [100] = {.lex_state = 1},
  [101] = {.lex_state = 1},
  [102] = {.lex_state = 1},
  [103] = {.lex_state = 1},
  [104] = {.lex_state = 1},
  [105] = {.lex_state = 1},
  [106] = {.lex_state = 1},
  [107] = {.lex_state = 1},
  [108] = {.lex_state = 1},
  [109] = {.lex_state = 1},
  [110] = {.lex_state = 1},
  [111] = {.lex_state = 1},
  [112] = {.lex_state = 1},
  [113] = {.lex_state = 1},
  [114] = {.lex_state = 1},
  [115] = {.lex_state = 1},
  [116] = {.lex_state = 1},
  [117] = {.lex_state = 1},
  [118] = {.lex_state = 1},
  [119] = {.lex_state = 63},
  [120] = {.lex_state = 63},
  [121] = {.lex_state = 63},
  [122] = {.lex_state = 63},
  [123] = {.lex_state = 63},
  [124] = {.lex_state = 63},
  [125] = {.lex_state = 63},
  [126] = {.lex_state = 63},
  [127] = {.lex_state = 63},
  [128] = {.lex_state = 63},
  [129] = {.lex_state = 63},
  [130] = {.lex_state = 63},
  [131] = {.lex_state = 63},
  [132] = {.lex_state = 63},
  [133] = {.lex_state = 1},
  [134] = {.lex_state = 63},
  [135] = {.lex_state = 63},
  [136] = {.lex_state = 63},
  [137] = {.lex_state = 63},
  [138] = {.lex_state = 1},
  [139] = {.lex_state = 63},
  [140] = {.lex_state = 63},
  [141] = {.lex_state = 63},
  [142] = {.lex_state = 63},
  [143] = {.lex_state = 63},
  [144] = {.lex_state = 63},
  [145] = {.lex_state = 63},
  [146] = {.lex_state = 63},
  [147] = {.lex_state = 63},
  [148] = {.lex_state = 63},
  [149] = {.lex_state = 63},
  [150] = {.lex_state = 63},
  [151] = {.lex_state = 63},
  [152] = {.lex_state = 63},
  [153] = {.lex_state = 63},
  [154] = {.lex_state = 63},
  [155] = {.lex_state = 63},
  [156] = {.lex_state = 1},
  [157] = {.lex_state = 1},
  [158] = {.lex_state = 1},
  [159] = {.lex_state = 1},
  [160] = {.lex_state = 63},
  [161] = {.lex_state = 63},
  [162] = {.lex_state = 63},
  [163] = {.lex_state = 63},
  [164] = {.lex_state = 63},
  [165] = {.lex_state = 63},
  [166] = {.lex_state = 63},
  [167] = {.lex_state = 1},
  [168] = {.lex_state = 1},
  [169] = {.lex_state = 1},
  [170] = {.lex_state = 1},
  [171] = {.lex_state = 1},
  [172] = {.lex_state = 1},
  [173] = {.lex_state = 1},
  [174] = {.lex_state = 1},
  [175] = {.lex_state = 1},
  [176] = {.lex_state = 1},
  [177] = {.lex_state = 1},
  [178] = {.lex_state = 1},
  [179] = {.lex_state = 1},
  [180] = {.lex_state = 1},
  [181] = {.lex_state = 1},
  [182] = {.lex_state = 1},
  [183] = {.lex_state = 1},
  [184] = {.lex_state = 1},
  [185] = {.lex_state = 1},
  [186] = {.lex_state = 1},
  [187] = {.lex_state = 1},
  [188] = {.lex_state = 1},
  [189] = {.lex_state = 1},
  [190] = {.lex_state = 1},
  [191] = {.lex_state = 1},
  [192] = {.lex_state = 1},
  [193] = {.lex_state = 1},
  [194] = {.lex_state = 1},
  [195] = {.lex_state = 1},
  [196] = {.lex_state = 1},
  [197] = {.lex_state = 1},
  [198] = {.lex_state = 1},
  [199] = {.lex_state = 1},
  [200] = {.lex_state = 1},
  [201] = {.lex_state = 1},
  [202] = {.lex_state = 1},
  [203] = {.lex_state = 1},
  [204] = {.lex_state = 1},
  [205] = {.lex_state = 1},
  [206] = {.lex_state = 1},
  [207] = {.lex_state = 1},
  [208] = {.lex_state = 1},
  [209] = {.lex_state = 1},
  [210] = {.lex_state = 1},
  [211] = {.lex_state = 1},
  [212] = {.lex_state = 1},
  [213] = {.lex_state = 1},
  [214] = {.lex_state = 1},
  [215] = {.lex_state = 1},
  [216] = {.lex_state = 14},
  [217] = {.lex_state = 14},
  [218] = {.lex_state = 14},
  [219] = {.lex_state = 14},
  [220] = {.lex_state = 67},
  [221] = {.lex_state = 67},
  [222] = {.lex_state = 63},
  [223] = {.lex_state = 14},
  [224] = {.lex_state = 14},
  [225] = {.lex_state = 14},
  [226] = {.lex_state = 14},
  [227] = {.lex_state = 62},
  [228] = {.lex_state = 62},
  [229] = {.lex_state = 62},
  [230] = {.lex_state = 0},
  [231] = {.lex_state = 0},
  [232] = {.lex_state = 14},
  [233] = {.lex_state = 14},
  [234] = {.lex_state = 14},
  [235] = {.lex_state = 14},
  [236] = {.lex_state = 14},
  [237] = {.lex_state = 14},
  [238] = {.lex_state = 14},
  [239] = {.lex_state = 0},
  [240] = {.lex_state = 14},
  [241] = {.lex_state = 0},
  [242] = {.lex_state = 14},
  [243] = {.lex_state = 14},
  [244] = {.lex_state = 14},
  [245] = {.lex_state = 14},
  [246] = {.lex_state = 14},
  [247] = {.lex_state = 14},
  [248] = {.lex_state = 14},
  [249] = {.lex_state = 14},
  [250] = {.lex_state = 14},
  [251] = {.lex_state = 14},
  [252] = {.lex_state = 14},
  [253] = {.lex_state = 63},
  [254] = {.lex_state = 14},
  [255] = {.lex_state = 5},
  [256] = {.lex_state = 14},
  [257] = {.lex_state = 14},
  [258] = {.lex_state = 14},
  [259] = {.lex_state = 14},
  [260] = {.lex_state = 14},
  [261] = {.lex_state = 14},
  [262] = {.lex_state = 14},
  [263] = {.lex_state = 14},
  [264] = {.lex_state = 5},
  [265] = {.lex_state = 14},
  [266] = {.lex_state = 14},
  [267] = {.lex_state = 14},
  [268] = {.lex_state = 14},
  [269] = {.lex_state = 14},
  [270] = {.lex_state = 14},
  [271] = {.lex_state = 0},
  [272] = {.lex_state = 66},
  [273] = {.lex_state = 66},
  [274] = {.lex_state = 66},
  [275] = {.lex_state = 0},
  [276] = {.lex_state = 0},
  [277] = {.lex_state = 0},
  [278] = {.lex_state = 0},
  [279] = {.lex_state = 0},
  [280] = {.lex_state = 0},
  [281] = {.lex_state = 0},
  [282] = {.lex_state = 0},
  [283] = {.lex_state = 0},
  [284] = {.lex_state = 0},
  [285] = {.lex_state = 0},
  [286] = {.lex_state = 0},
  [287] = {.lex_state = 65},
  [288] = {.lex_state = 65},
  [289] = {.lex_state = 65},
  [290] = {.lex_state = 7},
  [291] = {.lex_state = 7},
  [292] = {.lex_state = 7},
  [293] = {.lex_state = 7},
  [294] = {.lex_state = 0},
  [295] = {.lex_state = 7},
  [296] = {.lex_state = 7},
  [297] = {.lex_state = 7},
  [298] = {.lex_state = 7},
  [299] = {.lex_state = 7},
  [300] = {.lex_state = 0},
  [301] = {.lex_state = 14},
  [302] = {.lex_state = 3},
  [303] = {.lex_state = 14},
  [304] = {.lex_state = 3},
  [305] = {.lex_state = 14},
  [306] = {.lex_state = 14},
  [307] = {.lex_state = 1},
  [308] = {.lex_state = 7},
  [309] = {.lex_state = 7},
  [310] = {.lex_state = 14},
  [311] = {.lex_state = 0},
  [312] = {.lex_state = 0},
  [313] = {.lex_state = 0},
  [314] = {.lex_state = 14},
  [315] = {.lex_state = 7},
  [316] = {.lex_state = 14},
  [317] = {.lex_state = 14},
  [318] = {.lex_state = 14},
  [319] = {.lex_state = 1},
  [320] = {.lex_state = 14},
  [321] = {.lex_state = 14},
  [322] = {.lex_state = 14},
  [323] = {.lex_state = 0},
  [324] = {.lex_state = 14},
  [325] = {.lex_state = 14},
  [326] = {.lex_state = 0},
  [327] = {.lex_state = 14},
  [328] = {.lex_state = 14},
  [329] = {.lex_state = 14},
  [330] = {.lex_state = 14},
  [331] = {.lex_state = 14},
  [332] = {.lex_state = 14},
  [333] = {.lex_state = 14},
  [334] = {.lex_state = 14},
  [335] = {.lex_state = 14},
  [336] = {.lex_state = 14},
  [337] = {.lex_state = 14},
  [338] = {.lex_state = 14},
  [339] = {.lex_state = 14},
  [340] = {.lex_state = 14},
  [341] = {.lex_state = 14},
  [342] = {.lex_state = 14},
  [343] = {.lex_state = 14},
  [344] = {.lex_state = 14},
  [345] = {.lex_state = 14},
  [346] = {.lex_state = 14},
  [347] = {.lex_state = 14},
  [348] = {.lex_state = 14},
  [349] = {.lex_state = 14},
  [350] = {.lex_state = 14},
  [351] = {.lex_state = 14},
  [352] = {.lex_state = 14},
  [353] = {.lex_state = 14},
  [354] = {.lex_state = 14},
  [355] = {.lex_state = 14},
  [356] = {.lex_state = 14},
  [357] = {.lex_state = 14},
  [358] = {.lex_state = 14},
  [359] = {.lex_state = 14},
  [360] = {.lex_state = 14},
  [361] = {.lex_state = 14},
  [362] = {.lex_state = 14},
  [363] = {.lex_state = 14},
  [364] = {.lex_state = 1},
  [365] = {.lex_state = 14},
  [366] = {.lex_state = 1},
  [367] = {.lex_state = 1},
  [368] = {.lex_state = 14},
  [369] = {.lex_state = 14},
  [370] = {.lex_state = 1},
  [371] = {.lex_state = 14},
  [372] = {.lex_state = 0},
  [373] = {.lex_state = 0},
  [374] = {.lex_state = 0},
  [375] = {.lex_state = 1},
  [376] = {.lex_state = 0},
  [377] = {.lex_state = 0},
  [378] = {.lex_state = 0},
  [379] = {.lex_state = 0},
  [380] = {.lex_state = 0},
  [381] = {.lex_state = 13},
  [382] = {.lex_state = 0},
  [383] = {.lex_state = 13},
  [384] = {.lex_state = 13},
  [385] = {.lex_state = 0},
  [386] = {.lex_state = 0},
  [387] = {.lex_state = 6},
  [388] = {.lex_state = 0},
  [389] = {.lex_state = 0},
  [390] = {.lex_state = 1},
  [391] = {.lex_state = 0},
  [392] = {.lex_state = 0},
  [393] = {.lex_state = 0},
  [394] = {.lex_state = 7},
  [395] = {.lex_state = 14},
  [396] = {.lex_state = 14},
  [397] = {.lex_state = 1},
  [398] = {.lex_state = 0},
  [399] = {.lex_state = 1},
  [400] = {.lex_state = 1},
  [401] = {.lex_state = 0},
  [402] = {.lex_state = 0},
  [403] = {.lex_state = 0},
  [404] = {.lex_state = 0},
  [405] = {.lex_state = 0},
  [406] = {.lex_state = 1},
  [407] = {.lex_state = 0},
  [408] = {.lex_state = 14},
  [409] = {.lex_state = 0},
  [410] = {.lex_state = 1},
  [411] = {.lex_state = 1},
  [412] = {.lex_state = 1},
  [413] = {.lex_state = 18},
  [414] = {.lex_state = 0},
  [415] = {.lex_state = 1},
  [416] = {.lex_state = 0},
  [417] = {.lex_state = 1},
  [418] = {.lex_state = 14},
  [419] = {.lex_state = 0},
  [420] = {.lex_state = 14},
  [421] = {.lex_state = 0},
  [422] = {.lex_state = 14},
  [423] = {.lex_state = 14},
  [424] = {.lex_state = 14},
  [425] = {.lex_state = 14},
  [426] = {.lex_state = 14},
  [427] = {.lex_state = 14},
  [428] = {.lex_state = 14},
  [429] = {.lex_state = 14},
  [430] = {.lex_state = 14},
  [431] = {.lex_state = 0},
  [432] = {.lex_state = 3},
  [433] = {.lex_state = 14},
  [434] = {.lex_state = 0},
  [435] = {.lex_state = 0},
  [436] = {.lex_state = 0},
  [437] = {.lex_state = 0},
  [438] = {.lex_state = 14},
  [439] = {.lex_state = 0},
  [440] = {.lex_state = 0},
  [441] = {.lex_state = 0},
  [442] = {.lex_state = 0},
  [443] = {.lex_state = 0},
  [444] = {.lex_state = 0},
  [445] = {.lex_state = 0},
  [446] = {.lex_state = 0},
  [447] = {.lex_state = 0},
  [448] = {.lex_state = 0},
  [449] = {.lex_state = 0},
  [450] = {.lex_state = 0},
  [451] = {.lex_state = 0},
  [452] = {.lex_state = 0},
  [453] = {.lex_state = 0},
  [454] = {.lex_state = 0},
  [455] = {.lex_state = 0},
  [456] = {.lex_state = 0},
  [457] = {.lex_state = 0},
  [458] = {.lex_state = 0},
  [459] = {.lex_state = 0},
  [460] = {.lex_state = 0},
  [461] = {.lex_state = 0},
  [462] = {.lex_state = 0},
  [463] = {.lex_state = 3},
  [464] = {.lex_state = 14},
  [465] = {.lex_state = 14},
  [466] = {.lex_state = 3},
  [467] = {.lex_state = 1},
  [468] = {.lex_state = 14},
  [469] = {.lex_state = 14},
  [470] = {.lex_state = 0},
  [471] = {.lex_state = 0},
  [472] = {.lex_state = 0},
  [473] = {.lex_state = 0},
  [474] = {.lex_state = 14},
  [475] = {.lex_state = 0},
  [476] = {.lex_state = 0},
  [477] = {.lex_state = 14},
  [478] = {.lex_state = 0},
  [479] = {.lex_state = 0},
  [480] = {.lex_state = 0},
  [481] = {.lex_state = 0},
  [482] = {.lex_state = 0},
  [483] = {.lex_state = 0},
  [484] = {.lex_state = 7},
  [485] = {.lex_state = 0},
  [486] = {.lex_state = 0},
  [487] = {.lex_state = 14},
  [488] = {.lex_state = 14},
  [489] = {.lex_state = 14},
  [490] = {.lex_state = 14},
  [491] = {.lex_state = 14},
  [492] = {.lex_state = 0},
  [493] = {.lex_state = 1},
  [494] = {.lex_state = 1},
  [495] = {.lex_state = 1},
  [496] = {.lex_state = 1},
  [497] = {.lex_state = 1},
  [498] = {.lex_state = 1},
  [499] = {.lex_state = 1},
  [500] = {.lex_state = 1},
  [501] = {.lex_state = 0},
  [502] = {.lex_state = 14},
  [503] = {.lex_state = 0},
  [504] = {.lex_state = 1},
  [505] = {.lex_state = 1},
  [506] = {.lex_state = 7},
  [507] = {.lex_state = 1},
  [508] = {.lex_state = 1},
  [509] = {.lex_state = 1},
  [510] = {.lex_state = 1},
  [511] = {.lex_state = 1},
  [512] = {.lex_state = 1},
  [513] = {.lex_state = 0},
  [514] = {.lex_state = 1},
  [515] = {.lex_state = 1},
  [516] = {.lex_state = 7},
  [517] = {.lex_state = 0},
  [518] = {.lex_state = 1},
  [519] = {.lex_state = 14},
  [520] = {.lex_state = 1},
  [521] = {.lex_state = 0},
  [522] = {.lex_state = 14},
  [523] = {.lex_state = 14},
  [524] = {.lex_state = 0},
  [525] = {.lex_state = 14},
  [526] = {.lex_state = 14},
  [527] = {.lex_state = 14},
  [528] = {.lex_state = 14},
  [529] = {.lex_state = 14},
  [530] = {.lex_state = 14},
  [531] = {.lex_state = 7},
  [532] = {.lex_state = 7},
  [533] = {.lex_state = 7},
  [534] = {.lex_state = 7},
  [535] = {.lex_state = 7},
  [536] = {.lex_state = 7},
  [537] = {.lex_state = 7},
  [538] = {.lex_state = 7},
  [539] = {.lex_state = 7},
  [540] = {.lex_state = 7},
  [541] = {.lex_state = 7},
  [542] = {.lex_state = 7},
  [543] = {.lex_state = 7},
  [544] = {.lex_state = 7},
  [545] = {.lex_state = 7},
  [546] = {.lex_state = 7},
  [547] = {.lex_state = 7},
  [548] = {.lex_state = 3},
  [549] = {.lex_state = 7},
  [550] = {.lex_state = 7},
  [551] = {.lex_state = 7},
  [552] = {.lex_state = 7},
  [553] = {.lex_state = 7},
  [554] = {.lex_state = 7},
  [555] = {.lex_state = 7},
  [556] = {.lex_state = 7},
  [557] = {.lex_state = 7},
  [558] = {.lex_state = 7},
  [559] = {.lex_state = 7},
  [560] = {.lex_state = 3},
  [561] = {.lex_state = 7},
  [562] = {.lex_state = 7},
  [563] = {.lex_state = 7},
  [564] = {.lex_state = 7},
  [565] = {.lex_state = 7},
  [566] = {.lex_state = 7},
  [567] = {.lex_state = 7},
  [568] = {.lex_state = 7},
  [569] = {.lex_state = 7},
  [570] = {.lex_state = 7},
  [571] = {.lex_state = 7},
  [572] = {.lex_state = 7},
  [573] = {.lex_state = 7},
  [574] = {.lex_state = 7},
  [575] = {.lex_state = 7},
  [576] = {.lex_state = 7},
  [577] = {.lex_state = 7},
  [578] = {.lex_state = 7},
  [579] = {.lex_state = 1},
  [580] = {.lex_state = 7},
  [581] = {.lex_state = 7},
  [582] = {.lex_state = 7},
  [583] = {.lex_state = 7},
  [584] = {.lex_state = 7},
  [585] = {.lex_state = 7},
  [586] = {.lex_state = 7},
  [587] = {.lex_state = 3},
  [588] = {.lex_state = 7},
  [589] = {.lex_state = 7},
  [590] = {.lex_state = 7},
  [591] = {.lex_state = 7},
  [592] = {.lex_state = 7},
  [593] = {.lex_state = 7},
  [594] = {.lex_state = 7},
  [595] = {.lex_state = 7},
  [596] = {.lex_state = 7},
  [597] = {.lex_state = 7},
  [598] = {.lex_state = 7},
  [599] = {.lex_state = 7},
  [600] = {.lex_state = 7},
  [601] = {.lex_state = 1},
  [602] = {.lex_state = 16},
  [603] = {.lex_state = 7},
  [604] = {.lex_state = 16},
  [605] = {.lex_state = 7},
  [606] = {.lex_state = 1},
  [607] = {.lex_state = 1},
  [608] = {.lex_state = 7},
  [609] = {.lex_state = 1},
  [610] = {.lex_state = 1},
  [611] = {.lex_state = 1},
  [612] = {.lex_state = 7},
  [613] = {.lex_state = 3},
  [614] = {.lex_state = 7},
  [615] = {.lex_state = 7},
  [616] = {.lex_state = 7},
  [617] = {.lex_state = 7},
  [618] = {.lex_state = 7},
  [619] = {.lex_state = 7},
  [620] = {.lex_state = 16},
  [621] = {.lex_state = 7},
  [622] = {.lex_state = 7},
  [623] = {.lex_state = 7},
  [624] = {.lex_state = 7},
  [625] = {.lex_state = 7},
  [626] = {.lex_state = 7},
  [627] = {.lex_state = 7},
  [628] = {.lex_state = 1},
  [629] = {.lex_state = 7},
  [630] = {.lex_state = 7},
  [631] = {.lex_state = 7},
  [632] = {.lex_state = 7},
  [633] = {.lex_state = 7},
  [634] = {.lex_state = 7},
  [635] = {.lex_state = 7},
  [636] = {.lex_state = 7},
  [637] = {.lex_state = 7},
  [638] = {.lex_state = 7},
  [639] = {.lex_state = 7},
  [640] = {.lex_state = 7},
  [641] = {.lex_state = 7},
  [642] = {.lex_state = 7},
  [643] = {.lex_state = 7},
  [644] = {.lex_state = 7},
  [645] = {.lex_state = 7},
  [646] = {.lex_state = 7},
  [647] = {.lex_state = 7},
  [648] = {.lex_state = 7},
  [649] = {.lex_state = 7},
  [650] = {.lex_state = 7},
  [651] = {.lex_state = 7},
  [652] = {.lex_state = 7},
  [653] = {.lex_state = 7},
  [654] = {.lex_state = 7},
  [655] = {.lex_state = 7},
  [656] = {.lex_state = 7},
  [657] = {.lex_state = 7},
  [658] = {.lex_state = 7},
  [659] = {.lex_state = 7},
  [660] = {.lex_state = 7},
  [661] = {.lex_state = 7},
  [662] = {.lex_state = 7},
  [663] = {.lex_state = 7},
  [664] = {.lex_state = 7},
  [665] = {.lex_state = 7},
  [666] = {.lex_state = 7},
  [667] = {.lex_state = 7},
  [668] = {.lex_state = 7},
  [669] = {.lex_state = 7},
  [670] = {.lex_state = 7},
  [671] = {.lex_state = 7},
  [672] = {.lex_state = 7},
  [673] = {.lex_state = 7},
  [674] = {.lex_state = 7},
  [675] = {.lex_state = 7},
  [676] = {.lex_state = 7},
  [677] = {.lex_state = 7},
  [678] = {.lex_state = 7},
  [679] = {.lex_state = 7},
  [680] = {.lex_state = 7},
  [681] = {.lex_state = 7},
  [682] = {.lex_state = 7},
  [683] = {.lex_state = 7},
  [684] = {.lex_state = 7},
  [685] = {.lex_state = 1},
  [686] = {.lex_state = 7},
  [687] = {.lex_state = 7},
  [688] = {.lex_state = 7},
  [689] = {.lex_state = 1},
  [690] = {.lex_state = 7},
  [691] = {.lex_state = 7},
  [692] = {.lex_state = 7},
  [693] = {.lex_state = 1},
  [694] = {.lex_state = 1},
  [695] = {.lex_state = 7},
  [696] = {.lex_state = 7},
  [697] = {.lex_state = 7},
  [698] = {.lex_state = 7},
  [699] = {.lex_state = 7},
  [700] = {.lex_state = 7},
  [701] = {.lex_state = 1},
  [702] = {.lex_state = 1},
  [703] = {.lex_state = 7},
  [704] = {.lex_state = 7},
  [705] = {.lex_state = 1},
  [706] = {.lex_state = 1},
  [707] = {.lex_state = 1},
  [708] = {.lex_state = 7},
  [709] = {.lex_state = 7},
  [710] = {.lex_state = 1},
  [711] = {.lex_state = 1},
  [712] = {.lex_state = 1},
  [713] = {.lex_state = 7},
  [714] = {.lex_state = 1},
  [715] = {.lex_state = 1},
  [716] = {.lex_state = 1},
  [717] = {.lex_state = 1},
  [718] = {.lex_state = 1},
  [719] = {.lex_state = 1},
  [720] = {.lex_state = 1},
  [721] = {.lex_state = 1},
  [722] = {.lex_state = 7},
  [723] = {.lex_state = 7},
  [724] = {.lex_state = 1},
  [725] = {.lex_state = 1},
  [726] = {.lex_state = 1},
  [727] = {.lex_state = 1},
  [728] = {.lex_state = 1},
  [729] = {.lex_state = 1},
  [730] = {.lex_state = 7},
  [731] = {.lex_state = 1},
  [732] = {.lex_state = 1},
  [733] = {.lex_state = 1},
  [734] = {.lex_state = 63},
  [735] = {.lex_state = 2},
  [736] = {.lex_state = 2},
  [737] = {.lex_state = 1},
  [738] = {.lex_state = 63},
  [739] = {.lex_state = 63},
  [740] = {.lex_state = 1},
  [741] = {.lex_state = 1},
  [742] = {.lex_state = 63},
  [743] = {.lex_state = 1},
  [744] = {.lex_state = 63},
  [745] = {.lex_state = 63},
  [746] = {.lex_state = 63},
  [747] = {.lex_state = 63},
  [748] = {.lex_state = 1},
  [749] = {.lex_state = 1},
  [750] = {.lex_state = 2},
  [751] = {.lex_state = 1},
  [752] = {.lex_state = 1},
  [753] = {.lex_state = 1},
  [754] = {.lex_state = 1},
  [755] = {.lex_state = 1},
  [756] = {.lex_state = 1},
  [757] = {.lex_state = 1},
  [758] = {.lex_state = 1},
  [759] = {.lex_state = 1},
  [760] = {.lex_state = 1},
  [761] = {.lex_state = 1},
  [762] = {.lex_state = 1},
  [763] = {.lex_state = 1},
  [764] = {.lex_state = 1},
  [765] = {.lex_state = 1},
  [766] = {.lex_state = 1},
  [767] = {.lex_state = 1},
  [768] = {.lex_state = 1},
  [769] = {.lex_state = 1},
  [770] = {.lex_state = 1},
  [771] = {.lex_state = 1},
  [772] = {.lex_state = 1},
  [773] = {.lex_state = 1},
  [774] = {.lex_state = 1},
  [775] = {.lex_state = 1},
  [776] = {.lex_state = 1},
  [777] = {.lex_state = 1},
  [778] = {.lex_state = 0},
  [779] = {.lex_state = 1},
  [780] = {.lex_state = 1},
  [781] = {.lex_state = 22},
  [782] = {.lex_state = 10},
  [783] = {.lex_state = 22},
  [784] = {.lex_state = 1},
  [785] = {.lex_state = 22},
  [786] = {.lex_state = 22},
  [787] = {.lex_state = 10},
  [788] = {.lex_state = 1},
  [789] = {.lex_state = 10},
  [790] = {.lex_state = 22},
  [791] = {.lex_state = 10},
  [792] = {.lex_state = 10},
  [793] = {.lex_state = 22},
  [794] = {.lex_state = 10},
  [795] = {.lex_state = 22},
  [796] = {.lex_state = 10},
  [797] = {.lex_state = 1},
  [798] = {.lex_state = 0},
  [799] = {.lex_state = 1},
  [800] = {.lex_state = 1},
  [801] = {.lex_state = 1},
  [802] = {.lex_state = 1},
  [803] = {.lex_state = 1},
  [804] = {.lex_state = 7},
  [805] = {.lex_state = 7},
  [806] = {.lex_state = 18},
  [807] = {.lex_state = 7},
  [808] = {.lex_state = 10},
  [809] = {.lex_state = 18},
  [810] = {.lex_state = 18},
  [811] = {.lex_state = 7},
  [812] = {.lex_state = 1},
  [813] = {.lex_state = 22},
  [814] = {.lex_state = 1},
  [815] = {.lex_state = 7},
  [816] = {.lex_state = 1},
  [817] = {.lex_state = 1},
  [818] = {.lex_state = 0},
  [819] = {.lex_state = 23},
  [820] = {.lex_state = 12},
  [821] = {.lex_state = 0},
  [822] = {.lex_state = 1},
  [823] = {.lex_state = 23},
  [824] = {.lex_state = 12},
  [825] = {.lex_state = 7},
  [826] = {.lex_state = 0},
  [827] = {.lex_state = 23},
  [828] = {.lex_state = 12},
  [829] = {.lex_state = 1},
  [830] = {.lex_state = 1},
  [831] = {.lex_state = 23},
  [832] = {.lex_state = 12},
  [833] = {.lex_state = 23},
  [834] = {.lex_state = 12},
  [835] = {.lex_state = 0},
  [836] = {.lex_state = 0},
  [837] = {.lex_state = 65},
  [838] = {.lex_state = 7},
  [839] = {.lex_state = 1},
  [840] = {.lex_state = 1},
  [841] = {.lex_state = 1},
  [842] = {.lex_state = 1},
  [843] = {.lex_state = 1},
  [844] = {.lex_state = 1},
  [845] = {.lex_state = 65},
  [846] = {.lex_state = 12},
  [847] = {.lex_state = 65},
  [848] = {.lex_state = 65},
  [849] = {.lex_state = 65},
  [850] = {.lex_state = 23},
  [851] = {.lex_state = 65},
  [852] = {.lex_state = 12},
  [853] = {.lex_state = 0},
  [854] = {.lex_state = 0},
  [855] = {.lex_state = 1},
  [856] = {.lex_state = 65},
  [857] = {.lex_state = 65},
  [858] = {.lex_state = 65},
  [859] = {.lex_state = 0},
  [860] = {.lex_state = 1},
  [861] = {.lex_state = 0},
  [862] = {.lex_state = 65},
  [863] = {.lex_state = 1},
  [864] = {.lex_state = 7},
  [865] = {.lex_state = 65},
  [866] = {.lex_state = 1},
  [867] = {.lex_state = 0},
  [868] = {.lex_state = 1},
  [869] = {.lex_state = 1},
  [870] = {.lex_state = 1},
  [871] = {.lex_state = 0},
  [872] = {.lex_state = 1},
  [873] = {.lex_state = 63},
  [874] = {.lex_state = 0},
  [875] = {.lex_state = 0},
  [876] = {.lex_state = 1},
  [877] = {.lex_state = 0},
  [878] = {.lex_state = 0},
  [879] = {.lex_state = 65},
  [880] = {.lex_state = 23},
  [881] = {.lex_state = 0},
  [882] = {.lex_state = 0},
  [883] = {.lex_state = 1},
  [884] = {.lex_state = 0},
  [885] = {.lex_state = 1},
  [886] = {.lex_state = 0},
  [887] = {.lex_state = 0},
  [888] = {.lex_state = 0},
  [889] = {.lex_state = 0},
  [890] = {.lex_state = 1},
  [891] = {.lex_state = 63},
  [892] = {.lex_state = 63},
  [893] = {.lex_state = 0},
  [894] = {.lex_state = 0},
  [895] = {.lex_state = 0},
  [896] = {.lex_state = 0},
  [897] = {.lex_state = 0},
  [898] = {.lex_state = 0},
  [899] = {.lex_state = 63},
  [900] = {.lex_state = 0},
  [901] = {.lex_state = 0},
  [902] = {.lex_state = 0},
  [903] = {.lex_state = 1},
  [904] = {.lex_state = 0},
  [905] = {.lex_state = 63},
  [906] = {.lex_state = 0},
  [907] = {.lex_state = 1},
  [908] = {.lex_state = 63},
  [909] = {.lex_state = 7},
  [910] = {.lex_state = 7},
  [911] = {.lex_state = 0},
  [912] = {.lex_state = 63},
  [913] = {.lex_state = 0},
  [914] = {.lex_state = 1},
  [915] = {.lex_state = 0},
  [916] = {.lex_state = 1},
  [917] = {.lex_state = 0},
  [918] = {.lex_state = 1},
  [919] = {.lex_state = 1},
  [920] = {.lex_state = 63},
  [921] = {.lex_state = 0},
  [922] = {.lex_state = 0},
  [923] = {.lex_state = 0},
  [924] = {.lex_state = 0},
  [925] = {.lex_state = 0},
  [926] = {.lex_state = 0},
  [927] = {.lex_state = 0},
  [928] = {.lex_state = 1},
  [929] = {.lex_state = 0},
  [930] = {.lex_state = 63},
  [931] = {.lex_state = 0},
  [932] = {.lex_state = 0},
  [933] = {.lex_state = 0},
  [934] = {.lex_state = 63},
  [935] = {.lex_state = 0},
  [936] = {.lex_state = 0},
  [937] = {.lex_state = 0},
  [938] = {.lex_state = 63},
  [939] = {.lex_state = 1},
  [940] = {.lex_state = 0},
  [941] = {.lex_state = 0},
  [942] = {.lex_state = 1},
  [943] = {.lex_state = 0},
  [944] = {.lex_state = 1},
  [945] = {.lex_state = 63},
  [946] = {.lex_state = 10},
  [947] = {.lex_state = 22},
  [948] = {.lex_state = 63},
  [949] = {.lex_state = 63},
  [950] = {.lex_state = 63},
  [951] = {.lex_state = 1},
  [952] = {.lex_state = 0},
  [953] = {.lex_state = 0},
  [954] = {.lex_state = 1},
  [955] = {.lex_state = 0},
  [956] = {.lex_state = 0},
  [957] = {.lex_state = 0},
  [958] = {.lex_state = 0},
  [959] = {.lex_state = 0},
  [960] = {.lex_state = 0},
  [961] = {.lex_state = 0},
  [962] = {.lex_state = 0},
  [963] = {.lex_state = 0},
  [964] = {.lex_state = 63},
  [965] = {.lex_state = 0},
  [966] = {.lex_state = 0},
  [967] = {.lex_state = 0},
  [968] = {.lex_state = 0},
  [969] = {.lex_state = 63},
  [970] = {.lex_state = 1},
  [971] = {.lex_state = 1},
  [972] = {.lex_state = 0},
  [973] = {.lex_state = 0},
  [974] = {.lex_state = 0},
  [975] = {.lex_state = 63},
  [976] = {.lex_state = 0},
  [977] = {.lex_state = 0},
  [978] = {.lex_state = 63},
  [979] = {.lex_state = 63},
  [980] = {.lex_state = 1},
  [981] = {.lex_state = 0},
  [982] = {.lex_state = 0},
  [983] = {.lex_state = 0},
  [984] = {.lex_state = 0},
  [985] = {.lex_state = 0},
  [986] = {.lex_state = 63},
  [987] = {.lex_state = 0},
  [988] = {.lex_state = 63},
  [989] = {.lex_state = 0},
  [990] = {.lex_state = 63},
  [991] = {.lex_state = 0},
  [992] = {.lex_state = 0},
  [993] = {.lex_state = 0},
  [994] = {.lex_state = 0},
  [995] = {.lex_state = 63},
  [996] = {.lex_state = 0},
  [997] = {.lex_state = 63},
  [998] = {.lex_state = 63},
  [999] = {.lex_state = 0},
  [1000] = {.lex_state = 1},
  [1001] = {.lex_state = 0},
  [1002] = {.lex_state = 63},
  [1003] = {.lex_state = 112},
  [1004] = {.lex_state = 0},
  [1005] = {.lex_state = 1},
  [1006] = {.lex_state = 0},
  [1007] = {.lex_state = 0},
  [1008] = {.lex_state = 0},
  [1009] = {.lex_state = 0},
  [1010] = {.lex_state = 0},
  [1011] = {.lex_state = 0},
  [1012] = {.lex_state = 0},
  [1013] = {.lex_state = 63},
  [1014] = {.lex_state = 63},
  [1015] = {.lex_state = 0},
  [1016] = {.lex_state = 1},
  [1017] = {.lex_state = 0},
  [1018] = {.lex_state = 1},
  [1019] = {.lex_state = 0},
  [1020] = {.lex_state = 1},
  [1021] = {.lex_state = 0},
  [1022] = {.lex_state = 0},
  [1023] = {.lex_state = 0},
  [1024] = {.lex_state = 0},
  [1025] = {.lex_state = 63},
  [1026] = {.lex_state = 112},
  [1027] = {.lex_state = 0},
  [1028] = {.lex_state = 1},
  [1029] = {.lex_state = 0},
  [1030] = {.lex_state = 0},
  [1031] = {.lex_state = 0},
  [1032] = {.lex_state = 0},
  [1033] = {.lex_state = 0},
  [1034] = {.lex_state = 0},
  [1035] = {.lex_state = 63},
  [1036] = {.lex_state = 0},
  [1037] = {.lex_state = 1},
  [1038] = {.lex_state = 1},
  [1039] = {.lex_state = 1},
  [1040] = {.lex_state = 1},
  [1041] = {.lex_state = 112},
  [1042] = {.lex_state = 0},
  [1043] = {.lex_state = 1},
  [1044] = {.lex_state = 0},
  [1045] = {.lex_state = 1},
  [1046] = {.lex_state = 0},
  [1047] = {.lex_state = 0},
  [1048] = {.lex_state = 0},
  [1049] = {.lex_state = 112},
  [1050] = {.lex_state = 63},
  [1051] = {.lex_state = 63},
  [1052] = {.lex_state = 63},
  [1053] = {.lex_state = 63},
  [1054] = {.lex_state = 0},
  [1055] = {.lex_state = 0},
  [1056] = {.lex_state = 0},
  [1057] = {.lex_state = 0},
  [1058] = {.lex_state = 0},
  [1059] = {.lex_state = 0},
  [1060] = {.lex_state = 21},
  [1061] = {.lex_state = 0},
  [1062] = {.lex_state = 0},
  [1063] = {.lex_state = 63},
  [1064] = {.lex_state = 63},
  [1065] = {.lex_state = 63},
  [1066] = {.lex_state = 0},
  [1067] = {.lex_state = 1},
  [1068] = {.lex_state = 0},
  [1069] = {.lex_state = 63},
  [1070] = {.lex_state = 1},
  [1071] = {.lex_state = 0},
  [1072] = {.lex_state = 0},
  [1073] = {.lex_state = 0},
  [1074] = {.lex_state = 63},
  [1075] = {.lex_state = 63},
  [1076] = {.lex_state = 63},
  [1077] = {.lex_state = 63},
  [1078] = {.lex_state = 0},
  [1079] = {.lex_state = 112},
  [1080] = {.lex_state = 0},
  [1081] = {.lex_state = 1},
  [1082] = {.lex_state = 21},
  [1083] = {.lex_state = 0},
  [1084] = {.lex_state = 0},
  [1085] = {.lex_state = 0},
  [1086] = {.lex_state = 0},
  [1087] = {.lex_state = 1},
  [1088] = {.lex_state = 1},
  [1089] = {.lex_state = 0},
  [1090] = {.lex_state = 63},
  [1091] = {.lex_state = 1},
  [1092] = {.lex_state = 1},
  [1093] = {.lex_state = 0},
  [1094] = {.lex_state = 63},
  [1095] = {.lex_state = 0},
  [1096] = {.lex_state = 0},
  [1097] = {.lex_state = 0},
  [1098] = {.lex_state = 1},
  [1099] = {.lex_state = 1},
  [1100] = {.lex_state = 0},
  [1101] = {.lex_state = 0},
  [1102] = {.lex_state = 0},
  [1103] = {.lex_state = 0},
  [1104] = {.lex_state = 0},
  [1105] = {.lex_state = 1},
  [1106] = {.lex_state = 1},
  [1107] = {.lex_state = 63},
  [1108] = {.lex_state = 0},
  [1109] = {.lex_state = 63},
  [1110] = {.lex_state = 0},
  [1111] = {.lex_state = 0},
  [1112] = {.lex_state = 63},
  [1113] = {.lex_state = 63},
  [1114] = {.lex_state = 63},
  [1115] = {.lex_state = 0},
  [1116] = {.lex_state = 63},
  [1117] = {.lex_state = 63},
  [1118] = {.lex_state = 63},
  [1119] = {.lex_state = 63},
  [1120] = {.lex_state = 0},
  [1121] = {.lex_state = 63},
  [1122] = {.lex_state = 63},
  [1123] = {.lex_state = 63},
  [1124] = {.lex_state = 0},
  [1125] = {.lex_state = 0},
  [1126] = {.lex_state = 0},
  [1127] = {.lex_state = 0},
  [1128] = {.lex_state = 63},
  [1129] = {.lex_state = 63},
  [1130] = {.lex_state = 63},
  [1131] = {.lex_state = 63},
  [1132] = {.lex_state = 63},
  [1133] = {.lex_state = 63},
  [1134] = {.lex_state = 63},
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [0] = {
    [ts_builtin_sym_end] = ACTIONS(1),
    [sym_pn_prefix] = ACTIONS(1),
    [sym_comment] = ACTIONS(3),
    [anon_sym_SEMI] = ACTIONS(1),
    [aux_sym_base_declaration_token1] = ACTIONS(1),
    [aux_sym_prefix_declaration_token1] = ACTIONS(1),
    [aux_sym_select_clause_token1] = ACTIONS(1),
    [aux_sym_select_clause_token2] = ACTIONS(1),
    [aux_sym_select_clause_token3] = ACTIONS(1),
    [anon_sym_LPAREN] = ACTIONS(1),
    [aux_sym_select_clause_token4] = ACTIONS(1),
    [anon_sym_RPAREN] = ACTIONS(1),
    [anon_sym_STAR] = ACTIONS(1),
    [aux_sym_construct_query_token1] = ACTIONS(1),
    [aux_sym_construct_query_token2] = ACTIONS(1),
    [anon_sym_LBRACE] = ACTIONS(1),
    [anon_sym_RBRACE] = ACTIONS(1),
    [aux_sym_describe_query_token1] = ACTIONS(1),
    [aux_sym_ask_query_token1] = ACTIONS(1),
    [aux_sym_dataset_clause_token1] = ACTIONS(1),
    [aux_sym_named_graph_clause_token1] = ACTIONS(1),
    [aux_sym_group_clause_token1] = ACTIONS(1),
    [aux_sym_group_clause_token2] = ACTIONS(1),
    [aux_sym_having_clause_token1] = ACTIONS(1),
    [aux_sym_order_clause_token1] = ACTIONS(1),
    [aux_sym_order_condition_token1] = ACTIONS(1),
    [aux_sym_order_condition_token2] = ACTIONS(1),
    [aux_sym_limit_clause_token1] = ACTIONS(1),
    [aux_sym_offset_clause_token1] = ACTIONS(1),
    [aux_sym_values_clause_token1] = ACTIONS(1),
    [aux_sym_load_token1] = ACTIONS(1),
    [aux_sym_load_token2] = ACTIONS(1),
    [aux_sym_load_token3] = ACTIONS(1),
    [aux_sym_clear_token1] = ACTIONS(1),
    [aux_sym_drop_token1] = ACTIONS(1),
    [aux_sym_create_token1] = ACTIONS(1),
    [aux_sym_add_token1] = ACTIONS(1),
    [aux_sym_add_token2] = ACTIONS(1),
    [aux_sym_move_token1] = ACTIONS(1),
    [aux_sym_copy_token1] = ACTIONS(1),
    [anon_sym_INSERTDATA] = ACTIONS(1),
    [anon_sym_DELETEDATA] = ACTIONS(1),
    [anon_sym_DELETEWHERE] = ACTIONS(1),
    [aux_sym_modify_token1] = ACTIONS(1),
    [aux_sym_delete_clause_token1] = ACTIONS(1),
    [aux_sym_insert_clause_token1] = ACTIONS(1),
    [aux_sym_using_clause_token1] = ACTIONS(1),
    [aux_sym_graph_or_default_token1] = ACTIONS(1),
    [aux_sym_graph_or_default_token2] = ACTIONS(1),
    [aux_sym_graph_ref_all_token1] = ACTIONS(1),
    [anon_sym_DOT] = ACTIONS(1),
    [aux_sym_optional_graph_pattern_token1] = ACTIONS(1),
    [aux_sym_service_graph_pattern_token1] = ACTIONS(1),
    [aux_sym_bind_token1] = ACTIONS(1),
    [aux_sym__data_block_value_token1] = ACTIONS(1),
    [aux_sym_minus_graph_pattern_token1] = ACTIONS(1),
    [aux_sym_group_or_union_graph_pattern_token1] = ACTIONS(1),
    [aux_sym_filter_token1] = ACTIONS(1),
    [anon_sym_COMMA] = ACTIONS(1),
    [anon_sym_a] = ACTIONS(1),
    [anon_sym_SLASH] = ACTIONS(1),
    [anon_sym_PIPE] = ACTIONS(1),
    [anon_sym_CARET] = ACTIONS(1),
    [sym_path_mod] = ACTIONS(1),
    [anon_sym_BANG] = ACTIONS(1),
    [anon_sym_LBRACK] = ACTIONS(1),
    [anon_sym_RBRACK] = ACTIONS(1),
    [sym_var] = ACTIONS(1),
    [anon_sym_PIPE_PIPE] = ACTIONS(1),
    [anon_sym_AMP_AMP] = ACTIONS(1),
    [anon_sym_EQ] = ACTIONS(1),
    [anon_sym_BANG_EQ] = ACTIONS(1),
    [anon_sym_LT] = ACTIONS(1),
    [anon_sym_GT] = ACTIONS(1),
    [anon_sym_LT_EQ] = ACTIONS(1),
    [anon_sym_GT_EQ] = ACTIONS(1),
    [aux_sym_binary_expression_token1] = ACTIONS(1),
    [aux_sym_binary_expression_token2] = ACTIONS(1),
    [anon_sym_PLUS] = ACTIONS(1),
    [anon_sym_DASH] = ACTIONS(1),
    [aux_sym_build_in_function_token1] = ACTIONS(1),
    [aux_sym_build_in_function_token2] = ACTIONS(1),
    [aux_sym_build_in_function_token3] = ACTIONS(1),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(1),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(1),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(1),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(1),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(1),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(1),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(1),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(1),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(1),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(1),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(1),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(1),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(1),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(1),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(1),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(1),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(1),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(1),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(1),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(1),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(1),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(1),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(1),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(1),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(1),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(1),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(1),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(1),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(1),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(1),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(1),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(1),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(1),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(1),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(1),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(1),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(1),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(1),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(1),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(1),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(1),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(1),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(1),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(1),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(1),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(1),
    [aux_sym_regex_expression_token1] = ACTIONS(1),
    [aux_sym_substring_expression_token1] = ACTIONS(1),
    [aux_sym_string_replace_expression_token1] = ACTIONS(1),
    [aux_sym_exists_func_token1] = ACTIONS(1),
    [aux_sym_aggregate_token1] = ACTIONS(1),
    [aux_sym_aggregate_token2] = ACTIONS(1),
    [aux_sym_aggregate_token3] = ACTIONS(1),
    [aux_sym_aggregate_token4] = ACTIONS(1),
    [aux_sym_aggregate_token5] = ACTIONS(1),
    [aux_sym_aggregate_token6] = ACTIONS(1),
    [anon_sym_GROUP_CONCAT] = ACTIONS(1),
    [aux_sym_aggregate_token7] = ACTIONS(1),
    [anon_sym_CARET_CARET] = ACTIONS(1),
    [anon_sym_true] = ACTIONS(1),
    [anon_sym_false] = ACTIONS(1),
    [anon_sym_COLON] = ACTIONS(1),
    [anon_sym__COLON] = ACTIONS(1),
    [sym_lang_tag] = ACTIONS(1),
    [sym_integer] = ACTIONS(1),
    [sym_decimal] = ACTIONS(1),
    [sym_double] = ACTIONS(1),
    [anon_sym_SQUOTE] = ACTIONS(1),
    [anon_sym_DQUOTE] = ACTIONS(1),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(1),
    [anon_sym_SQUOTE_SQUOTE] = ACTIONS(1),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(1),
    [anon_sym_DQUOTE_DQUOTE] = ACTIONS(1),
    [sym_echar] = ACTIONS(1),
    [sym_nil] = ACTIONS(1),
    [sym_anon] = ACTIONS(1),
  },
  [1] = {
    [sym_unit] = STATE(1034),
    [sym__update] = STATE(231),
    [sym_prologue] = STATE(271),
    [sym_base_declaration] = STATE(404),
    [sym_prefix_declaration] = STATE(404),
    [sym_select_query] = STATE(414),
    [sym_select_clause] = STATE(757),
    [sym_construct_query] = STATE(414),
    [sym_describe_query] = STATE(414),
    [sym_ask_query] = STATE(414),
    [sym_load] = STATE(486),
    [sym_clear] = STATE(486),
    [sym_drop] = STATE(486),
    [sym_create] = STATE(486),
    [sym_add] = STATE(486),
    [sym_move] = STATE(486),
    [sym_copy] = STATE(486),
    [sym_insert_data] = STATE(486),
    [sym_delete_data] = STATE(486),
    [sym_delete_where] = STATE(486),
    [sym_modify] = STATE(486),
    [sym_delete_clause] = STATE(788),
    [sym_insert_clause] = STATE(863),
    [aux_sym_unit_repeat1] = STATE(231),
    [aux_sym_prologue_repeat1] = STATE(404),
    [ts_builtin_sym_end] = ACTIONS(5),
    [sym_comment] = ACTIONS(3),
    [aux_sym_base_declaration_token1] = ACTIONS(7),
    [aux_sym_prefix_declaration_token1] = ACTIONS(9),
    [aux_sym_select_clause_token1] = ACTIONS(11),
    [aux_sym_construct_query_token1] = ACTIONS(13),
    [aux_sym_describe_query_token1] = ACTIONS(15),
    [aux_sym_ask_query_token1] = ACTIONS(17),
    [aux_sym_load_token1] = ACTIONS(19),
    [aux_sym_clear_token1] = ACTIONS(21),
    [aux_sym_drop_token1] = ACTIONS(23),
    [aux_sym_create_token1] = ACTIONS(25),
    [aux_sym_add_token1] = ACTIONS(27),
    [aux_sym_move_token1] = ACTIONS(29),
    [aux_sym_copy_token1] = ACTIONS(31),
    [anon_sym_INSERTDATA] = ACTIONS(33),
    [anon_sym_DELETEDATA] = ACTIONS(35),
    [anon_sym_DELETEWHERE] = ACTIONS(37),
    [aux_sym_modify_token1] = ACTIONS(39),
    [aux_sym_delete_clause_token1] = ACTIONS(41),
    [aux_sym_insert_clause_token1] = ACTIONS(43),
  },
  [2] = {
    [sym_order_condition] = STATE(3),
    [sym__constraint] = STATE(163),
    [sym_function_call] = STATE(163),
    [sym_bracketted_expression] = STATE(163),
    [sym__build_in_call] = STATE(163),
    [sym_build_in_function] = STATE(163),
    [sym__nullary_build_in_function] = STATE(136),
    [sym__unary_build_in_function] = STATE(120),
    [sym__binary_build_in_function] = STATE(121),
    [sym__variadic_build_in_function] = STATE(122),
    [sym_regex_expression] = STATE(163),
    [sym_substring_expression] = STATE(163),
    [sym_string_replace_expression] = STATE(163),
    [sym_exists_func] = STATE(163),
    [sym_not_exists_func] = STATE(163),
    [sym_aggregate] = STATE(163),
    [sym__iri] = STATE(913),
    [sym_prefixed_name] = STATE(913),
    [sym_iri_reference] = STATE(913),
    [sym_namespace] = STATE(413),
    [aux_sym_order_clause_repeat1] = STATE(3),
    [ts_builtin_sym_end] = ACTIONS(45),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [aux_sym_base_declaration_token1] = ACTIONS(49),
    [aux_sym_prefix_declaration_token1] = ACTIONS(49),
    [aux_sym_select_clause_token1] = ACTIONS(49),
    [anon_sym_LPAREN] = ACTIONS(51),
    [aux_sym_construct_query_token1] = ACTIONS(49),
    [aux_sym_describe_query_token1] = ACTIONS(49),
    [aux_sym_ask_query_token1] = ACTIONS(49),
    [aux_sym_order_condition_token1] = ACTIONS(53),
    [aux_sym_order_condition_token2] = ACTIONS(53),
    [aux_sym_limit_clause_token1] = ACTIONS(49),
    [aux_sym_offset_clause_token1] = ACTIONS(49),
    [aux_sym_values_clause_token1] = ACTIONS(49),
    [aux_sym_load_token1] = ACTIONS(49),
    [aux_sym_clear_token1] = ACTIONS(49),
    [aux_sym_drop_token1] = ACTIONS(49),
    [aux_sym_create_token1] = ACTIONS(49),
    [aux_sym_add_token1] = ACTIONS(49),
    [aux_sym_move_token1] = ACTIONS(49),
    [aux_sym_copy_token1] = ACTIONS(49),
    [anon_sym_INSERTDATA] = ACTIONS(45),
    [anon_sym_DELETEDATA] = ACTIONS(45),
    [anon_sym_DELETEWHERE] = ACTIONS(45),
    [aux_sym_modify_token1] = ACTIONS(49),
    [aux_sym_delete_clause_token1] = ACTIONS(49),
    [aux_sym_insert_clause_token1] = ACTIONS(49),
    [sym_var] = ACTIONS(55),
    [anon_sym_LT] = ACTIONS(57),
    [aux_sym_binary_expression_token2] = ACTIONS(59),
    [aux_sym_build_in_function_token1] = ACTIONS(61),
    [aux_sym_build_in_function_token2] = ACTIONS(63),
    [aux_sym_build_in_function_token3] = ACTIONS(65),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(67),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(67),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(67),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(67),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(69),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(71),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(71),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(71),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(71),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(71),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(71),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(71),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(71),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(71),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(73),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(73),
    [aux_sym_regex_expression_token1] = ACTIONS(75),
    [aux_sym_substring_expression_token1] = ACTIONS(77),
    [aux_sym_string_replace_expression_token1] = ACTIONS(79),
    [aux_sym_exists_func_token1] = ACTIONS(81),
    [aux_sym_aggregate_token1] = ACTIONS(83),
    [aux_sym_aggregate_token2] = ACTIONS(85),
    [aux_sym_aggregate_token3] = ACTIONS(85),
    [aux_sym_aggregate_token4] = ACTIONS(85),
    [aux_sym_aggregate_token5] = ACTIONS(85),
    [aux_sym_aggregate_token6] = ACTIONS(85),
    [anon_sym_GROUP_CONCAT] = ACTIONS(87),
    [anon_sym_COLON] = ACTIONS(89),
  },
  [3] = {
    [sym_order_condition] = STATE(3),
    [sym__constraint] = STATE(163),
    [sym_function_call] = STATE(163),
    [sym_bracketted_expression] = STATE(163),
    [sym__build_in_call] = STATE(163),
    [sym_build_in_function] = STATE(163),
    [sym__nullary_build_in_function] = STATE(136),
    [sym__unary_build_in_function] = STATE(120),
    [sym__binary_build_in_function] = STATE(121),
    [sym__variadic_build_in_function] = STATE(122),
    [sym_regex_expression] = STATE(163),
    [sym_substring_expression] = STATE(163),
    [sym_string_replace_expression] = STATE(163),
    [sym_exists_func] = STATE(163),
    [sym_not_exists_func] = STATE(163),
    [sym_aggregate] = STATE(163),
    [sym__iri] = STATE(913),
    [sym_prefixed_name] = STATE(913),
    [sym_iri_reference] = STATE(913),
    [sym_namespace] = STATE(413),
    [aux_sym_order_clause_repeat1] = STATE(3),
    [ts_builtin_sym_end] = ACTIONS(91),
    [sym_pn_prefix] = ACTIONS(93),
    [sym_comment] = ACTIONS(3),
    [aux_sym_base_declaration_token1] = ACTIONS(96),
    [aux_sym_prefix_declaration_token1] = ACTIONS(96),
    [aux_sym_select_clause_token1] = ACTIONS(96),
    [anon_sym_LPAREN] = ACTIONS(98),
    [aux_sym_construct_query_token1] = ACTIONS(96),
    [aux_sym_describe_query_token1] = ACTIONS(96),
    [aux_sym_ask_query_token1] = ACTIONS(96),
    [aux_sym_order_condition_token1] = ACTIONS(101),
    [aux_sym_order_condition_token2] = ACTIONS(101),
    [aux_sym_limit_clause_token1] = ACTIONS(96),
    [aux_sym_offset_clause_token1] = ACTIONS(96),
    [aux_sym_values_clause_token1] = ACTIONS(96),
    [aux_sym_load_token1] = ACTIONS(96),
    [aux_sym_clear_token1] = ACTIONS(96),
    [aux_sym_drop_token1] = ACTIONS(96),
    [aux_sym_create_token1] = ACTIONS(96),
    [aux_sym_add_token1] = ACTIONS(96),
    [aux_sym_move_token1] = ACTIONS(96),
    [aux_sym_copy_token1] = ACTIONS(96),
    [anon_sym_INSERTDATA] = ACTIONS(91),
    [anon_sym_DELETEDATA] = ACTIONS(91),
    [anon_sym_DELETEWHERE] = ACTIONS(91),
    [aux_sym_modify_token1] = ACTIONS(96),
    [aux_sym_delete_clause_token1] = ACTIONS(96),
    [aux_sym_insert_clause_token1] = ACTIONS(96),
    [sym_var] = ACTIONS(104),
    [anon_sym_LT] = ACTIONS(107),
    [aux_sym_binary_expression_token2] = ACTIONS(110),
    [aux_sym_build_in_function_token1] = ACTIONS(113),
    [aux_sym_build_in_function_token2] = ACTIONS(116),
    [aux_sym_build_in_function_token3] = ACTIONS(119),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(122),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(122),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(122),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(122),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(125),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(125),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(125),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(125),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(125),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(125),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(125),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(125),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(125),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(125),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(125),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(125),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(125),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(125),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(125),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(125),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(125),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(125),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(125),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(125),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(125),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(125),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(125),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(125),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(125),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(125),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(125),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(125),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(125),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(125),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(125),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(128),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(128),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(128),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(128),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(128),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(128),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(128),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(128),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(128),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(131),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(131),
    [aux_sym_regex_expression_token1] = ACTIONS(134),
    [aux_sym_substring_expression_token1] = ACTIONS(137),
    [aux_sym_string_replace_expression_token1] = ACTIONS(140),
    [aux_sym_exists_func_token1] = ACTIONS(143),
    [aux_sym_aggregate_token1] = ACTIONS(146),
    [aux_sym_aggregate_token2] = ACTIONS(149),
    [aux_sym_aggregate_token3] = ACTIONS(149),
    [aux_sym_aggregate_token4] = ACTIONS(149),
    [aux_sym_aggregate_token5] = ACTIONS(149),
    [aux_sym_aggregate_token6] = ACTIONS(149),
    [anon_sym_GROUP_CONCAT] = ACTIONS(152),
    [anon_sym_COLON] = ACTIONS(155),
  },
  [4] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(625),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [aux_sym_select_clause_token2] = ACTIONS(158),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_STAR] = ACTIONS(162),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [5] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(644),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [aux_sym_select_clause_token2] = ACTIONS(214),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_STAR] = ACTIONS(216),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [6] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(640),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [aux_sym_select_clause_token2] = ACTIONS(218),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_STAR] = ACTIONS(220),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [7] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(646),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [aux_sym_select_clause_token2] = ACTIONS(222),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_STAR] = ACTIONS(224),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [8] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(600),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [aux_sym_select_clause_token2] = ACTIONS(226),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [9] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(574),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [aux_sym_select_clause_token2] = ACTIONS(228),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [10] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(649),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_STAR] = ACTIONS(230),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [11] = {
    [sym_group_condition] = STATE(14),
    [sym_function_call] = STATE(162),
    [sym__build_in_call] = STATE(162),
    [sym_build_in_function] = STATE(162),
    [sym__nullary_build_in_function] = STATE(136),
    [sym__unary_build_in_function] = STATE(120),
    [sym__binary_build_in_function] = STATE(121),
    [sym__variadic_build_in_function] = STATE(122),
    [sym_regex_expression] = STATE(162),
    [sym_substring_expression] = STATE(162),
    [sym_string_replace_expression] = STATE(162),
    [sym_exists_func] = STATE(162),
    [sym_not_exists_func] = STATE(162),
    [sym_aggregate] = STATE(162),
    [sym__iri] = STATE(913),
    [sym_prefixed_name] = STATE(913),
    [sym_iri_reference] = STATE(913),
    [sym_namespace] = STATE(413),
    [aux_sym_group_clause_repeat1] = STATE(14),
    [ts_builtin_sym_end] = ACTIONS(232),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [aux_sym_base_declaration_token1] = ACTIONS(234),
    [aux_sym_prefix_declaration_token1] = ACTIONS(234),
    [aux_sym_select_clause_token1] = ACTIONS(234),
    [anon_sym_LPAREN] = ACTIONS(236),
    [aux_sym_construct_query_token1] = ACTIONS(234),
    [aux_sym_describe_query_token1] = ACTIONS(234),
    [aux_sym_ask_query_token1] = ACTIONS(234),
    [aux_sym_having_clause_token1] = ACTIONS(234),
    [aux_sym_order_clause_token1] = ACTIONS(234),
    [aux_sym_limit_clause_token1] = ACTIONS(234),
    [aux_sym_offset_clause_token1] = ACTIONS(234),
    [aux_sym_values_clause_token1] = ACTIONS(234),
    [aux_sym_load_token1] = ACTIONS(234),
    [aux_sym_clear_token1] = ACTIONS(234),
    [aux_sym_drop_token1] = ACTIONS(234),
    [aux_sym_create_token1] = ACTIONS(234),
    [aux_sym_add_token1] = ACTIONS(234),
    [aux_sym_move_token1] = ACTIONS(234),
    [aux_sym_copy_token1] = ACTIONS(234),
    [anon_sym_INSERTDATA] = ACTIONS(232),
    [anon_sym_DELETEDATA] = ACTIONS(232),
    [anon_sym_DELETEWHERE] = ACTIONS(232),
    [aux_sym_modify_token1] = ACTIONS(234),
    [aux_sym_delete_clause_token1] = ACTIONS(234),
    [aux_sym_insert_clause_token1] = ACTIONS(234),
    [sym_var] = ACTIONS(238),
    [anon_sym_LT] = ACTIONS(57),
    [aux_sym_binary_expression_token2] = ACTIONS(59),
    [aux_sym_build_in_function_token1] = ACTIONS(61),
    [aux_sym_build_in_function_token2] = ACTIONS(63),
    [aux_sym_build_in_function_token3] = ACTIONS(65),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(67),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(67),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(67),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(67),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(69),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(71),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(71),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(71),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(71),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(71),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(71),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(71),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(71),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(71),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(73),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(73),
    [aux_sym_regex_expression_token1] = ACTIONS(75),
    [aux_sym_substring_expression_token1] = ACTIONS(77),
    [aux_sym_string_replace_expression_token1] = ACTIONS(79),
    [aux_sym_exists_func_token1] = ACTIONS(81),
    [aux_sym_aggregate_token1] = ACTIONS(83),
    [aux_sym_aggregate_token2] = ACTIONS(85),
    [aux_sym_aggregate_token3] = ACTIONS(85),
    [aux_sym_aggregate_token4] = ACTIONS(85),
    [aux_sym_aggregate_token5] = ACTIONS(85),
    [aux_sym_aggregate_token6] = ACTIONS(85),
    [anon_sym_GROUP_CONCAT] = ACTIONS(87),
    [anon_sym_COLON] = ACTIONS(89),
  },
  [12] = {
    [sym_having_condition] = STATE(12),
    [sym__constraint] = STATE(166),
    [sym_function_call] = STATE(166),
    [sym_bracketted_expression] = STATE(166),
    [sym__build_in_call] = STATE(166),
    [sym_build_in_function] = STATE(166),
    [sym__nullary_build_in_function] = STATE(136),
    [sym__unary_build_in_function] = STATE(120),
    [sym__binary_build_in_function] = STATE(121),
    [sym__variadic_build_in_function] = STATE(122),
    [sym_regex_expression] = STATE(166),
    [sym_substring_expression] = STATE(166),
    [sym_string_replace_expression] = STATE(166),
    [sym_exists_func] = STATE(166),
    [sym_not_exists_func] = STATE(166),
    [sym_aggregate] = STATE(166),
    [sym__iri] = STATE(913),
    [sym_prefixed_name] = STATE(913),
    [sym_iri_reference] = STATE(913),
    [sym_namespace] = STATE(413),
    [aux_sym_having_clause_repeat1] = STATE(12),
    [ts_builtin_sym_end] = ACTIONS(240),
    [sym_pn_prefix] = ACTIONS(242),
    [sym_comment] = ACTIONS(3),
    [aux_sym_base_declaration_token1] = ACTIONS(245),
    [aux_sym_prefix_declaration_token1] = ACTIONS(245),
    [aux_sym_select_clause_token1] = ACTIONS(245),
    [anon_sym_LPAREN] = ACTIONS(247),
    [aux_sym_construct_query_token1] = ACTIONS(245),
    [aux_sym_describe_query_token1] = ACTIONS(245),
    [aux_sym_ask_query_token1] = ACTIONS(245),
    [aux_sym_order_clause_token1] = ACTIONS(245),
    [aux_sym_limit_clause_token1] = ACTIONS(245),
    [aux_sym_offset_clause_token1] = ACTIONS(245),
    [aux_sym_values_clause_token1] = ACTIONS(245),
    [aux_sym_load_token1] = ACTIONS(245),
    [aux_sym_clear_token1] = ACTIONS(245),
    [aux_sym_drop_token1] = ACTIONS(245),
    [aux_sym_create_token1] = ACTIONS(245),
    [aux_sym_add_token1] = ACTIONS(245),
    [aux_sym_move_token1] = ACTIONS(245),
    [aux_sym_copy_token1] = ACTIONS(245),
    [anon_sym_INSERTDATA] = ACTIONS(240),
    [anon_sym_DELETEDATA] = ACTIONS(240),
    [anon_sym_DELETEWHERE] = ACTIONS(240),
    [aux_sym_modify_token1] = ACTIONS(245),
    [aux_sym_delete_clause_token1] = ACTIONS(245),
    [aux_sym_insert_clause_token1] = ACTIONS(245),
    [anon_sym_LT] = ACTIONS(250),
    [aux_sym_binary_expression_token2] = ACTIONS(253),
    [aux_sym_build_in_function_token1] = ACTIONS(256),
    [aux_sym_build_in_function_token2] = ACTIONS(259),
    [aux_sym_build_in_function_token3] = ACTIONS(262),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(265),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(265),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(265),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(265),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(268),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(268),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(268),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(268),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(268),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(268),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(268),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(268),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(268),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(268),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(268),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(268),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(268),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(268),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(268),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(268),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(268),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(268),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(268),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(268),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(268),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(268),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(268),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(268),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(268),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(268),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(268),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(268),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(268),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(268),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(268),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(271),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(271),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(271),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(271),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(271),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(271),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(271),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(271),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(271),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(274),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(274),
    [aux_sym_regex_expression_token1] = ACTIONS(277),
    [aux_sym_substring_expression_token1] = ACTIONS(280),
    [aux_sym_string_replace_expression_token1] = ACTIONS(283),
    [aux_sym_exists_func_token1] = ACTIONS(286),
    [aux_sym_aggregate_token1] = ACTIONS(289),
    [aux_sym_aggregate_token2] = ACTIONS(292),
    [aux_sym_aggregate_token3] = ACTIONS(292),
    [aux_sym_aggregate_token4] = ACTIONS(292),
    [aux_sym_aggregate_token5] = ACTIONS(292),
    [aux_sym_aggregate_token6] = ACTIONS(292),
    [anon_sym_GROUP_CONCAT] = ACTIONS(295),
    [anon_sym_COLON] = ACTIONS(298),
  },
  [13] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(625),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [aux_sym_select_clause_token2] = ACTIONS(301),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [14] = {
    [sym_group_condition] = STATE(14),
    [sym_function_call] = STATE(162),
    [sym__build_in_call] = STATE(162),
    [sym_build_in_function] = STATE(162),
    [sym__nullary_build_in_function] = STATE(136),
    [sym__unary_build_in_function] = STATE(120),
    [sym__binary_build_in_function] = STATE(121),
    [sym__variadic_build_in_function] = STATE(122),
    [sym_regex_expression] = STATE(162),
    [sym_substring_expression] = STATE(162),
    [sym_string_replace_expression] = STATE(162),
    [sym_exists_func] = STATE(162),
    [sym_not_exists_func] = STATE(162),
    [sym_aggregate] = STATE(162),
    [sym__iri] = STATE(913),
    [sym_prefixed_name] = STATE(913),
    [sym_iri_reference] = STATE(913),
    [sym_namespace] = STATE(413),
    [aux_sym_group_clause_repeat1] = STATE(14),
    [ts_builtin_sym_end] = ACTIONS(303),
    [sym_pn_prefix] = ACTIONS(305),
    [sym_comment] = ACTIONS(3),
    [aux_sym_base_declaration_token1] = ACTIONS(308),
    [aux_sym_prefix_declaration_token1] = ACTIONS(308),
    [aux_sym_select_clause_token1] = ACTIONS(308),
    [anon_sym_LPAREN] = ACTIONS(310),
    [aux_sym_construct_query_token1] = ACTIONS(308),
    [aux_sym_describe_query_token1] = ACTIONS(308),
    [aux_sym_ask_query_token1] = ACTIONS(308),
    [aux_sym_having_clause_token1] = ACTIONS(308),
    [aux_sym_order_clause_token1] = ACTIONS(308),
    [aux_sym_limit_clause_token1] = ACTIONS(308),
    [aux_sym_offset_clause_token1] = ACTIONS(308),
    [aux_sym_values_clause_token1] = ACTIONS(308),
    [aux_sym_load_token1] = ACTIONS(308),
    [aux_sym_clear_token1] = ACTIONS(308),
    [aux_sym_drop_token1] = ACTIONS(308),
    [aux_sym_create_token1] = ACTIONS(308),
    [aux_sym_add_token1] = ACTIONS(308),
    [aux_sym_move_token1] = ACTIONS(308),
    [aux_sym_copy_token1] = ACTIONS(308),
    [anon_sym_INSERTDATA] = ACTIONS(303),
    [anon_sym_DELETEDATA] = ACTIONS(303),
    [anon_sym_DELETEWHERE] = ACTIONS(303),
    [aux_sym_modify_token1] = ACTIONS(308),
    [aux_sym_delete_clause_token1] = ACTIONS(308),
    [aux_sym_insert_clause_token1] = ACTIONS(308),
    [sym_var] = ACTIONS(313),
    [anon_sym_LT] = ACTIONS(316),
    [aux_sym_binary_expression_token2] = ACTIONS(319),
    [aux_sym_build_in_function_token1] = ACTIONS(322),
    [aux_sym_build_in_function_token2] = ACTIONS(325),
    [aux_sym_build_in_function_token3] = ACTIONS(328),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(331),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(331),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(331),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(331),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(334),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(334),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(334),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(334),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(334),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(334),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(334),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(334),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(334),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(334),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(334),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(334),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(334),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(334),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(334),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(334),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(334),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(334),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(334),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(334),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(334),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(334),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(334),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(334),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(334),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(334),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(334),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(334),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(334),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(334),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(334),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(337),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(337),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(337),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(337),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(337),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(337),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(337),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(337),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(337),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(340),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(340),
    [aux_sym_regex_expression_token1] = ACTIONS(343),
    [aux_sym_substring_expression_token1] = ACTIONS(346),
    [aux_sym_string_replace_expression_token1] = ACTIONS(349),
    [aux_sym_exists_func_token1] = ACTIONS(352),
    [aux_sym_aggregate_token1] = ACTIONS(355),
    [aux_sym_aggregate_token2] = ACTIONS(358),
    [aux_sym_aggregate_token3] = ACTIONS(358),
    [aux_sym_aggregate_token4] = ACTIONS(358),
    [aux_sym_aggregate_token5] = ACTIONS(358),
    [aux_sym_aggregate_token6] = ACTIONS(358),
    [anon_sym_GROUP_CONCAT] = ACTIONS(361),
    [anon_sym_COLON] = ACTIONS(364),
  },
  [15] = {
    [sym_having_condition] = STATE(12),
    [sym__constraint] = STATE(166),
    [sym_function_call] = STATE(166),
    [sym_bracketted_expression] = STATE(166),
    [sym__build_in_call] = STATE(166),
    [sym_build_in_function] = STATE(166),
    [sym__nullary_build_in_function] = STATE(136),
    [sym__unary_build_in_function] = STATE(120),
    [sym__binary_build_in_function] = STATE(121),
    [sym__variadic_build_in_function] = STATE(122),
    [sym_regex_expression] = STATE(166),
    [sym_substring_expression] = STATE(166),
    [sym_string_replace_expression] = STATE(166),
    [sym_exists_func] = STATE(166),
    [sym_not_exists_func] = STATE(166),
    [sym_aggregate] = STATE(166),
    [sym__iri] = STATE(913),
    [sym_prefixed_name] = STATE(913),
    [sym_iri_reference] = STATE(913),
    [sym_namespace] = STATE(413),
    [aux_sym_having_clause_repeat1] = STATE(12),
    [ts_builtin_sym_end] = ACTIONS(367),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [aux_sym_base_declaration_token1] = ACTIONS(369),
    [aux_sym_prefix_declaration_token1] = ACTIONS(369),
    [aux_sym_select_clause_token1] = ACTIONS(369),
    [anon_sym_LPAREN] = ACTIONS(51),
    [aux_sym_construct_query_token1] = ACTIONS(369),
    [aux_sym_describe_query_token1] = ACTIONS(369),
    [aux_sym_ask_query_token1] = ACTIONS(369),
    [aux_sym_order_clause_token1] = ACTIONS(369),
    [aux_sym_limit_clause_token1] = ACTIONS(369),
    [aux_sym_offset_clause_token1] = ACTIONS(369),
    [aux_sym_values_clause_token1] = ACTIONS(369),
    [aux_sym_load_token1] = ACTIONS(369),
    [aux_sym_clear_token1] = ACTIONS(369),
    [aux_sym_drop_token1] = ACTIONS(369),
    [aux_sym_create_token1] = ACTIONS(369),
    [aux_sym_add_token1] = ACTIONS(369),
    [aux_sym_move_token1] = ACTIONS(369),
    [aux_sym_copy_token1] = ACTIONS(369),
    [anon_sym_INSERTDATA] = ACTIONS(367),
    [anon_sym_DELETEDATA] = ACTIONS(367),
    [anon_sym_DELETEWHERE] = ACTIONS(367),
    [aux_sym_modify_token1] = ACTIONS(369),
    [aux_sym_delete_clause_token1] = ACTIONS(369),
    [aux_sym_insert_clause_token1] = ACTIONS(369),
    [anon_sym_LT] = ACTIONS(57),
    [aux_sym_binary_expression_token2] = ACTIONS(59),
    [aux_sym_build_in_function_token1] = ACTIONS(61),
    [aux_sym_build_in_function_token2] = ACTIONS(63),
    [aux_sym_build_in_function_token3] = ACTIONS(65),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(67),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(67),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(67),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(67),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(69),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(71),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(71),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(71),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(71),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(71),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(71),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(71),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(71),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(71),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(73),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(73),
    [aux_sym_regex_expression_token1] = ACTIONS(75),
    [aux_sym_substring_expression_token1] = ACTIONS(77),
    [aux_sym_string_replace_expression_token1] = ACTIONS(79),
    [aux_sym_exists_func_token1] = ACTIONS(81),
    [aux_sym_aggregate_token1] = ACTIONS(83),
    [aux_sym_aggregate_token2] = ACTIONS(85),
    [aux_sym_aggregate_token3] = ACTIONS(85),
    [aux_sym_aggregate_token4] = ACTIONS(85),
    [aux_sym_aggregate_token5] = ACTIONS(85),
    [aux_sym_aggregate_token6] = ACTIONS(85),
    [anon_sym_GROUP_CONCAT] = ACTIONS(87),
    [anon_sym_COLON] = ACTIONS(89),
  },
  [16] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(642),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_STAR] = ACTIONS(371),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [17] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(647),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_STAR] = ACTIONS(373),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [18] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(644),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [aux_sym_select_clause_token2] = ACTIONS(375),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [19] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(575),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [aux_sym_select_clause_token2] = ACTIONS(377),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [20] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(646),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [aux_sym_select_clause_token2] = ACTIONS(379),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [21] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(588),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [aux_sym_select_clause_token2] = ACTIONS(381),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [22] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(582),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [aux_sym_select_clause_token2] = ACTIONS(383),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [23] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(632),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_STAR] = ACTIONS(385),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [24] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(612),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [aux_sym_select_clause_token2] = ACTIONS(387),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [25] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(640),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [aux_sym_select_clause_token2] = ACTIONS(389),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [26] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(595),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [aux_sym_select_clause_token2] = ACTIONS(391),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [27] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(585),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [aux_sym_select_clause_token2] = ACTIONS(393),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [28] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(682),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [29] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(635),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [30] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(639),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [31] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(578),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [32] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(645),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [33] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(622),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [34] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(624),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [35] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(636),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [36] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(570),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [37] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(533),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [38] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(534),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [39] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(535),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [40] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(540),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [41] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(634),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [42] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(649),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [43] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(616),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [44] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(583),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [45] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(619),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [46] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(670),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [47] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(630),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [48] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(605),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [49] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(593),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [50] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(594),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [51] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(629),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [52] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(637),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [53] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(638),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [54] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(621),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [55] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(608),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [56] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(626),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [57] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(641),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [58] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(576),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [59] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(671),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [60] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(647),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [61] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(614),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [62] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(577),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [63] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(615),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [64] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(667),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [65] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(617),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [66] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(618),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [67] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(672),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [68] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(673),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [69] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(674),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [70] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(603),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [71] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(676),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [72] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(683),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [73] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(581),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [74] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(632),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [75] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(681),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [76] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(584),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [77] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(631),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [78] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(590),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [79] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(591),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [80] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(643),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [81] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(648),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [82] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(650),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [83] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(592),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [84] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(627),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [85] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(633),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [86] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(580),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [87] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(642),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [88] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(596),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [89] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(586),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [90] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(684),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [91] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(597),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [92] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(598),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [93] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(651),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [94] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(668),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [95] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(669),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [96] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(599),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [97] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(675),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [98] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(652),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [99] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(653),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [100] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(654),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [101] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(655),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [102] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(656),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [103] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(657),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [104] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(658),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [105] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(659),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [106] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(660),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [107] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(661),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [108] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(662),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [109] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(663),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [110] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(664),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [111] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(665),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [112] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(666),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [113] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(677),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [114] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(678),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [115] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(679),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [116] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(680),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [117] = {
    [sym_function_call] = STATE(546),
    [sym__expression] = STATE(589),
    [sym_binary_expression] = STATE(546),
    [sym_unary_expression] = STATE(546),
    [sym__primary_expression] = STATE(546),
    [sym_bracketted_expression] = STATE(546),
    [sym__build_in_call] = STATE(546),
    [sym_build_in_function] = STATE(546),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(546),
    [sym_substring_expression] = STATE(546),
    [sym_string_replace_expression] = STATE(546),
    [sym_exists_func] = STATE(546),
    [sym_not_exists_func] = STATE(546),
    [sym_aggregate] = STATE(546),
    [sym__iri_or_function] = STATE(546),
    [sym_rdf_literal] = STATE(546),
    [sym__numeric_literal] = STATE(546),
    [sym_boolean_literal] = STATE(546),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [anon_sym_BANG] = ACTIONS(164),
    [sym_var] = ACTIONS(166),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [anon_sym_PLUS] = ACTIONS(172),
    [anon_sym_DASH] = ACTIONS(172),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(204),
    [sym_decimal] = ACTIONS(204),
    [sym_double] = ACTIONS(166),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [118] = {
    [sym_function_call] = STATE(563),
    [sym__primary_expression] = STATE(563),
    [sym_bracketted_expression] = STATE(563),
    [sym__build_in_call] = STATE(563),
    [sym_build_in_function] = STATE(563),
    [sym__nullary_build_in_function] = STATE(567),
    [sym__unary_build_in_function] = STATE(573),
    [sym__binary_build_in_function] = STATE(532),
    [sym__variadic_build_in_function] = STATE(537),
    [sym_regex_expression] = STATE(563),
    [sym_substring_expression] = STATE(563),
    [sym_string_replace_expression] = STATE(563),
    [sym_exists_func] = STATE(563),
    [sym_not_exists_func] = STATE(563),
    [sym_aggregate] = STATE(563),
    [sym__iri_or_function] = STATE(563),
    [sym_rdf_literal] = STATE(563),
    [sym__numeric_literal] = STATE(563),
    [sym_boolean_literal] = STATE(563),
    [sym_string] = STATE(506),
    [sym__iri] = STATE(484),
    [sym_prefixed_name] = STATE(484),
    [sym_iri_reference] = STATE(484),
    [sym_namespace] = STATE(387),
    [sym__string_literal1] = STATE(296),
    [sym__string_literal2] = STATE(296),
    [sym__string_literal_long1] = STATE(296),
    [sym__string_literal_long2] = STATE(296),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(160),
    [sym_var] = ACTIONS(395),
    [anon_sym_LT] = ACTIONS(168),
    [aux_sym_binary_expression_token2] = ACTIONS(170),
    [aux_sym_build_in_function_token1] = ACTIONS(174),
    [aux_sym_build_in_function_token2] = ACTIONS(176),
    [aux_sym_build_in_function_token3] = ACTIONS(178),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(180),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(180),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(182),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(182),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(184),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(184),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(186),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(186),
    [aux_sym_regex_expression_token1] = ACTIONS(188),
    [aux_sym_substring_expression_token1] = ACTIONS(190),
    [aux_sym_string_replace_expression_token1] = ACTIONS(192),
    [aux_sym_exists_func_token1] = ACTIONS(194),
    [aux_sym_aggregate_token1] = ACTIONS(196),
    [aux_sym_aggregate_token2] = ACTIONS(198),
    [aux_sym_aggregate_token3] = ACTIONS(198),
    [aux_sym_aggregate_token4] = ACTIONS(198),
    [aux_sym_aggregate_token5] = ACTIONS(198),
    [aux_sym_aggregate_token6] = ACTIONS(198),
    [anon_sym_GROUP_CONCAT] = ACTIONS(200),
    [anon_sym_true] = ACTIONS(202),
    [anon_sym_false] = ACTIONS(202),
    [anon_sym_COLON] = ACTIONS(89),
    [sym_integer] = ACTIONS(397),
    [sym_decimal] = ACTIONS(397),
    [sym_double] = ACTIONS(395),
    [anon_sym_SQUOTE] = ACTIONS(206),
    [anon_sym_DQUOTE] = ACTIONS(208),
    [anon_sym_SQUOTE_SQUOTE_SQUOTE] = ACTIONS(210),
    [anon_sym_DQUOTE_DQUOTE_DQUOTE] = ACTIONS(212),
  },
  [119] = {
    [ts_builtin_sym_end] = ACTIONS(399),
    [sym_pn_prefix] = ACTIONS(401),
    [sym_comment] = ACTIONS(3),
    [aux_sym_base_declaration_token1] = ACTIONS(401),
    [aux_sym_prefix_declaration_token1] = ACTIONS(401),
    [aux_sym_select_clause_token1] = ACTIONS(401),
    [anon_sym_LPAREN] = ACTIONS(399),
    [aux_sym_construct_query_token1] = ACTIONS(401),
    [aux_sym_describe_query_token1] = ACTIONS(401),
    [aux_sym_ask_query_token1] = ACTIONS(401),
    [aux_sym_having_clause_token1] = ACTIONS(401),
    [aux_sym_order_clause_token1] = ACTIONS(401),
    [aux_sym_order_condition_token1] = ACTIONS(401),
    [aux_sym_order_condition_token2] = ACTIONS(401),
    [aux_sym_limit_clause_token1] = ACTIONS(401),
    [aux_sym_offset_clause_token1] = ACTIONS(401),
    [aux_sym_values_clause_token1] = ACTIONS(401),
    [aux_sym_load_token1] = ACTIONS(401),
    [aux_sym_clear_token1] = ACTIONS(401),
    [aux_sym_drop_token1] = ACTIONS(401),
    [aux_sym_create_token1] = ACTIONS(401),
    [aux_sym_add_token1] = ACTIONS(401),
    [aux_sym_move_token1] = ACTIONS(401),
    [aux_sym_copy_token1] = ACTIONS(401),
    [anon_sym_INSERTDATA] = ACTIONS(399),
    [anon_sym_DELETEDATA] = ACTIONS(399),
    [anon_sym_DELETEWHERE] = ACTIONS(399),
    [aux_sym_modify_token1] = ACTIONS(401),
    [aux_sym_delete_clause_token1] = ACTIONS(401),
    [aux_sym_insert_clause_token1] = ACTIONS(401),
    [sym_var] = ACTIONS(399),
    [anon_sym_LT] = ACTIONS(399),
    [aux_sym_binary_expression_token2] = ACTIONS(401),
    [aux_sym_build_in_function_token1] = ACTIONS(401),
    [aux_sym_build_in_function_token2] = ACTIONS(401),
    [aux_sym_build_in_function_token3] = ACTIONS(401),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(401),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(401),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(401),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(401),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(401),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(401),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(401),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(401),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(401),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(401),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(401),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(401),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(401),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(401),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(401),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(401),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(401),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(401),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(401),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(401),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(401),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(401),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(401),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(401),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(401),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(401),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(401),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(401),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(401),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(401),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(401),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(401),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(401),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(401),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(401),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(401),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(401),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(401),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(401),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(401),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(401),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(401),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(401),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(401),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(401),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(401),
    [aux_sym_regex_expression_token1] = ACTIONS(401),
    [aux_sym_substring_expression_token1] = ACTIONS(401),
    [aux_sym_string_replace_expression_token1] = ACTIONS(401),
    [aux_sym_exists_func_token1] = ACTIONS(401),
    [aux_sym_aggregate_token1] = ACTIONS(401),
    [aux_sym_aggregate_token2] = ACTIONS(401),
    [aux_sym_aggregate_token3] = ACTIONS(401),
    [aux_sym_aggregate_token4] = ACTIONS(401),
    [aux_sym_aggregate_token5] = ACTIONS(401),
    [aux_sym_aggregate_token6] = ACTIONS(401),
    [anon_sym_GROUP_CONCAT] = ACTIONS(401),
    [anon_sym_COLON] = ACTIONS(399),
  },
  [120] = {
    [ts_builtin_sym_end] = ACTIONS(403),
    [sym_pn_prefix] = ACTIONS(405),
    [sym_comment] = ACTIONS(3),
    [aux_sym_base_declaration_token1] = ACTIONS(405),
    [aux_sym_prefix_declaration_token1] = ACTIONS(405),
    [aux_sym_select_clause_token1] = ACTIONS(405),
    [anon_sym_LPAREN] = ACTIONS(403),
    [aux_sym_construct_query_token1] = ACTIONS(405),
    [aux_sym_describe_query_token1] = ACTIONS(405),
    [aux_sym_ask_query_token1] = ACTIONS(405),
    [aux_sym_having_clause_token1] = ACTIONS(405),
    [aux_sym_order_clause_token1] = ACTIONS(405),
    [aux_sym_order_condition_token1] = ACTIONS(405),
    [aux_sym_order_condition_token2] = ACTIONS(405),
    [aux_sym_limit_clause_token1] = ACTIONS(405),
    [aux_sym_offset_clause_token1] = ACTIONS(405),
    [aux_sym_values_clause_token1] = ACTIONS(405),
    [aux_sym_load_token1] = ACTIONS(405),
    [aux_sym_clear_token1] = ACTIONS(405),
    [aux_sym_drop_token1] = ACTIONS(405),
    [aux_sym_create_token1] = ACTIONS(405),
    [aux_sym_add_token1] = ACTIONS(405),
    [aux_sym_move_token1] = ACTIONS(405),
    [aux_sym_copy_token1] = ACTIONS(405),
    [anon_sym_INSERTDATA] = ACTIONS(403),
    [anon_sym_DELETEDATA] = ACTIONS(403),
    [anon_sym_DELETEWHERE] = ACTIONS(403),
    [aux_sym_modify_token1] = ACTIONS(405),
    [aux_sym_delete_clause_token1] = ACTIONS(405),
    [aux_sym_insert_clause_token1] = ACTIONS(405),
    [sym_var] = ACTIONS(403),
    [anon_sym_LT] = ACTIONS(403),
    [aux_sym_binary_expression_token2] = ACTIONS(405),
    [aux_sym_build_in_function_token1] = ACTIONS(405),
    [aux_sym_build_in_function_token2] = ACTIONS(405),
    [aux_sym_build_in_function_token3] = ACTIONS(405),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(405),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(405),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(405),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(405),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(405),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(405),
    [aux_sym_regex_expression_token1] = ACTIONS(405),
    [aux_sym_substring_expression_token1] = ACTIONS(405),
    [aux_sym_string_replace_expression_token1] = ACTIONS(405),
    [aux_sym_exists_func_token1] = ACTIONS(405),
    [aux_sym_aggregate_token1] = ACTIONS(405),
    [aux_sym_aggregate_token2] = ACTIONS(405),
    [aux_sym_aggregate_token3] = ACTIONS(405),
    [aux_sym_aggregate_token4] = ACTIONS(405),
    [aux_sym_aggregate_token5] = ACTIONS(405),
    [aux_sym_aggregate_token6] = ACTIONS(405),
    [anon_sym_GROUP_CONCAT] = ACTIONS(405),
    [anon_sym_COLON] = ACTIONS(403),
  },
  [121] = {
    [ts_builtin_sym_end] = ACTIONS(403),
    [sym_pn_prefix] = ACTIONS(405),
    [sym_comment] = ACTIONS(3),
    [aux_sym_base_declaration_token1] = ACTIONS(405),
    [aux_sym_prefix_declaration_token1] = ACTIONS(405),
    [aux_sym_select_clause_token1] = ACTIONS(405),
    [anon_sym_LPAREN] = ACTIONS(403),
    [aux_sym_construct_query_token1] = ACTIONS(405),
    [aux_sym_describe_query_token1] = ACTIONS(405),
    [aux_sym_ask_query_token1] = ACTIONS(405),
    [aux_sym_having_clause_token1] = ACTIONS(405),
    [aux_sym_order_clause_token1] = ACTIONS(405),
    [aux_sym_order_condition_token1] = ACTIONS(405),
    [aux_sym_order_condition_token2] = ACTIONS(405),
    [aux_sym_limit_clause_token1] = ACTIONS(405),
    [aux_sym_offset_clause_token1] = ACTIONS(405),
    [aux_sym_values_clause_token1] = ACTIONS(405),
    [aux_sym_load_token1] = ACTIONS(405),
    [aux_sym_clear_token1] = ACTIONS(405),
    [aux_sym_drop_token1] = ACTIONS(405),
    [aux_sym_create_token1] = ACTIONS(405),
    [aux_sym_add_token1] = ACTIONS(405),
    [aux_sym_move_token1] = ACTIONS(405),
    [aux_sym_copy_token1] = ACTIONS(405),
    [anon_sym_INSERTDATA] = ACTIONS(403),
    [anon_sym_DELETEDATA] = ACTIONS(403),
    [anon_sym_DELETEWHERE] = ACTIONS(403),
    [aux_sym_modify_token1] = ACTIONS(405),
    [aux_sym_delete_clause_token1] = ACTIONS(405),
    [aux_sym_insert_clause_token1] = ACTIONS(405),
    [sym_var] = ACTIONS(403),
    [anon_sym_LT] = ACTIONS(403),
    [aux_sym_binary_expression_token2] = ACTIONS(405),
    [aux_sym_build_in_function_token1] = ACTIONS(405),
    [aux_sym_build_in_function_token2] = ACTIONS(405),
    [aux_sym_build_in_function_token3] = ACTIONS(405),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(405),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(405),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(405),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(405),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(405),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(405),
    [aux_sym_regex_expression_token1] = ACTIONS(405),
    [aux_sym_substring_expression_token1] = ACTIONS(405),
    [aux_sym_string_replace_expression_token1] = ACTIONS(405),
    [aux_sym_exists_func_token1] = ACTIONS(405),
    [aux_sym_aggregate_token1] = ACTIONS(405),
    [aux_sym_aggregate_token2] = ACTIONS(405),
    [aux_sym_aggregate_token3] = ACTIONS(405),
    [aux_sym_aggregate_token4] = ACTIONS(405),
    [aux_sym_aggregate_token5] = ACTIONS(405),
    [aux_sym_aggregate_token6] = ACTIONS(405),
    [anon_sym_GROUP_CONCAT] = ACTIONS(405),
    [anon_sym_COLON] = ACTIONS(403),
  },
  [122] = {
    [ts_builtin_sym_end] = ACTIONS(403),
    [sym_pn_prefix] = ACTIONS(405),
    [sym_comment] = ACTIONS(3),
    [aux_sym_base_declaration_token1] = ACTIONS(405),
    [aux_sym_prefix_declaration_token1] = ACTIONS(405),
    [aux_sym_select_clause_token1] = ACTIONS(405),
    [anon_sym_LPAREN] = ACTIONS(403),
    [aux_sym_construct_query_token1] = ACTIONS(405),
    [aux_sym_describe_query_token1] = ACTIONS(405),
    [aux_sym_ask_query_token1] = ACTIONS(405),
    [aux_sym_having_clause_token1] = ACTIONS(405),
    [aux_sym_order_clause_token1] = ACTIONS(405),
    [aux_sym_order_condition_token1] = ACTIONS(405),
    [aux_sym_order_condition_token2] = ACTIONS(405),
    [aux_sym_limit_clause_token1] = ACTIONS(405),
    [aux_sym_offset_clause_token1] = ACTIONS(405),
    [aux_sym_values_clause_token1] = ACTIONS(405),
    [aux_sym_load_token1] = ACTIONS(405),
    [aux_sym_clear_token1] = ACTIONS(405),
    [aux_sym_drop_token1] = ACTIONS(405),
    [aux_sym_create_token1] = ACTIONS(405),
    [aux_sym_add_token1] = ACTIONS(405),
    [aux_sym_move_token1] = ACTIONS(405),
    [aux_sym_copy_token1] = ACTIONS(405),
    [anon_sym_INSERTDATA] = ACTIONS(403),
    [anon_sym_DELETEDATA] = ACTIONS(403),
    [anon_sym_DELETEWHERE] = ACTIONS(403),
    [aux_sym_modify_token1] = ACTIONS(405),
    [aux_sym_delete_clause_token1] = ACTIONS(405),
    [aux_sym_insert_clause_token1] = ACTIONS(405),
    [sym_var] = ACTIONS(403),
    [anon_sym_LT] = ACTIONS(403),
    [aux_sym_binary_expression_token2] = ACTIONS(405),
    [aux_sym_build_in_function_token1] = ACTIONS(405),
    [aux_sym_build_in_function_token2] = ACTIONS(405),
    [aux_sym_build_in_function_token3] = ACTIONS(405),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(405),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(405),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(405),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(405),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(405),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(405),
    [aux_sym_regex_expression_token1] = ACTIONS(405),
    [aux_sym_substring_expression_token1] = ACTIONS(405),
    [aux_sym_string_replace_expression_token1] = ACTIONS(405),
    [aux_sym_exists_func_token1] = ACTIONS(405),
    [aux_sym_aggregate_token1] = ACTIONS(405),
    [aux_sym_aggregate_token2] = ACTIONS(405),
    [aux_sym_aggregate_token3] = ACTIONS(405),
    [aux_sym_aggregate_token4] = ACTIONS(405),
    [aux_sym_aggregate_token5] = ACTIONS(405),
    [aux_sym_aggregate_token6] = ACTIONS(405),
    [anon_sym_GROUP_CONCAT] = ACTIONS(405),
    [anon_sym_COLON] = ACTIONS(403),
  },
  [123] = {
    [ts_builtin_sym_end] = ACTIONS(407),
    [sym_pn_prefix] = ACTIONS(409),
    [sym_comment] = ACTIONS(3),
    [aux_sym_base_declaration_token1] = ACTIONS(409),
    [aux_sym_prefix_declaration_token1] = ACTIONS(409),
    [aux_sym_select_clause_token1] = ACTIONS(409),
    [anon_sym_LPAREN] = ACTIONS(407),
    [aux_sym_construct_query_token1] = ACTIONS(409),
    [aux_sym_describe_query_token1] = ACTIONS(409),
    [aux_sym_ask_query_token1] = ACTIONS(409),
    [aux_sym_having_clause_token1] = ACTIONS(409),
    [aux_sym_order_clause_token1] = ACTIONS(409),
    [aux_sym_order_condition_token1] = ACTIONS(409),
    [aux_sym_order_condition_token2] = ACTIONS(409),
    [aux_sym_limit_clause_token1] = ACTIONS(409),
    [aux_sym_offset_clause_token1] = ACTIONS(409),
    [aux_sym_values_clause_token1] = ACTIONS(409),
    [aux_sym_load_token1] = ACTIONS(409),
    [aux_sym_clear_token1] = ACTIONS(409),
    [aux_sym_drop_token1] = ACTIONS(409),
    [aux_sym_create_token1] = ACTIONS(409),
    [aux_sym_add_token1] = ACTIONS(409),
    [aux_sym_move_token1] = ACTIONS(409),
    [aux_sym_copy_token1] = ACTIONS(409),
    [anon_sym_INSERTDATA] = ACTIONS(407),
    [anon_sym_DELETEDATA] = ACTIONS(407),
    [anon_sym_DELETEWHERE] = ACTIONS(407),
    [aux_sym_modify_token1] = ACTIONS(409),
    [aux_sym_delete_clause_token1] = ACTIONS(409),
    [aux_sym_insert_clause_token1] = ACTIONS(409),
    [sym_var] = ACTIONS(407),
    [anon_sym_LT] = ACTIONS(407),
    [aux_sym_binary_expression_token2] = ACTIONS(409),
    [aux_sym_build_in_function_token1] = ACTIONS(409),
    [aux_sym_build_in_function_token2] = ACTIONS(409),
    [aux_sym_build_in_function_token3] = ACTIONS(409),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(409),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(409),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(409),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(409),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(409),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(409),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(409),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(409),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(409),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(409),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(409),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(409),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(409),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(409),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(409),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(409),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(409),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(409),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(409),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(409),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(409),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(409),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(409),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(409),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(409),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(409),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(409),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(409),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(409),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(409),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(409),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(409),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(409),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(409),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(409),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(409),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(409),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(409),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(409),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(409),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(409),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(409),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(409),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(409),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(409),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(409),
    [aux_sym_regex_expression_token1] = ACTIONS(409),
    [aux_sym_substring_expression_token1] = ACTIONS(409),
    [aux_sym_string_replace_expression_token1] = ACTIONS(409),
    [aux_sym_exists_func_token1] = ACTIONS(409),
    [aux_sym_aggregate_token1] = ACTIONS(409),
    [aux_sym_aggregate_token2] = ACTIONS(409),
    [aux_sym_aggregate_token3] = ACTIONS(409),
    [aux_sym_aggregate_token4] = ACTIONS(409),
    [aux_sym_aggregate_token5] = ACTIONS(409),
    [aux_sym_aggregate_token6] = ACTIONS(409),
    [anon_sym_GROUP_CONCAT] = ACTIONS(409),
    [anon_sym_COLON] = ACTIONS(407),
  },
  [124] = {
    [ts_builtin_sym_end] = ACTIONS(411),
    [sym_pn_prefix] = ACTIONS(413),
    [sym_comment] = ACTIONS(3),
    [aux_sym_base_declaration_token1] = ACTIONS(413),
    [aux_sym_prefix_declaration_token1] = ACTIONS(413),
    [aux_sym_select_clause_token1] = ACTIONS(413),
    [anon_sym_LPAREN] = ACTIONS(411),
    [aux_sym_construct_query_token1] = ACTIONS(413),
    [aux_sym_describe_query_token1] = ACTIONS(413),
    [aux_sym_ask_query_token1] = ACTIONS(413),
    [aux_sym_having_clause_token1] = ACTIONS(413),
    [aux_sym_order_clause_token1] = ACTIONS(413),
    [aux_sym_order_condition_token1] = ACTIONS(413),
    [aux_sym_order_condition_token2] = ACTIONS(413),
    [aux_sym_limit_clause_token1] = ACTIONS(413),
    [aux_sym_offset_clause_token1] = ACTIONS(413),
    [aux_sym_values_clause_token1] = ACTIONS(413),
    [aux_sym_load_token1] = ACTIONS(413),
    [aux_sym_clear_token1] = ACTIONS(413),
    [aux_sym_drop_token1] = ACTIONS(413),
    [aux_sym_create_token1] = ACTIONS(413),
    [aux_sym_add_token1] = ACTIONS(413),
    [aux_sym_move_token1] = ACTIONS(413),
    [aux_sym_copy_token1] = ACTIONS(413),
    [anon_sym_INSERTDATA] = ACTIONS(411),
    [anon_sym_DELETEDATA] = ACTIONS(411),
    [anon_sym_DELETEWHERE] = ACTIONS(411),
    [aux_sym_modify_token1] = ACTIONS(413),
    [aux_sym_delete_clause_token1] = ACTIONS(413),
    [aux_sym_insert_clause_token1] = ACTIONS(413),
    [sym_var] = ACTIONS(411),
    [anon_sym_LT] = ACTIONS(411),
    [aux_sym_binary_expression_token2] = ACTIONS(413),
    [aux_sym_build_in_function_token1] = ACTIONS(413),
    [aux_sym_build_in_function_token2] = ACTIONS(413),
    [aux_sym_build_in_function_token3] = ACTIONS(413),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(413),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(413),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(413),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(413),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(413),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(413),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(413),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(413),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(413),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(413),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(413),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(413),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(413),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(413),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(413),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(413),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(413),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(413),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(413),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(413),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(413),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(413),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(413),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(413),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(413),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(413),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(413),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(413),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(413),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(413),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(413),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(413),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(413),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(413),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(413),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(413),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(413),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(413),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(413),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(413),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(413),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(413),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(413),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(413),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(413),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(413),
    [aux_sym_regex_expression_token1] = ACTIONS(413),
    [aux_sym_substring_expression_token1] = ACTIONS(413),
    [aux_sym_string_replace_expression_token1] = ACTIONS(413),
    [aux_sym_exists_func_token1] = ACTIONS(413),
    [aux_sym_aggregate_token1] = ACTIONS(413),
    [aux_sym_aggregate_token2] = ACTIONS(413),
    [aux_sym_aggregate_token3] = ACTIONS(413),
    [aux_sym_aggregate_token4] = ACTIONS(413),
    [aux_sym_aggregate_token5] = ACTIONS(413),
    [aux_sym_aggregate_token6] = ACTIONS(413),
    [anon_sym_GROUP_CONCAT] = ACTIONS(413),
    [anon_sym_COLON] = ACTIONS(411),
  },
  [125] = {
    [ts_builtin_sym_end] = ACTIONS(415),
    [sym_pn_prefix] = ACTIONS(417),
    [sym_comment] = ACTIONS(3),
    [aux_sym_base_declaration_token1] = ACTIONS(417),
    [aux_sym_prefix_declaration_token1] = ACTIONS(417),
    [aux_sym_select_clause_token1] = ACTIONS(417),
    [anon_sym_LPAREN] = ACTIONS(415),
    [aux_sym_construct_query_token1] = ACTIONS(417),
    [aux_sym_describe_query_token1] = ACTIONS(417),
    [aux_sym_ask_query_token1] = ACTIONS(417),
    [aux_sym_having_clause_token1] = ACTIONS(417),
    [aux_sym_order_clause_token1] = ACTIONS(417),
    [aux_sym_order_condition_token1] = ACTIONS(417),
    [aux_sym_order_condition_token2] = ACTIONS(417),
    [aux_sym_limit_clause_token1] = ACTIONS(417),
    [aux_sym_offset_clause_token1] = ACTIONS(417),
    [aux_sym_values_clause_token1] = ACTIONS(417),
    [aux_sym_load_token1] = ACTIONS(417),
    [aux_sym_clear_token1] = ACTIONS(417),
    [aux_sym_drop_token1] = ACTIONS(417),
    [aux_sym_create_token1] = ACTIONS(417),
    [aux_sym_add_token1] = ACTIONS(417),
    [aux_sym_move_token1] = ACTIONS(417),
    [aux_sym_copy_token1] = ACTIONS(417),
    [anon_sym_INSERTDATA] = ACTIONS(415),
    [anon_sym_DELETEDATA] = ACTIONS(415),
    [anon_sym_DELETEWHERE] = ACTIONS(415),
    [aux_sym_modify_token1] = ACTIONS(417),
    [aux_sym_delete_clause_token1] = ACTIONS(417),
    [aux_sym_insert_clause_token1] = ACTIONS(417),
    [sym_var] = ACTIONS(415),
    [anon_sym_LT] = ACTIONS(415),
    [aux_sym_binary_expression_token2] = ACTIONS(417),
    [aux_sym_build_in_function_token1] = ACTIONS(417),
    [aux_sym_build_in_function_token2] = ACTIONS(417),
    [aux_sym_build_in_function_token3] = ACTIONS(417),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(417),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(417),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(417),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(417),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(417),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(417),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(417),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(417),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(417),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(417),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(417),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(417),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(417),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(417),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(417),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(417),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(417),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(417),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(417),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(417),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(417),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(417),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(417),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(417),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(417),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(417),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(417),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(417),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(417),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(417),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(417),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(417),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(417),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(417),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(417),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(417),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(417),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(417),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(417),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(417),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(417),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(417),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(417),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(417),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(417),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(417),
    [aux_sym_regex_expression_token1] = ACTIONS(417),
    [aux_sym_substring_expression_token1] = ACTIONS(417),
    [aux_sym_string_replace_expression_token1] = ACTIONS(417),
    [aux_sym_exists_func_token1] = ACTIONS(417),
    [aux_sym_aggregate_token1] = ACTIONS(417),
    [aux_sym_aggregate_token2] = ACTIONS(417),
    [aux_sym_aggregate_token3] = ACTIONS(417),
    [aux_sym_aggregate_token4] = ACTIONS(417),
    [aux_sym_aggregate_token5] = ACTIONS(417),
    [aux_sym_aggregate_token6] = ACTIONS(417),
    [anon_sym_GROUP_CONCAT] = ACTIONS(417),
    [anon_sym_COLON] = ACTIONS(415),
  },
  [126] = {
    [ts_builtin_sym_end] = ACTIONS(419),
    [sym_pn_prefix] = ACTIONS(421),
    [sym_comment] = ACTIONS(3),
    [aux_sym_base_declaration_token1] = ACTIONS(421),
    [aux_sym_prefix_declaration_token1] = ACTIONS(421),
    [aux_sym_select_clause_token1] = ACTIONS(421),
    [anon_sym_LPAREN] = ACTIONS(419),
    [aux_sym_construct_query_token1] = ACTIONS(421),
    [aux_sym_describe_query_token1] = ACTIONS(421),
    [aux_sym_ask_query_token1] = ACTIONS(421),
    [aux_sym_having_clause_token1] = ACTIONS(421),
    [aux_sym_order_clause_token1] = ACTIONS(421),
    [aux_sym_order_condition_token1] = ACTIONS(421),
    [aux_sym_order_condition_token2] = ACTIONS(421),
    [aux_sym_limit_clause_token1] = ACTIONS(421),
    [aux_sym_offset_clause_token1] = ACTIONS(421),
    [aux_sym_values_clause_token1] = ACTIONS(421),
    [aux_sym_load_token1] = ACTIONS(421),
    [aux_sym_clear_token1] = ACTIONS(421),
    [aux_sym_drop_token1] = ACTIONS(421),
    [aux_sym_create_token1] = ACTIONS(421),
    [aux_sym_add_token1] = ACTIONS(421),
    [aux_sym_move_token1] = ACTIONS(421),
    [aux_sym_copy_token1] = ACTIONS(421),
    [anon_sym_INSERTDATA] = ACTIONS(419),
    [anon_sym_DELETEDATA] = ACTIONS(419),
    [anon_sym_DELETEWHERE] = ACTIONS(419),
    [aux_sym_modify_token1] = ACTIONS(421),
    [aux_sym_delete_clause_token1] = ACTIONS(421),
    [aux_sym_insert_clause_token1] = ACTIONS(421),
    [sym_var] = ACTIONS(419),
    [anon_sym_LT] = ACTIONS(419),
    [aux_sym_binary_expression_token2] = ACTIONS(421),
    [aux_sym_build_in_function_token1] = ACTIONS(421),
    [aux_sym_build_in_function_token2] = ACTIONS(421),
    [aux_sym_build_in_function_token3] = ACTIONS(421),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(421),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(421),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(421),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(421),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(421),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(421),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(421),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(421),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(421),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(421),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(421),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(421),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(421),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(421),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(421),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(421),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(421),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(421),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(421),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(421),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(421),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(421),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(421),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(421),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(421),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(421),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(421),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(421),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(421),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(421),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(421),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(421),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(421),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(421),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(421),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(421),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(421),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(421),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(421),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(421),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(421),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(421),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(421),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(421),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(421),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(421),
    [aux_sym_regex_expression_token1] = ACTIONS(421),
    [aux_sym_substring_expression_token1] = ACTIONS(421),
    [aux_sym_string_replace_expression_token1] = ACTIONS(421),
    [aux_sym_exists_func_token1] = ACTIONS(421),
    [aux_sym_aggregate_token1] = ACTIONS(421),
    [aux_sym_aggregate_token2] = ACTIONS(421),
    [aux_sym_aggregate_token3] = ACTIONS(421),
    [aux_sym_aggregate_token4] = ACTIONS(421),
    [aux_sym_aggregate_token5] = ACTIONS(421),
    [aux_sym_aggregate_token6] = ACTIONS(421),
    [anon_sym_GROUP_CONCAT] = ACTIONS(421),
    [anon_sym_COLON] = ACTIONS(419),
  },
  [127] = {
    [ts_builtin_sym_end] = ACTIONS(423),
    [sym_pn_prefix] = ACTIONS(425),
    [sym_comment] = ACTIONS(3),
    [aux_sym_base_declaration_token1] = ACTIONS(425),
    [aux_sym_prefix_declaration_token1] = ACTIONS(425),
    [aux_sym_select_clause_token1] = ACTIONS(425),
    [anon_sym_LPAREN] = ACTIONS(423),
    [aux_sym_construct_query_token1] = ACTIONS(425),
    [aux_sym_describe_query_token1] = ACTIONS(425),
    [aux_sym_ask_query_token1] = ACTIONS(425),
    [aux_sym_having_clause_token1] = ACTIONS(425),
    [aux_sym_order_clause_token1] = ACTIONS(425),
    [aux_sym_order_condition_token1] = ACTIONS(425),
    [aux_sym_order_condition_token2] = ACTIONS(425),
    [aux_sym_limit_clause_token1] = ACTIONS(425),
    [aux_sym_offset_clause_token1] = ACTIONS(425),
    [aux_sym_values_clause_token1] = ACTIONS(425),
    [aux_sym_load_token1] = ACTIONS(425),
    [aux_sym_clear_token1] = ACTIONS(425),
    [aux_sym_drop_token1] = ACTIONS(425),
    [aux_sym_create_token1] = ACTIONS(425),
    [aux_sym_add_token1] = ACTIONS(425),
    [aux_sym_move_token1] = ACTIONS(425),
    [aux_sym_copy_token1] = ACTIONS(425),
    [anon_sym_INSERTDATA] = ACTIONS(423),
    [anon_sym_DELETEDATA] = ACTIONS(423),
    [anon_sym_DELETEWHERE] = ACTIONS(423),
    [aux_sym_modify_token1] = ACTIONS(425),
    [aux_sym_delete_clause_token1] = ACTIONS(425),
    [aux_sym_insert_clause_token1] = ACTIONS(425),
    [sym_var] = ACTIONS(423),
    [anon_sym_LT] = ACTIONS(423),
    [aux_sym_binary_expression_token2] = ACTIONS(425),
    [aux_sym_build_in_function_token1] = ACTIONS(425),
    [aux_sym_build_in_function_token2] = ACTIONS(425),
    [aux_sym_build_in_function_token3] = ACTIONS(425),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(425),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(425),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(425),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(425),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(425),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(425),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(425),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(425),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(425),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(425),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(425),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(425),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(425),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(425),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(425),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(425),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(425),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(425),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(425),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(425),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(425),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(425),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(425),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(425),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(425),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(425),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(425),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(425),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(425),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(425),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(425),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(425),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(425),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(425),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(425),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(425),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(425),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(425),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(425),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(425),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(425),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(425),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(425),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(425),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(425),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(425),
    [aux_sym_regex_expression_token1] = ACTIONS(425),
    [aux_sym_substring_expression_token1] = ACTIONS(425),
    [aux_sym_string_replace_expression_token1] = ACTIONS(425),
    [aux_sym_exists_func_token1] = ACTIONS(425),
    [aux_sym_aggregate_token1] = ACTIONS(425),
    [aux_sym_aggregate_token2] = ACTIONS(425),
    [aux_sym_aggregate_token3] = ACTIONS(425),
    [aux_sym_aggregate_token4] = ACTIONS(425),
    [aux_sym_aggregate_token5] = ACTIONS(425),
    [aux_sym_aggregate_token6] = ACTIONS(425),
    [anon_sym_GROUP_CONCAT] = ACTIONS(425),
    [anon_sym_COLON] = ACTIONS(423),
  },
  [128] = {
    [ts_builtin_sym_end] = ACTIONS(427),
    [sym_pn_prefix] = ACTIONS(429),
    [sym_comment] = ACTIONS(3),
    [aux_sym_base_declaration_token1] = ACTIONS(429),
    [aux_sym_prefix_declaration_token1] = ACTIONS(429),
    [aux_sym_select_clause_token1] = ACTIONS(429),
    [anon_sym_LPAREN] = ACTIONS(427),
    [aux_sym_construct_query_token1] = ACTIONS(429),
    [aux_sym_describe_query_token1] = ACTIONS(429),
    [aux_sym_ask_query_token1] = ACTIONS(429),
    [aux_sym_having_clause_token1] = ACTIONS(429),
    [aux_sym_order_clause_token1] = ACTIONS(429),
    [aux_sym_order_condition_token1] = ACTIONS(429),
    [aux_sym_order_condition_token2] = ACTIONS(429),
    [aux_sym_limit_clause_token1] = ACTIONS(429),
    [aux_sym_offset_clause_token1] = ACTIONS(429),
    [aux_sym_values_clause_token1] = ACTIONS(429),
    [aux_sym_load_token1] = ACTIONS(429),
    [aux_sym_clear_token1] = ACTIONS(429),
    [aux_sym_drop_token1] = ACTIONS(429),
    [aux_sym_create_token1] = ACTIONS(429),
    [aux_sym_add_token1] = ACTIONS(429),
    [aux_sym_move_token1] = ACTIONS(429),
    [aux_sym_copy_token1] = ACTIONS(429),
    [anon_sym_INSERTDATA] = ACTIONS(427),
    [anon_sym_DELETEDATA] = ACTIONS(427),
    [anon_sym_DELETEWHERE] = ACTIONS(427),
    [aux_sym_modify_token1] = ACTIONS(429),
    [aux_sym_delete_clause_token1] = ACTIONS(429),
    [aux_sym_insert_clause_token1] = ACTIONS(429),
    [sym_var] = ACTIONS(427),
    [anon_sym_LT] = ACTIONS(427),
    [aux_sym_binary_expression_token2] = ACTIONS(429),
    [aux_sym_build_in_function_token1] = ACTIONS(429),
    [aux_sym_build_in_function_token2] = ACTIONS(429),
    [aux_sym_build_in_function_token3] = ACTIONS(429),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(429),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(429),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(429),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(429),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(429),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(429),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(429),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(429),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(429),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(429),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(429),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(429),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(429),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(429),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(429),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(429),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(429),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(429),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(429),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(429),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(429),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(429),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(429),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(429),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(429),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(429),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(429),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(429),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(429),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(429),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(429),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(429),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(429),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(429),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(429),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(429),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(429),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(429),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(429),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(429),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(429),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(429),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(429),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(429),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(429),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(429),
    [aux_sym_regex_expression_token1] = ACTIONS(429),
    [aux_sym_substring_expression_token1] = ACTIONS(429),
    [aux_sym_string_replace_expression_token1] = ACTIONS(429),
    [aux_sym_exists_func_token1] = ACTIONS(429),
    [aux_sym_aggregate_token1] = ACTIONS(429),
    [aux_sym_aggregate_token2] = ACTIONS(429),
    [aux_sym_aggregate_token3] = ACTIONS(429),
    [aux_sym_aggregate_token4] = ACTIONS(429),
    [aux_sym_aggregate_token5] = ACTIONS(429),
    [aux_sym_aggregate_token6] = ACTIONS(429),
    [anon_sym_GROUP_CONCAT] = ACTIONS(429),
    [anon_sym_COLON] = ACTIONS(427),
  },
  [129] = {
    [ts_builtin_sym_end] = ACTIONS(431),
    [sym_pn_prefix] = ACTIONS(433),
    [sym_comment] = ACTIONS(3),
    [aux_sym_base_declaration_token1] = ACTIONS(433),
    [aux_sym_prefix_declaration_token1] = ACTIONS(433),
    [aux_sym_select_clause_token1] = ACTIONS(433),
    [anon_sym_LPAREN] = ACTIONS(431),
    [aux_sym_construct_query_token1] = ACTIONS(433),
    [aux_sym_describe_query_token1] = ACTIONS(433),
    [aux_sym_ask_query_token1] = ACTIONS(433),
    [aux_sym_having_clause_token1] = ACTIONS(433),
    [aux_sym_order_clause_token1] = ACTIONS(433),
    [aux_sym_order_condition_token1] = ACTIONS(433),
    [aux_sym_order_condition_token2] = ACTIONS(433),
    [aux_sym_limit_clause_token1] = ACTIONS(433),
    [aux_sym_offset_clause_token1] = ACTIONS(433),
    [aux_sym_values_clause_token1] = ACTIONS(433),
    [aux_sym_load_token1] = ACTIONS(433),
    [aux_sym_clear_token1] = ACTIONS(433),
    [aux_sym_drop_token1] = ACTIONS(433),
    [aux_sym_create_token1] = ACTIONS(433),
    [aux_sym_add_token1] = ACTIONS(433),
    [aux_sym_move_token1] = ACTIONS(433),
    [aux_sym_copy_token1] = ACTIONS(433),
    [anon_sym_INSERTDATA] = ACTIONS(431),
    [anon_sym_DELETEDATA] = ACTIONS(431),
    [anon_sym_DELETEWHERE] = ACTIONS(431),
    [aux_sym_modify_token1] = ACTIONS(433),
    [aux_sym_delete_clause_token1] = ACTIONS(433),
    [aux_sym_insert_clause_token1] = ACTIONS(433),
    [sym_var] = ACTIONS(431),
    [anon_sym_LT] = ACTIONS(431),
    [aux_sym_binary_expression_token2] = ACTIONS(433),
    [aux_sym_build_in_function_token1] = ACTIONS(433),
    [aux_sym_build_in_function_token2] = ACTIONS(433),
    [aux_sym_build_in_function_token3] = ACTIONS(433),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(433),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(433),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(433),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(433),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(433),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(433),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(433),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(433),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(433),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(433),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(433),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(433),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(433),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(433),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(433),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(433),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(433),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(433),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(433),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(433),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(433),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(433),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(433),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(433),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(433),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(433),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(433),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(433),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(433),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(433),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(433),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(433),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(433),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(433),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(433),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(433),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(433),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(433),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(433),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(433),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(433),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(433),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(433),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(433),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(433),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(433),
    [aux_sym_regex_expression_token1] = ACTIONS(433),
    [aux_sym_substring_expression_token1] = ACTIONS(433),
    [aux_sym_string_replace_expression_token1] = ACTIONS(433),
    [aux_sym_exists_func_token1] = ACTIONS(433),
    [aux_sym_aggregate_token1] = ACTIONS(433),
    [aux_sym_aggregate_token2] = ACTIONS(433),
    [aux_sym_aggregate_token3] = ACTIONS(433),
    [aux_sym_aggregate_token4] = ACTIONS(433),
    [aux_sym_aggregate_token5] = ACTIONS(433),
    [aux_sym_aggregate_token6] = ACTIONS(433),
    [anon_sym_GROUP_CONCAT] = ACTIONS(433),
    [anon_sym_COLON] = ACTIONS(431),
  },
  [130] = {
    [ts_builtin_sym_end] = ACTIONS(435),
    [sym_pn_prefix] = ACTIONS(437),
    [sym_comment] = ACTIONS(3),
    [aux_sym_base_declaration_token1] = ACTIONS(437),
    [aux_sym_prefix_declaration_token1] = ACTIONS(437),
    [aux_sym_select_clause_token1] = ACTIONS(437),
    [anon_sym_LPAREN] = ACTIONS(435),
    [aux_sym_construct_query_token1] = ACTIONS(437),
    [aux_sym_describe_query_token1] = ACTIONS(437),
    [aux_sym_ask_query_token1] = ACTIONS(437),
    [aux_sym_having_clause_token1] = ACTIONS(437),
    [aux_sym_order_clause_token1] = ACTIONS(437),
    [aux_sym_order_condition_token1] = ACTIONS(437),
    [aux_sym_order_condition_token2] = ACTIONS(437),
    [aux_sym_limit_clause_token1] = ACTIONS(437),
    [aux_sym_offset_clause_token1] = ACTIONS(437),
    [aux_sym_values_clause_token1] = ACTIONS(437),
    [aux_sym_load_token1] = ACTIONS(437),
    [aux_sym_clear_token1] = ACTIONS(437),
    [aux_sym_drop_token1] = ACTIONS(437),
    [aux_sym_create_token1] = ACTIONS(437),
    [aux_sym_add_token1] = ACTIONS(437),
    [aux_sym_move_token1] = ACTIONS(437),
    [aux_sym_copy_token1] = ACTIONS(437),
    [anon_sym_INSERTDATA] = ACTIONS(435),
    [anon_sym_DELETEDATA] = ACTIONS(435),
    [anon_sym_DELETEWHERE] = ACTIONS(435),
    [aux_sym_modify_token1] = ACTIONS(437),
    [aux_sym_delete_clause_token1] = ACTIONS(437),
    [aux_sym_insert_clause_token1] = ACTIONS(437),
    [sym_var] = ACTIONS(435),
    [anon_sym_LT] = ACTIONS(435),
    [aux_sym_binary_expression_token2] = ACTIONS(437),
    [aux_sym_build_in_function_token1] = ACTIONS(437),
    [aux_sym_build_in_function_token2] = ACTIONS(437),
    [aux_sym_build_in_function_token3] = ACTIONS(437),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(437),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(437),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(437),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(437),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(437),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(437),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(437),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(437),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(437),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(437),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(437),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(437),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(437),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(437),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(437),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(437),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(437),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(437),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(437),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(437),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(437),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(437),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(437),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(437),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(437),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(437),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(437),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(437),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(437),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(437),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(437),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(437),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(437),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(437),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(437),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(437),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(437),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(437),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(437),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(437),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(437),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(437),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(437),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(437),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(437),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(437),
    [aux_sym_regex_expression_token1] = ACTIONS(437),
    [aux_sym_substring_expression_token1] = ACTIONS(437),
    [aux_sym_string_replace_expression_token1] = ACTIONS(437),
    [aux_sym_exists_func_token1] = ACTIONS(437),
    [aux_sym_aggregate_token1] = ACTIONS(437),
    [aux_sym_aggregate_token2] = ACTIONS(437),
    [aux_sym_aggregate_token3] = ACTIONS(437),
    [aux_sym_aggregate_token4] = ACTIONS(437),
    [aux_sym_aggregate_token5] = ACTIONS(437),
    [aux_sym_aggregate_token6] = ACTIONS(437),
    [anon_sym_GROUP_CONCAT] = ACTIONS(437),
    [anon_sym_COLON] = ACTIONS(435),
  },
  [131] = {
    [ts_builtin_sym_end] = ACTIONS(439),
    [sym_pn_prefix] = ACTIONS(441),
    [sym_comment] = ACTIONS(3),
    [aux_sym_base_declaration_token1] = ACTIONS(441),
    [aux_sym_prefix_declaration_token1] = ACTIONS(441),
    [aux_sym_select_clause_token1] = ACTIONS(441),
    [anon_sym_LPAREN] = ACTIONS(439),
    [aux_sym_construct_query_token1] = ACTIONS(441),
    [aux_sym_describe_query_token1] = ACTIONS(441),
    [aux_sym_ask_query_token1] = ACTIONS(441),
    [aux_sym_having_clause_token1] = ACTIONS(441),
    [aux_sym_order_clause_token1] = ACTIONS(441),
    [aux_sym_order_condition_token1] = ACTIONS(441),
    [aux_sym_order_condition_token2] = ACTIONS(441),
    [aux_sym_limit_clause_token1] = ACTIONS(441),
    [aux_sym_offset_clause_token1] = ACTIONS(441),
    [aux_sym_values_clause_token1] = ACTIONS(441),
    [aux_sym_load_token1] = ACTIONS(441),
    [aux_sym_clear_token1] = ACTIONS(441),
    [aux_sym_drop_token1] = ACTIONS(441),
    [aux_sym_create_token1] = ACTIONS(441),
    [aux_sym_add_token1] = ACTIONS(441),
    [aux_sym_move_token1] = ACTIONS(441),
    [aux_sym_copy_token1] = ACTIONS(441),
    [anon_sym_INSERTDATA] = ACTIONS(439),
    [anon_sym_DELETEDATA] = ACTIONS(439),
    [anon_sym_DELETEWHERE] = ACTIONS(439),
    [aux_sym_modify_token1] = ACTIONS(441),
    [aux_sym_delete_clause_token1] = ACTIONS(441),
    [aux_sym_insert_clause_token1] = ACTIONS(441),
    [sym_var] = ACTIONS(439),
    [anon_sym_LT] = ACTIONS(439),
    [aux_sym_binary_expression_token2] = ACTIONS(441),
    [aux_sym_build_in_function_token1] = ACTIONS(441),
    [aux_sym_build_in_function_token2] = ACTIONS(441),
    [aux_sym_build_in_function_token3] = ACTIONS(441),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(441),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(441),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(441),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(441),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(441),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(441),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(441),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(441),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(441),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(441),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(441),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(441),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(441),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(441),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(441),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(441),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(441),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(441),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(441),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(441),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(441),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(441),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(441),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(441),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(441),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(441),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(441),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(441),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(441),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(441),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(441),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(441),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(441),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(441),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(441),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(441),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(441),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(441),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(441),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(441),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(441),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(441),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(441),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(441),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(441),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(441),
    [aux_sym_regex_expression_token1] = ACTIONS(441),
    [aux_sym_substring_expression_token1] = ACTIONS(441),
    [aux_sym_string_replace_expression_token1] = ACTIONS(441),
    [aux_sym_exists_func_token1] = ACTIONS(441),
    [aux_sym_aggregate_token1] = ACTIONS(441),
    [aux_sym_aggregate_token2] = ACTIONS(441),
    [aux_sym_aggregate_token3] = ACTIONS(441),
    [aux_sym_aggregate_token4] = ACTIONS(441),
    [aux_sym_aggregate_token5] = ACTIONS(441),
    [aux_sym_aggregate_token6] = ACTIONS(441),
    [anon_sym_GROUP_CONCAT] = ACTIONS(441),
    [anon_sym_COLON] = ACTIONS(439),
  },
  [132] = {
    [ts_builtin_sym_end] = ACTIONS(443),
    [sym_pn_prefix] = ACTIONS(445),
    [sym_comment] = ACTIONS(3),
    [aux_sym_base_declaration_token1] = ACTIONS(445),
    [aux_sym_prefix_declaration_token1] = ACTIONS(445),
    [aux_sym_select_clause_token1] = ACTIONS(445),
    [anon_sym_LPAREN] = ACTIONS(443),
    [aux_sym_construct_query_token1] = ACTIONS(445),
    [aux_sym_describe_query_token1] = ACTIONS(445),
    [aux_sym_ask_query_token1] = ACTIONS(445),
    [aux_sym_having_clause_token1] = ACTIONS(445),
    [aux_sym_order_clause_token1] = ACTIONS(445),
    [aux_sym_order_condition_token1] = ACTIONS(445),
    [aux_sym_order_condition_token2] = ACTIONS(445),
    [aux_sym_limit_clause_token1] = ACTIONS(445),
    [aux_sym_offset_clause_token1] = ACTIONS(445),
    [aux_sym_values_clause_token1] = ACTIONS(445),
    [aux_sym_load_token1] = ACTIONS(445),
    [aux_sym_clear_token1] = ACTIONS(445),
    [aux_sym_drop_token1] = ACTIONS(445),
    [aux_sym_create_token1] = ACTIONS(445),
    [aux_sym_add_token1] = ACTIONS(445),
    [aux_sym_move_token1] = ACTIONS(445),
    [aux_sym_copy_token1] = ACTIONS(445),
    [anon_sym_INSERTDATA] = ACTIONS(443),
    [anon_sym_DELETEDATA] = ACTIONS(443),
    [anon_sym_DELETEWHERE] = ACTIONS(443),
    [aux_sym_modify_token1] = ACTIONS(445),
    [aux_sym_delete_clause_token1] = ACTIONS(445),
    [aux_sym_insert_clause_token1] = ACTIONS(445),
    [sym_var] = ACTIONS(443),
    [anon_sym_LT] = ACTIONS(443),
    [aux_sym_binary_expression_token2] = ACTIONS(445),
    [aux_sym_build_in_function_token1] = ACTIONS(445),
    [aux_sym_build_in_function_token2] = ACTIONS(445),
    [aux_sym_build_in_function_token3] = ACTIONS(445),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(445),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(445),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(445),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(445),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(445),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(445),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(445),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(445),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(445),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(445),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(445),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(445),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(445),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(445),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(445),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(445),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(445),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(445),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(445),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(445),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(445),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(445),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(445),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(445),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(445),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(445),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(445),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(445),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(445),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(445),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(445),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(445),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(445),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(445),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(445),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(445),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(445),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(445),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(445),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(445),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(445),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(445),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(445),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(445),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(445),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(445),
    [aux_sym_regex_expression_token1] = ACTIONS(445),
    [aux_sym_substring_expression_token1] = ACTIONS(445),
    [aux_sym_string_replace_expression_token1] = ACTIONS(445),
    [aux_sym_exists_func_token1] = ACTIONS(445),
    [aux_sym_aggregate_token1] = ACTIONS(445),
    [aux_sym_aggregate_token2] = ACTIONS(445),
    [aux_sym_aggregate_token3] = ACTIONS(445),
    [aux_sym_aggregate_token4] = ACTIONS(445),
    [aux_sym_aggregate_token5] = ACTIONS(445),
    [aux_sym_aggregate_token6] = ACTIONS(445),
    [anon_sym_GROUP_CONCAT] = ACTIONS(445),
    [anon_sym_COLON] = ACTIONS(443),
  },
  [133] = {
    [sym_order_condition] = STATE(138),
    [sym__constraint] = STATE(211),
    [sym_function_call] = STATE(211),
    [sym_bracketted_expression] = STATE(211),
    [sym__build_in_call] = STATE(211),
    [sym_build_in_function] = STATE(211),
    [sym__nullary_build_in_function] = STATE(200),
    [sym__unary_build_in_function] = STATE(201),
    [sym__binary_build_in_function] = STATE(202),
    [sym__variadic_build_in_function] = STATE(203),
    [sym_regex_expression] = STATE(211),
    [sym_substring_expression] = STATE(211),
    [sym_string_replace_expression] = STATE(211),
    [sym_exists_func] = STATE(211),
    [sym_not_exists_func] = STATE(211),
    [sym_aggregate] = STATE(211),
    [sym__iri] = STATE(882),
    [sym_prefixed_name] = STATE(882),
    [sym_iri_reference] = STATE(882),
    [sym_namespace] = STATE(413),
    [aux_sym_order_clause_repeat1] = STATE(138),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(447),
    [anon_sym_RBRACE] = ACTIONS(45),
    [aux_sym_order_condition_token1] = ACTIONS(449),
    [aux_sym_order_condition_token2] = ACTIONS(449),
    [aux_sym_limit_clause_token1] = ACTIONS(49),
    [aux_sym_offset_clause_token1] = ACTIONS(49),
    [aux_sym_values_clause_token1] = ACTIONS(49),
    [sym_var] = ACTIONS(451),
    [anon_sym_LT] = ACTIONS(57),
    [aux_sym_binary_expression_token2] = ACTIONS(453),
    [aux_sym_build_in_function_token1] = ACTIONS(455),
    [aux_sym_build_in_function_token2] = ACTIONS(457),
    [aux_sym_build_in_function_token3] = ACTIONS(459),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(461),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(461),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(461),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(461),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(463),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(465),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(465),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(465),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(465),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(465),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(465),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(465),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(465),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(465),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(467),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(467),
    [aux_sym_regex_expression_token1] = ACTIONS(469),
    [aux_sym_substring_expression_token1] = ACTIONS(471),
    [aux_sym_string_replace_expression_token1] = ACTIONS(473),
    [aux_sym_exists_func_token1] = ACTIONS(475),
    [aux_sym_aggregate_token1] = ACTIONS(477),
    [aux_sym_aggregate_token2] = ACTIONS(479),
    [aux_sym_aggregate_token3] = ACTIONS(479),
    [aux_sym_aggregate_token4] = ACTIONS(479),
    [aux_sym_aggregate_token5] = ACTIONS(479),
    [aux_sym_aggregate_token6] = ACTIONS(479),
    [anon_sym_GROUP_CONCAT] = ACTIONS(481),
    [anon_sym_COLON] = ACTIONS(89),
  },
  [134] = {
    [ts_builtin_sym_end] = ACTIONS(483),
    [sym_pn_prefix] = ACTIONS(485),
    [sym_comment] = ACTIONS(3),
    [aux_sym_base_declaration_token1] = ACTIONS(485),
    [aux_sym_prefix_declaration_token1] = ACTIONS(485),
    [aux_sym_select_clause_token1] = ACTIONS(485),
    [anon_sym_LPAREN] = ACTIONS(483),
    [aux_sym_construct_query_token1] = ACTIONS(485),
    [aux_sym_describe_query_token1] = ACTIONS(485),
    [aux_sym_ask_query_token1] = ACTIONS(485),
    [aux_sym_having_clause_token1] = ACTIONS(485),
    [aux_sym_order_clause_token1] = ACTIONS(485),
    [aux_sym_order_condition_token1] = ACTIONS(485),
    [aux_sym_order_condition_token2] = ACTIONS(485),
    [aux_sym_limit_clause_token1] = ACTIONS(485),
    [aux_sym_offset_clause_token1] = ACTIONS(485),
    [aux_sym_values_clause_token1] = ACTIONS(485),
    [aux_sym_load_token1] = ACTIONS(485),
    [aux_sym_clear_token1] = ACTIONS(485),
    [aux_sym_drop_token1] = ACTIONS(485),
    [aux_sym_create_token1] = ACTIONS(485),
    [aux_sym_add_token1] = ACTIONS(485),
    [aux_sym_move_token1] = ACTIONS(485),
    [aux_sym_copy_token1] = ACTIONS(485),
    [anon_sym_INSERTDATA] = ACTIONS(483),
    [anon_sym_DELETEDATA] = ACTIONS(483),
    [anon_sym_DELETEWHERE] = ACTIONS(483),
    [aux_sym_modify_token1] = ACTIONS(485),
    [aux_sym_delete_clause_token1] = ACTIONS(485),
    [aux_sym_insert_clause_token1] = ACTIONS(485),
    [sym_var] = ACTIONS(483),
    [anon_sym_LT] = ACTIONS(483),
    [aux_sym_binary_expression_token2] = ACTIONS(485),
    [aux_sym_build_in_function_token1] = ACTIONS(485),
    [aux_sym_build_in_function_token2] = ACTIONS(485),
    [aux_sym_build_in_function_token3] = ACTIONS(485),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(485),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(485),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(485),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(485),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(485),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(485),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(485),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(485),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(485),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(485),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(485),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(485),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(485),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(485),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(485),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(485),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(485),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(485),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(485),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(485),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(485),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(485),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(485),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(485),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(485),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(485),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(485),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(485),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(485),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(485),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(485),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(485),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(485),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(485),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(485),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(485),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(485),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(485),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(485),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(485),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(485),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(485),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(485),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(485),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(485),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(485),
    [aux_sym_regex_expression_token1] = ACTIONS(485),
    [aux_sym_substring_expression_token1] = ACTIONS(485),
    [aux_sym_string_replace_expression_token1] = ACTIONS(485),
    [aux_sym_exists_func_token1] = ACTIONS(485),
    [aux_sym_aggregate_token1] = ACTIONS(485),
    [aux_sym_aggregate_token2] = ACTIONS(485),
    [aux_sym_aggregate_token3] = ACTIONS(485),
    [aux_sym_aggregate_token4] = ACTIONS(485),
    [aux_sym_aggregate_token5] = ACTIONS(485),
    [aux_sym_aggregate_token6] = ACTIONS(485),
    [anon_sym_GROUP_CONCAT] = ACTIONS(485),
    [anon_sym_COLON] = ACTIONS(483),
  },
  [135] = {
    [ts_builtin_sym_end] = ACTIONS(487),
    [sym_pn_prefix] = ACTIONS(489),
    [sym_comment] = ACTIONS(3),
    [aux_sym_base_declaration_token1] = ACTIONS(489),
    [aux_sym_prefix_declaration_token1] = ACTIONS(489),
    [aux_sym_select_clause_token1] = ACTIONS(489),
    [anon_sym_LPAREN] = ACTIONS(487),
    [aux_sym_construct_query_token1] = ACTIONS(489),
    [aux_sym_describe_query_token1] = ACTIONS(489),
    [aux_sym_ask_query_token1] = ACTIONS(489),
    [aux_sym_having_clause_token1] = ACTIONS(489),
    [aux_sym_order_clause_token1] = ACTIONS(489),
    [aux_sym_order_condition_token1] = ACTIONS(489),
    [aux_sym_order_condition_token2] = ACTIONS(489),
    [aux_sym_limit_clause_token1] = ACTIONS(489),
    [aux_sym_offset_clause_token1] = ACTIONS(489),
    [aux_sym_values_clause_token1] = ACTIONS(489),
    [aux_sym_load_token1] = ACTIONS(489),
    [aux_sym_clear_token1] = ACTIONS(489),
    [aux_sym_drop_token1] = ACTIONS(489),
    [aux_sym_create_token1] = ACTIONS(489),
    [aux_sym_add_token1] = ACTIONS(489),
    [aux_sym_move_token1] = ACTIONS(489),
    [aux_sym_copy_token1] = ACTIONS(489),
    [anon_sym_INSERTDATA] = ACTIONS(487),
    [anon_sym_DELETEDATA] = ACTIONS(487),
    [anon_sym_DELETEWHERE] = ACTIONS(487),
    [aux_sym_modify_token1] = ACTIONS(489),
    [aux_sym_delete_clause_token1] = ACTIONS(489),
    [aux_sym_insert_clause_token1] = ACTIONS(489),
    [sym_var] = ACTIONS(487),
    [anon_sym_LT] = ACTIONS(487),
    [aux_sym_binary_expression_token2] = ACTIONS(489),
    [aux_sym_build_in_function_token1] = ACTIONS(489),
    [aux_sym_build_in_function_token2] = ACTIONS(489),
    [aux_sym_build_in_function_token3] = ACTIONS(489),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(489),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(489),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(489),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(489),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(489),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(489),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(489),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(489),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(489),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(489),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(489),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(489),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(489),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(489),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(489),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(489),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(489),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(489),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(489),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(489),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(489),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(489),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(489),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(489),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(489),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(489),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(489),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(489),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(489),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(489),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(489),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(489),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(489),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(489),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(489),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(489),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(489),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(489),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(489),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(489),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(489),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(489),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(489),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(489),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(489),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(489),
    [aux_sym_regex_expression_token1] = ACTIONS(489),
    [aux_sym_substring_expression_token1] = ACTIONS(489),
    [aux_sym_string_replace_expression_token1] = ACTIONS(489),
    [aux_sym_exists_func_token1] = ACTIONS(489),
    [aux_sym_aggregate_token1] = ACTIONS(489),
    [aux_sym_aggregate_token2] = ACTIONS(489),
    [aux_sym_aggregate_token3] = ACTIONS(489),
    [aux_sym_aggregate_token4] = ACTIONS(489),
    [aux_sym_aggregate_token5] = ACTIONS(489),
    [aux_sym_aggregate_token6] = ACTIONS(489),
    [anon_sym_GROUP_CONCAT] = ACTIONS(489),
    [anon_sym_COLON] = ACTIONS(487),
  },
  [136] = {
    [ts_builtin_sym_end] = ACTIONS(403),
    [sym_pn_prefix] = ACTIONS(405),
    [sym_comment] = ACTIONS(3),
    [aux_sym_base_declaration_token1] = ACTIONS(405),
    [aux_sym_prefix_declaration_token1] = ACTIONS(405),
    [aux_sym_select_clause_token1] = ACTIONS(405),
    [anon_sym_LPAREN] = ACTIONS(403),
    [aux_sym_construct_query_token1] = ACTIONS(405),
    [aux_sym_describe_query_token1] = ACTIONS(405),
    [aux_sym_ask_query_token1] = ACTIONS(405),
    [aux_sym_having_clause_token1] = ACTIONS(405),
    [aux_sym_order_clause_token1] = ACTIONS(405),
    [aux_sym_order_condition_token1] = ACTIONS(405),
    [aux_sym_order_condition_token2] = ACTIONS(405),
    [aux_sym_limit_clause_token1] = ACTIONS(405),
    [aux_sym_offset_clause_token1] = ACTIONS(405),
    [aux_sym_values_clause_token1] = ACTIONS(405),
    [aux_sym_load_token1] = ACTIONS(405),
    [aux_sym_clear_token1] = ACTIONS(405),
    [aux_sym_drop_token1] = ACTIONS(405),
    [aux_sym_create_token1] = ACTIONS(405),
    [aux_sym_add_token1] = ACTIONS(405),
    [aux_sym_move_token1] = ACTIONS(405),
    [aux_sym_copy_token1] = ACTIONS(405),
    [anon_sym_INSERTDATA] = ACTIONS(403),
    [anon_sym_DELETEDATA] = ACTIONS(403),
    [anon_sym_DELETEWHERE] = ACTIONS(403),
    [aux_sym_modify_token1] = ACTIONS(405),
    [aux_sym_delete_clause_token1] = ACTIONS(405),
    [aux_sym_insert_clause_token1] = ACTIONS(405),
    [sym_var] = ACTIONS(403),
    [anon_sym_LT] = ACTIONS(403),
    [aux_sym_binary_expression_token2] = ACTIONS(405),
    [aux_sym_build_in_function_token1] = ACTIONS(405),
    [aux_sym_build_in_function_token2] = ACTIONS(405),
    [aux_sym_build_in_function_token3] = ACTIONS(405),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(405),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(405),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(405),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(405),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(405),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(405),
    [aux_sym_regex_expression_token1] = ACTIONS(405),
    [aux_sym_substring_expression_token1] = ACTIONS(405),
    [aux_sym_string_replace_expression_token1] = ACTIONS(405),
    [aux_sym_exists_func_token1] = ACTIONS(405),
    [aux_sym_aggregate_token1] = ACTIONS(405),
    [aux_sym_aggregate_token2] = ACTIONS(405),
    [aux_sym_aggregate_token3] = ACTIONS(405),
    [aux_sym_aggregate_token4] = ACTIONS(405),
    [aux_sym_aggregate_token5] = ACTIONS(405),
    [aux_sym_aggregate_token6] = ACTIONS(405),
    [anon_sym_GROUP_CONCAT] = ACTIONS(405),
    [anon_sym_COLON] = ACTIONS(403),
  },
  [137] = {
    [ts_builtin_sym_end] = ACTIONS(491),
    [sym_pn_prefix] = ACTIONS(493),
    [sym_comment] = ACTIONS(3),
    [aux_sym_base_declaration_token1] = ACTIONS(493),
    [aux_sym_prefix_declaration_token1] = ACTIONS(493),
    [aux_sym_select_clause_token1] = ACTIONS(493),
    [anon_sym_LPAREN] = ACTIONS(491),
    [aux_sym_construct_query_token1] = ACTIONS(493),
    [aux_sym_describe_query_token1] = ACTIONS(493),
    [aux_sym_ask_query_token1] = ACTIONS(493),
    [aux_sym_having_clause_token1] = ACTIONS(493),
    [aux_sym_order_clause_token1] = ACTIONS(493),
    [aux_sym_order_condition_token1] = ACTIONS(493),
    [aux_sym_order_condition_token2] = ACTIONS(493),
    [aux_sym_limit_clause_token1] = ACTIONS(493),
    [aux_sym_offset_clause_token1] = ACTIONS(493),
    [aux_sym_values_clause_token1] = ACTIONS(493),
    [aux_sym_load_token1] = ACTIONS(493),
    [aux_sym_clear_token1] = ACTIONS(493),
    [aux_sym_drop_token1] = ACTIONS(493),
    [aux_sym_create_token1] = ACTIONS(493),
    [aux_sym_add_token1] = ACTIONS(493),
    [aux_sym_move_token1] = ACTIONS(493),
    [aux_sym_copy_token1] = ACTIONS(493),
    [anon_sym_INSERTDATA] = ACTIONS(491),
    [anon_sym_DELETEDATA] = ACTIONS(491),
    [anon_sym_DELETEWHERE] = ACTIONS(491),
    [aux_sym_modify_token1] = ACTIONS(493),
    [aux_sym_delete_clause_token1] = ACTIONS(493),
    [aux_sym_insert_clause_token1] = ACTIONS(493),
    [sym_var] = ACTIONS(491),
    [anon_sym_LT] = ACTIONS(491),
    [aux_sym_binary_expression_token2] = ACTIONS(493),
    [aux_sym_build_in_function_token1] = ACTIONS(493),
    [aux_sym_build_in_function_token2] = ACTIONS(493),
    [aux_sym_build_in_function_token3] = ACTIONS(493),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(493),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(493),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(493),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(493),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(493),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(493),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(493),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(493),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(493),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(493),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(493),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(493),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(493),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(493),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(493),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(493),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(493),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(493),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(493),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(493),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(493),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(493),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(493),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(493),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(493),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(493),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(493),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(493),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(493),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(493),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(493),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(493),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(493),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(493),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(493),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(493),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(493),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(493),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(493),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(493),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(493),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(493),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(493),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(493),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(493),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(493),
    [aux_sym_regex_expression_token1] = ACTIONS(493),
    [aux_sym_substring_expression_token1] = ACTIONS(493),
    [aux_sym_string_replace_expression_token1] = ACTIONS(493),
    [aux_sym_exists_func_token1] = ACTIONS(493),
    [aux_sym_aggregate_token1] = ACTIONS(493),
    [aux_sym_aggregate_token2] = ACTIONS(493),
    [aux_sym_aggregate_token3] = ACTIONS(493),
    [aux_sym_aggregate_token4] = ACTIONS(493),
    [aux_sym_aggregate_token5] = ACTIONS(493),
    [aux_sym_aggregate_token6] = ACTIONS(493),
    [anon_sym_GROUP_CONCAT] = ACTIONS(493),
    [anon_sym_COLON] = ACTIONS(491),
  },
  [138] = {
    [sym_order_condition] = STATE(138),
    [sym__constraint] = STATE(211),
    [sym_function_call] = STATE(211),
    [sym_bracketted_expression] = STATE(211),
    [sym__build_in_call] = STATE(211),
    [sym_build_in_function] = STATE(211),
    [sym__nullary_build_in_function] = STATE(200),
    [sym__unary_build_in_function] = STATE(201),
    [sym__binary_build_in_function] = STATE(202),
    [sym__variadic_build_in_function] = STATE(203),
    [sym_regex_expression] = STATE(211),
    [sym_substring_expression] = STATE(211),
    [sym_string_replace_expression] = STATE(211),
    [sym_exists_func] = STATE(211),
    [sym_not_exists_func] = STATE(211),
    [sym_aggregate] = STATE(211),
    [sym__iri] = STATE(882),
    [sym_prefixed_name] = STATE(882),
    [sym_iri_reference] = STATE(882),
    [sym_namespace] = STATE(413),
    [aux_sym_order_clause_repeat1] = STATE(138),
    [sym_pn_prefix] = ACTIONS(93),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(495),
    [anon_sym_RBRACE] = ACTIONS(91),
    [aux_sym_order_condition_token1] = ACTIONS(498),
    [aux_sym_order_condition_token2] = ACTIONS(498),
    [aux_sym_limit_clause_token1] = ACTIONS(96),
    [aux_sym_offset_clause_token1] = ACTIONS(96),
    [aux_sym_values_clause_token1] = ACTIONS(96),
    [sym_var] = ACTIONS(501),
    [anon_sym_LT] = ACTIONS(107),
    [aux_sym_binary_expression_token2] = ACTIONS(504),
    [aux_sym_build_in_function_token1] = ACTIONS(507),
    [aux_sym_build_in_function_token2] = ACTIONS(510),
    [aux_sym_build_in_function_token3] = ACTIONS(513),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(516),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(516),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(516),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(516),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(519),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(519),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(519),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(519),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(519),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(519),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(519),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(519),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(519),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(519),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(519),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(519),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(519),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(519),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(519),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(519),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(519),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(519),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(519),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(519),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(519),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(519),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(519),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(519),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(519),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(519),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(519),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(519),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(519),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(519),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(519),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(522),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(522),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(522),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(522),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(522),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(522),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(522),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(522),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(522),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(525),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(525),
    [aux_sym_regex_expression_token1] = ACTIONS(528),
    [aux_sym_substring_expression_token1] = ACTIONS(531),
    [aux_sym_string_replace_expression_token1] = ACTIONS(534),
    [aux_sym_exists_func_token1] = ACTIONS(537),
    [aux_sym_aggregate_token1] = ACTIONS(540),
    [aux_sym_aggregate_token2] = ACTIONS(543),
    [aux_sym_aggregate_token3] = ACTIONS(543),
    [aux_sym_aggregate_token4] = ACTIONS(543),
    [aux_sym_aggregate_token5] = ACTIONS(543),
    [aux_sym_aggregate_token6] = ACTIONS(543),
    [anon_sym_GROUP_CONCAT] = ACTIONS(546),
    [anon_sym_COLON] = ACTIONS(155),
  },
  [139] = {
    [ts_builtin_sym_end] = ACTIONS(549),
    [sym_pn_prefix] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [aux_sym_base_declaration_token1] = ACTIONS(551),
    [aux_sym_prefix_declaration_token1] = ACTIONS(551),
    [aux_sym_select_clause_token1] = ACTIONS(551),
    [anon_sym_LPAREN] = ACTIONS(549),
    [aux_sym_construct_query_token1] = ACTIONS(551),
    [aux_sym_describe_query_token1] = ACTIONS(551),
    [aux_sym_ask_query_token1] = ACTIONS(551),
    [aux_sym_having_clause_token1] = ACTIONS(551),
    [aux_sym_order_clause_token1] = ACTIONS(551),
    [aux_sym_order_condition_token1] = ACTIONS(551),
    [aux_sym_order_condition_token2] = ACTIONS(551),
    [aux_sym_limit_clause_token1] = ACTIONS(551),
    [aux_sym_offset_clause_token1] = ACTIONS(551),
    [aux_sym_values_clause_token1] = ACTIONS(551),
    [aux_sym_load_token1] = ACTIONS(551),
    [aux_sym_clear_token1] = ACTIONS(551),
    [aux_sym_drop_token1] = ACTIONS(551),
    [aux_sym_create_token1] = ACTIONS(551),
    [aux_sym_add_token1] = ACTIONS(551),
    [aux_sym_move_token1] = ACTIONS(551),
    [aux_sym_copy_token1] = ACTIONS(551),
    [anon_sym_INSERTDATA] = ACTIONS(549),
    [anon_sym_DELETEDATA] = ACTIONS(549),
    [anon_sym_DELETEWHERE] = ACTIONS(549),
    [aux_sym_modify_token1] = ACTIONS(551),
    [aux_sym_delete_clause_token1] = ACTIONS(551),
    [aux_sym_insert_clause_token1] = ACTIONS(551),
    [sym_var] = ACTIONS(549),
    [anon_sym_LT] = ACTIONS(549),
    [aux_sym_binary_expression_token2] = ACTIONS(551),
    [aux_sym_build_in_function_token1] = ACTIONS(551),
    [aux_sym_build_in_function_token2] = ACTIONS(551),
    [aux_sym_build_in_function_token3] = ACTIONS(551),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(551),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(551),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(551),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(551),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(551),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(551),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(551),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(551),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(551),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(551),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(551),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(551),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(551),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(551),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(551),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(551),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(551),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(551),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(551),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(551),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(551),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(551),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(551),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(551),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(551),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(551),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(551),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(551),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(551),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(551),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(551),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(551),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(551),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(551),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(551),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(551),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(551),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(551),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(551),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(551),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(551),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(551),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(551),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(551),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(551),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(551),
    [aux_sym_regex_expression_token1] = ACTIONS(551),
    [aux_sym_substring_expression_token1] = ACTIONS(551),
    [aux_sym_string_replace_expression_token1] = ACTIONS(551),
    [aux_sym_exists_func_token1] = ACTIONS(551),
    [aux_sym_aggregate_token1] = ACTIONS(551),
    [aux_sym_aggregate_token2] = ACTIONS(551),
    [aux_sym_aggregate_token3] = ACTIONS(551),
    [aux_sym_aggregate_token4] = ACTIONS(551),
    [aux_sym_aggregate_token5] = ACTIONS(551),
    [aux_sym_aggregate_token6] = ACTIONS(551),
    [anon_sym_GROUP_CONCAT] = ACTIONS(551),
    [anon_sym_COLON] = ACTIONS(549),
  },
  [140] = {
    [ts_builtin_sym_end] = ACTIONS(553),
    [sym_pn_prefix] = ACTIONS(555),
    [sym_comment] = ACTIONS(3),
    [aux_sym_base_declaration_token1] = ACTIONS(555),
    [aux_sym_prefix_declaration_token1] = ACTIONS(555),
    [aux_sym_select_clause_token1] = ACTIONS(555),
    [anon_sym_LPAREN] = ACTIONS(553),
    [aux_sym_construct_query_token1] = ACTIONS(555),
    [aux_sym_describe_query_token1] = ACTIONS(555),
    [aux_sym_ask_query_token1] = ACTIONS(555),
    [aux_sym_having_clause_token1] = ACTIONS(555),
    [aux_sym_order_clause_token1] = ACTIONS(555),
    [aux_sym_order_condition_token1] = ACTIONS(555),
    [aux_sym_order_condition_token2] = ACTIONS(555),
    [aux_sym_limit_clause_token1] = ACTIONS(555),
    [aux_sym_offset_clause_token1] = ACTIONS(555),
    [aux_sym_values_clause_token1] = ACTIONS(555),
    [aux_sym_load_token1] = ACTIONS(555),
    [aux_sym_clear_token1] = ACTIONS(555),
    [aux_sym_drop_token1] = ACTIONS(555),
    [aux_sym_create_token1] = ACTIONS(555),
    [aux_sym_add_token1] = ACTIONS(555),
    [aux_sym_move_token1] = ACTIONS(555),
    [aux_sym_copy_token1] = ACTIONS(555),
    [anon_sym_INSERTDATA] = ACTIONS(553),
    [anon_sym_DELETEDATA] = ACTIONS(553),
    [anon_sym_DELETEWHERE] = ACTIONS(553),
    [aux_sym_modify_token1] = ACTIONS(555),
    [aux_sym_delete_clause_token1] = ACTIONS(555),
    [aux_sym_insert_clause_token1] = ACTIONS(555),
    [sym_var] = ACTIONS(553),
    [anon_sym_LT] = ACTIONS(553),
    [aux_sym_binary_expression_token2] = ACTIONS(555),
    [aux_sym_build_in_function_token1] = ACTIONS(555),
    [aux_sym_build_in_function_token2] = ACTIONS(555),
    [aux_sym_build_in_function_token3] = ACTIONS(555),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(555),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(555),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(555),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(555),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(555),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(555),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(555),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(555),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(555),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(555),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(555),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(555),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(555),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(555),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(555),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(555),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(555),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(555),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(555),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(555),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(555),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(555),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(555),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(555),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(555),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(555),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(555),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(555),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(555),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(555),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(555),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(555),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(555),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(555),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(555),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(555),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(555),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(555),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(555),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(555),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(555),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(555),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(555),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(555),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(555),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(555),
    [aux_sym_regex_expression_token1] = ACTIONS(555),
    [aux_sym_substring_expression_token1] = ACTIONS(555),
    [aux_sym_string_replace_expression_token1] = ACTIONS(555),
    [aux_sym_exists_func_token1] = ACTIONS(555),
    [aux_sym_aggregate_token1] = ACTIONS(555),
    [aux_sym_aggregate_token2] = ACTIONS(555),
    [aux_sym_aggregate_token3] = ACTIONS(555),
    [aux_sym_aggregate_token4] = ACTIONS(555),
    [aux_sym_aggregate_token5] = ACTIONS(555),
    [aux_sym_aggregate_token6] = ACTIONS(555),
    [anon_sym_GROUP_CONCAT] = ACTIONS(555),
    [anon_sym_COLON] = ACTIONS(553),
  },
  [141] = {
    [ts_builtin_sym_end] = ACTIONS(557),
    [sym_pn_prefix] = ACTIONS(559),
    [sym_comment] = ACTIONS(3),
    [aux_sym_base_declaration_token1] = ACTIONS(559),
    [aux_sym_prefix_declaration_token1] = ACTIONS(559),
    [aux_sym_select_clause_token1] = ACTIONS(559),
    [anon_sym_LPAREN] = ACTIONS(557),
    [aux_sym_construct_query_token1] = ACTIONS(559),
    [aux_sym_describe_query_token1] = ACTIONS(559),
    [aux_sym_ask_query_token1] = ACTIONS(559),
    [aux_sym_having_clause_token1] = ACTIONS(559),
    [aux_sym_order_clause_token1] = ACTIONS(559),
    [aux_sym_order_condition_token1] = ACTIONS(559),
    [aux_sym_order_condition_token2] = ACTIONS(559),
    [aux_sym_limit_clause_token1] = ACTIONS(559),
    [aux_sym_offset_clause_token1] = ACTIONS(559),
    [aux_sym_values_clause_token1] = ACTIONS(559),
    [aux_sym_load_token1] = ACTIONS(559),
    [aux_sym_clear_token1] = ACTIONS(559),
    [aux_sym_drop_token1] = ACTIONS(559),
    [aux_sym_create_token1] = ACTIONS(559),
    [aux_sym_add_token1] = ACTIONS(559),
    [aux_sym_move_token1] = ACTIONS(559),
    [aux_sym_copy_token1] = ACTIONS(559),
    [anon_sym_INSERTDATA] = ACTIONS(557),
    [anon_sym_DELETEDATA] = ACTIONS(557),
    [anon_sym_DELETEWHERE] = ACTIONS(557),
    [aux_sym_modify_token1] = ACTIONS(559),
    [aux_sym_delete_clause_token1] = ACTIONS(559),
    [aux_sym_insert_clause_token1] = ACTIONS(559),
    [sym_var] = ACTIONS(557),
    [anon_sym_LT] = ACTIONS(557),
    [aux_sym_binary_expression_token2] = ACTIONS(559),
    [aux_sym_build_in_function_token1] = ACTIONS(559),
    [aux_sym_build_in_function_token2] = ACTIONS(559),
    [aux_sym_build_in_function_token3] = ACTIONS(559),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(559),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(559),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(559),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(559),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(559),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(559),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(559),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(559),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(559),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(559),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(559),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(559),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(559),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(559),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(559),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(559),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(559),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(559),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(559),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(559),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(559),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(559),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(559),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(559),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(559),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(559),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(559),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(559),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(559),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(559),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(559),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(559),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(559),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(559),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(559),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(559),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(559),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(559),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(559),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(559),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(559),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(559),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(559),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(559),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(559),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(559),
    [aux_sym_regex_expression_token1] = ACTIONS(559),
    [aux_sym_substring_expression_token1] = ACTIONS(559),
    [aux_sym_string_replace_expression_token1] = ACTIONS(559),
    [aux_sym_exists_func_token1] = ACTIONS(559),
    [aux_sym_aggregate_token1] = ACTIONS(559),
    [aux_sym_aggregate_token2] = ACTIONS(559),
    [aux_sym_aggregate_token3] = ACTIONS(559),
    [aux_sym_aggregate_token4] = ACTIONS(559),
    [aux_sym_aggregate_token5] = ACTIONS(559),
    [aux_sym_aggregate_token6] = ACTIONS(559),
    [anon_sym_GROUP_CONCAT] = ACTIONS(559),
    [anon_sym_COLON] = ACTIONS(557),
  },
  [142] = {
    [ts_builtin_sym_end] = ACTIONS(561),
    [sym_pn_prefix] = ACTIONS(563),
    [sym_comment] = ACTIONS(3),
    [aux_sym_base_declaration_token1] = ACTIONS(563),
    [aux_sym_prefix_declaration_token1] = ACTIONS(563),
    [aux_sym_select_clause_token1] = ACTIONS(563),
    [anon_sym_LPAREN] = ACTIONS(561),
    [aux_sym_construct_query_token1] = ACTIONS(563),
    [aux_sym_describe_query_token1] = ACTIONS(563),
    [aux_sym_ask_query_token1] = ACTIONS(563),
    [aux_sym_having_clause_token1] = ACTIONS(563),
    [aux_sym_order_clause_token1] = ACTIONS(563),
    [aux_sym_order_condition_token1] = ACTIONS(563),
    [aux_sym_order_condition_token2] = ACTIONS(563),
    [aux_sym_limit_clause_token1] = ACTIONS(563),
    [aux_sym_offset_clause_token1] = ACTIONS(563),
    [aux_sym_values_clause_token1] = ACTIONS(563),
    [aux_sym_load_token1] = ACTIONS(563),
    [aux_sym_clear_token1] = ACTIONS(563),
    [aux_sym_drop_token1] = ACTIONS(563),
    [aux_sym_create_token1] = ACTIONS(563),
    [aux_sym_add_token1] = ACTIONS(563),
    [aux_sym_move_token1] = ACTIONS(563),
    [aux_sym_copy_token1] = ACTIONS(563),
    [anon_sym_INSERTDATA] = ACTIONS(561),
    [anon_sym_DELETEDATA] = ACTIONS(561),
    [anon_sym_DELETEWHERE] = ACTIONS(561),
    [aux_sym_modify_token1] = ACTIONS(563),
    [aux_sym_delete_clause_token1] = ACTIONS(563),
    [aux_sym_insert_clause_token1] = ACTIONS(563),
    [sym_var] = ACTIONS(561),
    [anon_sym_LT] = ACTIONS(561),
    [aux_sym_binary_expression_token2] = ACTIONS(563),
    [aux_sym_build_in_function_token1] = ACTIONS(563),
    [aux_sym_build_in_function_token2] = ACTIONS(563),
    [aux_sym_build_in_function_token3] = ACTIONS(563),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(563),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(563),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(563),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(563),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(563),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(563),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(563),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(563),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(563),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(563),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(563),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(563),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(563),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(563),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(563),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(563),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(563),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(563),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(563),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(563),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(563),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(563),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(563),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(563),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(563),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(563),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(563),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(563),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(563),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(563),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(563),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(563),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(563),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(563),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(563),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(563),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(563),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(563),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(563),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(563),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(563),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(563),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(563),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(563),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(563),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(563),
    [aux_sym_regex_expression_token1] = ACTIONS(563),
    [aux_sym_substring_expression_token1] = ACTIONS(563),
    [aux_sym_string_replace_expression_token1] = ACTIONS(563),
    [aux_sym_exists_func_token1] = ACTIONS(563),
    [aux_sym_aggregate_token1] = ACTIONS(563),
    [aux_sym_aggregate_token2] = ACTIONS(563),
    [aux_sym_aggregate_token3] = ACTIONS(563),
    [aux_sym_aggregate_token4] = ACTIONS(563),
    [aux_sym_aggregate_token5] = ACTIONS(563),
    [aux_sym_aggregate_token6] = ACTIONS(563),
    [anon_sym_GROUP_CONCAT] = ACTIONS(563),
    [anon_sym_COLON] = ACTIONS(561),
  },
  [143] = {
    [ts_builtin_sym_end] = ACTIONS(565),
    [sym_pn_prefix] = ACTIONS(567),
    [sym_comment] = ACTIONS(3),
    [aux_sym_base_declaration_token1] = ACTIONS(567),
    [aux_sym_prefix_declaration_token1] = ACTIONS(567),
    [aux_sym_select_clause_token1] = ACTIONS(567),
    [anon_sym_LPAREN] = ACTIONS(565),
    [aux_sym_construct_query_token1] = ACTIONS(567),
    [aux_sym_describe_query_token1] = ACTIONS(567),
    [aux_sym_ask_query_token1] = ACTIONS(567),
    [aux_sym_having_clause_token1] = ACTIONS(567),
    [aux_sym_order_clause_token1] = ACTIONS(567),
    [aux_sym_order_condition_token1] = ACTIONS(567),
    [aux_sym_order_condition_token2] = ACTIONS(567),
    [aux_sym_limit_clause_token1] = ACTIONS(567),
    [aux_sym_offset_clause_token1] = ACTIONS(567),
    [aux_sym_values_clause_token1] = ACTIONS(567),
    [aux_sym_load_token1] = ACTIONS(567),
    [aux_sym_clear_token1] = ACTIONS(567),
    [aux_sym_drop_token1] = ACTIONS(567),
    [aux_sym_create_token1] = ACTIONS(567),
    [aux_sym_add_token1] = ACTIONS(567),
    [aux_sym_move_token1] = ACTIONS(567),
    [aux_sym_copy_token1] = ACTIONS(567),
    [anon_sym_INSERTDATA] = ACTIONS(565),
    [anon_sym_DELETEDATA] = ACTIONS(565),
    [anon_sym_DELETEWHERE] = ACTIONS(565),
    [aux_sym_modify_token1] = ACTIONS(567),
    [aux_sym_delete_clause_token1] = ACTIONS(567),
    [aux_sym_insert_clause_token1] = ACTIONS(567),
    [sym_var] = ACTIONS(565),
    [anon_sym_LT] = ACTIONS(565),
    [aux_sym_binary_expression_token2] = ACTIONS(567),
    [aux_sym_build_in_function_token1] = ACTIONS(567),
    [aux_sym_build_in_function_token2] = ACTIONS(567),
    [aux_sym_build_in_function_token3] = ACTIONS(567),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(567),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(567),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(567),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(567),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(567),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(567),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(567),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(567),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(567),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(567),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(567),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(567),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(567),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(567),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(567),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(567),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(567),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(567),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(567),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(567),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(567),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(567),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(567),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(567),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(567),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(567),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(567),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(567),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(567),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(567),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(567),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(567),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(567),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(567),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(567),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(567),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(567),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(567),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(567),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(567),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(567),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(567),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(567),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(567),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(567),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(567),
    [aux_sym_regex_expression_token1] = ACTIONS(567),
    [aux_sym_substring_expression_token1] = ACTIONS(567),
    [aux_sym_string_replace_expression_token1] = ACTIONS(567),
    [aux_sym_exists_func_token1] = ACTIONS(567),
    [aux_sym_aggregate_token1] = ACTIONS(567),
    [aux_sym_aggregate_token2] = ACTIONS(567),
    [aux_sym_aggregate_token3] = ACTIONS(567),
    [aux_sym_aggregate_token4] = ACTIONS(567),
    [aux_sym_aggregate_token5] = ACTIONS(567),
    [aux_sym_aggregate_token6] = ACTIONS(567),
    [anon_sym_GROUP_CONCAT] = ACTIONS(567),
    [anon_sym_COLON] = ACTIONS(565),
  },
  [144] = {
    [ts_builtin_sym_end] = ACTIONS(569),
    [sym_pn_prefix] = ACTIONS(571),
    [sym_comment] = ACTIONS(3),
    [aux_sym_base_declaration_token1] = ACTIONS(571),
    [aux_sym_prefix_declaration_token1] = ACTIONS(571),
    [aux_sym_select_clause_token1] = ACTIONS(571),
    [anon_sym_LPAREN] = ACTIONS(569),
    [aux_sym_construct_query_token1] = ACTIONS(571),
    [aux_sym_describe_query_token1] = ACTIONS(571),
    [aux_sym_ask_query_token1] = ACTIONS(571),
    [aux_sym_having_clause_token1] = ACTIONS(571),
    [aux_sym_order_clause_token1] = ACTIONS(571),
    [aux_sym_order_condition_token1] = ACTIONS(571),
    [aux_sym_order_condition_token2] = ACTIONS(571),
    [aux_sym_limit_clause_token1] = ACTIONS(571),
    [aux_sym_offset_clause_token1] = ACTIONS(571),
    [aux_sym_values_clause_token1] = ACTIONS(571),
    [aux_sym_load_token1] = ACTIONS(571),
    [aux_sym_clear_token1] = ACTIONS(571),
    [aux_sym_drop_token1] = ACTIONS(571),
    [aux_sym_create_token1] = ACTIONS(571),
    [aux_sym_add_token1] = ACTIONS(571),
    [aux_sym_move_token1] = ACTIONS(571),
    [aux_sym_copy_token1] = ACTIONS(571),
    [anon_sym_INSERTDATA] = ACTIONS(569),
    [anon_sym_DELETEDATA] = ACTIONS(569),
    [anon_sym_DELETEWHERE] = ACTIONS(569),
    [aux_sym_modify_token1] = ACTIONS(571),
    [aux_sym_delete_clause_token1] = ACTIONS(571),
    [aux_sym_insert_clause_token1] = ACTIONS(571),
    [sym_var] = ACTIONS(569),
    [anon_sym_LT] = ACTIONS(569),
    [aux_sym_binary_expression_token2] = ACTIONS(571),
    [aux_sym_build_in_function_token1] = ACTIONS(571),
    [aux_sym_build_in_function_token2] = ACTIONS(571),
    [aux_sym_build_in_function_token3] = ACTIONS(571),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(571),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(571),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(571),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(571),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(571),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(571),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(571),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(571),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(571),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(571),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(571),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(571),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(571),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(571),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(571),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(571),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(571),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(571),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(571),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(571),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(571),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(571),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(571),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(571),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(571),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(571),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(571),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(571),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(571),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(571),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(571),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(571),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(571),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(571),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(571),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(571),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(571),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(571),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(571),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(571),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(571),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(571),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(571),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(571),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(571),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(571),
    [aux_sym_regex_expression_token1] = ACTIONS(571),
    [aux_sym_substring_expression_token1] = ACTIONS(571),
    [aux_sym_string_replace_expression_token1] = ACTIONS(571),
    [aux_sym_exists_func_token1] = ACTIONS(571),
    [aux_sym_aggregate_token1] = ACTIONS(571),
    [aux_sym_aggregate_token2] = ACTIONS(571),
    [aux_sym_aggregate_token3] = ACTIONS(571),
    [aux_sym_aggregate_token4] = ACTIONS(571),
    [aux_sym_aggregate_token5] = ACTIONS(571),
    [aux_sym_aggregate_token6] = ACTIONS(571),
    [anon_sym_GROUP_CONCAT] = ACTIONS(571),
    [anon_sym_COLON] = ACTIONS(569),
  },
  [145] = {
    [ts_builtin_sym_end] = ACTIONS(573),
    [sym_pn_prefix] = ACTIONS(575),
    [sym_comment] = ACTIONS(3),
    [aux_sym_base_declaration_token1] = ACTIONS(575),
    [aux_sym_prefix_declaration_token1] = ACTIONS(575),
    [aux_sym_select_clause_token1] = ACTIONS(575),
    [anon_sym_LPAREN] = ACTIONS(573),
    [aux_sym_construct_query_token1] = ACTIONS(575),
    [aux_sym_describe_query_token1] = ACTIONS(575),
    [aux_sym_ask_query_token1] = ACTIONS(575),
    [aux_sym_having_clause_token1] = ACTIONS(575),
    [aux_sym_order_clause_token1] = ACTIONS(575),
    [aux_sym_order_condition_token1] = ACTIONS(575),
    [aux_sym_order_condition_token2] = ACTIONS(575),
    [aux_sym_limit_clause_token1] = ACTIONS(575),
    [aux_sym_offset_clause_token1] = ACTIONS(575),
    [aux_sym_values_clause_token1] = ACTIONS(575),
    [aux_sym_load_token1] = ACTIONS(575),
    [aux_sym_clear_token1] = ACTIONS(575),
    [aux_sym_drop_token1] = ACTIONS(575),
    [aux_sym_create_token1] = ACTIONS(575),
    [aux_sym_add_token1] = ACTIONS(575),
    [aux_sym_move_token1] = ACTIONS(575),
    [aux_sym_copy_token1] = ACTIONS(575),
    [anon_sym_INSERTDATA] = ACTIONS(573),
    [anon_sym_DELETEDATA] = ACTIONS(573),
    [anon_sym_DELETEWHERE] = ACTIONS(573),
    [aux_sym_modify_token1] = ACTIONS(575),
    [aux_sym_delete_clause_token1] = ACTIONS(575),
    [aux_sym_insert_clause_token1] = ACTIONS(575),
    [sym_var] = ACTIONS(573),
    [anon_sym_LT] = ACTIONS(573),
    [aux_sym_binary_expression_token2] = ACTIONS(575),
    [aux_sym_build_in_function_token1] = ACTIONS(575),
    [aux_sym_build_in_function_token2] = ACTIONS(575),
    [aux_sym_build_in_function_token3] = ACTIONS(575),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(575),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(575),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(575),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(575),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(575),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(575),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(575),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(575),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(575),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(575),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(575),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(575),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(575),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(575),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(575),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(575),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(575),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(575),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(575),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(575),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(575),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(575),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(575),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(575),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(575),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(575),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(575),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(575),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(575),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(575),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(575),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(575),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(575),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(575),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(575),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(575),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(575),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(575),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(575),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(575),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(575),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(575),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(575),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(575),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(575),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(575),
    [aux_sym_regex_expression_token1] = ACTIONS(575),
    [aux_sym_substring_expression_token1] = ACTIONS(575),
    [aux_sym_string_replace_expression_token1] = ACTIONS(575),
    [aux_sym_exists_func_token1] = ACTIONS(575),
    [aux_sym_aggregate_token1] = ACTIONS(575),
    [aux_sym_aggregate_token2] = ACTIONS(575),
    [aux_sym_aggregate_token3] = ACTIONS(575),
    [aux_sym_aggregate_token4] = ACTIONS(575),
    [aux_sym_aggregate_token5] = ACTIONS(575),
    [aux_sym_aggregate_token6] = ACTIONS(575),
    [anon_sym_GROUP_CONCAT] = ACTIONS(575),
    [anon_sym_COLON] = ACTIONS(573),
  },
  [146] = {
    [ts_builtin_sym_end] = ACTIONS(577),
    [sym_pn_prefix] = ACTIONS(579),
    [sym_comment] = ACTIONS(3),
    [aux_sym_base_declaration_token1] = ACTIONS(579),
    [aux_sym_prefix_declaration_token1] = ACTIONS(579),
    [aux_sym_select_clause_token1] = ACTIONS(579),
    [anon_sym_LPAREN] = ACTIONS(577),
    [aux_sym_construct_query_token1] = ACTIONS(579),
    [aux_sym_describe_query_token1] = ACTIONS(579),
    [aux_sym_ask_query_token1] = ACTIONS(579),
    [aux_sym_having_clause_token1] = ACTIONS(579),
    [aux_sym_order_clause_token1] = ACTIONS(579),
    [aux_sym_order_condition_token1] = ACTIONS(579),
    [aux_sym_order_condition_token2] = ACTIONS(579),
    [aux_sym_limit_clause_token1] = ACTIONS(579),
    [aux_sym_offset_clause_token1] = ACTIONS(579),
    [aux_sym_values_clause_token1] = ACTIONS(579),
    [aux_sym_load_token1] = ACTIONS(579),
    [aux_sym_clear_token1] = ACTIONS(579),
    [aux_sym_drop_token1] = ACTIONS(579),
    [aux_sym_create_token1] = ACTIONS(579),
    [aux_sym_add_token1] = ACTIONS(579),
    [aux_sym_move_token1] = ACTIONS(579),
    [aux_sym_copy_token1] = ACTIONS(579),
    [anon_sym_INSERTDATA] = ACTIONS(577),
    [anon_sym_DELETEDATA] = ACTIONS(577),
    [anon_sym_DELETEWHERE] = ACTIONS(577),
    [aux_sym_modify_token1] = ACTIONS(579),
    [aux_sym_delete_clause_token1] = ACTIONS(579),
    [aux_sym_insert_clause_token1] = ACTIONS(579),
    [sym_var] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(577),
    [aux_sym_binary_expression_token2] = ACTIONS(579),
    [aux_sym_build_in_function_token1] = ACTIONS(579),
    [aux_sym_build_in_function_token2] = ACTIONS(579),
    [aux_sym_build_in_function_token3] = ACTIONS(579),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(579),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(579),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(579),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(579),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(579),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(579),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(579),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(579),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(579),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(579),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(579),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(579),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(579),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(579),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(579),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(579),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(579),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(579),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(579),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(579),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(579),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(579),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(579),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(579),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(579),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(579),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(579),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(579),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(579),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(579),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(579),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(579),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(579),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(579),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(579),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(579),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(579),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(579),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(579),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(579),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(579),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(579),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(579),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(579),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(579),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(579),
    [aux_sym_regex_expression_token1] = ACTIONS(579),
    [aux_sym_substring_expression_token1] = ACTIONS(579),
    [aux_sym_string_replace_expression_token1] = ACTIONS(579),
    [aux_sym_exists_func_token1] = ACTIONS(579),
    [aux_sym_aggregate_token1] = ACTIONS(579),
    [aux_sym_aggregate_token2] = ACTIONS(579),
    [aux_sym_aggregate_token3] = ACTIONS(579),
    [aux_sym_aggregate_token4] = ACTIONS(579),
    [aux_sym_aggregate_token5] = ACTIONS(579),
    [aux_sym_aggregate_token6] = ACTIONS(579),
    [anon_sym_GROUP_CONCAT] = ACTIONS(579),
    [anon_sym_COLON] = ACTIONS(577),
  },
  [147] = {
    [ts_builtin_sym_end] = ACTIONS(581),
    [sym_pn_prefix] = ACTIONS(583),
    [sym_comment] = ACTIONS(3),
    [aux_sym_base_declaration_token1] = ACTIONS(583),
    [aux_sym_prefix_declaration_token1] = ACTIONS(583),
    [aux_sym_select_clause_token1] = ACTIONS(583),
    [anon_sym_LPAREN] = ACTIONS(581),
    [aux_sym_construct_query_token1] = ACTIONS(583),
    [aux_sym_describe_query_token1] = ACTIONS(583),
    [aux_sym_ask_query_token1] = ACTIONS(583),
    [aux_sym_having_clause_token1] = ACTIONS(583),
    [aux_sym_order_clause_token1] = ACTIONS(583),
    [aux_sym_order_condition_token1] = ACTIONS(583),
    [aux_sym_order_condition_token2] = ACTIONS(583),
    [aux_sym_limit_clause_token1] = ACTIONS(583),
    [aux_sym_offset_clause_token1] = ACTIONS(583),
    [aux_sym_values_clause_token1] = ACTIONS(583),
    [aux_sym_load_token1] = ACTIONS(583),
    [aux_sym_clear_token1] = ACTIONS(583),
    [aux_sym_drop_token1] = ACTIONS(583),
    [aux_sym_create_token1] = ACTIONS(583),
    [aux_sym_add_token1] = ACTIONS(583),
    [aux_sym_move_token1] = ACTIONS(583),
    [aux_sym_copy_token1] = ACTIONS(583),
    [anon_sym_INSERTDATA] = ACTIONS(581),
    [anon_sym_DELETEDATA] = ACTIONS(581),
    [anon_sym_DELETEWHERE] = ACTIONS(581),
    [aux_sym_modify_token1] = ACTIONS(583),
    [aux_sym_delete_clause_token1] = ACTIONS(583),
    [aux_sym_insert_clause_token1] = ACTIONS(583),
    [sym_var] = ACTIONS(581),
    [anon_sym_LT] = ACTIONS(581),
    [aux_sym_binary_expression_token2] = ACTIONS(583),
    [aux_sym_build_in_function_token1] = ACTIONS(583),
    [aux_sym_build_in_function_token2] = ACTIONS(583),
    [aux_sym_build_in_function_token3] = ACTIONS(583),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(583),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(583),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(583),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(583),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(583),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(583),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(583),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(583),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(583),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(583),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(583),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(583),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(583),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(583),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(583),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(583),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(583),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(583),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(583),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(583),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(583),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(583),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(583),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(583),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(583),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(583),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(583),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(583),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(583),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(583),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(583),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(583),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(583),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(583),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(583),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(583),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(583),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(583),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(583),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(583),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(583),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(583),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(583),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(583),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(583),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(583),
    [aux_sym_regex_expression_token1] = ACTIONS(583),
    [aux_sym_substring_expression_token1] = ACTIONS(583),
    [aux_sym_string_replace_expression_token1] = ACTIONS(583),
    [aux_sym_exists_func_token1] = ACTIONS(583),
    [aux_sym_aggregate_token1] = ACTIONS(583),
    [aux_sym_aggregate_token2] = ACTIONS(583),
    [aux_sym_aggregate_token3] = ACTIONS(583),
    [aux_sym_aggregate_token4] = ACTIONS(583),
    [aux_sym_aggregate_token5] = ACTIONS(583),
    [aux_sym_aggregate_token6] = ACTIONS(583),
    [anon_sym_GROUP_CONCAT] = ACTIONS(583),
    [anon_sym_COLON] = ACTIONS(581),
  },
  [148] = {
    [ts_builtin_sym_end] = ACTIONS(585),
    [sym_pn_prefix] = ACTIONS(587),
    [sym_comment] = ACTIONS(3),
    [aux_sym_base_declaration_token1] = ACTIONS(587),
    [aux_sym_prefix_declaration_token1] = ACTIONS(587),
    [aux_sym_select_clause_token1] = ACTIONS(587),
    [anon_sym_LPAREN] = ACTIONS(585),
    [aux_sym_construct_query_token1] = ACTIONS(587),
    [aux_sym_describe_query_token1] = ACTIONS(587),
    [aux_sym_ask_query_token1] = ACTIONS(587),
    [aux_sym_having_clause_token1] = ACTIONS(587),
    [aux_sym_order_clause_token1] = ACTIONS(587),
    [aux_sym_order_condition_token1] = ACTIONS(587),
    [aux_sym_order_condition_token2] = ACTIONS(587),
    [aux_sym_limit_clause_token1] = ACTIONS(587),
    [aux_sym_offset_clause_token1] = ACTIONS(587),
    [aux_sym_values_clause_token1] = ACTIONS(587),
    [aux_sym_load_token1] = ACTIONS(587),
    [aux_sym_clear_token1] = ACTIONS(587),
    [aux_sym_drop_token1] = ACTIONS(587),
    [aux_sym_create_token1] = ACTIONS(587),
    [aux_sym_add_token1] = ACTIONS(587),
    [aux_sym_move_token1] = ACTIONS(587),
    [aux_sym_copy_token1] = ACTIONS(587),
    [anon_sym_INSERTDATA] = ACTIONS(585),
    [anon_sym_DELETEDATA] = ACTIONS(585),
    [anon_sym_DELETEWHERE] = ACTIONS(585),
    [aux_sym_modify_token1] = ACTIONS(587),
    [aux_sym_delete_clause_token1] = ACTIONS(587),
    [aux_sym_insert_clause_token1] = ACTIONS(587),
    [sym_var] = ACTIONS(585),
    [anon_sym_LT] = ACTIONS(585),
    [aux_sym_binary_expression_token2] = ACTIONS(587),
    [aux_sym_build_in_function_token1] = ACTIONS(587),
    [aux_sym_build_in_function_token2] = ACTIONS(587),
    [aux_sym_build_in_function_token3] = ACTIONS(587),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(587),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(587),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(587),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(587),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(587),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(587),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(587),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(587),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(587),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(587),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(587),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(587),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(587),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(587),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(587),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(587),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(587),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(587),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(587),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(587),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(587),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(587),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(587),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(587),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(587),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(587),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(587),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(587),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(587),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(587),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(587),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(587),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(587),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(587),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(587),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(587),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(587),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(587),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(587),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(587),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(587),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(587),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(587),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(587),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(587),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(587),
    [aux_sym_regex_expression_token1] = ACTIONS(587),
    [aux_sym_substring_expression_token1] = ACTIONS(587),
    [aux_sym_string_replace_expression_token1] = ACTIONS(587),
    [aux_sym_exists_func_token1] = ACTIONS(587),
    [aux_sym_aggregate_token1] = ACTIONS(587),
    [aux_sym_aggregate_token2] = ACTIONS(587),
    [aux_sym_aggregate_token3] = ACTIONS(587),
    [aux_sym_aggregate_token4] = ACTIONS(587),
    [aux_sym_aggregate_token5] = ACTIONS(587),
    [aux_sym_aggregate_token6] = ACTIONS(587),
    [anon_sym_GROUP_CONCAT] = ACTIONS(587),
    [anon_sym_COLON] = ACTIONS(585),
  },
  [149] = {
    [ts_builtin_sym_end] = ACTIONS(589),
    [sym_pn_prefix] = ACTIONS(591),
    [sym_comment] = ACTIONS(3),
    [aux_sym_base_declaration_token1] = ACTIONS(591),
    [aux_sym_prefix_declaration_token1] = ACTIONS(591),
    [aux_sym_select_clause_token1] = ACTIONS(591),
    [anon_sym_LPAREN] = ACTIONS(589),
    [aux_sym_construct_query_token1] = ACTIONS(591),
    [aux_sym_describe_query_token1] = ACTIONS(591),
    [aux_sym_ask_query_token1] = ACTIONS(591),
    [aux_sym_having_clause_token1] = ACTIONS(591),
    [aux_sym_order_clause_token1] = ACTIONS(591),
    [aux_sym_order_condition_token1] = ACTIONS(591),
    [aux_sym_order_condition_token2] = ACTIONS(591),
    [aux_sym_limit_clause_token1] = ACTIONS(591),
    [aux_sym_offset_clause_token1] = ACTIONS(591),
    [aux_sym_values_clause_token1] = ACTIONS(591),
    [aux_sym_load_token1] = ACTIONS(591),
    [aux_sym_clear_token1] = ACTIONS(591),
    [aux_sym_drop_token1] = ACTIONS(591),
    [aux_sym_create_token1] = ACTIONS(591),
    [aux_sym_add_token1] = ACTIONS(591),
    [aux_sym_move_token1] = ACTIONS(591),
    [aux_sym_copy_token1] = ACTIONS(591),
    [anon_sym_INSERTDATA] = ACTIONS(589),
    [anon_sym_DELETEDATA] = ACTIONS(589),
    [anon_sym_DELETEWHERE] = ACTIONS(589),
    [aux_sym_modify_token1] = ACTIONS(591),
    [aux_sym_delete_clause_token1] = ACTIONS(591),
    [aux_sym_insert_clause_token1] = ACTIONS(591),
    [sym_var] = ACTIONS(589),
    [anon_sym_LT] = ACTIONS(589),
    [aux_sym_binary_expression_token2] = ACTIONS(591),
    [aux_sym_build_in_function_token1] = ACTIONS(591),
    [aux_sym_build_in_function_token2] = ACTIONS(591),
    [aux_sym_build_in_function_token3] = ACTIONS(591),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(591),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(591),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(591),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(591),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(591),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(591),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(591),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(591),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(591),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(591),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(591),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(591),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(591),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(591),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(591),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(591),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(591),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(591),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(591),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(591),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(591),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(591),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(591),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(591),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(591),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(591),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(591),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(591),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(591),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(591),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(591),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(591),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(591),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(591),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(591),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(591),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(591),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(591),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(591),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(591),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(591),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(591),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(591),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(591),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(591),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(591),
    [aux_sym_regex_expression_token1] = ACTIONS(591),
    [aux_sym_substring_expression_token1] = ACTIONS(591),
    [aux_sym_string_replace_expression_token1] = ACTIONS(591),
    [aux_sym_exists_func_token1] = ACTIONS(591),
    [aux_sym_aggregate_token1] = ACTIONS(591),
    [aux_sym_aggregate_token2] = ACTIONS(591),
    [aux_sym_aggregate_token3] = ACTIONS(591),
    [aux_sym_aggregate_token4] = ACTIONS(591),
    [aux_sym_aggregate_token5] = ACTIONS(591),
    [aux_sym_aggregate_token6] = ACTIONS(591),
    [anon_sym_GROUP_CONCAT] = ACTIONS(591),
    [anon_sym_COLON] = ACTIONS(589),
  },
  [150] = {
    [ts_builtin_sym_end] = ACTIONS(593),
    [sym_pn_prefix] = ACTIONS(595),
    [sym_comment] = ACTIONS(3),
    [aux_sym_base_declaration_token1] = ACTIONS(595),
    [aux_sym_prefix_declaration_token1] = ACTIONS(595),
    [aux_sym_select_clause_token1] = ACTIONS(595),
    [anon_sym_LPAREN] = ACTIONS(593),
    [aux_sym_construct_query_token1] = ACTIONS(595),
    [aux_sym_describe_query_token1] = ACTIONS(595),
    [aux_sym_ask_query_token1] = ACTIONS(595),
    [aux_sym_having_clause_token1] = ACTIONS(595),
    [aux_sym_order_clause_token1] = ACTIONS(595),
    [aux_sym_order_condition_token1] = ACTIONS(595),
    [aux_sym_order_condition_token2] = ACTIONS(595),
    [aux_sym_limit_clause_token1] = ACTIONS(595),
    [aux_sym_offset_clause_token1] = ACTIONS(595),
    [aux_sym_values_clause_token1] = ACTIONS(595),
    [aux_sym_load_token1] = ACTIONS(595),
    [aux_sym_clear_token1] = ACTIONS(595),
    [aux_sym_drop_token1] = ACTIONS(595),
    [aux_sym_create_token1] = ACTIONS(595),
    [aux_sym_add_token1] = ACTIONS(595),
    [aux_sym_move_token1] = ACTIONS(595),
    [aux_sym_copy_token1] = ACTIONS(595),
    [anon_sym_INSERTDATA] = ACTIONS(593),
    [anon_sym_DELETEDATA] = ACTIONS(593),
    [anon_sym_DELETEWHERE] = ACTIONS(593),
    [aux_sym_modify_token1] = ACTIONS(595),
    [aux_sym_delete_clause_token1] = ACTIONS(595),
    [aux_sym_insert_clause_token1] = ACTIONS(595),
    [sym_var] = ACTIONS(593),
    [anon_sym_LT] = ACTIONS(593),
    [aux_sym_binary_expression_token2] = ACTIONS(595),
    [aux_sym_build_in_function_token1] = ACTIONS(595),
    [aux_sym_build_in_function_token2] = ACTIONS(595),
    [aux_sym_build_in_function_token3] = ACTIONS(595),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(595),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(595),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(595),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(595),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(595),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(595),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(595),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(595),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(595),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(595),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(595),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(595),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(595),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(595),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(595),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(595),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(595),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(595),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(595),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(595),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(595),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(595),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(595),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(595),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(595),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(595),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(595),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(595),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(595),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(595),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(595),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(595),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(595),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(595),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(595),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(595),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(595),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(595),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(595),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(595),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(595),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(595),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(595),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(595),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(595),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(595),
    [aux_sym_regex_expression_token1] = ACTIONS(595),
    [aux_sym_substring_expression_token1] = ACTIONS(595),
    [aux_sym_string_replace_expression_token1] = ACTIONS(595),
    [aux_sym_exists_func_token1] = ACTIONS(595),
    [aux_sym_aggregate_token1] = ACTIONS(595),
    [aux_sym_aggregate_token2] = ACTIONS(595),
    [aux_sym_aggregate_token3] = ACTIONS(595),
    [aux_sym_aggregate_token4] = ACTIONS(595),
    [aux_sym_aggregate_token5] = ACTIONS(595),
    [aux_sym_aggregate_token6] = ACTIONS(595),
    [anon_sym_GROUP_CONCAT] = ACTIONS(595),
    [anon_sym_COLON] = ACTIONS(593),
  },
  [151] = {
    [ts_builtin_sym_end] = ACTIONS(597),
    [sym_pn_prefix] = ACTIONS(599),
    [sym_comment] = ACTIONS(3),
    [aux_sym_base_declaration_token1] = ACTIONS(599),
    [aux_sym_prefix_declaration_token1] = ACTIONS(599),
    [aux_sym_select_clause_token1] = ACTIONS(599),
    [anon_sym_LPAREN] = ACTIONS(597),
    [aux_sym_construct_query_token1] = ACTIONS(599),
    [aux_sym_describe_query_token1] = ACTIONS(599),
    [aux_sym_ask_query_token1] = ACTIONS(599),
    [aux_sym_having_clause_token1] = ACTIONS(599),
    [aux_sym_order_clause_token1] = ACTIONS(599),
    [aux_sym_order_condition_token1] = ACTIONS(599),
    [aux_sym_order_condition_token2] = ACTIONS(599),
    [aux_sym_limit_clause_token1] = ACTIONS(599),
    [aux_sym_offset_clause_token1] = ACTIONS(599),
    [aux_sym_values_clause_token1] = ACTIONS(599),
    [aux_sym_load_token1] = ACTIONS(599),
    [aux_sym_clear_token1] = ACTIONS(599),
    [aux_sym_drop_token1] = ACTIONS(599),
    [aux_sym_create_token1] = ACTIONS(599),
    [aux_sym_add_token1] = ACTIONS(599),
    [aux_sym_move_token1] = ACTIONS(599),
    [aux_sym_copy_token1] = ACTIONS(599),
    [anon_sym_INSERTDATA] = ACTIONS(597),
    [anon_sym_DELETEDATA] = ACTIONS(597),
    [anon_sym_DELETEWHERE] = ACTIONS(597),
    [aux_sym_modify_token1] = ACTIONS(599),
    [aux_sym_delete_clause_token1] = ACTIONS(599),
    [aux_sym_insert_clause_token1] = ACTIONS(599),
    [sym_var] = ACTIONS(597),
    [anon_sym_LT] = ACTIONS(597),
    [aux_sym_binary_expression_token2] = ACTIONS(599),
    [aux_sym_build_in_function_token1] = ACTIONS(599),
    [aux_sym_build_in_function_token2] = ACTIONS(599),
    [aux_sym_build_in_function_token3] = ACTIONS(599),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(599),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(599),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(599),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(599),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(599),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(599),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(599),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(599),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(599),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(599),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(599),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(599),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(599),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(599),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(599),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(599),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(599),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(599),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(599),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(599),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(599),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(599),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(599),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(599),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(599),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(599),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(599),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(599),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(599),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(599),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(599),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(599),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(599),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(599),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(599),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(599),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(599),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(599),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(599),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(599),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(599),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(599),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(599),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(599),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(599),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(599),
    [aux_sym_regex_expression_token1] = ACTIONS(599),
    [aux_sym_substring_expression_token1] = ACTIONS(599),
    [aux_sym_string_replace_expression_token1] = ACTIONS(599),
    [aux_sym_exists_func_token1] = ACTIONS(599),
    [aux_sym_aggregate_token1] = ACTIONS(599),
    [aux_sym_aggregate_token2] = ACTIONS(599),
    [aux_sym_aggregate_token3] = ACTIONS(599),
    [aux_sym_aggregate_token4] = ACTIONS(599),
    [aux_sym_aggregate_token5] = ACTIONS(599),
    [aux_sym_aggregate_token6] = ACTIONS(599),
    [anon_sym_GROUP_CONCAT] = ACTIONS(599),
    [anon_sym_COLON] = ACTIONS(597),
  },
  [152] = {
    [ts_builtin_sym_end] = ACTIONS(601),
    [sym_pn_prefix] = ACTIONS(603),
    [sym_comment] = ACTIONS(3),
    [aux_sym_base_declaration_token1] = ACTIONS(603),
    [aux_sym_prefix_declaration_token1] = ACTIONS(603),
    [aux_sym_select_clause_token1] = ACTIONS(603),
    [anon_sym_LPAREN] = ACTIONS(601),
    [aux_sym_construct_query_token1] = ACTIONS(603),
    [aux_sym_describe_query_token1] = ACTIONS(603),
    [aux_sym_ask_query_token1] = ACTIONS(603),
    [aux_sym_having_clause_token1] = ACTIONS(603),
    [aux_sym_order_clause_token1] = ACTIONS(603),
    [aux_sym_order_condition_token1] = ACTIONS(603),
    [aux_sym_order_condition_token2] = ACTIONS(603),
    [aux_sym_limit_clause_token1] = ACTIONS(603),
    [aux_sym_offset_clause_token1] = ACTIONS(603),
    [aux_sym_values_clause_token1] = ACTIONS(603),
    [aux_sym_load_token1] = ACTIONS(603),
    [aux_sym_clear_token1] = ACTIONS(603),
    [aux_sym_drop_token1] = ACTIONS(603),
    [aux_sym_create_token1] = ACTIONS(603),
    [aux_sym_add_token1] = ACTIONS(603),
    [aux_sym_move_token1] = ACTIONS(603),
    [aux_sym_copy_token1] = ACTIONS(603),
    [anon_sym_INSERTDATA] = ACTIONS(601),
    [anon_sym_DELETEDATA] = ACTIONS(601),
    [anon_sym_DELETEWHERE] = ACTIONS(601),
    [aux_sym_modify_token1] = ACTIONS(603),
    [aux_sym_delete_clause_token1] = ACTIONS(603),
    [aux_sym_insert_clause_token1] = ACTIONS(603),
    [sym_var] = ACTIONS(601),
    [anon_sym_LT] = ACTIONS(601),
    [aux_sym_binary_expression_token2] = ACTIONS(603),
    [aux_sym_build_in_function_token1] = ACTIONS(603),
    [aux_sym_build_in_function_token2] = ACTIONS(603),
    [aux_sym_build_in_function_token3] = ACTIONS(603),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(603),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(603),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(603),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(603),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(603),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(603),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(603),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(603),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(603),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(603),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(603),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(603),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(603),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(603),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(603),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(603),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(603),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(603),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(603),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(603),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(603),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(603),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(603),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(603),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(603),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(603),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(603),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(603),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(603),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(603),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(603),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(603),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(603),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(603),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(603),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(603),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(603),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(603),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(603),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(603),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(603),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(603),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(603),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(603),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(603),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(603),
    [aux_sym_regex_expression_token1] = ACTIONS(603),
    [aux_sym_substring_expression_token1] = ACTIONS(603),
    [aux_sym_string_replace_expression_token1] = ACTIONS(603),
    [aux_sym_exists_func_token1] = ACTIONS(603),
    [aux_sym_aggregate_token1] = ACTIONS(603),
    [aux_sym_aggregate_token2] = ACTIONS(603),
    [aux_sym_aggregate_token3] = ACTIONS(603),
    [aux_sym_aggregate_token4] = ACTIONS(603),
    [aux_sym_aggregate_token5] = ACTIONS(603),
    [aux_sym_aggregate_token6] = ACTIONS(603),
    [anon_sym_GROUP_CONCAT] = ACTIONS(603),
    [anon_sym_COLON] = ACTIONS(601),
  },
  [153] = {
    [ts_builtin_sym_end] = ACTIONS(605),
    [sym_pn_prefix] = ACTIONS(607),
    [sym_comment] = ACTIONS(3),
    [aux_sym_base_declaration_token1] = ACTIONS(607),
    [aux_sym_prefix_declaration_token1] = ACTIONS(607),
    [aux_sym_select_clause_token1] = ACTIONS(607),
    [anon_sym_LPAREN] = ACTIONS(605),
    [aux_sym_construct_query_token1] = ACTIONS(607),
    [aux_sym_describe_query_token1] = ACTIONS(607),
    [aux_sym_ask_query_token1] = ACTIONS(607),
    [aux_sym_having_clause_token1] = ACTIONS(607),
    [aux_sym_order_clause_token1] = ACTIONS(607),
    [aux_sym_order_condition_token1] = ACTIONS(607),
    [aux_sym_order_condition_token2] = ACTIONS(607),
    [aux_sym_limit_clause_token1] = ACTIONS(607),
    [aux_sym_offset_clause_token1] = ACTIONS(607),
    [aux_sym_values_clause_token1] = ACTIONS(607),
    [aux_sym_load_token1] = ACTIONS(607),
    [aux_sym_clear_token1] = ACTIONS(607),
    [aux_sym_drop_token1] = ACTIONS(607),
    [aux_sym_create_token1] = ACTIONS(607),
    [aux_sym_add_token1] = ACTIONS(607),
    [aux_sym_move_token1] = ACTIONS(607),
    [aux_sym_copy_token1] = ACTIONS(607),
    [anon_sym_INSERTDATA] = ACTIONS(605),
    [anon_sym_DELETEDATA] = ACTIONS(605),
    [anon_sym_DELETEWHERE] = ACTIONS(605),
    [aux_sym_modify_token1] = ACTIONS(607),
    [aux_sym_delete_clause_token1] = ACTIONS(607),
    [aux_sym_insert_clause_token1] = ACTIONS(607),
    [sym_var] = ACTIONS(605),
    [anon_sym_LT] = ACTIONS(605),
    [aux_sym_binary_expression_token2] = ACTIONS(607),
    [aux_sym_build_in_function_token1] = ACTIONS(607),
    [aux_sym_build_in_function_token2] = ACTIONS(607),
    [aux_sym_build_in_function_token3] = ACTIONS(607),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(607),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(607),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(607),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(607),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(607),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(607),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(607),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(607),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(607),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(607),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(607),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(607),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(607),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(607),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(607),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(607),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(607),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(607),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(607),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(607),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(607),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(607),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(607),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(607),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(607),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(607),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(607),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(607),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(607),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(607),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(607),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(607),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(607),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(607),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(607),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(607),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(607),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(607),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(607),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(607),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(607),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(607),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(607),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(607),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(607),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(607),
    [aux_sym_regex_expression_token1] = ACTIONS(607),
    [aux_sym_substring_expression_token1] = ACTIONS(607),
    [aux_sym_string_replace_expression_token1] = ACTIONS(607),
    [aux_sym_exists_func_token1] = ACTIONS(607),
    [aux_sym_aggregate_token1] = ACTIONS(607),
    [aux_sym_aggregate_token2] = ACTIONS(607),
    [aux_sym_aggregate_token3] = ACTIONS(607),
    [aux_sym_aggregate_token4] = ACTIONS(607),
    [aux_sym_aggregate_token5] = ACTIONS(607),
    [aux_sym_aggregate_token6] = ACTIONS(607),
    [anon_sym_GROUP_CONCAT] = ACTIONS(607),
    [anon_sym_COLON] = ACTIONS(605),
  },
  [154] = {
    [ts_builtin_sym_end] = ACTIONS(609),
    [sym_pn_prefix] = ACTIONS(611),
    [sym_comment] = ACTIONS(3),
    [aux_sym_base_declaration_token1] = ACTIONS(611),
    [aux_sym_prefix_declaration_token1] = ACTIONS(611),
    [aux_sym_select_clause_token1] = ACTIONS(611),
    [anon_sym_LPAREN] = ACTIONS(609),
    [aux_sym_construct_query_token1] = ACTIONS(611),
    [aux_sym_describe_query_token1] = ACTIONS(611),
    [aux_sym_ask_query_token1] = ACTIONS(611),
    [aux_sym_having_clause_token1] = ACTIONS(611),
    [aux_sym_order_clause_token1] = ACTIONS(611),
    [aux_sym_order_condition_token1] = ACTIONS(611),
    [aux_sym_order_condition_token2] = ACTIONS(611),
    [aux_sym_limit_clause_token1] = ACTIONS(611),
    [aux_sym_offset_clause_token1] = ACTIONS(611),
    [aux_sym_values_clause_token1] = ACTIONS(611),
    [aux_sym_load_token1] = ACTIONS(611),
    [aux_sym_clear_token1] = ACTIONS(611),
    [aux_sym_drop_token1] = ACTIONS(611),
    [aux_sym_create_token1] = ACTIONS(611),
    [aux_sym_add_token1] = ACTIONS(611),
    [aux_sym_move_token1] = ACTIONS(611),
    [aux_sym_copy_token1] = ACTIONS(611),
    [anon_sym_INSERTDATA] = ACTIONS(609),
    [anon_sym_DELETEDATA] = ACTIONS(609),
    [anon_sym_DELETEWHERE] = ACTIONS(609),
    [aux_sym_modify_token1] = ACTIONS(611),
    [aux_sym_delete_clause_token1] = ACTIONS(611),
    [aux_sym_insert_clause_token1] = ACTIONS(611),
    [sym_var] = ACTIONS(609),
    [anon_sym_LT] = ACTIONS(609),
    [aux_sym_binary_expression_token2] = ACTIONS(611),
    [aux_sym_build_in_function_token1] = ACTIONS(611),
    [aux_sym_build_in_function_token2] = ACTIONS(611),
    [aux_sym_build_in_function_token3] = ACTIONS(611),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(611),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(611),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(611),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(611),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(611),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(611),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(611),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(611),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(611),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(611),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(611),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(611),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(611),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(611),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(611),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(611),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(611),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(611),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(611),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(611),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(611),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(611),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(611),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(611),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(611),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(611),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(611),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(611),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(611),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(611),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(611),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(611),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(611),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(611),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(611),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(611),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(611),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(611),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(611),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(611),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(611),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(611),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(611),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(611),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(611),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(611),
    [aux_sym_regex_expression_token1] = ACTIONS(611),
    [aux_sym_substring_expression_token1] = ACTIONS(611),
    [aux_sym_string_replace_expression_token1] = ACTIONS(611),
    [aux_sym_exists_func_token1] = ACTIONS(611),
    [aux_sym_aggregate_token1] = ACTIONS(611),
    [aux_sym_aggregate_token2] = ACTIONS(611),
    [aux_sym_aggregate_token3] = ACTIONS(611),
    [aux_sym_aggregate_token4] = ACTIONS(611),
    [aux_sym_aggregate_token5] = ACTIONS(611),
    [aux_sym_aggregate_token6] = ACTIONS(611),
    [anon_sym_GROUP_CONCAT] = ACTIONS(611),
    [anon_sym_COLON] = ACTIONS(609),
  },
  [155] = {
    [ts_builtin_sym_end] = ACTIONS(613),
    [sym_pn_prefix] = ACTIONS(615),
    [sym_comment] = ACTIONS(3),
    [aux_sym_base_declaration_token1] = ACTIONS(615),
    [aux_sym_prefix_declaration_token1] = ACTIONS(615),
    [aux_sym_select_clause_token1] = ACTIONS(615),
    [anon_sym_LPAREN] = ACTIONS(613),
    [aux_sym_construct_query_token1] = ACTIONS(615),
    [aux_sym_describe_query_token1] = ACTIONS(615),
    [aux_sym_ask_query_token1] = ACTIONS(615),
    [aux_sym_having_clause_token1] = ACTIONS(615),
    [aux_sym_order_clause_token1] = ACTIONS(615),
    [aux_sym_order_condition_token1] = ACTIONS(615),
    [aux_sym_order_condition_token2] = ACTIONS(615),
    [aux_sym_limit_clause_token1] = ACTIONS(615),
    [aux_sym_offset_clause_token1] = ACTIONS(615),
    [aux_sym_values_clause_token1] = ACTIONS(615),
    [aux_sym_load_token1] = ACTIONS(615),
    [aux_sym_clear_token1] = ACTIONS(615),
    [aux_sym_drop_token1] = ACTIONS(615),
    [aux_sym_create_token1] = ACTIONS(615),
    [aux_sym_add_token1] = ACTIONS(615),
    [aux_sym_move_token1] = ACTIONS(615),
    [aux_sym_copy_token1] = ACTIONS(615),
    [anon_sym_INSERTDATA] = ACTIONS(613),
    [anon_sym_DELETEDATA] = ACTIONS(613),
    [anon_sym_DELETEWHERE] = ACTIONS(613),
    [aux_sym_modify_token1] = ACTIONS(615),
    [aux_sym_delete_clause_token1] = ACTIONS(615),
    [aux_sym_insert_clause_token1] = ACTIONS(615),
    [sym_var] = ACTIONS(613),
    [anon_sym_LT] = ACTIONS(613),
    [aux_sym_binary_expression_token2] = ACTIONS(615),
    [aux_sym_build_in_function_token1] = ACTIONS(615),
    [aux_sym_build_in_function_token2] = ACTIONS(615),
    [aux_sym_build_in_function_token3] = ACTIONS(615),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(615),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(615),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(615),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(615),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(615),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(615),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(615),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(615),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(615),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(615),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(615),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(615),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(615),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(615),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(615),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(615),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(615),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(615),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(615),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(615),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(615),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(615),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(615),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(615),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(615),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(615),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(615),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(615),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(615),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(615),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(615),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(615),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(615),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(615),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(615),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(615),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(615),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(615),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(615),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(615),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(615),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(615),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(615),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(615),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(615),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(615),
    [aux_sym_regex_expression_token1] = ACTIONS(615),
    [aux_sym_substring_expression_token1] = ACTIONS(615),
    [aux_sym_string_replace_expression_token1] = ACTIONS(615),
    [aux_sym_exists_func_token1] = ACTIONS(615),
    [aux_sym_aggregate_token1] = ACTIONS(615),
    [aux_sym_aggregate_token2] = ACTIONS(615),
    [aux_sym_aggregate_token3] = ACTIONS(615),
    [aux_sym_aggregate_token4] = ACTIONS(615),
    [aux_sym_aggregate_token5] = ACTIONS(615),
    [aux_sym_aggregate_token6] = ACTIONS(615),
    [anon_sym_GROUP_CONCAT] = ACTIONS(615),
    [anon_sym_COLON] = ACTIONS(613),
  },
  [156] = {
    [sym_having_condition] = STATE(159),
    [sym__constraint] = STATE(215),
    [sym_function_call] = STATE(215),
    [sym_bracketted_expression] = STATE(215),
    [sym__build_in_call] = STATE(215),
    [sym_build_in_function] = STATE(215),
    [sym__nullary_build_in_function] = STATE(200),
    [sym__unary_build_in_function] = STATE(201),
    [sym__binary_build_in_function] = STATE(202),
    [sym__variadic_build_in_function] = STATE(203),
    [sym_regex_expression] = STATE(215),
    [sym_substring_expression] = STATE(215),
    [sym_string_replace_expression] = STATE(215),
    [sym_exists_func] = STATE(215),
    [sym_not_exists_func] = STATE(215),
    [sym_aggregate] = STATE(215),
    [sym__iri] = STATE(882),
    [sym_prefixed_name] = STATE(882),
    [sym_iri_reference] = STATE(882),
    [sym_namespace] = STATE(413),
    [aux_sym_having_clause_repeat1] = STATE(159),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(447),
    [anon_sym_RBRACE] = ACTIONS(367),
    [aux_sym_order_clause_token1] = ACTIONS(369),
    [aux_sym_limit_clause_token1] = ACTIONS(369),
    [aux_sym_offset_clause_token1] = ACTIONS(369),
    [aux_sym_values_clause_token1] = ACTIONS(369),
    [anon_sym_LT] = ACTIONS(57),
    [aux_sym_binary_expression_token2] = ACTIONS(453),
    [aux_sym_build_in_function_token1] = ACTIONS(455),
    [aux_sym_build_in_function_token2] = ACTIONS(457),
    [aux_sym_build_in_function_token3] = ACTIONS(459),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(461),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(461),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(461),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(461),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(463),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(465),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(465),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(465),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(465),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(465),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(465),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(465),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(465),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(465),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(467),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(467),
    [aux_sym_regex_expression_token1] = ACTIONS(469),
    [aux_sym_substring_expression_token1] = ACTIONS(471),
    [aux_sym_string_replace_expression_token1] = ACTIONS(473),
    [aux_sym_exists_func_token1] = ACTIONS(475),
    [aux_sym_aggregate_token1] = ACTIONS(477),
    [aux_sym_aggregate_token2] = ACTIONS(479),
    [aux_sym_aggregate_token3] = ACTIONS(479),
    [aux_sym_aggregate_token4] = ACTIONS(479),
    [aux_sym_aggregate_token5] = ACTIONS(479),
    [aux_sym_aggregate_token6] = ACTIONS(479),
    [anon_sym_GROUP_CONCAT] = ACTIONS(481),
    [anon_sym_COLON] = ACTIONS(89),
  },
  [157] = {
    [sym_group_condition] = STATE(158),
    [sym_function_call] = STATE(212),
    [sym__build_in_call] = STATE(212),
    [sym_build_in_function] = STATE(212),
    [sym__nullary_build_in_function] = STATE(200),
    [sym__unary_build_in_function] = STATE(201),
    [sym__binary_build_in_function] = STATE(202),
    [sym__variadic_build_in_function] = STATE(203),
    [sym_regex_expression] = STATE(212),
    [sym_substring_expression] = STATE(212),
    [sym_string_replace_expression] = STATE(212),
    [sym_exists_func] = STATE(212),
    [sym_not_exists_func] = STATE(212),
    [sym_aggregate] = STATE(212),
    [sym__iri] = STATE(882),
    [sym_prefixed_name] = STATE(882),
    [sym_iri_reference] = STATE(882),
    [sym_namespace] = STATE(413),
    [aux_sym_group_clause_repeat1] = STATE(158),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(617),
    [anon_sym_RBRACE] = ACTIONS(232),
    [aux_sym_having_clause_token1] = ACTIONS(234),
    [aux_sym_order_clause_token1] = ACTIONS(234),
    [aux_sym_limit_clause_token1] = ACTIONS(234),
    [aux_sym_offset_clause_token1] = ACTIONS(234),
    [aux_sym_values_clause_token1] = ACTIONS(234),
    [sym_var] = ACTIONS(619),
    [anon_sym_LT] = ACTIONS(57),
    [aux_sym_binary_expression_token2] = ACTIONS(453),
    [aux_sym_build_in_function_token1] = ACTIONS(455),
    [aux_sym_build_in_function_token2] = ACTIONS(457),
    [aux_sym_build_in_function_token3] = ACTIONS(459),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(461),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(461),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(461),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(461),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(463),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(465),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(465),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(465),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(465),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(465),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(465),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(465),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(465),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(465),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(467),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(467),
    [aux_sym_regex_expression_token1] = ACTIONS(469),
    [aux_sym_substring_expression_token1] = ACTIONS(471),
    [aux_sym_string_replace_expression_token1] = ACTIONS(473),
    [aux_sym_exists_func_token1] = ACTIONS(475),
    [aux_sym_aggregate_token1] = ACTIONS(477),
    [aux_sym_aggregate_token2] = ACTIONS(479),
    [aux_sym_aggregate_token3] = ACTIONS(479),
    [aux_sym_aggregate_token4] = ACTIONS(479),
    [aux_sym_aggregate_token5] = ACTIONS(479),
    [aux_sym_aggregate_token6] = ACTIONS(479),
    [anon_sym_GROUP_CONCAT] = ACTIONS(481),
    [anon_sym_COLON] = ACTIONS(89),
  },
  [158] = {
    [sym_group_condition] = STATE(158),
    [sym_function_call] = STATE(212),
    [sym__build_in_call] = STATE(212),
    [sym_build_in_function] = STATE(212),
    [sym__nullary_build_in_function] = STATE(200),
    [sym__unary_build_in_function] = STATE(201),
    [sym__binary_build_in_function] = STATE(202),
    [sym__variadic_build_in_function] = STATE(203),
    [sym_regex_expression] = STATE(212),
    [sym_substring_expression] = STATE(212),
    [sym_string_replace_expression] = STATE(212),
    [sym_exists_func] = STATE(212),
    [sym_not_exists_func] = STATE(212),
    [sym_aggregate] = STATE(212),
    [sym__iri] = STATE(882),
    [sym_prefixed_name] = STATE(882),
    [sym_iri_reference] = STATE(882),
    [sym_namespace] = STATE(413),
    [aux_sym_group_clause_repeat1] = STATE(158),
    [sym_pn_prefix] = ACTIONS(305),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(621),
    [anon_sym_RBRACE] = ACTIONS(303),
    [aux_sym_having_clause_token1] = ACTIONS(308),
    [aux_sym_order_clause_token1] = ACTIONS(308),
    [aux_sym_limit_clause_token1] = ACTIONS(308),
    [aux_sym_offset_clause_token1] = ACTIONS(308),
    [aux_sym_values_clause_token1] = ACTIONS(308),
    [sym_var] = ACTIONS(624),
    [anon_sym_LT] = ACTIONS(316),
    [aux_sym_binary_expression_token2] = ACTIONS(627),
    [aux_sym_build_in_function_token1] = ACTIONS(630),
    [aux_sym_build_in_function_token2] = ACTIONS(633),
    [aux_sym_build_in_function_token3] = ACTIONS(636),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(639),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(639),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(639),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(639),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(642),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(642),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(642),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(642),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(642),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(642),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(642),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(642),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(642),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(642),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(642),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(642),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(642),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(642),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(642),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(642),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(642),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(642),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(642),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(642),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(642),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(642),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(642),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(642),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(642),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(642),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(642),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(642),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(642),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(642),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(642),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(645),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(645),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(645),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(645),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(645),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(645),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(645),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(645),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(645),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(648),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(648),
    [aux_sym_regex_expression_token1] = ACTIONS(651),
    [aux_sym_substring_expression_token1] = ACTIONS(654),
    [aux_sym_string_replace_expression_token1] = ACTIONS(657),
    [aux_sym_exists_func_token1] = ACTIONS(660),
    [aux_sym_aggregate_token1] = ACTIONS(663),
    [aux_sym_aggregate_token2] = ACTIONS(666),
    [aux_sym_aggregate_token3] = ACTIONS(666),
    [aux_sym_aggregate_token4] = ACTIONS(666),
    [aux_sym_aggregate_token5] = ACTIONS(666),
    [aux_sym_aggregate_token6] = ACTIONS(666),
    [anon_sym_GROUP_CONCAT] = ACTIONS(669),
    [anon_sym_COLON] = ACTIONS(364),
  },
  [159] = {
    [sym_having_condition] = STATE(159),
    [sym__constraint] = STATE(215),
    [sym_function_call] = STATE(215),
    [sym_bracketted_expression] = STATE(215),
    [sym__build_in_call] = STATE(215),
    [sym_build_in_function] = STATE(215),
    [sym__nullary_build_in_function] = STATE(200),
    [sym__unary_build_in_function] = STATE(201),
    [sym__binary_build_in_function] = STATE(202),
    [sym__variadic_build_in_function] = STATE(203),
    [sym_regex_expression] = STATE(215),
    [sym_substring_expression] = STATE(215),
    [sym_string_replace_expression] = STATE(215),
    [sym_exists_func] = STATE(215),
    [sym_not_exists_func] = STATE(215),
    [sym_aggregate] = STATE(215),
    [sym__iri] = STATE(882),
    [sym_prefixed_name] = STATE(882),
    [sym_iri_reference] = STATE(882),
    [sym_namespace] = STATE(413),
    [aux_sym_having_clause_repeat1] = STATE(159),
    [sym_pn_prefix] = ACTIONS(242),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(672),
    [anon_sym_RBRACE] = ACTIONS(240),
    [aux_sym_order_clause_token1] = ACTIONS(245),
    [aux_sym_limit_clause_token1] = ACTIONS(245),
    [aux_sym_offset_clause_token1] = ACTIONS(245),
    [aux_sym_values_clause_token1] = ACTIONS(245),
    [anon_sym_LT] = ACTIONS(250),
    [aux_sym_binary_expression_token2] = ACTIONS(675),
    [aux_sym_build_in_function_token1] = ACTIONS(678),
    [aux_sym_build_in_function_token2] = ACTIONS(681),
    [aux_sym_build_in_function_token3] = ACTIONS(684),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(687),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(687),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(687),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(687),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(690),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(690),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(690),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(690),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(690),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(690),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(690),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(690),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(690),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(690),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(690),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(690),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(690),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(690),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(690),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(690),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(690),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(690),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(690),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(690),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(690),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(690),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(690),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(690),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(690),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(690),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(690),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(690),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(690),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(690),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(690),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(693),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(693),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(693),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(693),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(693),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(693),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(693),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(693),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(693),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(696),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(696),
    [aux_sym_regex_expression_token1] = ACTIONS(699),
    [aux_sym_substring_expression_token1] = ACTIONS(702),
    [aux_sym_string_replace_expression_token1] = ACTIONS(705),
    [aux_sym_exists_func_token1] = ACTIONS(708),
    [aux_sym_aggregate_token1] = ACTIONS(711),
    [aux_sym_aggregate_token2] = ACTIONS(714),
    [aux_sym_aggregate_token3] = ACTIONS(714),
    [aux_sym_aggregate_token4] = ACTIONS(714),
    [aux_sym_aggregate_token5] = ACTIONS(714),
    [aux_sym_aggregate_token6] = ACTIONS(714),
    [anon_sym_GROUP_CONCAT] = ACTIONS(717),
    [anon_sym_COLON] = ACTIONS(298),
  },
  [160] = {
    [ts_builtin_sym_end] = ACTIONS(720),
    [sym_pn_prefix] = ACTIONS(722),
    [sym_comment] = ACTIONS(3),
    [aux_sym_base_declaration_token1] = ACTIONS(722),
    [aux_sym_prefix_declaration_token1] = ACTIONS(722),
    [aux_sym_select_clause_token1] = ACTIONS(722),
    [anon_sym_LPAREN] = ACTIONS(720),
    [aux_sym_construct_query_token1] = ACTIONS(722),
    [aux_sym_describe_query_token1] = ACTIONS(722),
    [aux_sym_ask_query_token1] = ACTIONS(722),
    [aux_sym_having_clause_token1] = ACTIONS(722),
    [aux_sym_order_clause_token1] = ACTIONS(722),
    [aux_sym_limit_clause_token1] = ACTIONS(722),
    [aux_sym_offset_clause_token1] = ACTIONS(722),
    [aux_sym_values_clause_token1] = ACTIONS(722),
    [aux_sym_load_token1] = ACTIONS(722),
    [aux_sym_clear_token1] = ACTIONS(722),
    [aux_sym_drop_token1] = ACTIONS(722),
    [aux_sym_create_token1] = ACTIONS(722),
    [aux_sym_add_token1] = ACTIONS(722),
    [aux_sym_move_token1] = ACTIONS(722),
    [aux_sym_copy_token1] = ACTIONS(722),
    [anon_sym_INSERTDATA] = ACTIONS(720),
    [anon_sym_DELETEDATA] = ACTIONS(720),
    [anon_sym_DELETEWHERE] = ACTIONS(720),
    [aux_sym_modify_token1] = ACTIONS(722),
    [aux_sym_delete_clause_token1] = ACTIONS(722),
    [aux_sym_insert_clause_token1] = ACTIONS(722),
    [sym_var] = ACTIONS(720),
    [anon_sym_LT] = ACTIONS(720),
    [aux_sym_binary_expression_token2] = ACTIONS(722),
    [aux_sym_build_in_function_token1] = ACTIONS(722),
    [aux_sym_build_in_function_token2] = ACTIONS(722),
    [aux_sym_build_in_function_token3] = ACTIONS(722),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(722),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(722),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(722),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(722),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(722),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(722),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(722),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(722),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(722),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(722),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(722),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(722),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(722),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(722),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(722),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(722),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(722),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(722),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(722),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(722),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(722),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(722),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(722),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(722),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(722),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(722),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(722),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(722),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(722),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(722),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(722),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(722),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(722),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(722),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(722),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(722),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(722),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(722),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(722),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(722),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(722),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(722),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(722),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(722),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(722),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(722),
    [aux_sym_regex_expression_token1] = ACTIONS(722),
    [aux_sym_substring_expression_token1] = ACTIONS(722),
    [aux_sym_string_replace_expression_token1] = ACTIONS(722),
    [aux_sym_exists_func_token1] = ACTIONS(722),
    [aux_sym_aggregate_token1] = ACTIONS(722),
    [aux_sym_aggregate_token2] = ACTIONS(722),
    [aux_sym_aggregate_token3] = ACTIONS(722),
    [aux_sym_aggregate_token4] = ACTIONS(722),
    [aux_sym_aggregate_token5] = ACTIONS(722),
    [aux_sym_aggregate_token6] = ACTIONS(722),
    [anon_sym_GROUP_CONCAT] = ACTIONS(722),
    [anon_sym_COLON] = ACTIONS(720),
  },
  [161] = {
    [ts_builtin_sym_end] = ACTIONS(724),
    [sym_pn_prefix] = ACTIONS(726),
    [sym_comment] = ACTIONS(3),
    [aux_sym_base_declaration_token1] = ACTIONS(726),
    [aux_sym_prefix_declaration_token1] = ACTIONS(726),
    [aux_sym_select_clause_token1] = ACTIONS(726),
    [anon_sym_LPAREN] = ACTIONS(724),
    [aux_sym_construct_query_token1] = ACTIONS(726),
    [aux_sym_describe_query_token1] = ACTIONS(726),
    [aux_sym_ask_query_token1] = ACTIONS(726),
    [aux_sym_having_clause_token1] = ACTIONS(726),
    [aux_sym_order_clause_token1] = ACTIONS(726),
    [aux_sym_limit_clause_token1] = ACTIONS(726),
    [aux_sym_offset_clause_token1] = ACTIONS(726),
    [aux_sym_values_clause_token1] = ACTIONS(726),
    [aux_sym_load_token1] = ACTIONS(726),
    [aux_sym_clear_token1] = ACTIONS(726),
    [aux_sym_drop_token1] = ACTIONS(726),
    [aux_sym_create_token1] = ACTIONS(726),
    [aux_sym_add_token1] = ACTIONS(726),
    [aux_sym_move_token1] = ACTIONS(726),
    [aux_sym_copy_token1] = ACTIONS(726),
    [anon_sym_INSERTDATA] = ACTIONS(724),
    [anon_sym_DELETEDATA] = ACTIONS(724),
    [anon_sym_DELETEWHERE] = ACTIONS(724),
    [aux_sym_modify_token1] = ACTIONS(726),
    [aux_sym_delete_clause_token1] = ACTIONS(726),
    [aux_sym_insert_clause_token1] = ACTIONS(726),
    [sym_var] = ACTIONS(724),
    [anon_sym_LT] = ACTIONS(724),
    [aux_sym_binary_expression_token2] = ACTIONS(726),
    [aux_sym_build_in_function_token1] = ACTIONS(726),
    [aux_sym_build_in_function_token2] = ACTIONS(726),
    [aux_sym_build_in_function_token3] = ACTIONS(726),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(726),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(726),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(726),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(726),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(726),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(726),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(726),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(726),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(726),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(726),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(726),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(726),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(726),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(726),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(726),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(726),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(726),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(726),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(726),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(726),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(726),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(726),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(726),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(726),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(726),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(726),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(726),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(726),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(726),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(726),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(726),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(726),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(726),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(726),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(726),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(726),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(726),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(726),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(726),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(726),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(726),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(726),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(726),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(726),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(726),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(726),
    [aux_sym_regex_expression_token1] = ACTIONS(726),
    [aux_sym_substring_expression_token1] = ACTIONS(726),
    [aux_sym_string_replace_expression_token1] = ACTIONS(726),
    [aux_sym_exists_func_token1] = ACTIONS(726),
    [aux_sym_aggregate_token1] = ACTIONS(726),
    [aux_sym_aggregate_token2] = ACTIONS(726),
    [aux_sym_aggregate_token3] = ACTIONS(726),
    [aux_sym_aggregate_token4] = ACTIONS(726),
    [aux_sym_aggregate_token5] = ACTIONS(726),
    [aux_sym_aggregate_token6] = ACTIONS(726),
    [anon_sym_GROUP_CONCAT] = ACTIONS(726),
    [anon_sym_COLON] = ACTIONS(724),
  },
  [162] = {
    [ts_builtin_sym_end] = ACTIONS(728),
    [sym_pn_prefix] = ACTIONS(730),
    [sym_comment] = ACTIONS(3),
    [aux_sym_base_declaration_token1] = ACTIONS(730),
    [aux_sym_prefix_declaration_token1] = ACTIONS(730),
    [aux_sym_select_clause_token1] = ACTIONS(730),
    [anon_sym_LPAREN] = ACTIONS(728),
    [aux_sym_construct_query_token1] = ACTIONS(730),
    [aux_sym_describe_query_token1] = ACTIONS(730),
    [aux_sym_ask_query_token1] = ACTIONS(730),
    [aux_sym_having_clause_token1] = ACTIONS(730),
    [aux_sym_order_clause_token1] = ACTIONS(730),
    [aux_sym_limit_clause_token1] = ACTIONS(730),
    [aux_sym_offset_clause_token1] = ACTIONS(730),
    [aux_sym_values_clause_token1] = ACTIONS(730),
    [aux_sym_load_token1] = ACTIONS(730),
    [aux_sym_clear_token1] = ACTIONS(730),
    [aux_sym_drop_token1] = ACTIONS(730),
    [aux_sym_create_token1] = ACTIONS(730),
    [aux_sym_add_token1] = ACTIONS(730),
    [aux_sym_move_token1] = ACTIONS(730),
    [aux_sym_copy_token1] = ACTIONS(730),
    [anon_sym_INSERTDATA] = ACTIONS(728),
    [anon_sym_DELETEDATA] = ACTIONS(728),
    [anon_sym_DELETEWHERE] = ACTIONS(728),
    [aux_sym_modify_token1] = ACTIONS(730),
    [aux_sym_delete_clause_token1] = ACTIONS(730),
    [aux_sym_insert_clause_token1] = ACTIONS(730),
    [sym_var] = ACTIONS(728),
    [anon_sym_LT] = ACTIONS(728),
    [aux_sym_binary_expression_token2] = ACTIONS(730),
    [aux_sym_build_in_function_token1] = ACTIONS(730),
    [aux_sym_build_in_function_token2] = ACTIONS(730),
    [aux_sym_build_in_function_token3] = ACTIONS(730),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(730),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(730),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(730),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(730),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(730),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(730),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(730),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(730),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(730),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(730),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(730),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(730),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(730),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(730),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(730),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(730),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(730),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(730),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(730),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(730),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(730),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(730),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(730),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(730),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(730),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(730),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(730),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(730),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(730),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(730),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(730),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(730),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(730),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(730),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(730),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(730),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(730),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(730),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(730),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(730),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(730),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(730),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(730),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(730),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(730),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(730),
    [aux_sym_regex_expression_token1] = ACTIONS(730),
    [aux_sym_substring_expression_token1] = ACTIONS(730),
    [aux_sym_string_replace_expression_token1] = ACTIONS(730),
    [aux_sym_exists_func_token1] = ACTIONS(730),
    [aux_sym_aggregate_token1] = ACTIONS(730),
    [aux_sym_aggregate_token2] = ACTIONS(730),
    [aux_sym_aggregate_token3] = ACTIONS(730),
    [aux_sym_aggregate_token4] = ACTIONS(730),
    [aux_sym_aggregate_token5] = ACTIONS(730),
    [aux_sym_aggregate_token6] = ACTIONS(730),
    [anon_sym_GROUP_CONCAT] = ACTIONS(730),
    [anon_sym_COLON] = ACTIONS(728),
  },
  [163] = {
    [ts_builtin_sym_end] = ACTIONS(732),
    [sym_pn_prefix] = ACTIONS(734),
    [sym_comment] = ACTIONS(3),
    [aux_sym_base_declaration_token1] = ACTIONS(734),
    [aux_sym_prefix_declaration_token1] = ACTIONS(734),
    [aux_sym_select_clause_token1] = ACTIONS(734),
    [anon_sym_LPAREN] = ACTIONS(732),
    [aux_sym_construct_query_token1] = ACTIONS(734),
    [aux_sym_describe_query_token1] = ACTIONS(734),
    [aux_sym_ask_query_token1] = ACTIONS(734),
    [aux_sym_order_condition_token1] = ACTIONS(734),
    [aux_sym_order_condition_token2] = ACTIONS(734),
    [aux_sym_limit_clause_token1] = ACTIONS(734),
    [aux_sym_offset_clause_token1] = ACTIONS(734),
    [aux_sym_values_clause_token1] = ACTIONS(734),
    [aux_sym_load_token1] = ACTIONS(734),
    [aux_sym_clear_token1] = ACTIONS(734),
    [aux_sym_drop_token1] = ACTIONS(734),
    [aux_sym_create_token1] = ACTIONS(734),
    [aux_sym_add_token1] = ACTIONS(734),
    [aux_sym_move_token1] = ACTIONS(734),
    [aux_sym_copy_token1] = ACTIONS(734),
    [anon_sym_INSERTDATA] = ACTIONS(732),
    [anon_sym_DELETEDATA] = ACTIONS(732),
    [anon_sym_DELETEWHERE] = ACTIONS(732),
    [aux_sym_modify_token1] = ACTIONS(734),
    [aux_sym_delete_clause_token1] = ACTIONS(734),
    [aux_sym_insert_clause_token1] = ACTIONS(734),
    [sym_var] = ACTIONS(732),
    [anon_sym_LT] = ACTIONS(732),
    [aux_sym_binary_expression_token2] = ACTIONS(734),
    [aux_sym_build_in_function_token1] = ACTIONS(734),
    [aux_sym_build_in_function_token2] = ACTIONS(734),
    [aux_sym_build_in_function_token3] = ACTIONS(734),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(734),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(734),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(734),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(734),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(734),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(734),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(734),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(734),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(734),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(734),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(734),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(734),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(734),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(734),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(734),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(734),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(734),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(734),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(734),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(734),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(734),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(734),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(734),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(734),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(734),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(734),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(734),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(734),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(734),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(734),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(734),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(734),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(734),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(734),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(734),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(734),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(734),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(734),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(734),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(734),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(734),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(734),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(734),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(734),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(734),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(734),
    [aux_sym_regex_expression_token1] = ACTIONS(734),
    [aux_sym_substring_expression_token1] = ACTIONS(734),
    [aux_sym_string_replace_expression_token1] = ACTIONS(734),
    [aux_sym_exists_func_token1] = ACTIONS(734),
    [aux_sym_aggregate_token1] = ACTIONS(734),
    [aux_sym_aggregate_token2] = ACTIONS(734),
    [aux_sym_aggregate_token3] = ACTIONS(734),
    [aux_sym_aggregate_token4] = ACTIONS(734),
    [aux_sym_aggregate_token5] = ACTIONS(734),
    [aux_sym_aggregate_token6] = ACTIONS(734),
    [anon_sym_GROUP_CONCAT] = ACTIONS(734),
    [anon_sym_COLON] = ACTIONS(732),
  },
  [164] = {
    [ts_builtin_sym_end] = ACTIONS(736),
    [sym_pn_prefix] = ACTIONS(738),
    [sym_comment] = ACTIONS(3),
    [aux_sym_base_declaration_token1] = ACTIONS(738),
    [aux_sym_prefix_declaration_token1] = ACTIONS(738),
    [aux_sym_select_clause_token1] = ACTIONS(738),
    [anon_sym_LPAREN] = ACTIONS(736),
    [aux_sym_construct_query_token1] = ACTIONS(738),
    [aux_sym_describe_query_token1] = ACTIONS(738),
    [aux_sym_ask_query_token1] = ACTIONS(738),
    [aux_sym_order_condition_token1] = ACTIONS(738),
    [aux_sym_order_condition_token2] = ACTIONS(738),
    [aux_sym_limit_clause_token1] = ACTIONS(738),
    [aux_sym_offset_clause_token1] = ACTIONS(738),
    [aux_sym_values_clause_token1] = ACTIONS(738),
    [aux_sym_load_token1] = ACTIONS(738),
    [aux_sym_clear_token1] = ACTIONS(738),
    [aux_sym_drop_token1] = ACTIONS(738),
    [aux_sym_create_token1] = ACTIONS(738),
    [aux_sym_add_token1] = ACTIONS(738),
    [aux_sym_move_token1] = ACTIONS(738),
    [aux_sym_copy_token1] = ACTIONS(738),
    [anon_sym_INSERTDATA] = ACTIONS(736),
    [anon_sym_DELETEDATA] = ACTIONS(736),
    [anon_sym_DELETEWHERE] = ACTIONS(736),
    [aux_sym_modify_token1] = ACTIONS(738),
    [aux_sym_delete_clause_token1] = ACTIONS(738),
    [aux_sym_insert_clause_token1] = ACTIONS(738),
    [sym_var] = ACTIONS(736),
    [anon_sym_LT] = ACTIONS(736),
    [aux_sym_binary_expression_token2] = ACTIONS(738),
    [aux_sym_build_in_function_token1] = ACTIONS(738),
    [aux_sym_build_in_function_token2] = ACTIONS(738),
    [aux_sym_build_in_function_token3] = ACTIONS(738),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(738),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(738),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(738),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(738),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(738),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(738),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(738),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(738),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(738),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(738),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(738),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(738),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(738),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(738),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(738),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(738),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(738),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(738),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(738),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(738),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(738),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(738),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(738),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(738),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(738),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(738),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(738),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(738),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(738),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(738),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(738),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(738),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(738),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(738),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(738),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(738),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(738),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(738),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(738),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(738),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(738),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(738),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(738),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(738),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(738),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(738),
    [aux_sym_regex_expression_token1] = ACTIONS(738),
    [aux_sym_substring_expression_token1] = ACTIONS(738),
    [aux_sym_string_replace_expression_token1] = ACTIONS(738),
    [aux_sym_exists_func_token1] = ACTIONS(738),
    [aux_sym_aggregate_token1] = ACTIONS(738),
    [aux_sym_aggregate_token2] = ACTIONS(738),
    [aux_sym_aggregate_token3] = ACTIONS(738),
    [aux_sym_aggregate_token4] = ACTIONS(738),
    [aux_sym_aggregate_token5] = ACTIONS(738),
    [aux_sym_aggregate_token6] = ACTIONS(738),
    [anon_sym_GROUP_CONCAT] = ACTIONS(738),
    [anon_sym_COLON] = ACTIONS(736),
  },
  [165] = {
    [ts_builtin_sym_end] = ACTIONS(740),
    [sym_pn_prefix] = ACTIONS(742),
    [sym_comment] = ACTIONS(3),
    [aux_sym_base_declaration_token1] = ACTIONS(742),
    [aux_sym_prefix_declaration_token1] = ACTIONS(742),
    [aux_sym_select_clause_token1] = ACTIONS(742),
    [anon_sym_LPAREN] = ACTIONS(740),
    [aux_sym_construct_query_token1] = ACTIONS(742),
    [aux_sym_describe_query_token1] = ACTIONS(742),
    [aux_sym_ask_query_token1] = ACTIONS(742),
    [aux_sym_having_clause_token1] = ACTIONS(742),
    [aux_sym_order_clause_token1] = ACTIONS(742),
    [aux_sym_limit_clause_token1] = ACTIONS(742),
    [aux_sym_offset_clause_token1] = ACTIONS(742),
    [aux_sym_values_clause_token1] = ACTIONS(742),
    [aux_sym_load_token1] = ACTIONS(742),
    [aux_sym_clear_token1] = ACTIONS(742),
    [aux_sym_drop_token1] = ACTIONS(742),
    [aux_sym_create_token1] = ACTIONS(742),
    [aux_sym_add_token1] = ACTIONS(742),
    [aux_sym_move_token1] = ACTIONS(742),
    [aux_sym_copy_token1] = ACTIONS(742),
    [anon_sym_INSERTDATA] = ACTIONS(740),
    [anon_sym_DELETEDATA] = ACTIONS(740),
    [anon_sym_DELETEWHERE] = ACTIONS(740),
    [aux_sym_modify_token1] = ACTIONS(742),
    [aux_sym_delete_clause_token1] = ACTIONS(742),
    [aux_sym_insert_clause_token1] = ACTIONS(742),
    [sym_var] = ACTIONS(740),
    [anon_sym_LT] = ACTIONS(740),
    [aux_sym_binary_expression_token2] = ACTIONS(742),
    [aux_sym_build_in_function_token1] = ACTIONS(742),
    [aux_sym_build_in_function_token2] = ACTIONS(742),
    [aux_sym_build_in_function_token3] = ACTIONS(742),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(742),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(742),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(742),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(742),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(742),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(742),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(742),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(742),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(742),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(742),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(742),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(742),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(742),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(742),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(742),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(742),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(742),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(742),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(742),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(742),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(742),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(742),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(742),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(742),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(742),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(742),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(742),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(742),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(742),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(742),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(742),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(742),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(742),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(742),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(742),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(742),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(742),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(742),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(742),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(742),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(742),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(742),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(742),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(742),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(742),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(742),
    [aux_sym_regex_expression_token1] = ACTIONS(742),
    [aux_sym_substring_expression_token1] = ACTIONS(742),
    [aux_sym_string_replace_expression_token1] = ACTIONS(742),
    [aux_sym_exists_func_token1] = ACTIONS(742),
    [aux_sym_aggregate_token1] = ACTIONS(742),
    [aux_sym_aggregate_token2] = ACTIONS(742),
    [aux_sym_aggregate_token3] = ACTIONS(742),
    [aux_sym_aggregate_token4] = ACTIONS(742),
    [aux_sym_aggregate_token5] = ACTIONS(742),
    [aux_sym_aggregate_token6] = ACTIONS(742),
    [anon_sym_GROUP_CONCAT] = ACTIONS(742),
    [anon_sym_COLON] = ACTIONS(740),
  },
  [166] = {
    [ts_builtin_sym_end] = ACTIONS(744),
    [sym_pn_prefix] = ACTIONS(746),
    [sym_comment] = ACTIONS(3),
    [aux_sym_base_declaration_token1] = ACTIONS(746),
    [aux_sym_prefix_declaration_token1] = ACTIONS(746),
    [aux_sym_select_clause_token1] = ACTIONS(746),
    [anon_sym_LPAREN] = ACTIONS(744),
    [aux_sym_construct_query_token1] = ACTIONS(746),
    [aux_sym_describe_query_token1] = ACTIONS(746),
    [aux_sym_ask_query_token1] = ACTIONS(746),
    [aux_sym_order_clause_token1] = ACTIONS(746),
    [aux_sym_limit_clause_token1] = ACTIONS(746),
    [aux_sym_offset_clause_token1] = ACTIONS(746),
    [aux_sym_values_clause_token1] = ACTIONS(746),
    [aux_sym_load_token1] = ACTIONS(746),
    [aux_sym_clear_token1] = ACTIONS(746),
    [aux_sym_drop_token1] = ACTIONS(746),
    [aux_sym_create_token1] = ACTIONS(746),
    [aux_sym_add_token1] = ACTIONS(746),
    [aux_sym_move_token1] = ACTIONS(746),
    [aux_sym_copy_token1] = ACTIONS(746),
    [anon_sym_INSERTDATA] = ACTIONS(744),
    [anon_sym_DELETEDATA] = ACTIONS(744),
    [anon_sym_DELETEWHERE] = ACTIONS(744),
    [aux_sym_modify_token1] = ACTIONS(746),
    [aux_sym_delete_clause_token1] = ACTIONS(746),
    [aux_sym_insert_clause_token1] = ACTIONS(746),
    [anon_sym_LT] = ACTIONS(744),
    [aux_sym_binary_expression_token2] = ACTIONS(746),
    [aux_sym_build_in_function_token1] = ACTIONS(746),
    [aux_sym_build_in_function_token2] = ACTIONS(746),
    [aux_sym_build_in_function_token3] = ACTIONS(746),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(746),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(746),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(746),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(746),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(746),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(746),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(746),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(746),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(746),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(746),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(746),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(746),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(746),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(746),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(746),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(746),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(746),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(746),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(746),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(746),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(746),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(746),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(746),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(746),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(746),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(746),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(746),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(746),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(746),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(746),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(746),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(746),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(746),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(746),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(746),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(746),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(746),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(746),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(746),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(746),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(746),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(746),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(746),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(746),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(746),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(746),
    [aux_sym_regex_expression_token1] = ACTIONS(746),
    [aux_sym_substring_expression_token1] = ACTIONS(746),
    [aux_sym_string_replace_expression_token1] = ACTIONS(746),
    [aux_sym_exists_func_token1] = ACTIONS(746),
    [aux_sym_aggregate_token1] = ACTIONS(746),
    [aux_sym_aggregate_token2] = ACTIONS(746),
    [aux_sym_aggregate_token3] = ACTIONS(746),
    [aux_sym_aggregate_token4] = ACTIONS(746),
    [aux_sym_aggregate_token5] = ACTIONS(746),
    [aux_sym_aggregate_token6] = ACTIONS(746),
    [anon_sym_GROUP_CONCAT] = ACTIONS(746),
    [anon_sym_COLON] = ACTIONS(744),
  },
  [167] = {
    [sym_order_condition] = STATE(133),
    [sym__constraint] = STATE(211),
    [sym_function_call] = STATE(211),
    [sym_bracketted_expression] = STATE(211),
    [sym__build_in_call] = STATE(211),
    [sym_build_in_function] = STATE(211),
    [sym__nullary_build_in_function] = STATE(200),
    [sym__unary_build_in_function] = STATE(201),
    [sym__binary_build_in_function] = STATE(202),
    [sym__variadic_build_in_function] = STATE(203),
    [sym_regex_expression] = STATE(211),
    [sym_substring_expression] = STATE(211),
    [sym_string_replace_expression] = STATE(211),
    [sym_exists_func] = STATE(211),
    [sym_not_exists_func] = STATE(211),
    [sym_aggregate] = STATE(211),
    [sym__iri] = STATE(882),
    [sym_prefixed_name] = STATE(882),
    [sym_iri_reference] = STATE(882),
    [sym_namespace] = STATE(413),
    [aux_sym_order_clause_repeat1] = STATE(133),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(447),
    [aux_sym_order_condition_token1] = ACTIONS(449),
    [aux_sym_order_condition_token2] = ACTIONS(449),
    [sym_var] = ACTIONS(451),
    [anon_sym_LT] = ACTIONS(57),
    [aux_sym_binary_expression_token2] = ACTIONS(453),
    [aux_sym_build_in_function_token1] = ACTIONS(455),
    [aux_sym_build_in_function_token2] = ACTIONS(457),
    [aux_sym_build_in_function_token3] = ACTIONS(459),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(461),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(461),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(461),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(461),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(463),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(465),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(465),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(465),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(465),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(465),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(465),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(465),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(465),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(465),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(467),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(467),
    [aux_sym_regex_expression_token1] = ACTIONS(469),
    [aux_sym_substring_expression_token1] = ACTIONS(471),
    [aux_sym_string_replace_expression_token1] = ACTIONS(473),
    [aux_sym_exists_func_token1] = ACTIONS(475),
    [aux_sym_aggregate_token1] = ACTIONS(477),
    [aux_sym_aggregate_token2] = ACTIONS(479),
    [aux_sym_aggregate_token3] = ACTIONS(479),
    [aux_sym_aggregate_token4] = ACTIONS(479),
    [aux_sym_aggregate_token5] = ACTIONS(479),
    [aux_sym_aggregate_token6] = ACTIONS(479),
    [anon_sym_GROUP_CONCAT] = ACTIONS(481),
    [anon_sym_COLON] = ACTIONS(89),
  },
  [168] = {
    [sym_order_condition] = STATE(2),
    [sym__constraint] = STATE(163),
    [sym_function_call] = STATE(163),
    [sym_bracketted_expression] = STATE(163),
    [sym__build_in_call] = STATE(163),
    [sym_build_in_function] = STATE(163),
    [sym__nullary_build_in_function] = STATE(136),
    [sym__unary_build_in_function] = STATE(120),
    [sym__binary_build_in_function] = STATE(121),
    [sym__variadic_build_in_function] = STATE(122),
    [sym_regex_expression] = STATE(163),
    [sym_substring_expression] = STATE(163),
    [sym_string_replace_expression] = STATE(163),
    [sym_exists_func] = STATE(163),
    [sym_not_exists_func] = STATE(163),
    [sym_aggregate] = STATE(163),
    [sym__iri] = STATE(913),
    [sym_prefixed_name] = STATE(913),
    [sym_iri_reference] = STATE(913),
    [sym_namespace] = STATE(413),
    [aux_sym_order_clause_repeat1] = STATE(2),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(51),
    [aux_sym_order_condition_token1] = ACTIONS(53),
    [aux_sym_order_condition_token2] = ACTIONS(53),
    [sym_var] = ACTIONS(55),
    [anon_sym_LT] = ACTIONS(57),
    [aux_sym_binary_expression_token2] = ACTIONS(59),
    [aux_sym_build_in_function_token1] = ACTIONS(61),
    [aux_sym_build_in_function_token2] = ACTIONS(63),
    [aux_sym_build_in_function_token3] = ACTIONS(65),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(67),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(67),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(67),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(67),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(69),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(71),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(71),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(71),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(71),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(71),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(71),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(71),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(71),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(71),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(73),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(73),
    [aux_sym_regex_expression_token1] = ACTIONS(75),
    [aux_sym_substring_expression_token1] = ACTIONS(77),
    [aux_sym_string_replace_expression_token1] = ACTIONS(79),
    [aux_sym_exists_func_token1] = ACTIONS(81),
    [aux_sym_aggregate_token1] = ACTIONS(83),
    [aux_sym_aggregate_token2] = ACTIONS(85),
    [aux_sym_aggregate_token3] = ACTIONS(85),
    [aux_sym_aggregate_token4] = ACTIONS(85),
    [aux_sym_aggregate_token5] = ACTIONS(85),
    [aux_sym_aggregate_token6] = ACTIONS(85),
    [anon_sym_GROUP_CONCAT] = ACTIONS(87),
    [anon_sym_COLON] = ACTIONS(89),
  },
  [169] = {
    [sym_having_condition] = STATE(15),
    [sym__constraint] = STATE(166),
    [sym_function_call] = STATE(166),
    [sym_bracketted_expression] = STATE(166),
    [sym__build_in_call] = STATE(166),
    [sym_build_in_function] = STATE(166),
    [sym__nullary_build_in_function] = STATE(136),
    [sym__unary_build_in_function] = STATE(120),
    [sym__binary_build_in_function] = STATE(121),
    [sym__variadic_build_in_function] = STATE(122),
    [sym_regex_expression] = STATE(166),
    [sym_substring_expression] = STATE(166),
    [sym_string_replace_expression] = STATE(166),
    [sym_exists_func] = STATE(166),
    [sym_not_exists_func] = STATE(166),
    [sym_aggregate] = STATE(166),
    [sym__iri] = STATE(913),
    [sym_prefixed_name] = STATE(913),
    [sym_iri_reference] = STATE(913),
    [sym_namespace] = STATE(413),
    [aux_sym_having_clause_repeat1] = STATE(15),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(51),
    [anon_sym_LT] = ACTIONS(57),
    [aux_sym_binary_expression_token2] = ACTIONS(59),
    [aux_sym_build_in_function_token1] = ACTIONS(61),
    [aux_sym_build_in_function_token2] = ACTIONS(63),
    [aux_sym_build_in_function_token3] = ACTIONS(65),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(67),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(67),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(67),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(67),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(69),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(71),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(71),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(71),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(71),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(71),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(71),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(71),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(71),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(71),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(73),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(73),
    [aux_sym_regex_expression_token1] = ACTIONS(75),
    [aux_sym_substring_expression_token1] = ACTIONS(77),
    [aux_sym_string_replace_expression_token1] = ACTIONS(79),
    [aux_sym_exists_func_token1] = ACTIONS(81),
    [aux_sym_aggregate_token1] = ACTIONS(83),
    [aux_sym_aggregate_token2] = ACTIONS(85),
    [aux_sym_aggregate_token3] = ACTIONS(85),
    [aux_sym_aggregate_token4] = ACTIONS(85),
    [aux_sym_aggregate_token5] = ACTIONS(85),
    [aux_sym_aggregate_token6] = ACTIONS(85),
    [anon_sym_GROUP_CONCAT] = ACTIONS(87),
    [anon_sym_COLON] = ACTIONS(89),
  },
  [170] = {
    [sym_having_condition] = STATE(156),
    [sym__constraint] = STATE(215),
    [sym_function_call] = STATE(215),
    [sym_bracketted_expression] = STATE(215),
    [sym__build_in_call] = STATE(215),
    [sym_build_in_function] = STATE(215),
    [sym__nullary_build_in_function] = STATE(200),
    [sym__unary_build_in_function] = STATE(201),
    [sym__binary_build_in_function] = STATE(202),
    [sym__variadic_build_in_function] = STATE(203),
    [sym_regex_expression] = STATE(215),
    [sym_substring_expression] = STATE(215),
    [sym_string_replace_expression] = STATE(215),
    [sym_exists_func] = STATE(215),
    [sym_not_exists_func] = STATE(215),
    [sym_aggregate] = STATE(215),
    [sym__iri] = STATE(882),
    [sym_prefixed_name] = STATE(882),
    [sym_iri_reference] = STATE(882),
    [sym_namespace] = STATE(413),
    [aux_sym_having_clause_repeat1] = STATE(156),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(447),
    [anon_sym_LT] = ACTIONS(57),
    [aux_sym_binary_expression_token2] = ACTIONS(453),
    [aux_sym_build_in_function_token1] = ACTIONS(455),
    [aux_sym_build_in_function_token2] = ACTIONS(457),
    [aux_sym_build_in_function_token3] = ACTIONS(459),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(461),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(461),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(461),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(461),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(463),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(465),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(465),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(465),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(465),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(465),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(465),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(465),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(465),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(465),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(467),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(467),
    [aux_sym_regex_expression_token1] = ACTIONS(469),
    [aux_sym_substring_expression_token1] = ACTIONS(471),
    [aux_sym_string_replace_expression_token1] = ACTIONS(473),
    [aux_sym_exists_func_token1] = ACTIONS(475),
    [aux_sym_aggregate_token1] = ACTIONS(477),
    [aux_sym_aggregate_token2] = ACTIONS(479),
    [aux_sym_aggregate_token3] = ACTIONS(479),
    [aux_sym_aggregate_token4] = ACTIONS(479),
    [aux_sym_aggregate_token5] = ACTIONS(479),
    [aux_sym_aggregate_token6] = ACTIONS(479),
    [anon_sym_GROUP_CONCAT] = ACTIONS(481),
    [anon_sym_COLON] = ACTIONS(89),
  },
  [171] = {
    [sym_group_condition] = STATE(157),
    [sym_function_call] = STATE(212),
    [sym__build_in_call] = STATE(212),
    [sym_build_in_function] = STATE(212),
    [sym__nullary_build_in_function] = STATE(200),
    [sym__unary_build_in_function] = STATE(201),
    [sym__binary_build_in_function] = STATE(202),
    [sym__variadic_build_in_function] = STATE(203),
    [sym_regex_expression] = STATE(212),
    [sym_substring_expression] = STATE(212),
    [sym_string_replace_expression] = STATE(212),
    [sym_exists_func] = STATE(212),
    [sym_not_exists_func] = STATE(212),
    [sym_aggregate] = STATE(212),
    [sym__iri] = STATE(882),
    [sym_prefixed_name] = STATE(882),
    [sym_iri_reference] = STATE(882),
    [sym_namespace] = STATE(413),
    [aux_sym_group_clause_repeat1] = STATE(157),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(617),
    [sym_var] = ACTIONS(619),
    [anon_sym_LT] = ACTIONS(57),
    [aux_sym_binary_expression_token2] = ACTIONS(453),
    [aux_sym_build_in_function_token1] = ACTIONS(455),
    [aux_sym_build_in_function_token2] = ACTIONS(457),
    [aux_sym_build_in_function_token3] = ACTIONS(459),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(461),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(461),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(461),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(461),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(463),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(463),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(465),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(465),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(465),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(465),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(465),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(465),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(465),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(465),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(465),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(467),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(467),
    [aux_sym_regex_expression_token1] = ACTIONS(469),
    [aux_sym_substring_expression_token1] = ACTIONS(471),
    [aux_sym_string_replace_expression_token1] = ACTIONS(473),
    [aux_sym_exists_func_token1] = ACTIONS(475),
    [aux_sym_aggregate_token1] = ACTIONS(477),
    [aux_sym_aggregate_token2] = ACTIONS(479),
    [aux_sym_aggregate_token3] = ACTIONS(479),
    [aux_sym_aggregate_token4] = ACTIONS(479),
    [aux_sym_aggregate_token5] = ACTIONS(479),
    [aux_sym_aggregate_token6] = ACTIONS(479),
    [anon_sym_GROUP_CONCAT] = ACTIONS(481),
    [anon_sym_COLON] = ACTIONS(89),
  },
  [172] = {
    [sym_group_condition] = STATE(11),
    [sym_function_call] = STATE(162),
    [sym__build_in_call] = STATE(162),
    [sym_build_in_function] = STATE(162),
    [sym__nullary_build_in_function] = STATE(136),
    [sym__unary_build_in_function] = STATE(120),
    [sym__binary_build_in_function] = STATE(121),
    [sym__variadic_build_in_function] = STATE(122),
    [sym_regex_expression] = STATE(162),
    [sym_substring_expression] = STATE(162),
    [sym_string_replace_expression] = STATE(162),
    [sym_exists_func] = STATE(162),
    [sym_not_exists_func] = STATE(162),
    [sym_aggregate] = STATE(162),
    [sym__iri] = STATE(913),
    [sym_prefixed_name] = STATE(913),
    [sym_iri_reference] = STATE(913),
    [sym_namespace] = STATE(413),
    [aux_sym_group_clause_repeat1] = STATE(11),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(236),
    [sym_var] = ACTIONS(238),
    [anon_sym_LT] = ACTIONS(57),
    [aux_sym_binary_expression_token2] = ACTIONS(59),
    [aux_sym_build_in_function_token1] = ACTIONS(61),
    [aux_sym_build_in_function_token2] = ACTIONS(63),
    [aux_sym_build_in_function_token3] = ACTIONS(65),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(67),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(67),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(67),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(67),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(69),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(69),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(71),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(71),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(71),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(71),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(71),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(71),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(71),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(71),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(71),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(73),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(73),
    [aux_sym_regex_expression_token1] = ACTIONS(75),
    [aux_sym_substring_expression_token1] = ACTIONS(77),
    [aux_sym_string_replace_expression_token1] = ACTIONS(79),
    [aux_sym_exists_func_token1] = ACTIONS(81),
    [aux_sym_aggregate_token1] = ACTIONS(83),
    [aux_sym_aggregate_token2] = ACTIONS(85),
    [aux_sym_aggregate_token3] = ACTIONS(85),
    [aux_sym_aggregate_token4] = ACTIONS(85),
    [aux_sym_aggregate_token5] = ACTIONS(85),
    [aux_sym_aggregate_token6] = ACTIONS(85),
    [anon_sym_GROUP_CONCAT] = ACTIONS(87),
    [anon_sym_COLON] = ACTIONS(89),
  },
  [173] = {
    [sym__constraint] = STATE(332),
    [sym_function_call] = STATE(332),
    [sym_bracketted_expression] = STATE(332),
    [sym__build_in_call] = STATE(332),
    [sym_build_in_function] = STATE(332),
    [sym__nullary_build_in_function] = STATE(333),
    [sym__unary_build_in_function] = STATE(334),
    [sym__binary_build_in_function] = STATE(335),
    [sym__variadic_build_in_function] = STATE(336),
    [sym_regex_expression] = STATE(332),
    [sym_substring_expression] = STATE(332),
    [sym_string_replace_expression] = STATE(332),
    [sym_exists_func] = STATE(332),
    [sym_not_exists_func] = STATE(332),
    [sym_aggregate] = STATE(332),
    [sym__iri] = STATE(897),
    [sym_prefixed_name] = STATE(897),
    [sym_iri_reference] = STATE(897),
    [sym_namespace] = STATE(413),
    [sym_pn_prefix] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(748),
    [anon_sym_LT] = ACTIONS(57),
    [aux_sym_binary_expression_token2] = ACTIONS(750),
    [aux_sym_build_in_function_token1] = ACTIONS(752),
    [aux_sym_build_in_function_token2] = ACTIONS(754),
    [aux_sym_build_in_function_token3] = ACTIONS(756),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(758),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(758),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(758),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(758),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(760),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(760),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(760),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(760),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(760),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(760),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(760),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(760),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(760),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(760),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(760),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(760),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(760),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(760),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(760),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(760),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(760),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(760),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(760),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(760),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(760),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(760),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(760),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(760),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(760),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(760),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(760),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(760),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(760),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(760),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(760),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(762),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(762),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(762),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(762),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(762),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(762),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(762),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(762),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(762),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(764),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(764),
    [aux_sym_regex_expression_token1] = ACTIONS(766),
    [aux_sym_substring_expression_token1] = ACTIONS(768),
    [aux_sym_string_replace_expression_token1] = ACTIONS(770),
    [aux_sym_exists_func_token1] = ACTIONS(772),
    [aux_sym_aggregate_token1] = ACTIONS(774),
    [aux_sym_aggregate_token2] = ACTIONS(776),
    [aux_sym_aggregate_token3] = ACTIONS(776),
    [aux_sym_aggregate_token4] = ACTIONS(776),
    [aux_sym_aggregate_token5] = ACTIONS(776),
    [aux_sym_aggregate_token6] = ACTIONS(776),
    [anon_sym_GROUP_CONCAT] = ACTIONS(778),
    [anon_sym_COLON] = ACTIONS(89),
  },
  [174] = {
    [sym_pn_prefix] = ACTIONS(559),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(557),
    [anon_sym_RBRACE] = ACTIONS(557),
    [aux_sym_having_clause_token1] = ACTIONS(559),
    [aux_sym_order_clause_token1] = ACTIONS(559),
    [aux_sym_order_condition_token1] = ACTIONS(559),
    [aux_sym_order_condition_token2] = ACTIONS(559),
    [aux_sym_limit_clause_token1] = ACTIONS(559),
    [aux_sym_offset_clause_token1] = ACTIONS(559),
    [aux_sym_values_clause_token1] = ACTIONS(559),
    [sym_var] = ACTIONS(557),
    [anon_sym_LT] = ACTIONS(557),
    [aux_sym_binary_expression_token2] = ACTIONS(559),
    [aux_sym_build_in_function_token1] = ACTIONS(559),
    [aux_sym_build_in_function_token2] = ACTIONS(559),
    [aux_sym_build_in_function_token3] = ACTIONS(559),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(559),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(559),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(559),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(559),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(559),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(559),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(559),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(559),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(559),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(559),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(559),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(559),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(559),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(559),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(559),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(559),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(559),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(559),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(559),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(559),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(559),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(559),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(559),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(559),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(559),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(559),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(559),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(559),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(559),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(559),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(559),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(559),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(559),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(559),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(559),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(559),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(559),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(559),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(559),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(559),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(559),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(559),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(559),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(559),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(559),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(559),
    [aux_sym_regex_expression_token1] = ACTIONS(559),
    [aux_sym_substring_expression_token1] = ACTIONS(559),
    [aux_sym_string_replace_expression_token1] = ACTIONS(559),
    [aux_sym_exists_func_token1] = ACTIONS(559),
    [aux_sym_aggregate_token1] = ACTIONS(559),
    [aux_sym_aggregate_token2] = ACTIONS(559),
    [aux_sym_aggregate_token3] = ACTIONS(559),
    [aux_sym_aggregate_token4] = ACTIONS(559),
    [aux_sym_aggregate_token5] = ACTIONS(559),
    [aux_sym_aggregate_token6] = ACTIONS(559),
    [anon_sym_GROUP_CONCAT] = ACTIONS(559),
    [anon_sym_COLON] = ACTIONS(557),
  },
  [175] = {
    [sym_pn_prefix] = ACTIONS(421),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(419),
    [anon_sym_RBRACE] = ACTIONS(419),
    [aux_sym_having_clause_token1] = ACTIONS(421),
    [aux_sym_order_clause_token1] = ACTIONS(421),
    [aux_sym_order_condition_token1] = ACTIONS(421),
    [aux_sym_order_condition_token2] = ACTIONS(421),
    [aux_sym_limit_clause_token1] = ACTIONS(421),
    [aux_sym_offset_clause_token1] = ACTIONS(421),
    [aux_sym_values_clause_token1] = ACTIONS(421),
    [sym_var] = ACTIONS(419),
    [anon_sym_LT] = ACTIONS(419),
    [aux_sym_binary_expression_token2] = ACTIONS(421),
    [aux_sym_build_in_function_token1] = ACTIONS(421),
    [aux_sym_build_in_function_token2] = ACTIONS(421),
    [aux_sym_build_in_function_token3] = ACTIONS(421),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(421),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(421),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(421),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(421),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(421),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(421),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(421),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(421),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(421),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(421),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(421),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(421),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(421),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(421),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(421),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(421),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(421),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(421),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(421),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(421),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(421),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(421),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(421),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(421),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(421),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(421),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(421),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(421),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(421),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(421),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(421),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(421),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(421),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(421),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(421),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(421),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(421),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(421),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(421),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(421),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(421),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(421),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(421),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(421),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(421),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(421),
    [aux_sym_regex_expression_token1] = ACTIONS(421),
    [aux_sym_substring_expression_token1] = ACTIONS(421),
    [aux_sym_string_replace_expression_token1] = ACTIONS(421),
    [aux_sym_exists_func_token1] = ACTIONS(421),
    [aux_sym_aggregate_token1] = ACTIONS(421),
    [aux_sym_aggregate_token2] = ACTIONS(421),
    [aux_sym_aggregate_token3] = ACTIONS(421),
    [aux_sym_aggregate_token4] = ACTIONS(421),
    [aux_sym_aggregate_token5] = ACTIONS(421),
    [aux_sym_aggregate_token6] = ACTIONS(421),
    [anon_sym_GROUP_CONCAT] = ACTIONS(421),
    [anon_sym_COLON] = ACTIONS(419),
  },
  [176] = {
    [sym_pn_prefix] = ACTIONS(425),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(423),
    [anon_sym_RBRACE] = ACTIONS(423),
    [aux_sym_having_clause_token1] = ACTIONS(425),
    [aux_sym_order_clause_token1] = ACTIONS(425),
    [aux_sym_order_condition_token1] = ACTIONS(425),
    [aux_sym_order_condition_token2] = ACTIONS(425),
    [aux_sym_limit_clause_token1] = ACTIONS(425),
    [aux_sym_offset_clause_token1] = ACTIONS(425),
    [aux_sym_values_clause_token1] = ACTIONS(425),
    [sym_var] = ACTIONS(423),
    [anon_sym_LT] = ACTIONS(423),
    [aux_sym_binary_expression_token2] = ACTIONS(425),
    [aux_sym_build_in_function_token1] = ACTIONS(425),
    [aux_sym_build_in_function_token2] = ACTIONS(425),
    [aux_sym_build_in_function_token3] = ACTIONS(425),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(425),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(425),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(425),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(425),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(425),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(425),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(425),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(425),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(425),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(425),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(425),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(425),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(425),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(425),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(425),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(425),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(425),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(425),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(425),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(425),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(425),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(425),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(425),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(425),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(425),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(425),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(425),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(425),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(425),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(425),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(425),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(425),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(425),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(425),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(425),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(425),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(425),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(425),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(425),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(425),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(425),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(425),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(425),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(425),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(425),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(425),
    [aux_sym_regex_expression_token1] = ACTIONS(425),
    [aux_sym_substring_expression_token1] = ACTIONS(425),
    [aux_sym_string_replace_expression_token1] = ACTIONS(425),
    [aux_sym_exists_func_token1] = ACTIONS(425),
    [aux_sym_aggregate_token1] = ACTIONS(425),
    [aux_sym_aggregate_token2] = ACTIONS(425),
    [aux_sym_aggregate_token3] = ACTIONS(425),
    [aux_sym_aggregate_token4] = ACTIONS(425),
    [aux_sym_aggregate_token5] = ACTIONS(425),
    [aux_sym_aggregate_token6] = ACTIONS(425),
    [anon_sym_GROUP_CONCAT] = ACTIONS(425),
    [anon_sym_COLON] = ACTIONS(423),
  },
  [177] = {
    [sym_pn_prefix] = ACTIONS(429),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(427),
    [anon_sym_RBRACE] = ACTIONS(427),
    [aux_sym_having_clause_token1] = ACTIONS(429),
    [aux_sym_order_clause_token1] = ACTIONS(429),
    [aux_sym_order_condition_token1] = ACTIONS(429),
    [aux_sym_order_condition_token2] = ACTIONS(429),
    [aux_sym_limit_clause_token1] = ACTIONS(429),
    [aux_sym_offset_clause_token1] = ACTIONS(429),
    [aux_sym_values_clause_token1] = ACTIONS(429),
    [sym_var] = ACTIONS(427),
    [anon_sym_LT] = ACTIONS(427),
    [aux_sym_binary_expression_token2] = ACTIONS(429),
    [aux_sym_build_in_function_token1] = ACTIONS(429),
    [aux_sym_build_in_function_token2] = ACTIONS(429),
    [aux_sym_build_in_function_token3] = ACTIONS(429),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(429),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(429),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(429),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(429),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(429),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(429),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(429),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(429),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(429),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(429),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(429),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(429),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(429),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(429),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(429),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(429),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(429),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(429),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(429),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(429),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(429),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(429),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(429),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(429),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(429),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(429),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(429),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(429),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(429),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(429),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(429),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(429),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(429),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(429),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(429),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(429),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(429),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(429),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(429),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(429),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(429),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(429),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(429),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(429),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(429),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(429),
    [aux_sym_regex_expression_token1] = ACTIONS(429),
    [aux_sym_substring_expression_token1] = ACTIONS(429),
    [aux_sym_string_replace_expression_token1] = ACTIONS(429),
    [aux_sym_exists_func_token1] = ACTIONS(429),
    [aux_sym_aggregate_token1] = ACTIONS(429),
    [aux_sym_aggregate_token2] = ACTIONS(429),
    [aux_sym_aggregate_token3] = ACTIONS(429),
    [aux_sym_aggregate_token4] = ACTIONS(429),
    [aux_sym_aggregate_token5] = ACTIONS(429),
    [aux_sym_aggregate_token6] = ACTIONS(429),
    [anon_sym_GROUP_CONCAT] = ACTIONS(429),
    [anon_sym_COLON] = ACTIONS(427),
  },
  [178] = {
    [sym_pn_prefix] = ACTIONS(433),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(431),
    [anon_sym_RBRACE] = ACTIONS(431),
    [aux_sym_having_clause_token1] = ACTIONS(433),
    [aux_sym_order_clause_token1] = ACTIONS(433),
    [aux_sym_order_condition_token1] = ACTIONS(433),
    [aux_sym_order_condition_token2] = ACTIONS(433),
    [aux_sym_limit_clause_token1] = ACTIONS(433),
    [aux_sym_offset_clause_token1] = ACTIONS(433),
    [aux_sym_values_clause_token1] = ACTIONS(433),
    [sym_var] = ACTIONS(431),
    [anon_sym_LT] = ACTIONS(431),
    [aux_sym_binary_expression_token2] = ACTIONS(433),
    [aux_sym_build_in_function_token1] = ACTIONS(433),
    [aux_sym_build_in_function_token2] = ACTIONS(433),
    [aux_sym_build_in_function_token3] = ACTIONS(433),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(433),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(433),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(433),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(433),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(433),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(433),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(433),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(433),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(433),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(433),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(433),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(433),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(433),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(433),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(433),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(433),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(433),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(433),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(433),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(433),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(433),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(433),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(433),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(433),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(433),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(433),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(433),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(433),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(433),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(433),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(433),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(433),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(433),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(433),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(433),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(433),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(433),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(433),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(433),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(433),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(433),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(433),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(433),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(433),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(433),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(433),
    [aux_sym_regex_expression_token1] = ACTIONS(433),
    [aux_sym_substring_expression_token1] = ACTIONS(433),
    [aux_sym_string_replace_expression_token1] = ACTIONS(433),
    [aux_sym_exists_func_token1] = ACTIONS(433),
    [aux_sym_aggregate_token1] = ACTIONS(433),
    [aux_sym_aggregate_token2] = ACTIONS(433),
    [aux_sym_aggregate_token3] = ACTIONS(433),
    [aux_sym_aggregate_token4] = ACTIONS(433),
    [aux_sym_aggregate_token5] = ACTIONS(433),
    [aux_sym_aggregate_token6] = ACTIONS(433),
    [anon_sym_GROUP_CONCAT] = ACTIONS(433),
    [anon_sym_COLON] = ACTIONS(431),
  },
  [179] = {
    [sym_pn_prefix] = ACTIONS(437),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(435),
    [anon_sym_RBRACE] = ACTIONS(435),
    [aux_sym_having_clause_token1] = ACTIONS(437),
    [aux_sym_order_clause_token1] = ACTIONS(437),
    [aux_sym_order_condition_token1] = ACTIONS(437),
    [aux_sym_order_condition_token2] = ACTIONS(437),
    [aux_sym_limit_clause_token1] = ACTIONS(437),
    [aux_sym_offset_clause_token1] = ACTIONS(437),
    [aux_sym_values_clause_token1] = ACTIONS(437),
    [sym_var] = ACTIONS(435),
    [anon_sym_LT] = ACTIONS(435),
    [aux_sym_binary_expression_token2] = ACTIONS(437),
    [aux_sym_build_in_function_token1] = ACTIONS(437),
    [aux_sym_build_in_function_token2] = ACTIONS(437),
    [aux_sym_build_in_function_token3] = ACTIONS(437),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(437),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(437),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(437),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(437),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(437),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(437),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(437),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(437),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(437),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(437),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(437),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(437),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(437),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(437),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(437),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(437),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(437),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(437),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(437),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(437),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(437),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(437),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(437),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(437),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(437),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(437),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(437),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(437),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(437),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(437),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(437),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(437),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(437),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(437),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(437),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(437),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(437),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(437),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(437),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(437),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(437),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(437),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(437),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(437),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(437),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(437),
    [aux_sym_regex_expression_token1] = ACTIONS(437),
    [aux_sym_substring_expression_token1] = ACTIONS(437),
    [aux_sym_string_replace_expression_token1] = ACTIONS(437),
    [aux_sym_exists_func_token1] = ACTIONS(437),
    [aux_sym_aggregate_token1] = ACTIONS(437),
    [aux_sym_aggregate_token2] = ACTIONS(437),
    [aux_sym_aggregate_token3] = ACTIONS(437),
    [aux_sym_aggregate_token4] = ACTIONS(437),
    [aux_sym_aggregate_token5] = ACTIONS(437),
    [aux_sym_aggregate_token6] = ACTIONS(437),
    [anon_sym_GROUP_CONCAT] = ACTIONS(437),
    [anon_sym_COLON] = ACTIONS(435),
  },
  [180] = {
    [sym_pn_prefix] = ACTIONS(441),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(439),
    [anon_sym_RBRACE] = ACTIONS(439),
    [aux_sym_having_clause_token1] = ACTIONS(441),
    [aux_sym_order_clause_token1] = ACTIONS(441),
    [aux_sym_order_condition_token1] = ACTIONS(441),
    [aux_sym_order_condition_token2] = ACTIONS(441),
    [aux_sym_limit_clause_token1] = ACTIONS(441),
    [aux_sym_offset_clause_token1] = ACTIONS(441),
    [aux_sym_values_clause_token1] = ACTIONS(441),
    [sym_var] = ACTIONS(439),
    [anon_sym_LT] = ACTIONS(439),
    [aux_sym_binary_expression_token2] = ACTIONS(441),
    [aux_sym_build_in_function_token1] = ACTIONS(441),
    [aux_sym_build_in_function_token2] = ACTIONS(441),
    [aux_sym_build_in_function_token3] = ACTIONS(441),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(441),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(441),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(441),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(441),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(441),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(441),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(441),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(441),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(441),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(441),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(441),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(441),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(441),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(441),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(441),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(441),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(441),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(441),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(441),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(441),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(441),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(441),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(441),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(441),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(441),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(441),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(441),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(441),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(441),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(441),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(441),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(441),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(441),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(441),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(441),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(441),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(441),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(441),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(441),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(441),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(441),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(441),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(441),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(441),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(441),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(441),
    [aux_sym_regex_expression_token1] = ACTIONS(441),
    [aux_sym_substring_expression_token1] = ACTIONS(441),
    [aux_sym_string_replace_expression_token1] = ACTIONS(441),
    [aux_sym_exists_func_token1] = ACTIONS(441),
    [aux_sym_aggregate_token1] = ACTIONS(441),
    [aux_sym_aggregate_token2] = ACTIONS(441),
    [aux_sym_aggregate_token3] = ACTIONS(441),
    [aux_sym_aggregate_token4] = ACTIONS(441),
    [aux_sym_aggregate_token5] = ACTIONS(441),
    [aux_sym_aggregate_token6] = ACTIONS(441),
    [anon_sym_GROUP_CONCAT] = ACTIONS(441),
    [anon_sym_COLON] = ACTIONS(439),
  },
  [181] = {
    [sym_pn_prefix] = ACTIONS(445),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(443),
    [anon_sym_RBRACE] = ACTIONS(443),
    [aux_sym_having_clause_token1] = ACTIONS(445),
    [aux_sym_order_clause_token1] = ACTIONS(445),
    [aux_sym_order_condition_token1] = ACTIONS(445),
    [aux_sym_order_condition_token2] = ACTIONS(445),
    [aux_sym_limit_clause_token1] = ACTIONS(445),
    [aux_sym_offset_clause_token1] = ACTIONS(445),
    [aux_sym_values_clause_token1] = ACTIONS(445),
    [sym_var] = ACTIONS(443),
    [anon_sym_LT] = ACTIONS(443),
    [aux_sym_binary_expression_token2] = ACTIONS(445),
    [aux_sym_build_in_function_token1] = ACTIONS(445),
    [aux_sym_build_in_function_token2] = ACTIONS(445),
    [aux_sym_build_in_function_token3] = ACTIONS(445),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(445),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(445),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(445),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(445),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(445),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(445),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(445),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(445),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(445),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(445),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(445),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(445),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(445),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(445),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(445),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(445),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(445),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(445),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(445),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(445),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(445),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(445),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(445),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(445),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(445),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(445),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(445),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(445),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(445),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(445),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(445),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(445),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(445),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(445),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(445),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(445),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(445),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(445),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(445),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(445),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(445),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(445),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(445),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(445),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(445),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(445),
    [aux_sym_regex_expression_token1] = ACTIONS(445),
    [aux_sym_substring_expression_token1] = ACTIONS(445),
    [aux_sym_string_replace_expression_token1] = ACTIONS(445),
    [aux_sym_exists_func_token1] = ACTIONS(445),
    [aux_sym_aggregate_token1] = ACTIONS(445),
    [aux_sym_aggregate_token2] = ACTIONS(445),
    [aux_sym_aggregate_token3] = ACTIONS(445),
    [aux_sym_aggregate_token4] = ACTIONS(445),
    [aux_sym_aggregate_token5] = ACTIONS(445),
    [aux_sym_aggregate_token6] = ACTIONS(445),
    [anon_sym_GROUP_CONCAT] = ACTIONS(445),
    [anon_sym_COLON] = ACTIONS(443),
  },
  [182] = {
    [sym_pn_prefix] = ACTIONS(485),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(483),
    [anon_sym_RBRACE] = ACTIONS(483),
    [aux_sym_having_clause_token1] = ACTIONS(485),
    [aux_sym_order_clause_token1] = ACTIONS(485),
    [aux_sym_order_condition_token1] = ACTIONS(485),
    [aux_sym_order_condition_token2] = ACTIONS(485),
    [aux_sym_limit_clause_token1] = ACTIONS(485),
    [aux_sym_offset_clause_token1] = ACTIONS(485),
    [aux_sym_values_clause_token1] = ACTIONS(485),
    [sym_var] = ACTIONS(483),
    [anon_sym_LT] = ACTIONS(483),
    [aux_sym_binary_expression_token2] = ACTIONS(485),
    [aux_sym_build_in_function_token1] = ACTIONS(485),
    [aux_sym_build_in_function_token2] = ACTIONS(485),
    [aux_sym_build_in_function_token3] = ACTIONS(485),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(485),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(485),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(485),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(485),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(485),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(485),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(485),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(485),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(485),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(485),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(485),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(485),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(485),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(485),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(485),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(485),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(485),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(485),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(485),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(485),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(485),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(485),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(485),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(485),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(485),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(485),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(485),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(485),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(485),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(485),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(485),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(485),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(485),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(485),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(485),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(485),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(485),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(485),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(485),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(485),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(485),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(485),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(485),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(485),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(485),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(485),
    [aux_sym_regex_expression_token1] = ACTIONS(485),
    [aux_sym_substring_expression_token1] = ACTIONS(485),
    [aux_sym_string_replace_expression_token1] = ACTIONS(485),
    [aux_sym_exists_func_token1] = ACTIONS(485),
    [aux_sym_aggregate_token1] = ACTIONS(485),
    [aux_sym_aggregate_token2] = ACTIONS(485),
    [aux_sym_aggregate_token3] = ACTIONS(485),
    [aux_sym_aggregate_token4] = ACTIONS(485),
    [aux_sym_aggregate_token5] = ACTIONS(485),
    [aux_sym_aggregate_token6] = ACTIONS(485),
    [anon_sym_GROUP_CONCAT] = ACTIONS(485),
    [anon_sym_COLON] = ACTIONS(483),
  },
  [183] = {
    [sym_pn_prefix] = ACTIONS(489),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(487),
    [anon_sym_RBRACE] = ACTIONS(487),
    [aux_sym_having_clause_token1] = ACTIONS(489),
    [aux_sym_order_clause_token1] = ACTIONS(489),
    [aux_sym_order_condition_token1] = ACTIONS(489),
    [aux_sym_order_condition_token2] = ACTIONS(489),
    [aux_sym_limit_clause_token1] = ACTIONS(489),
    [aux_sym_offset_clause_token1] = ACTIONS(489),
    [aux_sym_values_clause_token1] = ACTIONS(489),
    [sym_var] = ACTIONS(487),
    [anon_sym_LT] = ACTIONS(487),
    [aux_sym_binary_expression_token2] = ACTIONS(489),
    [aux_sym_build_in_function_token1] = ACTIONS(489),
    [aux_sym_build_in_function_token2] = ACTIONS(489),
    [aux_sym_build_in_function_token3] = ACTIONS(489),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(489),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(489),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(489),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(489),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(489),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(489),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(489),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(489),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(489),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(489),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(489),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(489),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(489),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(489),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(489),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(489),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(489),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(489),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(489),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(489),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(489),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(489),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(489),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(489),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(489),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(489),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(489),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(489),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(489),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(489),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(489),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(489),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(489),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(489),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(489),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(489),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(489),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(489),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(489),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(489),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(489),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(489),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(489),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(489),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(489),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(489),
    [aux_sym_regex_expression_token1] = ACTIONS(489),
    [aux_sym_substring_expression_token1] = ACTIONS(489),
    [aux_sym_string_replace_expression_token1] = ACTIONS(489),
    [aux_sym_exists_func_token1] = ACTIONS(489),
    [aux_sym_aggregate_token1] = ACTIONS(489),
    [aux_sym_aggregate_token2] = ACTIONS(489),
    [aux_sym_aggregate_token3] = ACTIONS(489),
    [aux_sym_aggregate_token4] = ACTIONS(489),
    [aux_sym_aggregate_token5] = ACTIONS(489),
    [aux_sym_aggregate_token6] = ACTIONS(489),
    [anon_sym_GROUP_CONCAT] = ACTIONS(489),
    [anon_sym_COLON] = ACTIONS(487),
  },
  [184] = {
    [sym_pn_prefix] = ACTIONS(615),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(613),
    [anon_sym_RBRACE] = ACTIONS(613),
    [aux_sym_having_clause_token1] = ACTIONS(615),
    [aux_sym_order_clause_token1] = ACTIONS(615),
    [aux_sym_order_condition_token1] = ACTIONS(615),
    [aux_sym_order_condition_token2] = ACTIONS(615),
    [aux_sym_limit_clause_token1] = ACTIONS(615),
    [aux_sym_offset_clause_token1] = ACTIONS(615),
    [aux_sym_values_clause_token1] = ACTIONS(615),
    [sym_var] = ACTIONS(613),
    [anon_sym_LT] = ACTIONS(613),
    [aux_sym_binary_expression_token2] = ACTIONS(615),
    [aux_sym_build_in_function_token1] = ACTIONS(615),
    [aux_sym_build_in_function_token2] = ACTIONS(615),
    [aux_sym_build_in_function_token3] = ACTIONS(615),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(615),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(615),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(615),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(615),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(615),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(615),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(615),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(615),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(615),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(615),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(615),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(615),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(615),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(615),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(615),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(615),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(615),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(615),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(615),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(615),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(615),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(615),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(615),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(615),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(615),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(615),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(615),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(615),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(615),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(615),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(615),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(615),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(615),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(615),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(615),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(615),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(615),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(615),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(615),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(615),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(615),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(615),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(615),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(615),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(615),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(615),
    [aux_sym_regex_expression_token1] = ACTIONS(615),
    [aux_sym_substring_expression_token1] = ACTIONS(615),
    [aux_sym_string_replace_expression_token1] = ACTIONS(615),
    [aux_sym_exists_func_token1] = ACTIONS(615),
    [aux_sym_aggregate_token1] = ACTIONS(615),
    [aux_sym_aggregate_token2] = ACTIONS(615),
    [aux_sym_aggregate_token3] = ACTIONS(615),
    [aux_sym_aggregate_token4] = ACTIONS(615),
    [aux_sym_aggregate_token5] = ACTIONS(615),
    [aux_sym_aggregate_token6] = ACTIONS(615),
    [anon_sym_GROUP_CONCAT] = ACTIONS(615),
    [anon_sym_COLON] = ACTIONS(613),
  },
  [185] = {
    [sym_pn_prefix] = ACTIONS(493),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(491),
    [anon_sym_RBRACE] = ACTIONS(491),
    [aux_sym_having_clause_token1] = ACTIONS(493),
    [aux_sym_order_clause_token1] = ACTIONS(493),
    [aux_sym_order_condition_token1] = ACTIONS(493),
    [aux_sym_order_condition_token2] = ACTIONS(493),
    [aux_sym_limit_clause_token1] = ACTIONS(493),
    [aux_sym_offset_clause_token1] = ACTIONS(493),
    [aux_sym_values_clause_token1] = ACTIONS(493),
    [sym_var] = ACTIONS(491),
    [anon_sym_LT] = ACTIONS(491),
    [aux_sym_binary_expression_token2] = ACTIONS(493),
    [aux_sym_build_in_function_token1] = ACTIONS(493),
    [aux_sym_build_in_function_token2] = ACTIONS(493),
    [aux_sym_build_in_function_token3] = ACTIONS(493),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(493),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(493),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(493),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(493),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(493),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(493),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(493),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(493),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(493),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(493),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(493),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(493),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(493),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(493),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(493),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(493),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(493),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(493),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(493),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(493),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(493),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(493),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(493),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(493),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(493),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(493),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(493),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(493),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(493),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(493),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(493),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(493),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(493),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(493),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(493),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(493),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(493),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(493),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(493),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(493),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(493),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(493),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(493),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(493),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(493),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(493),
    [aux_sym_regex_expression_token1] = ACTIONS(493),
    [aux_sym_substring_expression_token1] = ACTIONS(493),
    [aux_sym_string_replace_expression_token1] = ACTIONS(493),
    [aux_sym_exists_func_token1] = ACTIONS(493),
    [aux_sym_aggregate_token1] = ACTIONS(493),
    [aux_sym_aggregate_token2] = ACTIONS(493),
    [aux_sym_aggregate_token3] = ACTIONS(493),
    [aux_sym_aggregate_token4] = ACTIONS(493),
    [aux_sym_aggregate_token5] = ACTIONS(493),
    [aux_sym_aggregate_token6] = ACTIONS(493),
    [anon_sym_GROUP_CONCAT] = ACTIONS(493),
    [anon_sym_COLON] = ACTIONS(491),
  },
  [186] = {
    [sym_pn_prefix] = ACTIONS(551),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(549),
    [anon_sym_RBRACE] = ACTIONS(549),
    [aux_sym_having_clause_token1] = ACTIONS(551),
    [aux_sym_order_clause_token1] = ACTIONS(551),
    [aux_sym_order_condition_token1] = ACTIONS(551),
    [aux_sym_order_condition_token2] = ACTIONS(551),
    [aux_sym_limit_clause_token1] = ACTIONS(551),
    [aux_sym_offset_clause_token1] = ACTIONS(551),
    [aux_sym_values_clause_token1] = ACTIONS(551),
    [sym_var] = ACTIONS(549),
    [anon_sym_LT] = ACTIONS(549),
    [aux_sym_binary_expression_token2] = ACTIONS(551),
    [aux_sym_build_in_function_token1] = ACTIONS(551),
    [aux_sym_build_in_function_token2] = ACTIONS(551),
    [aux_sym_build_in_function_token3] = ACTIONS(551),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(551),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(551),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(551),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(551),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(551),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(551),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(551),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(551),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(551),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(551),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(551),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(551),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(551),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(551),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(551),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(551),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(551),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(551),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(551),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(551),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(551),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(551),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(551),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(551),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(551),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(551),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(551),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(551),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(551),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(551),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(551),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(551),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(551),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(551),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(551),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(551),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(551),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(551),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(551),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(551),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(551),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(551),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(551),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(551),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(551),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(551),
    [aux_sym_regex_expression_token1] = ACTIONS(551),
    [aux_sym_substring_expression_token1] = ACTIONS(551),
    [aux_sym_string_replace_expression_token1] = ACTIONS(551),
    [aux_sym_exists_func_token1] = ACTIONS(551),
    [aux_sym_aggregate_token1] = ACTIONS(551),
    [aux_sym_aggregate_token2] = ACTIONS(551),
    [aux_sym_aggregate_token3] = ACTIONS(551),
    [aux_sym_aggregate_token4] = ACTIONS(551),
    [aux_sym_aggregate_token5] = ACTIONS(551),
    [aux_sym_aggregate_token6] = ACTIONS(551),
    [anon_sym_GROUP_CONCAT] = ACTIONS(551),
    [anon_sym_COLON] = ACTIONS(549),
  },
  [187] = {
    [sym_pn_prefix] = ACTIONS(555),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(553),
    [anon_sym_RBRACE] = ACTIONS(553),
    [aux_sym_having_clause_token1] = ACTIONS(555),
    [aux_sym_order_clause_token1] = ACTIONS(555),
    [aux_sym_order_condition_token1] = ACTIONS(555),
    [aux_sym_order_condition_token2] = ACTIONS(555),
    [aux_sym_limit_clause_token1] = ACTIONS(555),
    [aux_sym_offset_clause_token1] = ACTIONS(555),
    [aux_sym_values_clause_token1] = ACTIONS(555),
    [sym_var] = ACTIONS(553),
    [anon_sym_LT] = ACTIONS(553),
    [aux_sym_binary_expression_token2] = ACTIONS(555),
    [aux_sym_build_in_function_token1] = ACTIONS(555),
    [aux_sym_build_in_function_token2] = ACTIONS(555),
    [aux_sym_build_in_function_token3] = ACTIONS(555),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(555),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(555),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(555),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(555),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(555),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(555),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(555),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(555),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(555),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(555),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(555),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(555),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(555),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(555),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(555),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(555),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(555),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(555),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(555),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(555),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(555),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(555),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(555),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(555),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(555),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(555),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(555),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(555),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(555),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(555),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(555),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(555),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(555),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(555),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(555),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(555),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(555),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(555),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(555),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(555),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(555),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(555),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(555),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(555),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(555),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(555),
    [aux_sym_regex_expression_token1] = ACTIONS(555),
    [aux_sym_substring_expression_token1] = ACTIONS(555),
    [aux_sym_string_replace_expression_token1] = ACTIONS(555),
    [aux_sym_exists_func_token1] = ACTIONS(555),
    [aux_sym_aggregate_token1] = ACTIONS(555),
    [aux_sym_aggregate_token2] = ACTIONS(555),
    [aux_sym_aggregate_token3] = ACTIONS(555),
    [aux_sym_aggregate_token4] = ACTIONS(555),
    [aux_sym_aggregate_token5] = ACTIONS(555),
    [aux_sym_aggregate_token6] = ACTIONS(555),
    [anon_sym_GROUP_CONCAT] = ACTIONS(555),
    [anon_sym_COLON] = ACTIONS(553),
  },
  [188] = {
    [sym_pn_prefix] = ACTIONS(607),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(605),
    [anon_sym_RBRACE] = ACTIONS(605),
    [aux_sym_having_clause_token1] = ACTIONS(607),
    [aux_sym_order_clause_token1] = ACTIONS(607),
    [aux_sym_order_condition_token1] = ACTIONS(607),
    [aux_sym_order_condition_token2] = ACTIONS(607),
    [aux_sym_limit_clause_token1] = ACTIONS(607),
    [aux_sym_offset_clause_token1] = ACTIONS(607),
    [aux_sym_values_clause_token1] = ACTIONS(607),
    [sym_var] = ACTIONS(605),
    [anon_sym_LT] = ACTIONS(605),
    [aux_sym_binary_expression_token2] = ACTIONS(607),
    [aux_sym_build_in_function_token1] = ACTIONS(607),
    [aux_sym_build_in_function_token2] = ACTIONS(607),
    [aux_sym_build_in_function_token3] = ACTIONS(607),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(607),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(607),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(607),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(607),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(607),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(607),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(607),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(607),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(607),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(607),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(607),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(607),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(607),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(607),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(607),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(607),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(607),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(607),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(607),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(607),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(607),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(607),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(607),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(607),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(607),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(607),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(607),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(607),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(607),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(607),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(607),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(607),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(607),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(607),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(607),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(607),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(607),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(607),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(607),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(607),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(607),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(607),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(607),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(607),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(607),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(607),
    [aux_sym_regex_expression_token1] = ACTIONS(607),
    [aux_sym_substring_expression_token1] = ACTIONS(607),
    [aux_sym_string_replace_expression_token1] = ACTIONS(607),
    [aux_sym_exists_func_token1] = ACTIONS(607),
    [aux_sym_aggregate_token1] = ACTIONS(607),
    [aux_sym_aggregate_token2] = ACTIONS(607),
    [aux_sym_aggregate_token3] = ACTIONS(607),
    [aux_sym_aggregate_token4] = ACTIONS(607),
    [aux_sym_aggregate_token5] = ACTIONS(607),
    [aux_sym_aggregate_token6] = ACTIONS(607),
    [anon_sym_GROUP_CONCAT] = ACTIONS(607),
    [anon_sym_COLON] = ACTIONS(605),
  },
  [189] = {
    [sym_pn_prefix] = ACTIONS(563),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(561),
    [anon_sym_RBRACE] = ACTIONS(561),
    [aux_sym_having_clause_token1] = ACTIONS(563),
    [aux_sym_order_clause_token1] = ACTIONS(563),
    [aux_sym_order_condition_token1] = ACTIONS(563),
    [aux_sym_order_condition_token2] = ACTIONS(563),
    [aux_sym_limit_clause_token1] = ACTIONS(563),
    [aux_sym_offset_clause_token1] = ACTIONS(563),
    [aux_sym_values_clause_token1] = ACTIONS(563),
    [sym_var] = ACTIONS(561),
    [anon_sym_LT] = ACTIONS(561),
    [aux_sym_binary_expression_token2] = ACTIONS(563),
    [aux_sym_build_in_function_token1] = ACTIONS(563),
    [aux_sym_build_in_function_token2] = ACTIONS(563),
    [aux_sym_build_in_function_token3] = ACTIONS(563),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(563),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(563),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(563),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(563),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(563),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(563),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(563),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(563),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(563),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(563),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(563),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(563),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(563),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(563),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(563),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(563),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(563),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(563),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(563),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(563),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(563),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(563),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(563),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(563),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(563),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(563),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(563),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(563),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(563),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(563),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(563),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(563),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(563),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(563),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(563),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(563),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(563),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(563),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(563),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(563),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(563),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(563),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(563),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(563),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(563),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(563),
    [aux_sym_regex_expression_token1] = ACTIONS(563),
    [aux_sym_substring_expression_token1] = ACTIONS(563),
    [aux_sym_string_replace_expression_token1] = ACTIONS(563),
    [aux_sym_exists_func_token1] = ACTIONS(563),
    [aux_sym_aggregate_token1] = ACTIONS(563),
    [aux_sym_aggregate_token2] = ACTIONS(563),
    [aux_sym_aggregate_token3] = ACTIONS(563),
    [aux_sym_aggregate_token4] = ACTIONS(563),
    [aux_sym_aggregate_token5] = ACTIONS(563),
    [aux_sym_aggregate_token6] = ACTIONS(563),
    [anon_sym_GROUP_CONCAT] = ACTIONS(563),
    [anon_sym_COLON] = ACTIONS(561),
  },
  [190] = {
    [sym_pn_prefix] = ACTIONS(567),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(565),
    [anon_sym_RBRACE] = ACTIONS(565),
    [aux_sym_having_clause_token1] = ACTIONS(567),
    [aux_sym_order_clause_token1] = ACTIONS(567),
    [aux_sym_order_condition_token1] = ACTIONS(567),
    [aux_sym_order_condition_token2] = ACTIONS(567),
    [aux_sym_limit_clause_token1] = ACTIONS(567),
    [aux_sym_offset_clause_token1] = ACTIONS(567),
    [aux_sym_values_clause_token1] = ACTIONS(567),
    [sym_var] = ACTIONS(565),
    [anon_sym_LT] = ACTIONS(565),
    [aux_sym_binary_expression_token2] = ACTIONS(567),
    [aux_sym_build_in_function_token1] = ACTIONS(567),
    [aux_sym_build_in_function_token2] = ACTIONS(567),
    [aux_sym_build_in_function_token3] = ACTIONS(567),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(567),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(567),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(567),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(567),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(567),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(567),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(567),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(567),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(567),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(567),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(567),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(567),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(567),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(567),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(567),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(567),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(567),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(567),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(567),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(567),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(567),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(567),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(567),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(567),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(567),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(567),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(567),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(567),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(567),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(567),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(567),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(567),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(567),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(567),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(567),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(567),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(567),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(567),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(567),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(567),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(567),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(567),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(567),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(567),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(567),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(567),
    [aux_sym_regex_expression_token1] = ACTIONS(567),
    [aux_sym_substring_expression_token1] = ACTIONS(567),
    [aux_sym_string_replace_expression_token1] = ACTIONS(567),
    [aux_sym_exists_func_token1] = ACTIONS(567),
    [aux_sym_aggregate_token1] = ACTIONS(567),
    [aux_sym_aggregate_token2] = ACTIONS(567),
    [aux_sym_aggregate_token3] = ACTIONS(567),
    [aux_sym_aggregate_token4] = ACTIONS(567),
    [aux_sym_aggregate_token5] = ACTIONS(567),
    [aux_sym_aggregate_token6] = ACTIONS(567),
    [anon_sym_GROUP_CONCAT] = ACTIONS(567),
    [anon_sym_COLON] = ACTIONS(565),
  },
  [191] = {
    [sym_pn_prefix] = ACTIONS(571),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(569),
    [anon_sym_RBRACE] = ACTIONS(569),
    [aux_sym_having_clause_token1] = ACTIONS(571),
    [aux_sym_order_clause_token1] = ACTIONS(571),
    [aux_sym_order_condition_token1] = ACTIONS(571),
    [aux_sym_order_condition_token2] = ACTIONS(571),
    [aux_sym_limit_clause_token1] = ACTIONS(571),
    [aux_sym_offset_clause_token1] = ACTIONS(571),
    [aux_sym_values_clause_token1] = ACTIONS(571),
    [sym_var] = ACTIONS(569),
    [anon_sym_LT] = ACTIONS(569),
    [aux_sym_binary_expression_token2] = ACTIONS(571),
    [aux_sym_build_in_function_token1] = ACTIONS(571),
    [aux_sym_build_in_function_token2] = ACTIONS(571),
    [aux_sym_build_in_function_token3] = ACTIONS(571),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(571),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(571),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(571),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(571),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(571),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(571),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(571),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(571),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(571),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(571),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(571),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(571),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(571),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(571),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(571),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(571),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(571),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(571),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(571),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(571),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(571),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(571),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(571),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(571),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(571),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(571),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(571),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(571),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(571),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(571),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(571),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(571),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(571),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(571),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(571),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(571),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(571),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(571),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(571),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(571),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(571),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(571),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(571),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(571),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(571),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(571),
    [aux_sym_regex_expression_token1] = ACTIONS(571),
    [aux_sym_substring_expression_token1] = ACTIONS(571),
    [aux_sym_string_replace_expression_token1] = ACTIONS(571),
    [aux_sym_exists_func_token1] = ACTIONS(571),
    [aux_sym_aggregate_token1] = ACTIONS(571),
    [aux_sym_aggregate_token2] = ACTIONS(571),
    [aux_sym_aggregate_token3] = ACTIONS(571),
    [aux_sym_aggregate_token4] = ACTIONS(571),
    [aux_sym_aggregate_token5] = ACTIONS(571),
    [aux_sym_aggregate_token6] = ACTIONS(571),
    [anon_sym_GROUP_CONCAT] = ACTIONS(571),
    [anon_sym_COLON] = ACTIONS(569),
  },
  [192] = {
    [sym_pn_prefix] = ACTIONS(611),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(609),
    [anon_sym_RBRACE] = ACTIONS(609),
    [aux_sym_having_clause_token1] = ACTIONS(611),
    [aux_sym_order_clause_token1] = ACTIONS(611),
    [aux_sym_order_condition_token1] = ACTIONS(611),
    [aux_sym_order_condition_token2] = ACTIONS(611),
    [aux_sym_limit_clause_token1] = ACTIONS(611),
    [aux_sym_offset_clause_token1] = ACTIONS(611),
    [aux_sym_values_clause_token1] = ACTIONS(611),
    [sym_var] = ACTIONS(609),
    [anon_sym_LT] = ACTIONS(609),
    [aux_sym_binary_expression_token2] = ACTIONS(611),
    [aux_sym_build_in_function_token1] = ACTIONS(611),
    [aux_sym_build_in_function_token2] = ACTIONS(611),
    [aux_sym_build_in_function_token3] = ACTIONS(611),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(611),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(611),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(611),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(611),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(611),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(611),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(611),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(611),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(611),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(611),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(611),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(611),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(611),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(611),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(611),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(611),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(611),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(611),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(611),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(611),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(611),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(611),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(611),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(611),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(611),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(611),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(611),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(611),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(611),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(611),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(611),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(611),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(611),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(611),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(611),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(611),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(611),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(611),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(611),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(611),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(611),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(611),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(611),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(611),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(611),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(611),
    [aux_sym_regex_expression_token1] = ACTIONS(611),
    [aux_sym_substring_expression_token1] = ACTIONS(611),
    [aux_sym_string_replace_expression_token1] = ACTIONS(611),
    [aux_sym_exists_func_token1] = ACTIONS(611),
    [aux_sym_aggregate_token1] = ACTIONS(611),
    [aux_sym_aggregate_token2] = ACTIONS(611),
    [aux_sym_aggregate_token3] = ACTIONS(611),
    [aux_sym_aggregate_token4] = ACTIONS(611),
    [aux_sym_aggregate_token5] = ACTIONS(611),
    [aux_sym_aggregate_token6] = ACTIONS(611),
    [anon_sym_GROUP_CONCAT] = ACTIONS(611),
    [anon_sym_COLON] = ACTIONS(609),
  },
  [193] = {
    [sym_pn_prefix] = ACTIONS(579),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(577),
    [anon_sym_RBRACE] = ACTIONS(577),
    [aux_sym_having_clause_token1] = ACTIONS(579),
    [aux_sym_order_clause_token1] = ACTIONS(579),
    [aux_sym_order_condition_token1] = ACTIONS(579),
    [aux_sym_order_condition_token2] = ACTIONS(579),
    [aux_sym_limit_clause_token1] = ACTIONS(579),
    [aux_sym_offset_clause_token1] = ACTIONS(579),
    [aux_sym_values_clause_token1] = ACTIONS(579),
    [sym_var] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(577),
    [aux_sym_binary_expression_token2] = ACTIONS(579),
    [aux_sym_build_in_function_token1] = ACTIONS(579),
    [aux_sym_build_in_function_token2] = ACTIONS(579),
    [aux_sym_build_in_function_token3] = ACTIONS(579),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(579),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(579),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(579),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(579),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(579),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(579),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(579),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(579),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(579),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(579),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(579),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(579),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(579),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(579),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(579),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(579),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(579),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(579),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(579),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(579),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(579),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(579),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(579),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(579),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(579),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(579),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(579),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(579),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(579),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(579),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(579),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(579),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(579),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(579),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(579),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(579),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(579),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(579),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(579),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(579),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(579),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(579),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(579),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(579),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(579),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(579),
    [aux_sym_regex_expression_token1] = ACTIONS(579),
    [aux_sym_substring_expression_token1] = ACTIONS(579),
    [aux_sym_string_replace_expression_token1] = ACTIONS(579),
    [aux_sym_exists_func_token1] = ACTIONS(579),
    [aux_sym_aggregate_token1] = ACTIONS(579),
    [aux_sym_aggregate_token2] = ACTIONS(579),
    [aux_sym_aggregate_token3] = ACTIONS(579),
    [aux_sym_aggregate_token4] = ACTIONS(579),
    [aux_sym_aggregate_token5] = ACTIONS(579),
    [aux_sym_aggregate_token6] = ACTIONS(579),
    [anon_sym_GROUP_CONCAT] = ACTIONS(579),
    [anon_sym_COLON] = ACTIONS(577),
  },
  [194] = {
    [sym_pn_prefix] = ACTIONS(583),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(581),
    [anon_sym_RBRACE] = ACTIONS(581),
    [aux_sym_having_clause_token1] = ACTIONS(583),
    [aux_sym_order_clause_token1] = ACTIONS(583),
    [aux_sym_order_condition_token1] = ACTIONS(583),
    [aux_sym_order_condition_token2] = ACTIONS(583),
    [aux_sym_limit_clause_token1] = ACTIONS(583),
    [aux_sym_offset_clause_token1] = ACTIONS(583),
    [aux_sym_values_clause_token1] = ACTIONS(583),
    [sym_var] = ACTIONS(581),
    [anon_sym_LT] = ACTIONS(581),
    [aux_sym_binary_expression_token2] = ACTIONS(583),
    [aux_sym_build_in_function_token1] = ACTIONS(583),
    [aux_sym_build_in_function_token2] = ACTIONS(583),
    [aux_sym_build_in_function_token3] = ACTIONS(583),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(583),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(583),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(583),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(583),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(583),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(583),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(583),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(583),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(583),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(583),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(583),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(583),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(583),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(583),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(583),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(583),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(583),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(583),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(583),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(583),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(583),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(583),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(583),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(583),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(583),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(583),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(583),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(583),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(583),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(583),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(583),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(583),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(583),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(583),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(583),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(583),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(583),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(583),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(583),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(583),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(583),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(583),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(583),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(583),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(583),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(583),
    [aux_sym_regex_expression_token1] = ACTIONS(583),
    [aux_sym_substring_expression_token1] = ACTIONS(583),
    [aux_sym_string_replace_expression_token1] = ACTIONS(583),
    [aux_sym_exists_func_token1] = ACTIONS(583),
    [aux_sym_aggregate_token1] = ACTIONS(583),
    [aux_sym_aggregate_token2] = ACTIONS(583),
    [aux_sym_aggregate_token3] = ACTIONS(583),
    [aux_sym_aggregate_token4] = ACTIONS(583),
    [aux_sym_aggregate_token5] = ACTIONS(583),
    [aux_sym_aggregate_token6] = ACTIONS(583),
    [anon_sym_GROUP_CONCAT] = ACTIONS(583),
    [anon_sym_COLON] = ACTIONS(581),
  },
  [195] = {
    [sym_pn_prefix] = ACTIONS(587),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(585),
    [anon_sym_RBRACE] = ACTIONS(585),
    [aux_sym_having_clause_token1] = ACTIONS(587),
    [aux_sym_order_clause_token1] = ACTIONS(587),
    [aux_sym_order_condition_token1] = ACTIONS(587),
    [aux_sym_order_condition_token2] = ACTIONS(587),
    [aux_sym_limit_clause_token1] = ACTIONS(587),
    [aux_sym_offset_clause_token1] = ACTIONS(587),
    [aux_sym_values_clause_token1] = ACTIONS(587),
    [sym_var] = ACTIONS(585),
    [anon_sym_LT] = ACTIONS(585),
    [aux_sym_binary_expression_token2] = ACTIONS(587),
    [aux_sym_build_in_function_token1] = ACTIONS(587),
    [aux_sym_build_in_function_token2] = ACTIONS(587),
    [aux_sym_build_in_function_token3] = ACTIONS(587),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(587),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(587),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(587),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(587),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(587),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(587),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(587),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(587),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(587),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(587),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(587),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(587),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(587),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(587),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(587),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(587),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(587),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(587),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(587),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(587),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(587),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(587),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(587),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(587),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(587),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(587),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(587),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(587),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(587),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(587),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(587),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(587),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(587),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(587),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(587),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(587),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(587),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(587),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(587),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(587),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(587),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(587),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(587),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(587),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(587),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(587),
    [aux_sym_regex_expression_token1] = ACTIONS(587),
    [aux_sym_substring_expression_token1] = ACTIONS(587),
    [aux_sym_string_replace_expression_token1] = ACTIONS(587),
    [aux_sym_exists_func_token1] = ACTIONS(587),
    [aux_sym_aggregate_token1] = ACTIONS(587),
    [aux_sym_aggregate_token2] = ACTIONS(587),
    [aux_sym_aggregate_token3] = ACTIONS(587),
    [aux_sym_aggregate_token4] = ACTIONS(587),
    [aux_sym_aggregate_token5] = ACTIONS(587),
    [aux_sym_aggregate_token6] = ACTIONS(587),
    [anon_sym_GROUP_CONCAT] = ACTIONS(587),
    [anon_sym_COLON] = ACTIONS(585),
  },
  [196] = {
    [sym_pn_prefix] = ACTIONS(591),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(589),
    [anon_sym_RBRACE] = ACTIONS(589),
    [aux_sym_having_clause_token1] = ACTIONS(591),
    [aux_sym_order_clause_token1] = ACTIONS(591),
    [aux_sym_order_condition_token1] = ACTIONS(591),
    [aux_sym_order_condition_token2] = ACTIONS(591),
    [aux_sym_limit_clause_token1] = ACTIONS(591),
    [aux_sym_offset_clause_token1] = ACTIONS(591),
    [aux_sym_values_clause_token1] = ACTIONS(591),
    [sym_var] = ACTIONS(589),
    [anon_sym_LT] = ACTIONS(589),
    [aux_sym_binary_expression_token2] = ACTIONS(591),
    [aux_sym_build_in_function_token1] = ACTIONS(591),
    [aux_sym_build_in_function_token2] = ACTIONS(591),
    [aux_sym_build_in_function_token3] = ACTIONS(591),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(591),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(591),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(591),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(591),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(591),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(591),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(591),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(591),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(591),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(591),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(591),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(591),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(591),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(591),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(591),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(591),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(591),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(591),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(591),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(591),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(591),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(591),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(591),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(591),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(591),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(591),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(591),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(591),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(591),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(591),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(591),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(591),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(591),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(591),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(591),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(591),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(591),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(591),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(591),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(591),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(591),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(591),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(591),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(591),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(591),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(591),
    [aux_sym_regex_expression_token1] = ACTIONS(591),
    [aux_sym_substring_expression_token1] = ACTIONS(591),
    [aux_sym_string_replace_expression_token1] = ACTIONS(591),
    [aux_sym_exists_func_token1] = ACTIONS(591),
    [aux_sym_aggregate_token1] = ACTIONS(591),
    [aux_sym_aggregate_token2] = ACTIONS(591),
    [aux_sym_aggregate_token3] = ACTIONS(591),
    [aux_sym_aggregate_token4] = ACTIONS(591),
    [aux_sym_aggregate_token5] = ACTIONS(591),
    [aux_sym_aggregate_token6] = ACTIONS(591),
    [anon_sym_GROUP_CONCAT] = ACTIONS(591),
    [anon_sym_COLON] = ACTIONS(589),
  },
  [197] = {
    [sym_pn_prefix] = ACTIONS(595),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(593),
    [anon_sym_RBRACE] = ACTIONS(593),
    [aux_sym_having_clause_token1] = ACTIONS(595),
    [aux_sym_order_clause_token1] = ACTIONS(595),
    [aux_sym_order_condition_token1] = ACTIONS(595),
    [aux_sym_order_condition_token2] = ACTIONS(595),
    [aux_sym_limit_clause_token1] = ACTIONS(595),
    [aux_sym_offset_clause_token1] = ACTIONS(595),
    [aux_sym_values_clause_token1] = ACTIONS(595),
    [sym_var] = ACTIONS(593),
    [anon_sym_LT] = ACTIONS(593),
    [aux_sym_binary_expression_token2] = ACTIONS(595),
    [aux_sym_build_in_function_token1] = ACTIONS(595),
    [aux_sym_build_in_function_token2] = ACTIONS(595),
    [aux_sym_build_in_function_token3] = ACTIONS(595),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(595),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(595),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(595),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(595),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(595),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(595),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(595),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(595),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(595),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(595),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(595),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(595),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(595),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(595),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(595),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(595),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(595),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(595),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(595),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(595),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(595),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(595),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(595),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(595),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(595),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(595),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(595),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(595),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(595),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(595),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(595),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(595),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(595),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(595),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(595),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(595),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(595),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(595),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(595),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(595),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(595),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(595),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(595),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(595),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(595),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(595),
    [aux_sym_regex_expression_token1] = ACTIONS(595),
    [aux_sym_substring_expression_token1] = ACTIONS(595),
    [aux_sym_string_replace_expression_token1] = ACTIONS(595),
    [aux_sym_exists_func_token1] = ACTIONS(595),
    [aux_sym_aggregate_token1] = ACTIONS(595),
    [aux_sym_aggregate_token2] = ACTIONS(595),
    [aux_sym_aggregate_token3] = ACTIONS(595),
    [aux_sym_aggregate_token4] = ACTIONS(595),
    [aux_sym_aggregate_token5] = ACTIONS(595),
    [aux_sym_aggregate_token6] = ACTIONS(595),
    [anon_sym_GROUP_CONCAT] = ACTIONS(595),
    [anon_sym_COLON] = ACTIONS(593),
  },
  [198] = {
    [sym_pn_prefix] = ACTIONS(599),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(597),
    [anon_sym_RBRACE] = ACTIONS(597),
    [aux_sym_having_clause_token1] = ACTIONS(599),
    [aux_sym_order_clause_token1] = ACTIONS(599),
    [aux_sym_order_condition_token1] = ACTIONS(599),
    [aux_sym_order_condition_token2] = ACTIONS(599),
    [aux_sym_limit_clause_token1] = ACTIONS(599),
    [aux_sym_offset_clause_token1] = ACTIONS(599),
    [aux_sym_values_clause_token1] = ACTIONS(599),
    [sym_var] = ACTIONS(597),
    [anon_sym_LT] = ACTIONS(597),
    [aux_sym_binary_expression_token2] = ACTIONS(599),
    [aux_sym_build_in_function_token1] = ACTIONS(599),
    [aux_sym_build_in_function_token2] = ACTIONS(599),
    [aux_sym_build_in_function_token3] = ACTIONS(599),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(599),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(599),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(599),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(599),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(599),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(599),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(599),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(599),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(599),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(599),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(599),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(599),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(599),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(599),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(599),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(599),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(599),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(599),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(599),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(599),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(599),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(599),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(599),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(599),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(599),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(599),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(599),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(599),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(599),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(599),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(599),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(599),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(599),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(599),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(599),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(599),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(599),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(599),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(599),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(599),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(599),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(599),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(599),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(599),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(599),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(599),
    [aux_sym_regex_expression_token1] = ACTIONS(599),
    [aux_sym_substring_expression_token1] = ACTIONS(599),
    [aux_sym_string_replace_expression_token1] = ACTIONS(599),
    [aux_sym_exists_func_token1] = ACTIONS(599),
    [aux_sym_aggregate_token1] = ACTIONS(599),
    [aux_sym_aggregate_token2] = ACTIONS(599),
    [aux_sym_aggregate_token3] = ACTIONS(599),
    [aux_sym_aggregate_token4] = ACTIONS(599),
    [aux_sym_aggregate_token5] = ACTIONS(599),
    [aux_sym_aggregate_token6] = ACTIONS(599),
    [anon_sym_GROUP_CONCAT] = ACTIONS(599),
    [anon_sym_COLON] = ACTIONS(597),
  },
  [199] = {
    [sym_pn_prefix] = ACTIONS(603),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(601),
    [anon_sym_RBRACE] = ACTIONS(601),
    [aux_sym_having_clause_token1] = ACTIONS(603),
    [aux_sym_order_clause_token1] = ACTIONS(603),
    [aux_sym_order_condition_token1] = ACTIONS(603),
    [aux_sym_order_condition_token2] = ACTIONS(603),
    [aux_sym_limit_clause_token1] = ACTIONS(603),
    [aux_sym_offset_clause_token1] = ACTIONS(603),
    [aux_sym_values_clause_token1] = ACTIONS(603),
    [sym_var] = ACTIONS(601),
    [anon_sym_LT] = ACTIONS(601),
    [aux_sym_binary_expression_token2] = ACTIONS(603),
    [aux_sym_build_in_function_token1] = ACTIONS(603),
    [aux_sym_build_in_function_token2] = ACTIONS(603),
    [aux_sym_build_in_function_token3] = ACTIONS(603),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(603),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(603),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(603),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(603),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(603),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(603),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(603),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(603),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(603),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(603),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(603),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(603),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(603),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(603),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(603),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(603),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(603),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(603),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(603),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(603),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(603),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(603),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(603),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(603),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(603),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(603),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(603),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(603),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(603),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(603),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(603),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(603),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(603),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(603),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(603),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(603),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(603),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(603),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(603),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(603),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(603),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(603),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(603),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(603),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(603),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(603),
    [aux_sym_regex_expression_token1] = ACTIONS(603),
    [aux_sym_substring_expression_token1] = ACTIONS(603),
    [aux_sym_string_replace_expression_token1] = ACTIONS(603),
    [aux_sym_exists_func_token1] = ACTIONS(603),
    [aux_sym_aggregate_token1] = ACTIONS(603),
    [aux_sym_aggregate_token2] = ACTIONS(603),
    [aux_sym_aggregate_token3] = ACTIONS(603),
    [aux_sym_aggregate_token4] = ACTIONS(603),
    [aux_sym_aggregate_token5] = ACTIONS(603),
    [aux_sym_aggregate_token6] = ACTIONS(603),
    [anon_sym_GROUP_CONCAT] = ACTIONS(603),
    [anon_sym_COLON] = ACTIONS(601),
  },
  [200] = {
    [sym_pn_prefix] = ACTIONS(405),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(403),
    [anon_sym_RBRACE] = ACTIONS(403),
    [aux_sym_having_clause_token1] = ACTIONS(405),
    [aux_sym_order_clause_token1] = ACTIONS(405),
    [aux_sym_order_condition_token1] = ACTIONS(405),
    [aux_sym_order_condition_token2] = ACTIONS(405),
    [aux_sym_limit_clause_token1] = ACTIONS(405),
    [aux_sym_offset_clause_token1] = ACTIONS(405),
    [aux_sym_values_clause_token1] = ACTIONS(405),
    [sym_var] = ACTIONS(403),
    [anon_sym_LT] = ACTIONS(403),
    [aux_sym_binary_expression_token2] = ACTIONS(405),
    [aux_sym_build_in_function_token1] = ACTIONS(405),
    [aux_sym_build_in_function_token2] = ACTIONS(405),
    [aux_sym_build_in_function_token3] = ACTIONS(405),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(405),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(405),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(405),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(405),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(405),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(405),
    [aux_sym_regex_expression_token1] = ACTIONS(405),
    [aux_sym_substring_expression_token1] = ACTIONS(405),
    [aux_sym_string_replace_expression_token1] = ACTIONS(405),
    [aux_sym_exists_func_token1] = ACTIONS(405),
    [aux_sym_aggregate_token1] = ACTIONS(405),
    [aux_sym_aggregate_token2] = ACTIONS(405),
    [aux_sym_aggregate_token3] = ACTIONS(405),
    [aux_sym_aggregate_token4] = ACTIONS(405),
    [aux_sym_aggregate_token5] = ACTIONS(405),
    [aux_sym_aggregate_token6] = ACTIONS(405),
    [anon_sym_GROUP_CONCAT] = ACTIONS(405),
    [anon_sym_COLON] = ACTIONS(403),
  },
  [201] = {
    [sym_pn_prefix] = ACTIONS(405),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(403),
    [anon_sym_RBRACE] = ACTIONS(403),
    [aux_sym_having_clause_token1] = ACTIONS(405),
    [aux_sym_order_clause_token1] = ACTIONS(405),
    [aux_sym_order_condition_token1] = ACTIONS(405),
    [aux_sym_order_condition_token2] = ACTIONS(405),
    [aux_sym_limit_clause_token1] = ACTIONS(405),
    [aux_sym_offset_clause_token1] = ACTIONS(405),
    [aux_sym_values_clause_token1] = ACTIONS(405),
    [sym_var] = ACTIONS(403),
    [anon_sym_LT] = ACTIONS(403),
    [aux_sym_binary_expression_token2] = ACTIONS(405),
    [aux_sym_build_in_function_token1] = ACTIONS(405),
    [aux_sym_build_in_function_token2] = ACTIONS(405),
    [aux_sym_build_in_function_token3] = ACTIONS(405),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(405),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(405),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(405),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(405),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(405),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(405),
    [aux_sym_regex_expression_token1] = ACTIONS(405),
    [aux_sym_substring_expression_token1] = ACTIONS(405),
    [aux_sym_string_replace_expression_token1] = ACTIONS(405),
    [aux_sym_exists_func_token1] = ACTIONS(405),
    [aux_sym_aggregate_token1] = ACTIONS(405),
    [aux_sym_aggregate_token2] = ACTIONS(405),
    [aux_sym_aggregate_token3] = ACTIONS(405),
    [aux_sym_aggregate_token4] = ACTIONS(405),
    [aux_sym_aggregate_token5] = ACTIONS(405),
    [aux_sym_aggregate_token6] = ACTIONS(405),
    [anon_sym_GROUP_CONCAT] = ACTIONS(405),
    [anon_sym_COLON] = ACTIONS(403),
  },
  [202] = {
    [sym_pn_prefix] = ACTIONS(405),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(403),
    [anon_sym_RBRACE] = ACTIONS(403),
    [aux_sym_having_clause_token1] = ACTIONS(405),
    [aux_sym_order_clause_token1] = ACTIONS(405),
    [aux_sym_order_condition_token1] = ACTIONS(405),
    [aux_sym_order_condition_token2] = ACTIONS(405),
    [aux_sym_limit_clause_token1] = ACTIONS(405),
    [aux_sym_offset_clause_token1] = ACTIONS(405),
    [aux_sym_values_clause_token1] = ACTIONS(405),
    [sym_var] = ACTIONS(403),
    [anon_sym_LT] = ACTIONS(403),
    [aux_sym_binary_expression_token2] = ACTIONS(405),
    [aux_sym_build_in_function_token1] = ACTIONS(405),
    [aux_sym_build_in_function_token2] = ACTIONS(405),
    [aux_sym_build_in_function_token3] = ACTIONS(405),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(405),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(405),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(405),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(405),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(405),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(405),
    [aux_sym_regex_expression_token1] = ACTIONS(405),
    [aux_sym_substring_expression_token1] = ACTIONS(405),
    [aux_sym_string_replace_expression_token1] = ACTIONS(405),
    [aux_sym_exists_func_token1] = ACTIONS(405),
    [aux_sym_aggregate_token1] = ACTIONS(405),
    [aux_sym_aggregate_token2] = ACTIONS(405),
    [aux_sym_aggregate_token3] = ACTIONS(405),
    [aux_sym_aggregate_token4] = ACTIONS(405),
    [aux_sym_aggregate_token5] = ACTIONS(405),
    [aux_sym_aggregate_token6] = ACTIONS(405),
    [anon_sym_GROUP_CONCAT] = ACTIONS(405),
    [anon_sym_COLON] = ACTIONS(403),
  },
  [203] = {
    [sym_pn_prefix] = ACTIONS(405),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(403),
    [anon_sym_RBRACE] = ACTIONS(403),
    [aux_sym_having_clause_token1] = ACTIONS(405),
    [aux_sym_order_clause_token1] = ACTIONS(405),
    [aux_sym_order_condition_token1] = ACTIONS(405),
    [aux_sym_order_condition_token2] = ACTIONS(405),
    [aux_sym_limit_clause_token1] = ACTIONS(405),
    [aux_sym_offset_clause_token1] = ACTIONS(405),
    [aux_sym_values_clause_token1] = ACTIONS(405),
    [sym_var] = ACTIONS(403),
    [anon_sym_LT] = ACTIONS(403),
    [aux_sym_binary_expression_token2] = ACTIONS(405),
    [aux_sym_build_in_function_token1] = ACTIONS(405),
    [aux_sym_build_in_function_token2] = ACTIONS(405),
    [aux_sym_build_in_function_token3] = ACTIONS(405),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(405),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(405),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(405),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(405),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(405),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(405),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(405),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(405),
    [aux_sym_regex_expression_token1] = ACTIONS(405),
    [aux_sym_substring_expression_token1] = ACTIONS(405),
    [aux_sym_string_replace_expression_token1] = ACTIONS(405),
    [aux_sym_exists_func_token1] = ACTIONS(405),
    [aux_sym_aggregate_token1] = ACTIONS(405),
    [aux_sym_aggregate_token2] = ACTIONS(405),
    [aux_sym_aggregate_token3] = ACTIONS(405),
    [aux_sym_aggregate_token4] = ACTIONS(405),
    [aux_sym_aggregate_token5] = ACTIONS(405),
    [aux_sym_aggregate_token6] = ACTIONS(405),
    [anon_sym_GROUP_CONCAT] = ACTIONS(405),
    [anon_sym_COLON] = ACTIONS(403),
  },
  [204] = {
    [sym_pn_prefix] = ACTIONS(409),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(407),
    [anon_sym_RBRACE] = ACTIONS(407),
    [aux_sym_having_clause_token1] = ACTIONS(409),
    [aux_sym_order_clause_token1] = ACTIONS(409),
    [aux_sym_order_condition_token1] = ACTIONS(409),
    [aux_sym_order_condition_token2] = ACTIONS(409),
    [aux_sym_limit_clause_token1] = ACTIONS(409),
    [aux_sym_offset_clause_token1] = ACTIONS(409),
    [aux_sym_values_clause_token1] = ACTIONS(409),
    [sym_var] = ACTIONS(407),
    [anon_sym_LT] = ACTIONS(407),
    [aux_sym_binary_expression_token2] = ACTIONS(409),
    [aux_sym_build_in_function_token1] = ACTIONS(409),
    [aux_sym_build_in_function_token2] = ACTIONS(409),
    [aux_sym_build_in_function_token3] = ACTIONS(409),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(409),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(409),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(409),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(409),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(409),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(409),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(409),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(409),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(409),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(409),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(409),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(409),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(409),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(409),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(409),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(409),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(409),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(409),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(409),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(409),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(409),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(409),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(409),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(409),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(409),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(409),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(409),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(409),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(409),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(409),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(409),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(409),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(409),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(409),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(409),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(409),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(409),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(409),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(409),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(409),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(409),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(409),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(409),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(409),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(409),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(409),
    [aux_sym_regex_expression_token1] = ACTIONS(409),
    [aux_sym_substring_expression_token1] = ACTIONS(409),
    [aux_sym_string_replace_expression_token1] = ACTIONS(409),
    [aux_sym_exists_func_token1] = ACTIONS(409),
    [aux_sym_aggregate_token1] = ACTIONS(409),
    [aux_sym_aggregate_token2] = ACTIONS(409),
    [aux_sym_aggregate_token3] = ACTIONS(409),
    [aux_sym_aggregate_token4] = ACTIONS(409),
    [aux_sym_aggregate_token5] = ACTIONS(409),
    [aux_sym_aggregate_token6] = ACTIONS(409),
    [anon_sym_GROUP_CONCAT] = ACTIONS(409),
    [anon_sym_COLON] = ACTIONS(407),
  },
  [205] = {
    [sym_pn_prefix] = ACTIONS(413),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(411),
    [anon_sym_RBRACE] = ACTIONS(411),
    [aux_sym_having_clause_token1] = ACTIONS(413),
    [aux_sym_order_clause_token1] = ACTIONS(413),
    [aux_sym_order_condition_token1] = ACTIONS(413),
    [aux_sym_order_condition_token2] = ACTIONS(413),
    [aux_sym_limit_clause_token1] = ACTIONS(413),
    [aux_sym_offset_clause_token1] = ACTIONS(413),
    [aux_sym_values_clause_token1] = ACTIONS(413),
    [sym_var] = ACTIONS(411),
    [anon_sym_LT] = ACTIONS(411),
    [aux_sym_binary_expression_token2] = ACTIONS(413),
    [aux_sym_build_in_function_token1] = ACTIONS(413),
    [aux_sym_build_in_function_token2] = ACTIONS(413),
    [aux_sym_build_in_function_token3] = ACTIONS(413),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(413),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(413),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(413),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(413),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(413),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(413),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(413),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(413),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(413),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(413),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(413),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(413),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(413),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(413),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(413),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(413),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(413),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(413),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(413),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(413),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(413),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(413),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(413),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(413),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(413),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(413),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(413),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(413),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(413),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(413),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(413),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(413),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(413),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(413),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(413),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(413),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(413),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(413),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(413),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(413),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(413),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(413),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(413),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(413),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(413),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(413),
    [aux_sym_regex_expression_token1] = ACTIONS(413),
    [aux_sym_substring_expression_token1] = ACTIONS(413),
    [aux_sym_string_replace_expression_token1] = ACTIONS(413),
    [aux_sym_exists_func_token1] = ACTIONS(413),
    [aux_sym_aggregate_token1] = ACTIONS(413),
    [aux_sym_aggregate_token2] = ACTIONS(413),
    [aux_sym_aggregate_token3] = ACTIONS(413),
    [aux_sym_aggregate_token4] = ACTIONS(413),
    [aux_sym_aggregate_token5] = ACTIONS(413),
    [aux_sym_aggregate_token6] = ACTIONS(413),
    [anon_sym_GROUP_CONCAT] = ACTIONS(413),
    [anon_sym_COLON] = ACTIONS(411),
  },
  [206] = {
    [sym_pn_prefix] = ACTIONS(417),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(415),
    [anon_sym_RBRACE] = ACTIONS(415),
    [aux_sym_having_clause_token1] = ACTIONS(417),
    [aux_sym_order_clause_token1] = ACTIONS(417),
    [aux_sym_order_condition_token1] = ACTIONS(417),
    [aux_sym_order_condition_token2] = ACTIONS(417),
    [aux_sym_limit_clause_token1] = ACTIONS(417),
    [aux_sym_offset_clause_token1] = ACTIONS(417),
    [aux_sym_values_clause_token1] = ACTIONS(417),
    [sym_var] = ACTIONS(415),
    [anon_sym_LT] = ACTIONS(415),
    [aux_sym_binary_expression_token2] = ACTIONS(417),
    [aux_sym_build_in_function_token1] = ACTIONS(417),
    [aux_sym_build_in_function_token2] = ACTIONS(417),
    [aux_sym_build_in_function_token3] = ACTIONS(417),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(417),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(417),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(417),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(417),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(417),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(417),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(417),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(417),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(417),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(417),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(417),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(417),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(417),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(417),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(417),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(417),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(417),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(417),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(417),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(417),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(417),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(417),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(417),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(417),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(417),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(417),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(417),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(417),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(417),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(417),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(417),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(417),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(417),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(417),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(417),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(417),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(417),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(417),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(417),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(417),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(417),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(417),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(417),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(417),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(417),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(417),
    [aux_sym_regex_expression_token1] = ACTIONS(417),
    [aux_sym_substring_expression_token1] = ACTIONS(417),
    [aux_sym_string_replace_expression_token1] = ACTIONS(417),
    [aux_sym_exists_func_token1] = ACTIONS(417),
    [aux_sym_aggregate_token1] = ACTIONS(417),
    [aux_sym_aggregate_token2] = ACTIONS(417),
    [aux_sym_aggregate_token3] = ACTIONS(417),
    [aux_sym_aggregate_token4] = ACTIONS(417),
    [aux_sym_aggregate_token5] = ACTIONS(417),
    [aux_sym_aggregate_token6] = ACTIONS(417),
    [anon_sym_GROUP_CONCAT] = ACTIONS(417),
    [anon_sym_COLON] = ACTIONS(415),
  },
  [207] = {
    [sym_pn_prefix] = ACTIONS(401),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(399),
    [anon_sym_RBRACE] = ACTIONS(399),
    [aux_sym_having_clause_token1] = ACTIONS(401),
    [aux_sym_order_clause_token1] = ACTIONS(401),
    [aux_sym_order_condition_token1] = ACTIONS(401),
    [aux_sym_order_condition_token2] = ACTIONS(401),
    [aux_sym_limit_clause_token1] = ACTIONS(401),
    [aux_sym_offset_clause_token1] = ACTIONS(401),
    [aux_sym_values_clause_token1] = ACTIONS(401),
    [sym_var] = ACTIONS(399),
    [anon_sym_LT] = ACTIONS(399),
    [aux_sym_binary_expression_token2] = ACTIONS(401),
    [aux_sym_build_in_function_token1] = ACTIONS(401),
    [aux_sym_build_in_function_token2] = ACTIONS(401),
    [aux_sym_build_in_function_token3] = ACTIONS(401),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(401),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(401),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(401),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(401),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(401),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(401),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(401),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(401),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(401),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(401),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(401),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(401),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(401),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(401),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(401),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(401),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(401),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(401),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(401),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(401),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(401),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(401),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(401),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(401),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(401),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(401),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(401),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(401),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(401),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(401),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(401),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(401),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(401),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(401),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(401),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(401),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(401),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(401),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(401),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(401),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(401),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(401),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(401),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(401),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(401),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(401),
    [aux_sym_regex_expression_token1] = ACTIONS(401),
    [aux_sym_substring_expression_token1] = ACTIONS(401),
    [aux_sym_string_replace_expression_token1] = ACTIONS(401),
    [aux_sym_exists_func_token1] = ACTIONS(401),
    [aux_sym_aggregate_token1] = ACTIONS(401),
    [aux_sym_aggregate_token2] = ACTIONS(401),
    [aux_sym_aggregate_token3] = ACTIONS(401),
    [aux_sym_aggregate_token4] = ACTIONS(401),
    [aux_sym_aggregate_token5] = ACTIONS(401),
    [aux_sym_aggregate_token6] = ACTIONS(401),
    [anon_sym_GROUP_CONCAT] = ACTIONS(401),
    [anon_sym_COLON] = ACTIONS(399),
  },
  [208] = {
    [sym_pn_prefix] = ACTIONS(575),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(573),
    [anon_sym_RBRACE] = ACTIONS(573),
    [aux_sym_having_clause_token1] = ACTIONS(575),
    [aux_sym_order_clause_token1] = ACTIONS(575),
    [aux_sym_order_condition_token1] = ACTIONS(575),
    [aux_sym_order_condition_token2] = ACTIONS(575),
    [aux_sym_limit_clause_token1] = ACTIONS(575),
    [aux_sym_offset_clause_token1] = ACTIONS(575),
    [aux_sym_values_clause_token1] = ACTIONS(575),
    [sym_var] = ACTIONS(573),
    [anon_sym_LT] = ACTIONS(573),
    [aux_sym_binary_expression_token2] = ACTIONS(575),
    [aux_sym_build_in_function_token1] = ACTIONS(575),
    [aux_sym_build_in_function_token2] = ACTIONS(575),
    [aux_sym_build_in_function_token3] = ACTIONS(575),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(575),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(575),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(575),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(575),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(575),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(575),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(575),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(575),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(575),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(575),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(575),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(575),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(575),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(575),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(575),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(575),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(575),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(575),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(575),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(575),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(575),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(575),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(575),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(575),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(575),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(575),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(575),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(575),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(575),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(575),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(575),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(575),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(575),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(575),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(575),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(575),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(575),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(575),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(575),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(575),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(575),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(575),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(575),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(575),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(575),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(575),
    [aux_sym_regex_expression_token1] = ACTIONS(575),
    [aux_sym_substring_expression_token1] = ACTIONS(575),
    [aux_sym_string_replace_expression_token1] = ACTIONS(575),
    [aux_sym_exists_func_token1] = ACTIONS(575),
    [aux_sym_aggregate_token1] = ACTIONS(575),
    [aux_sym_aggregate_token2] = ACTIONS(575),
    [aux_sym_aggregate_token3] = ACTIONS(575),
    [aux_sym_aggregate_token4] = ACTIONS(575),
    [aux_sym_aggregate_token5] = ACTIONS(575),
    [aux_sym_aggregate_token6] = ACTIONS(575),
    [anon_sym_GROUP_CONCAT] = ACTIONS(575),
    [anon_sym_COLON] = ACTIONS(573),
  },
  [209] = {
    [sym_pn_prefix] = ACTIONS(742),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(740),
    [anon_sym_RBRACE] = ACTIONS(740),
    [aux_sym_having_clause_token1] = ACTIONS(742),
    [aux_sym_order_clause_token1] = ACTIONS(742),
    [aux_sym_limit_clause_token1] = ACTIONS(742),
    [aux_sym_offset_clause_token1] = ACTIONS(742),
    [aux_sym_values_clause_token1] = ACTIONS(742),
    [sym_var] = ACTIONS(740),
    [anon_sym_LT] = ACTIONS(740),
    [aux_sym_binary_expression_token2] = ACTIONS(742),
    [aux_sym_build_in_function_token1] = ACTIONS(742),
    [aux_sym_build_in_function_token2] = ACTIONS(742),
    [aux_sym_build_in_function_token3] = ACTIONS(742),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(742),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(742),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(742),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(742),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(742),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(742),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(742),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(742),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(742),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(742),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(742),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(742),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(742),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(742),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(742),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(742),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(742),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(742),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(742),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(742),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(742),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(742),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(742),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(742),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(742),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(742),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(742),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(742),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(742),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(742),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(742),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(742),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(742),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(742),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(742),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(742),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(742),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(742),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(742),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(742),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(742),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(742),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(742),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(742),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(742),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(742),
    [aux_sym_regex_expression_token1] = ACTIONS(742),
    [aux_sym_substring_expression_token1] = ACTIONS(742),
    [aux_sym_string_replace_expression_token1] = ACTIONS(742),
    [aux_sym_exists_func_token1] = ACTIONS(742),
    [aux_sym_aggregate_token1] = ACTIONS(742),
    [aux_sym_aggregate_token2] = ACTIONS(742),
    [aux_sym_aggregate_token3] = ACTIONS(742),
    [aux_sym_aggregate_token4] = ACTIONS(742),
    [aux_sym_aggregate_token5] = ACTIONS(742),
    [aux_sym_aggregate_token6] = ACTIONS(742),
    [anon_sym_GROUP_CONCAT] = ACTIONS(742),
    [anon_sym_COLON] = ACTIONS(740),
  },
  [210] = {
    [sym_pn_prefix] = ACTIONS(726),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(724),
    [anon_sym_RBRACE] = ACTIONS(724),
    [aux_sym_having_clause_token1] = ACTIONS(726),
    [aux_sym_order_clause_token1] = ACTIONS(726),
    [aux_sym_limit_clause_token1] = ACTIONS(726),
    [aux_sym_offset_clause_token1] = ACTIONS(726),
    [aux_sym_values_clause_token1] = ACTIONS(726),
    [sym_var] = ACTIONS(724),
    [anon_sym_LT] = ACTIONS(724),
    [aux_sym_binary_expression_token2] = ACTIONS(726),
    [aux_sym_build_in_function_token1] = ACTIONS(726),
    [aux_sym_build_in_function_token2] = ACTIONS(726),
    [aux_sym_build_in_function_token3] = ACTIONS(726),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(726),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(726),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(726),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(726),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(726),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(726),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(726),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(726),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(726),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(726),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(726),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(726),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(726),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(726),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(726),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(726),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(726),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(726),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(726),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(726),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(726),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(726),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(726),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(726),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(726),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(726),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(726),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(726),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(726),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(726),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(726),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(726),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(726),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(726),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(726),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(726),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(726),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(726),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(726),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(726),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(726),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(726),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(726),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(726),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(726),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(726),
    [aux_sym_regex_expression_token1] = ACTIONS(726),
    [aux_sym_substring_expression_token1] = ACTIONS(726),
    [aux_sym_string_replace_expression_token1] = ACTIONS(726),
    [aux_sym_exists_func_token1] = ACTIONS(726),
    [aux_sym_aggregate_token1] = ACTIONS(726),
    [aux_sym_aggregate_token2] = ACTIONS(726),
    [aux_sym_aggregate_token3] = ACTIONS(726),
    [aux_sym_aggregate_token4] = ACTIONS(726),
    [aux_sym_aggregate_token5] = ACTIONS(726),
    [aux_sym_aggregate_token6] = ACTIONS(726),
    [anon_sym_GROUP_CONCAT] = ACTIONS(726),
    [anon_sym_COLON] = ACTIONS(724),
  },
  [211] = {
    [sym_pn_prefix] = ACTIONS(734),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(732),
    [anon_sym_RBRACE] = ACTIONS(732),
    [aux_sym_order_condition_token1] = ACTIONS(734),
    [aux_sym_order_condition_token2] = ACTIONS(734),
    [aux_sym_limit_clause_token1] = ACTIONS(734),
    [aux_sym_offset_clause_token1] = ACTIONS(734),
    [aux_sym_values_clause_token1] = ACTIONS(734),
    [sym_var] = ACTIONS(732),
    [anon_sym_LT] = ACTIONS(732),
    [aux_sym_binary_expression_token2] = ACTIONS(734),
    [aux_sym_build_in_function_token1] = ACTIONS(734),
    [aux_sym_build_in_function_token2] = ACTIONS(734),
    [aux_sym_build_in_function_token3] = ACTIONS(734),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(734),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(734),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(734),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(734),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(734),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(734),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(734),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(734),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(734),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(734),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(734),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(734),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(734),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(734),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(734),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(734),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(734),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(734),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(734),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(734),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(734),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(734),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(734),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(734),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(734),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(734),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(734),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(734),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(734),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(734),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(734),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(734),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(734),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(734),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(734),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(734),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(734),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(734),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(734),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(734),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(734),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(734),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(734),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(734),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(734),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(734),
    [aux_sym_regex_expression_token1] = ACTIONS(734),
    [aux_sym_substring_expression_token1] = ACTIONS(734),
    [aux_sym_string_replace_expression_token1] = ACTIONS(734),
    [aux_sym_exists_func_token1] = ACTIONS(734),
    [aux_sym_aggregate_token1] = ACTIONS(734),
    [aux_sym_aggregate_token2] = ACTIONS(734),
    [aux_sym_aggregate_token3] = ACTIONS(734),
    [aux_sym_aggregate_token4] = ACTIONS(734),
    [aux_sym_aggregate_token5] = ACTIONS(734),
    [aux_sym_aggregate_token6] = ACTIONS(734),
    [anon_sym_GROUP_CONCAT] = ACTIONS(734),
    [anon_sym_COLON] = ACTIONS(732),
  },
  [212] = {
    [sym_pn_prefix] = ACTIONS(730),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(728),
    [anon_sym_RBRACE] = ACTIONS(728),
    [aux_sym_having_clause_token1] = ACTIONS(730),
    [aux_sym_order_clause_token1] = ACTIONS(730),
    [aux_sym_limit_clause_token1] = ACTIONS(730),
    [aux_sym_offset_clause_token1] = ACTIONS(730),
    [aux_sym_values_clause_token1] = ACTIONS(730),
    [sym_var] = ACTIONS(728),
    [anon_sym_LT] = ACTIONS(728),
    [aux_sym_binary_expression_token2] = ACTIONS(730),
    [aux_sym_build_in_function_token1] = ACTIONS(730),
    [aux_sym_build_in_function_token2] = ACTIONS(730),
    [aux_sym_build_in_function_token3] = ACTIONS(730),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(730),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(730),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(730),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(730),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(730),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(730),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(730),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(730),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(730),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(730),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(730),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(730),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(730),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(730),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(730),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(730),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(730),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(730),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(730),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(730),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(730),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(730),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(730),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(730),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(730),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(730),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(730),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(730),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(730),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(730),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(730),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(730),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(730),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(730),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(730),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(730),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(730),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(730),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(730),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(730),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(730),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(730),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(730),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(730),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(730),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(730),
    [aux_sym_regex_expression_token1] = ACTIONS(730),
    [aux_sym_substring_expression_token1] = ACTIONS(730),
    [aux_sym_string_replace_expression_token1] = ACTIONS(730),
    [aux_sym_exists_func_token1] = ACTIONS(730),
    [aux_sym_aggregate_token1] = ACTIONS(730),
    [aux_sym_aggregate_token2] = ACTIONS(730),
    [aux_sym_aggregate_token3] = ACTIONS(730),
    [aux_sym_aggregate_token4] = ACTIONS(730),
    [aux_sym_aggregate_token5] = ACTIONS(730),
    [aux_sym_aggregate_token6] = ACTIONS(730),
    [anon_sym_GROUP_CONCAT] = ACTIONS(730),
    [anon_sym_COLON] = ACTIONS(728),
  },
  [213] = {
    [sym_pn_prefix] = ACTIONS(722),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(720),
    [anon_sym_RBRACE] = ACTIONS(720),
    [aux_sym_having_clause_token1] = ACTIONS(722),
    [aux_sym_order_clause_token1] = ACTIONS(722),
    [aux_sym_limit_clause_token1] = ACTIONS(722),
    [aux_sym_offset_clause_token1] = ACTIONS(722),
    [aux_sym_values_clause_token1] = ACTIONS(722),
    [sym_var] = ACTIONS(720),
    [anon_sym_LT] = ACTIONS(720),
    [aux_sym_binary_expression_token2] = ACTIONS(722),
    [aux_sym_build_in_function_token1] = ACTIONS(722),
    [aux_sym_build_in_function_token2] = ACTIONS(722),
    [aux_sym_build_in_function_token3] = ACTIONS(722),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(722),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(722),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(722),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(722),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(722),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(722),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(722),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(722),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(722),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(722),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(722),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(722),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(722),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(722),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(722),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(722),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(722),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(722),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(722),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(722),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(722),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(722),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(722),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(722),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(722),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(722),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(722),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(722),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(722),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(722),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(722),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(722),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(722),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(722),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(722),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(722),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(722),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(722),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(722),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(722),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(722),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(722),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(722),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(722),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(722),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(722),
    [aux_sym_regex_expression_token1] = ACTIONS(722),
    [aux_sym_substring_expression_token1] = ACTIONS(722),
    [aux_sym_string_replace_expression_token1] = ACTIONS(722),
    [aux_sym_exists_func_token1] = ACTIONS(722),
    [aux_sym_aggregate_token1] = ACTIONS(722),
    [aux_sym_aggregate_token2] = ACTIONS(722),
    [aux_sym_aggregate_token3] = ACTIONS(722),
    [aux_sym_aggregate_token4] = ACTIONS(722),
    [aux_sym_aggregate_token5] = ACTIONS(722),
    [aux_sym_aggregate_token6] = ACTIONS(722),
    [anon_sym_GROUP_CONCAT] = ACTIONS(722),
    [anon_sym_COLON] = ACTIONS(720),
  },
  [214] = {
    [sym_pn_prefix] = ACTIONS(738),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(736),
    [anon_sym_RBRACE] = ACTIONS(736),
    [aux_sym_order_condition_token1] = ACTIONS(738),
    [aux_sym_order_condition_token2] = ACTIONS(738),
    [aux_sym_limit_clause_token1] = ACTIONS(738),
    [aux_sym_offset_clause_token1] = ACTIONS(738),
    [aux_sym_values_clause_token1] = ACTIONS(738),
    [sym_var] = ACTIONS(736),
    [anon_sym_LT] = ACTIONS(736),
    [aux_sym_binary_expression_token2] = ACTIONS(738),
    [aux_sym_build_in_function_token1] = ACTIONS(738),
    [aux_sym_build_in_function_token2] = ACTIONS(738),
    [aux_sym_build_in_function_token3] = ACTIONS(738),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(738),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(738),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(738),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(738),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(738),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(738),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(738),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(738),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(738),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(738),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(738),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(738),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(738),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(738),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(738),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(738),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(738),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(738),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(738),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(738),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(738),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(738),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(738),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(738),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(738),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(738),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(738),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(738),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(738),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(738),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(738),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(738),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(738),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(738),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(738),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(738),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(738),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(738),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(738),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(738),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(738),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(738),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(738),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(738),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(738),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(738),
    [aux_sym_regex_expression_token1] = ACTIONS(738),
    [aux_sym_substring_expression_token1] = ACTIONS(738),
    [aux_sym_string_replace_expression_token1] = ACTIONS(738),
    [aux_sym_exists_func_token1] = ACTIONS(738),
    [aux_sym_aggregate_token1] = ACTIONS(738),
    [aux_sym_aggregate_token2] = ACTIONS(738),
    [aux_sym_aggregate_token3] = ACTIONS(738),
    [aux_sym_aggregate_token4] = ACTIONS(738),
    [aux_sym_aggregate_token5] = ACTIONS(738),
    [aux_sym_aggregate_token6] = ACTIONS(738),
    [anon_sym_GROUP_CONCAT] = ACTIONS(738),
    [anon_sym_COLON] = ACTIONS(736),
  },
  [215] = {
    [sym_pn_prefix] = ACTIONS(746),
    [sym_comment] = ACTIONS(3),
    [anon_sym_LPAREN] = ACTIONS(744),
    [anon_sym_RBRACE] = ACTIONS(744),
    [aux_sym_order_clause_token1] = ACTIONS(746),
    [aux_sym_limit_clause_token1] = ACTIONS(746),
    [aux_sym_offset_clause_token1] = ACTIONS(746),
    [aux_sym_values_clause_token1] = ACTIONS(746),
    [anon_sym_LT] = ACTIONS(744),
    [aux_sym_binary_expression_token2] = ACTIONS(746),
    [aux_sym_build_in_function_token1] = ACTIONS(746),
    [aux_sym_build_in_function_token2] = ACTIONS(746),
    [aux_sym_build_in_function_token3] = ACTIONS(746),
    [aux_sym__nullary_build_in_function_token1] = ACTIONS(746),
    [aux_sym__nullary_build_in_function_token2] = ACTIONS(746),
    [aux_sym__nullary_build_in_function_token3] = ACTIONS(746),
    [aux_sym__nullary_build_in_function_token4] = ACTIONS(746),
    [aux_sym__unary_build_in_function_token1] = ACTIONS(746),
    [aux_sym__unary_build_in_function_token2] = ACTIONS(746),
    [aux_sym__unary_build_in_function_token3] = ACTIONS(746),
    [aux_sym__unary_build_in_function_token4] = ACTIONS(746),
    [aux_sym__unary_build_in_function_token5] = ACTIONS(746),
    [aux_sym__unary_build_in_function_token6] = ACTIONS(746),
    [aux_sym__unary_build_in_function_token7] = ACTIONS(746),
    [aux_sym__unary_build_in_function_token8] = ACTIONS(746),
    [aux_sym__unary_build_in_function_token9] = ACTIONS(746),
    [aux_sym__unary_build_in_function_token10] = ACTIONS(746),
    [aux_sym__unary_build_in_function_token11] = ACTIONS(746),
    [aux_sym__unary_build_in_function_token12] = ACTIONS(746),
    [aux_sym__unary_build_in_function_token13] = ACTIONS(746),
    [aux_sym__unary_build_in_function_token14] = ACTIONS(746),
    [aux_sym__unary_build_in_function_token15] = ACTIONS(746),
    [aux_sym__unary_build_in_function_token16] = ACTIONS(746),
    [aux_sym__unary_build_in_function_token17] = ACTIONS(746),
    [aux_sym__unary_build_in_function_token18] = ACTIONS(746),
    [aux_sym__unary_build_in_function_token19] = ACTIONS(746),
    [aux_sym__unary_build_in_function_token20] = ACTIONS(746),
    [aux_sym__unary_build_in_function_token21] = ACTIONS(746),
    [aux_sym__unary_build_in_function_token22] = ACTIONS(746),
    [aux_sym__unary_build_in_function_token23] = ACTIONS(746),
    [aux_sym__unary_build_in_function_token24] = ACTIONS(746),
    [aux_sym__unary_build_in_function_token25] = ACTIONS(746),
    [aux_sym__unary_build_in_function_token26] = ACTIONS(746),
    [aux_sym__unary_build_in_function_token27] = ACTIONS(746),
    [aux_sym__unary_build_in_function_token28] = ACTIONS(746),
    [aux_sym__unary_build_in_function_token29] = ACTIONS(746),
    [aux_sym__unary_build_in_function_token30] = ACTIONS(746),
    [aux_sym__unary_build_in_function_token31] = ACTIONS(746),
    [aux_sym__binary_build_in_function_token1] = ACTIONS(746),
    [aux_sym__binary_build_in_function_token2] = ACTIONS(746),
    [aux_sym__binary_build_in_function_token3] = ACTIONS(746),
    [aux_sym__binary_build_in_function_token4] = ACTIONS(746),
    [aux_sym__binary_build_in_function_token5] = ACTIONS(746),
    [aux_sym__binary_build_in_function_token6] = ACTIONS(746),
    [aux_sym__binary_build_in_function_token7] = ACTIONS(746),
    [aux_sym__binary_build_in_function_token8] = ACTIONS(746),
    [aux_sym__binary_build_in_function_token9] = ACTIONS(746),
    [aux_sym__variadic_build_in_function_token1] = ACTIONS(746),
    [aux_sym__variadic_build_in_function_token2] = ACTIONS(746),
    [aux_sym_regex_expression_token1] = ACTIONS(746),
    [aux_sym_substring_expression_token1] = ACTIONS(746),
    [aux_sym_string_replace_expression_token1] = ACTIONS(746),
    [aux_sym_exists_func_token1] = ACTIONS(746),
    [aux_sym_aggregate_token1] = ACTIONS(746),
    [aux_sym_aggregate_token2] = ACTIONS(746),
    [aux_sym_aggregate_token3] = ACTIONS(746),
    [aux_sym_aggregate_token4] = ACTIONS(746),
    [aux_sym_aggregate_token5] = ACTIONS(746),
    [aux_sym_aggregate_token6] = ACTIONS(746),
    [anon_sym_GROUP_CONCAT] = ACTIONS(746),
    [anon_sym_COLON] = ACTIONS(744),
  },
};

static const uint16_t ts_small_parse_table[] = {
  [0] = 36,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(780), 1,
      sym_pn_prefix,
    ACTIONS(782), 1,
      aux_sym_select_clause_token1,
    ACTIONS(784), 1,
      anon_sym_LPAREN,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(788), 1,
      anon_sym_RBRACE,
    ACTIONS(790), 1,
      aux_sym_values_clause_token1,
    ACTIONS(792), 1,
      aux_sym_graph_or_default_token2,
    ACTIONS(794), 1,
      aux_sym_optional_graph_pattern_token1,
    ACTIONS(796), 1,
      aux_sym_service_graph_pattern_token1,
    ACTIONS(798), 1,
      aux_sym_bind_token1,
    ACTIONS(800), 1,
      aux_sym_minus_graph_pattern_token1,
    ACTIONS(802), 1,
      aux_sym_filter_token1,
    ACTIONS(804), 1,
      anon_sym_LBRACK,
    ACTIONS(808), 1,
      anon_sym_LT,
    ACTIONS(812), 1,
      anon_sym_COLON,
    ACTIONS(814), 1,
      anon_sym__COLON,
    ACTIONS(818), 1,
      anon_sym_SQUOTE,
    ACTIONS(820), 1,
      anon_sym_DQUOTE,
    ACTIONS(822), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(824), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(305), 1,
      sym_group_graph_pattern,
    STATE(497), 1,
      sym_triples_block,
    STATE(498), 1,
      aux_sym_group_graph_pattern_repeat1,
    STATE(708), 1,
      sym_triples_same_subject_path,
    STATE(729), 1,
      sym_string,
    STATE(736), 1,
      sym_namespace,
    STATE(876), 1,
      sym_select_clause,
    STATE(987), 1,
      sym_sub_select,
    ACTIONS(810), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(816), 2,
      sym_integer,
      sym_decimal,
    STATE(304), 3,
      sym__triples_node_path,
      sym_blank_node_property_list_path,
      sym_collection_path,
    ACTIONS(806), 4,
      sym_var,
      sym_double,
      sym_nil,
      sym_anon,
    STATE(417), 4,
      sym__string_literal1,
      sym__string_literal2,
      sym__string_literal_long1,
      sym__string_literal_long2,
    STATE(223), 9,
      sym__graph_pattern_not_triples,
      sym_optional_graph_pattern,
      sym_graph_graph_pattern,
      sym_service_graph_pattern,
      sym_bind,
      sym_inline_data,
      sym_minus_graph_pattern,
      sym_group_or_union_graph_pattern,
      sym_filter,
    STATE(493), 10,
      sym__var_or_term,
      sym__graph_term,
      sym_rdf_literal,
      sym__numeric_literal,
      sym_boolean_literal,
      sym__iri,
      sym_prefixed_name,
      sym__blank_node,
      sym_iri_reference,
      sym_blank_node_label,
  [136] = 36,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(780), 1,
      sym_pn_prefix,
    ACTIONS(782), 1,
      aux_sym_select_clause_token1,
    ACTIONS(784), 1,
      anon_sym_LPAREN,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(790), 1,
      aux_sym_values_clause_token1,
    ACTIONS(792), 1,
      aux_sym_graph_or_default_token2,
    ACTIONS(794), 1,
      aux_sym_optional_graph_pattern_token1,
    ACTIONS(796), 1,
      aux_sym_service_graph_pattern_token1,
    ACTIONS(798), 1,
      aux_sym_bind_token1,
    ACTIONS(800), 1,
      aux_sym_minus_graph_pattern_token1,
    ACTIONS(802), 1,
      aux_sym_filter_token1,
    ACTIONS(804), 1,
      anon_sym_LBRACK,
    ACTIONS(808), 1,
      anon_sym_LT,
    ACTIONS(812), 1,
      anon_sym_COLON,
    ACTIONS(814), 1,
      anon_sym__COLON,
    ACTIONS(818), 1,
      anon_sym_SQUOTE,
    ACTIONS(820), 1,
      anon_sym_DQUOTE,
    ACTIONS(822), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(824), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(826), 1,
      anon_sym_RBRACE,
    STATE(305), 1,
      sym_group_graph_pattern,
    STATE(505), 1,
      aux_sym_group_graph_pattern_repeat1,
    STATE(520), 1,
      sym_triples_block,
    STATE(708), 1,
      sym_triples_same_subject_path,
    STATE(729), 1,
      sym_string,
    STATE(736), 1,
      sym_namespace,
    STATE(876), 1,
      sym_select_clause,
    STATE(1042), 1,
      sym_sub_select,
    ACTIONS(810), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(816), 2,
      sym_integer,
      sym_decimal,
    STATE(304), 3,
      sym__triples_node_path,
      sym_blank_node_property_list_path,
      sym_collection_path,
    ACTIONS(806), 4,
      sym_var,
      sym_double,
      sym_nil,
      sym_anon,
    STATE(417), 4,
      sym__string_literal1,
      sym__string_literal2,
      sym__string_literal_long1,
      sym__string_literal_long2,
    STATE(223), 9,
      sym__graph_pattern_not_triples,
      sym_optional_graph_pattern,
      sym_graph_graph_pattern,
      sym_service_graph_pattern,
      sym_bind,
      sym_inline_data,
      sym_minus_graph_pattern,
      sym_group_or_union_graph_pattern,
      sym_filter,
    STATE(493), 10,
      sym__var_or_term,
      sym__graph_term,
      sym_rdf_literal,
      sym__numeric_literal,
      sym_boolean_literal,
      sym__iri,
      sym_prefixed_name,
      sym__blank_node,
      sym_iri_reference,
      sym_blank_node_label,
  [272] = 36,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(780), 1,
      sym_pn_prefix,
    ACTIONS(782), 1,
      aux_sym_select_clause_token1,
    ACTIONS(784), 1,
      anon_sym_LPAREN,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(790), 1,
      aux_sym_values_clause_token1,
    ACTIONS(792), 1,
      aux_sym_graph_or_default_token2,
    ACTIONS(794), 1,
      aux_sym_optional_graph_pattern_token1,
    ACTIONS(796), 1,
      aux_sym_service_graph_pattern_token1,
    ACTIONS(798), 1,
      aux_sym_bind_token1,
    ACTIONS(800), 1,
      aux_sym_minus_graph_pattern_token1,
    ACTIONS(802), 1,
      aux_sym_filter_token1,
    ACTIONS(804), 1,
      anon_sym_LBRACK,
    ACTIONS(808), 1,
      anon_sym_LT,
    ACTIONS(812), 1,
      anon_sym_COLON,
    ACTIONS(814), 1,
      anon_sym__COLON,
    ACTIONS(818), 1,
      anon_sym_SQUOTE,
    ACTIONS(820), 1,
      anon_sym_DQUOTE,
    ACTIONS(822), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(824), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(828), 1,
      anon_sym_RBRACE,
    STATE(305), 1,
      sym_group_graph_pattern,
    STATE(509), 1,
      sym_triples_block,
    STATE(510), 1,
      aux_sym_group_graph_pattern_repeat1,
    STATE(708), 1,
      sym_triples_same_subject_path,
    STATE(729), 1,
      sym_string,
    STATE(736), 1,
      sym_namespace,
    STATE(876), 1,
      sym_select_clause,
    STATE(1009), 1,
      sym_sub_select,
    ACTIONS(810), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(816), 2,
      sym_integer,
      sym_decimal,
    STATE(304), 3,
      sym__triples_node_path,
      sym_blank_node_property_list_path,
      sym_collection_path,
    ACTIONS(806), 4,
      sym_var,
      sym_double,
      sym_nil,
      sym_anon,
    STATE(417), 4,
      sym__string_literal1,
      sym__string_literal2,
      sym__string_literal_long1,
      sym__string_literal_long2,
    STATE(223), 9,
      sym__graph_pattern_not_triples,
      sym_optional_graph_pattern,
      sym_graph_graph_pattern,
      sym_service_graph_pattern,
      sym_bind,
      sym_inline_data,
      sym_minus_graph_pattern,
      sym_group_or_union_graph_pattern,
      sym_filter,
    STATE(493), 10,
      sym__var_or_term,
      sym__graph_term,
      sym_rdf_literal,
      sym__numeric_literal,
      sym_boolean_literal,
      sym__iri,
      sym_prefixed_name,
      sym__blank_node,
      sym_iri_reference,
      sym_blank_node_label,
  [408] = 36,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(780), 1,
      sym_pn_prefix,
    ACTIONS(782), 1,
      aux_sym_select_clause_token1,
    ACTIONS(784), 1,
      anon_sym_LPAREN,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(790), 1,
      aux_sym_values_clause_token1,
    ACTIONS(792), 1,
      aux_sym_graph_or_default_token2,
    ACTIONS(794), 1,
      aux_sym_optional_graph_pattern_token1,
    ACTIONS(796), 1,
      aux_sym_service_graph_pattern_token1,
    ACTIONS(798), 1,
      aux_sym_bind_token1,
    ACTIONS(800), 1,
      aux_sym_minus_graph_pattern_token1,
    ACTIONS(802), 1,
      aux_sym_filter_token1,
    ACTIONS(804), 1,
      anon_sym_LBRACK,
    ACTIONS(808), 1,
      anon_sym_LT,
    ACTIONS(812), 1,
      anon_sym_COLON,
    ACTIONS(814), 1,
      anon_sym__COLON,
    ACTIONS(818), 1,
      anon_sym_SQUOTE,
    ACTIONS(820), 1,
      anon_sym_DQUOTE,
    ACTIONS(822), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(824), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(830), 1,
      anon_sym_RBRACE,
    STATE(305), 1,
      sym_group_graph_pattern,
    STATE(496), 1,
      sym_triples_block,
    STATE(508), 1,
      aux_sym_group_graph_pattern_repeat1,
    STATE(708), 1,
      sym_triples_same_subject_path,
    STATE(729), 1,
      sym_string,
    STATE(736), 1,
      sym_namespace,
    STATE(876), 1,
      sym_select_clause,
    STATE(1100), 1,
      sym_sub_select,
    ACTIONS(810), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(816), 2,
      sym_integer,
      sym_decimal,
    STATE(304), 3,
      sym__triples_node_path,
      sym_blank_node_property_list_path,
      sym_collection_path,
    ACTIONS(806), 4,
      sym_var,
      sym_double,
      sym_nil,
      sym_anon,
    STATE(417), 4,
      sym__string_literal1,
      sym__string_literal2,
      sym__string_literal_long1,
      sym__string_literal_long2,
    STATE(223), 9,
      sym__graph_pattern_not_triples,
      sym_optional_graph_pattern,
      sym_graph_graph_pattern,
      sym_service_graph_pattern,
      sym_bind,
      sym_inline_data,
      sym_minus_graph_pattern,
      sym_group_or_union_graph_pattern,
      sym_filter,
    STATE(493), 10,
      sym__var_or_term,
      sym__graph_term,
      sym_rdf_literal,
      sym__numeric_literal,
      sym_boolean_literal,
      sym__iri,
      sym_prefixed_name,
      sym__blank_node,
      sym_iri_reference,
      sym_blank_node_label,
  [544] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(832), 16,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      sym_nil,
    ACTIONS(834), 35,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      anon_sym_LPAREN,
      aux_sym_construct_query_token1,
      aux_sym_construct_query_token2,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_dataset_clause_token1,
      aux_sym_group_clause_token1,
      aux_sym_having_clause_token1,
      aux_sym_order_clause_token1,
      aux_sym_limit_clause_token1,
      aux_sym_offset_clause_token1,
      aux_sym_values_clause_token1,
      aux_sym_load_token1,
      aux_sym_load_token3,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_add_token2,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      aux_sym_modify_token1,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
      aux_sym_using_clause_token1,
      aux_sym_graph_or_default_token2,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      sym_pn_prefix,
  [603] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(836), 16,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      sym_nil,
    ACTIONS(838), 35,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      anon_sym_LPAREN,
      aux_sym_construct_query_token1,
      aux_sym_construct_query_token2,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_dataset_clause_token1,
      aux_sym_group_clause_token1,
      aux_sym_having_clause_token1,
      aux_sym_order_clause_token1,
      aux_sym_limit_clause_token1,
      aux_sym_offset_clause_token1,
      aux_sym_values_clause_token1,
      aux_sym_load_token1,
      aux_sym_load_token3,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_add_token2,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      aux_sym_modify_token1,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
      aux_sym_using_clause_token1,
      aux_sym_graph_or_default_token2,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      sym_pn_prefix,
  [662] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(57), 1,
      anon_sym_LT,
    ACTIONS(842), 1,
      sym_pn_prefix,
    ACTIONS(846), 1,
      aux_sym_construct_query_token2,
    ACTIONS(848), 1,
      anon_sym_LBRACE,
    ACTIONS(850), 1,
      aux_sym_dataset_clause_token1,
    ACTIONS(852), 1,
      aux_sym_group_clause_token1,
    ACTIONS(854), 1,
      aux_sym_having_clause_token1,
    ACTIONS(856), 1,
      aux_sym_order_clause_token1,
    ACTIONS(858), 1,
      aux_sym_limit_clause_token1,
    ACTIONS(860), 1,
      aux_sym_offset_clause_token1,
    ACTIONS(862), 1,
      sym_var,
    ACTIONS(864), 1,
      anon_sym_COLON,
    STATE(274), 1,
      sym_namespace,
    STATE(284), 1,
      sym_where_clause,
    STATE(300), 1,
      sym_group_clause,
    STATE(323), 1,
      sym_having_clause,
    STATE(373), 1,
      sym_order_clause,
    STATE(377), 1,
      sym_group_graph_pattern,
    STATE(379), 1,
      sym_limit_clause,
    STATE(380), 1,
      sym_offset_clause,
    STATE(398), 1,
      sym_limit_offset_clauses,
    STATE(440), 1,
      sym_solution_modifier,
    STATE(241), 2,
      sym_dataset_clause,
      aux_sym_select_query_repeat1,
    ACTIONS(840), 4,
      ts_builtin_sym_end,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
    STATE(253), 5,
      sym__var_or_iri,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
      aux_sym_describe_query_repeat1,
    ACTIONS(844), 17,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_values_clause_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      aux_sym_modify_token1,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
  [768] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(780), 1,
      sym_pn_prefix,
    ACTIONS(784), 1,
      anon_sym_LPAREN,
    ACTIONS(804), 1,
      anon_sym_LBRACK,
    ACTIONS(808), 1,
      anon_sym_LT,
    ACTIONS(812), 1,
      anon_sym_COLON,
    ACTIONS(814), 1,
      anon_sym__COLON,
    ACTIONS(818), 1,
      anon_sym_SQUOTE,
    ACTIONS(820), 1,
      anon_sym_DQUOTE,
    ACTIONS(822), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(824), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(870), 1,
      anon_sym_DOT,
    STATE(708), 1,
      sym_triples_same_subject_path,
    STATE(729), 1,
      sym_string,
    STATE(736), 1,
      sym_namespace,
    STATE(751), 1,
      sym_triples_block,
    ACTIONS(810), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(816), 2,
      sym_integer,
      sym_decimal,
    ACTIONS(866), 2,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
    STATE(304), 3,
      sym__triples_node_path,
      sym_blank_node_property_list_path,
      sym_collection_path,
    ACTIONS(806), 4,
      sym_var,
      sym_double,
      sym_nil,
      sym_anon,
    STATE(417), 4,
      sym__string_literal1,
      sym__string_literal2,
      sym__string_literal_long1,
      sym__string_literal_long2,
    ACTIONS(868), 7,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
    STATE(493), 10,
      sym__var_or_term,
      sym__graph_term,
      sym_rdf_literal,
      sym__numeric_literal,
      sym_boolean_literal,
      sym__iri,
      sym_prefixed_name,
      sym__blank_node,
      sym_iri_reference,
      sym_blank_node_label,
  [867] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(780), 1,
      sym_pn_prefix,
    ACTIONS(784), 1,
      anon_sym_LPAREN,
    ACTIONS(804), 1,
      anon_sym_LBRACK,
    ACTIONS(808), 1,
      anon_sym_LT,
    ACTIONS(812), 1,
      anon_sym_COLON,
    ACTIONS(814), 1,
      anon_sym__COLON,
    ACTIONS(818), 1,
      anon_sym_SQUOTE,
    ACTIONS(820), 1,
      anon_sym_DQUOTE,
    ACTIONS(822), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(824), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(708), 1,
      sym_triples_same_subject_path,
    STATE(729), 1,
      sym_string,
    STATE(736), 1,
      sym_namespace,
    STATE(743), 1,
      sym_triples_block,
    ACTIONS(810), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(816), 2,
      sym_integer,
      sym_decimal,
    ACTIONS(872), 2,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
    STATE(304), 3,
      sym__triples_node_path,
      sym_blank_node_property_list_path,
      sym_collection_path,
    ACTIONS(806), 4,
      sym_var,
      sym_double,
      sym_nil,
      sym_anon,
    STATE(417), 4,
      sym__string_literal1,
      sym__string_literal2,
      sym__string_literal_long1,
      sym__string_literal_long2,
    ACTIONS(874), 7,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
    STATE(493), 10,
      sym__var_or_term,
      sym__graph_term,
      sym_rdf_literal,
      sym__numeric_literal,
      sym_boolean_literal,
      sym__iri,
      sym_prefixed_name,
      sym__blank_node,
      sym_iri_reference,
      sym_blank_node_label,
  [963] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(780), 1,
      sym_pn_prefix,
    ACTIONS(784), 1,
      anon_sym_LPAREN,
    ACTIONS(804), 1,
      anon_sym_LBRACK,
    ACTIONS(808), 1,
      anon_sym_LT,
    ACTIONS(812), 1,
      anon_sym_COLON,
    ACTIONS(814), 1,
      anon_sym__COLON,
    ACTIONS(818), 1,
      anon_sym_SQUOTE,
    ACTIONS(820), 1,
      anon_sym_DQUOTE,
    ACTIONS(822), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(824), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(729), 1,
      sym_string,
    STATE(730), 1,
      sym_triples_same_subject_path,
    STATE(736), 1,
      sym_namespace,
    ACTIONS(810), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(816), 2,
      sym_integer,
      sym_decimal,
    ACTIONS(876), 2,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
    STATE(304), 3,
      sym__triples_node_path,
      sym_blank_node_property_list_path,
      sym_collection_path,
    ACTIONS(806), 4,
      sym_var,
      sym_double,
      sym_nil,
      sym_anon,
    STATE(417), 4,
      sym__string_literal1,
      sym__string_literal2,
      sym__string_literal_long1,
      sym__string_literal_long2,
    ACTIONS(878), 7,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
    STATE(493), 10,
      sym__var_or_term,
      sym__graph_term,
      sym_rdf_literal,
      sym__numeric_literal,
      sym_boolean_literal,
      sym__iri,
      sym_prefixed_name,
      sym__blank_node,
      sym_iri_reference,
      sym_blank_node_label,
  [1056] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(780), 1,
      sym_pn_prefix,
    ACTIONS(784), 1,
      anon_sym_LPAREN,
    ACTIONS(804), 1,
      anon_sym_LBRACK,
    ACTIONS(808), 1,
      anon_sym_LT,
    ACTIONS(812), 1,
      anon_sym_COLON,
    ACTIONS(814), 1,
      anon_sym__COLON,
    ACTIONS(818), 1,
      anon_sym_SQUOTE,
    ACTIONS(820), 1,
      anon_sym_DQUOTE,
    ACTIONS(822), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(824), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(729), 1,
      sym_string,
    STATE(730), 1,
      sym_triples_same_subject_path,
    STATE(736), 1,
      sym_namespace,
    ACTIONS(810), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(816), 2,
      sym_integer,
      sym_decimal,
    ACTIONS(880), 2,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
    STATE(304), 3,
      sym__triples_node_path,
      sym_blank_node_property_list_path,
      sym_collection_path,
    ACTIONS(806), 4,
      sym_var,
      sym_double,
      sym_nil,
      sym_anon,
    STATE(417), 4,
      sym__string_literal1,
      sym__string_literal2,
      sym__string_literal_long1,
      sym__string_literal_long2,
    ACTIONS(882), 7,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
    STATE(493), 10,
      sym__var_or_term,
      sym__graph_term,
      sym_rdf_literal,
      sym__numeric_literal,
      sym_boolean_literal,
      sym__iri,
      sym_prefixed_name,
      sym__blank_node,
      sym_iri_reference,
      sym_blank_node_label,
  [1149] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(607), 6,
      aux_sym_select_clause_token4,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
      anon_sym_LT,
      anon_sym_GT,
      aux_sym_binary_expression_token1,
    ACTIONS(605), 39,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      anon_sym_RPAREN,
      anon_sym_STAR,
      aux_sym_construct_query_token1,
      anon_sym_RBRACE,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_group_clause_token1,
      aux_sym_having_clause_token1,
      aux_sym_order_clause_token1,
      aux_sym_limit_clause_token1,
      aux_sym_offset_clause_token1,
      aux_sym_values_clause_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
      anon_sym_COMMA,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      aux_sym_binary_expression_token2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [1202] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(401), 6,
      aux_sym_select_clause_token4,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
      anon_sym_LT,
      anon_sym_GT,
      aux_sym_binary_expression_token1,
    ACTIONS(399), 39,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      anon_sym_RPAREN,
      anon_sym_STAR,
      aux_sym_construct_query_token1,
      anon_sym_RBRACE,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_group_clause_token1,
      aux_sym_having_clause_token1,
      aux_sym_order_clause_token1,
      aux_sym_limit_clause_token1,
      aux_sym_offset_clause_token1,
      aux_sym_values_clause_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
      anon_sym_COMMA,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      aux_sym_binary_expression_token2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [1255] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(611), 6,
      aux_sym_select_clause_token4,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
      anon_sym_LT,
      anon_sym_GT,
      aux_sym_binary_expression_token1,
    ACTIONS(609), 39,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      anon_sym_RPAREN,
      anon_sym_STAR,
      aux_sym_construct_query_token1,
      anon_sym_RBRACE,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_group_clause_token1,
      aux_sym_having_clause_token1,
      aux_sym_order_clause_token1,
      aux_sym_limit_clause_token1,
      aux_sym_offset_clause_token1,
      aux_sym_values_clause_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
      anon_sym_COMMA,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      aux_sym_binary_expression_token2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [1308] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(884), 1,
      ts_builtin_sym_end,
    ACTIONS(886), 1,
      aux_sym_base_declaration_token1,
    ACTIONS(889), 1,
      aux_sym_prefix_declaration_token1,
    ACTIONS(892), 1,
      aux_sym_select_clause_token1,
    ACTIONS(895), 1,
      aux_sym_construct_query_token1,
    ACTIONS(898), 1,
      aux_sym_describe_query_token1,
    ACTIONS(901), 1,
      aux_sym_ask_query_token1,
    ACTIONS(904), 1,
      aux_sym_load_token1,
    ACTIONS(907), 1,
      aux_sym_clear_token1,
    ACTIONS(910), 1,
      aux_sym_drop_token1,
    ACTIONS(913), 1,
      aux_sym_create_token1,
    ACTIONS(916), 1,
      aux_sym_add_token1,
    ACTIONS(919), 1,
      aux_sym_move_token1,
    ACTIONS(922), 1,
      aux_sym_copy_token1,
    ACTIONS(925), 1,
      anon_sym_INSERTDATA,
    ACTIONS(928), 1,
      anon_sym_DELETEDATA,
    ACTIONS(931), 1,
      anon_sym_DELETEWHERE,
    ACTIONS(934), 1,
      aux_sym_modify_token1,
    ACTIONS(937), 1,
      aux_sym_delete_clause_token1,
    ACTIONS(940), 1,
      aux_sym_insert_clause_token1,
    STATE(271), 1,
      sym_prologue,
    STATE(757), 1,
      sym_select_clause,
    STATE(788), 1,
      sym_delete_clause,
    STATE(863), 1,
      sym_insert_clause,
    STATE(230), 2,
      sym__update,
      aux_sym_unit_repeat1,
    STATE(404), 3,
      sym_base_declaration,
      sym_prefix_declaration,
      aux_sym_prologue_repeat1,
    STATE(414), 4,
      sym_select_query,
      sym_construct_query,
      sym_describe_query,
      sym_ask_query,
    STATE(486), 11,
      sym_load,
      sym_clear,
      sym_drop,
      sym_create,
      sym_add,
      sym_move,
      sym_copy,
      sym_insert_data,
      sym_delete_data,
      sym_delete_where,
      sym_modify,
  [1412] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7), 1,
      aux_sym_base_declaration_token1,
    ACTIONS(9), 1,
      aux_sym_prefix_declaration_token1,
    ACTIONS(11), 1,
      aux_sym_select_clause_token1,
    ACTIONS(13), 1,
      aux_sym_construct_query_token1,
    ACTIONS(15), 1,
      aux_sym_describe_query_token1,
    ACTIONS(17), 1,
      aux_sym_ask_query_token1,
    ACTIONS(19), 1,
      aux_sym_load_token1,
    ACTIONS(21), 1,
      aux_sym_clear_token1,
    ACTIONS(23), 1,
      aux_sym_drop_token1,
    ACTIONS(25), 1,
      aux_sym_create_token1,
    ACTIONS(27), 1,
      aux_sym_add_token1,
    ACTIONS(29), 1,
      aux_sym_move_token1,
    ACTIONS(31), 1,
      aux_sym_copy_token1,
    ACTIONS(33), 1,
      anon_sym_INSERTDATA,
    ACTIONS(35), 1,
      anon_sym_DELETEDATA,
    ACTIONS(37), 1,
      anon_sym_DELETEWHERE,
    ACTIONS(39), 1,
      aux_sym_modify_token1,
    ACTIONS(41), 1,
      aux_sym_delete_clause_token1,
    ACTIONS(43), 1,
      aux_sym_insert_clause_token1,
    ACTIONS(943), 1,
      ts_builtin_sym_end,
    STATE(271), 1,
      sym_prologue,
    STATE(757), 1,
      sym_select_clause,
    STATE(788), 1,
      sym_delete_clause,
    STATE(863), 1,
      sym_insert_clause,
    STATE(230), 2,
      sym__update,
      aux_sym_unit_repeat1,
    STATE(404), 3,
      sym_base_declaration,
      sym_prefix_declaration,
      aux_sym_prologue_repeat1,
    STATE(414), 4,
      sym_select_query,
      sym_construct_query,
      sym_describe_query,
      sym_ask_query,
    STATE(486), 11,
      sym_load,
      sym_clear,
      sym_drop,
      sym_create,
      sym_add,
      sym_move,
      sym_copy,
      sym_insert_data,
      sym_delete_data,
      sym_delete_where,
      sym_modify,
  [1516] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(780), 1,
      sym_pn_prefix,
    ACTIONS(808), 1,
      anon_sym_LT,
    ACTIONS(812), 1,
      anon_sym_COLON,
    ACTIONS(814), 1,
      anon_sym__COLON,
    ACTIONS(818), 1,
      anon_sym_SQUOTE,
    ACTIONS(820), 1,
      anon_sym_DQUOTE,
    ACTIONS(822), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(824), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(945), 1,
      anon_sym_LPAREN,
    ACTIONS(947), 1,
      anon_sym_RBRACE,
    ACTIONS(949), 1,
      aux_sym_graph_or_default_token2,
    ACTIONS(951), 1,
      anon_sym_LBRACK,
    STATE(234), 1,
      sym_quads_not_triples,
    STATE(729), 1,
      sym_string,
    STATE(736), 1,
      sym_namespace,
    STATE(843), 1,
      sym_triples_template,
    STATE(844), 1,
      aux_sym_quads_repeat1,
    STATE(864), 1,
      sym_triples_same_subject,
    ACTIONS(810), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(955), 2,
      sym_integer,
      sym_decimal,
    STATE(613), 3,
      sym__triples_node,
      sym_blank_node_property_list,
      sym_collection,
    ACTIONS(953), 4,
      sym_var,
      sym_double,
      sym_nil,
      sym_anon,
    STATE(417), 4,
      sym__string_literal1,
      sym__string_literal2,
      sym__string_literal_long1,
      sym__string_literal_long2,
    STATE(694), 10,
      sym__var_or_term,
      sym__graph_term,
      sym_rdf_literal,
      sym__numeric_literal,
      sym_boolean_literal,
      sym__iri,
      sym_prefixed_name,
      sym__blank_node,
      sym_iri_reference,
      sym_blank_node_label,
  [1611] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(780), 1,
      sym_pn_prefix,
    ACTIONS(808), 1,
      anon_sym_LT,
    ACTIONS(812), 1,
      anon_sym_COLON,
    ACTIONS(814), 1,
      anon_sym__COLON,
    ACTIONS(818), 1,
      anon_sym_SQUOTE,
    ACTIONS(820), 1,
      anon_sym_DQUOTE,
    ACTIONS(822), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(824), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(945), 1,
      anon_sym_LPAREN,
    ACTIONS(949), 1,
      aux_sym_graph_or_default_token2,
    ACTIONS(951), 1,
      anon_sym_LBRACK,
    ACTIONS(957), 1,
      anon_sym_RBRACE,
    STATE(234), 1,
      sym_quads_not_triples,
    STATE(729), 1,
      sym_string,
    STATE(736), 1,
      sym_namespace,
    STATE(860), 1,
      sym_triples_template,
    STATE(864), 1,
      sym_triples_same_subject,
    STATE(868), 1,
      aux_sym_quads_repeat1,
    ACTIONS(810), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(955), 2,
      sym_integer,
      sym_decimal,
    STATE(613), 3,
      sym__triples_node,
      sym_blank_node_property_list,
      sym_collection,
    ACTIONS(953), 4,
      sym_var,
      sym_double,
      sym_nil,
      sym_anon,
    STATE(417), 4,
      sym__string_literal1,
      sym__string_literal2,
      sym__string_literal_long1,
      sym__string_literal_long2,
    STATE(694), 10,
      sym__var_or_term,
      sym__graph_term,
      sym_rdf_literal,
      sym__numeric_literal,
      sym_boolean_literal,
      sym__iri,
      sym_prefixed_name,
      sym__blank_node,
      sym_iri_reference,
      sym_blank_node_label,
  [1706] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(780), 1,
      sym_pn_prefix,
    ACTIONS(808), 1,
      anon_sym_LT,
    ACTIONS(812), 1,
      anon_sym_COLON,
    ACTIONS(814), 1,
      anon_sym__COLON,
    ACTIONS(818), 1,
      anon_sym_SQUOTE,
    ACTIONS(820), 1,
      anon_sym_DQUOTE,
    ACTIONS(822), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(824), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(945), 1,
      anon_sym_LPAREN,
    ACTIONS(951), 1,
      anon_sym_LBRACK,
    ACTIONS(959), 1,
      anon_sym_RBRACE,
    ACTIONS(961), 1,
      aux_sym_graph_or_default_token2,
    ACTIONS(963), 1,
      anon_sym_DOT,
    STATE(729), 1,
      sym_string,
    STATE(736), 1,
      sym_namespace,
    STATE(864), 1,
      sym_triples_same_subject,
    STATE(944), 1,
      sym_triples_template,
    ACTIONS(810), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(955), 2,
      sym_integer,
      sym_decimal,
    STATE(613), 3,
      sym__triples_node,
      sym_blank_node_property_list,
      sym_collection,
    ACTIONS(953), 4,
      sym_var,
      sym_double,
      sym_nil,
      sym_anon,
    STATE(417), 4,
      sym__string_literal1,
      sym__string_literal2,
      sym__string_literal_long1,
      sym__string_literal_long2,
    STATE(694), 10,
      sym__var_or_term,
      sym__graph_term,
      sym_rdf_literal,
      sym__numeric_literal,
      sym_boolean_literal,
      sym__iri,
      sym_prefixed_name,
      sym__blank_node,
      sym_iri_reference,
      sym_blank_node_label,
  [1798] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(780), 1,
      sym_pn_prefix,
    ACTIONS(808), 1,
      anon_sym_LT,
    ACTIONS(812), 1,
      anon_sym_COLON,
    ACTIONS(814), 1,
      anon_sym__COLON,
    ACTIONS(818), 1,
      anon_sym_SQUOTE,
    ACTIONS(820), 1,
      anon_sym_DQUOTE,
    ACTIONS(822), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(824), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(945), 1,
      anon_sym_LPAREN,
    ACTIONS(951), 1,
      anon_sym_LBRACK,
    ACTIONS(965), 1,
      anon_sym_RBRACE,
    ACTIONS(967), 1,
      aux_sym_graph_or_default_token2,
    STATE(729), 1,
      sym_string,
    STATE(736), 1,
      sym_namespace,
    STATE(864), 1,
      sym_triples_same_subject,
    STATE(970), 1,
      sym_triples_template,
    ACTIONS(810), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(955), 2,
      sym_integer,
      sym_decimal,
    STATE(613), 3,
      sym__triples_node,
      sym_blank_node_property_list,
      sym_collection,
    ACTIONS(953), 4,
      sym_var,
      sym_double,
      sym_nil,
      sym_anon,
    STATE(417), 4,
      sym__string_literal1,
      sym__string_literal2,
      sym__string_literal_long1,
      sym__string_literal_long2,
    STATE(694), 10,
      sym__var_or_term,
      sym__graph_term,
      sym_rdf_literal,
      sym__numeric_literal,
      sym_boolean_literal,
      sym__iri,
      sym_prefixed_name,
      sym__blank_node,
      sym_iri_reference,
      sym_blank_node_label,
  [1887] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(969), 1,
      sym_pn_prefix,
    ACTIONS(971), 1,
      anon_sym_LPAREN,
    ACTIONS(973), 1,
      anon_sym_RPAREN,
    ACTIONS(975), 1,
      anon_sym_LBRACK,
    ACTIONS(979), 1,
      anon_sym_LT,
    ACTIONS(983), 1,
      anon_sym_COLON,
    ACTIONS(985), 1,
      anon_sym__COLON,
    ACTIONS(989), 1,
      anon_sym_SQUOTE,
    ACTIONS(991), 1,
      anon_sym_DQUOTE,
    ACTIONS(993), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(995), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(384), 1,
      sym_namespace,
    STATE(491), 1,
      sym_string,
    ACTIONS(981), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(987), 2,
      sym_integer,
      sym_decimal,
    ACTIONS(977), 4,
      sym_var,
      sym_double,
      sym_nil,
      sym_anon,
    STATE(422), 4,
      sym__string_literal1,
      sym__string_literal2,
      sym__string_literal_long1,
      sym__string_literal_long2,
    STATE(242), 15,
      sym__triples_node_path,
      sym_blank_node_property_list_path,
      sym_collection_path,
      sym__graph_node_path,
      sym__var_or_term,
      sym__graph_term,
      sym_rdf_literal,
      sym__numeric_literal,
      sym_boolean_literal,
      sym__iri,
      sym_prefixed_name,
      sym__blank_node,
      sym_iri_reference,
      sym_blank_node_label,
      aux_sym_collection_path_repeat1,
  [1967] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(969), 1,
      sym_pn_prefix,
    ACTIONS(971), 1,
      anon_sym_LPAREN,
    ACTIONS(975), 1,
      anon_sym_LBRACK,
    ACTIONS(979), 1,
      anon_sym_LT,
    ACTIONS(983), 1,
      anon_sym_COLON,
    ACTIONS(985), 1,
      anon_sym__COLON,
    ACTIONS(989), 1,
      anon_sym_SQUOTE,
    ACTIONS(991), 1,
      anon_sym_DQUOTE,
    ACTIONS(993), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(995), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(997), 1,
      anon_sym_RPAREN,
    STATE(384), 1,
      sym_namespace,
    STATE(491), 1,
      sym_string,
    ACTIONS(981), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(987), 2,
      sym_integer,
      sym_decimal,
    ACTIONS(977), 4,
      sym_var,
      sym_double,
      sym_nil,
      sym_anon,
    STATE(422), 4,
      sym__string_literal1,
      sym__string_literal2,
      sym__string_literal_long1,
      sym__string_literal_long2,
    STATE(242), 15,
      sym__triples_node_path,
      sym_blank_node_property_list_path,
      sym_collection_path,
      sym__graph_node_path,
      sym__var_or_term,
      sym__graph_term,
      sym_rdf_literal,
      sym__numeric_literal,
      sym_boolean_literal,
      sym__iri,
      sym_prefixed_name,
      sym__blank_node,
      sym_iri_reference,
      sym_blank_node_label,
      aux_sym_collection_path_repeat1,
  [2047] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(969), 1,
      sym_pn_prefix,
    ACTIONS(979), 1,
      anon_sym_LT,
    ACTIONS(983), 1,
      anon_sym_COLON,
    ACTIONS(985), 1,
      anon_sym__COLON,
    ACTIONS(989), 1,
      anon_sym_SQUOTE,
    ACTIONS(991), 1,
      anon_sym_DQUOTE,
    ACTIONS(993), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(995), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(999), 1,
      anon_sym_LPAREN,
    ACTIONS(1001), 1,
      anon_sym_RPAREN,
    ACTIONS(1003), 1,
      anon_sym_LBRACK,
    STATE(384), 1,
      sym_namespace,
    STATE(491), 1,
      sym_string,
    ACTIONS(981), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1007), 2,
      sym_integer,
      sym_decimal,
    ACTIONS(1005), 4,
      sym_var,
      sym_double,
      sym_nil,
      sym_anon,
    STATE(422), 4,
      sym__string_literal1,
      sym__string_literal2,
      sym__string_literal_long1,
      sym__string_literal_long2,
    STATE(245), 15,
      sym__triples_node,
      sym_blank_node_property_list,
      sym_collection,
      sym__graph_node,
      sym__var_or_term,
      sym__graph_term,
      sym_rdf_literal,
      sym__numeric_literal,
      sym_boolean_literal,
      sym__iri,
      sym_prefixed_name,
      sym__blank_node,
      sym_iri_reference,
      sym_blank_node_label,
      aux_sym_collection_repeat1,
  [2127] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(848), 1,
      anon_sym_LBRACE,
    ACTIONS(1009), 1,
      aux_sym_construct_query_token2,
    ACTIONS(1011), 1,
      aux_sym_dataset_clause_token1,
    ACTIONS(1013), 1,
      aux_sym_group_clause_token1,
    ACTIONS(1015), 1,
      aux_sym_having_clause_token1,
    ACTIONS(1017), 1,
      aux_sym_order_clause_token1,
    ACTIONS(1019), 1,
      aux_sym_limit_clause_token1,
    ACTIONS(1021), 1,
      aux_sym_offset_clause_token1,
    STATE(284), 1,
      sym_where_clause,
    STATE(300), 1,
      sym_group_clause,
    STATE(323), 1,
      sym_having_clause,
    STATE(373), 1,
      sym_order_clause,
    STATE(377), 1,
      sym_group_graph_pattern,
    STATE(379), 1,
      sym_limit_clause,
    STATE(380), 1,
      sym_offset_clause,
    STATE(398), 1,
      sym_limit_offset_clauses,
    STATE(440), 1,
      sym_solution_modifier,
    ACTIONS(844), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    STATE(241), 2,
      sym_dataset_clause,
      aux_sym_select_query_repeat1,
    ACTIONS(840), 19,
      ts_builtin_sym_end,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_values_clause_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [2211] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(780), 1,
      sym_pn_prefix,
    ACTIONS(808), 1,
      anon_sym_LT,
    ACTIONS(812), 1,
      anon_sym_COLON,
    ACTIONS(814), 1,
      anon_sym__COLON,
    ACTIONS(818), 1,
      anon_sym_SQUOTE,
    ACTIONS(820), 1,
      anon_sym_DQUOTE,
    ACTIONS(822), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(824), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(945), 1,
      anon_sym_LPAREN,
    ACTIONS(951), 1,
      anon_sym_LBRACK,
    ACTIONS(1023), 1,
      anon_sym_RBRACE,
    ACTIONS(1025), 1,
      aux_sym_graph_or_default_token2,
    STATE(729), 1,
      sym_string,
    STATE(736), 1,
      sym_namespace,
    STATE(910), 1,
      sym_triples_same_subject,
    ACTIONS(810), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(955), 2,
      sym_integer,
      sym_decimal,
    STATE(613), 3,
      sym__triples_node,
      sym_blank_node_property_list,
      sym_collection,
    ACTIONS(953), 4,
      sym_var,
      sym_double,
      sym_nil,
      sym_anon,
    STATE(417), 4,
      sym__string_literal1,
      sym__string_literal2,
      sym__string_literal_long1,
      sym__string_literal_long2,
    STATE(694), 10,
      sym__var_or_term,
      sym__graph_term,
      sym_rdf_literal,
      sym__numeric_literal,
      sym_boolean_literal,
      sym__iri,
      sym_prefixed_name,
      sym__blank_node,
      sym_iri_reference,
      sym_blank_node_label,
  [2297] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(848), 1,
      anon_sym_LBRACE,
    ACTIONS(1009), 1,
      aux_sym_construct_query_token2,
    ACTIONS(1011), 1,
      aux_sym_dataset_clause_token1,
    ACTIONS(1013), 1,
      aux_sym_group_clause_token1,
    ACTIONS(1015), 1,
      aux_sym_having_clause_token1,
    ACTIONS(1017), 1,
      aux_sym_order_clause_token1,
    ACTIONS(1019), 1,
      aux_sym_limit_clause_token1,
    ACTIONS(1021), 1,
      aux_sym_offset_clause_token1,
    STATE(278), 1,
      sym_where_clause,
    STATE(300), 1,
      sym_group_clause,
    STATE(323), 1,
      sym_having_clause,
    STATE(373), 1,
      sym_order_clause,
    STATE(377), 1,
      sym_group_graph_pattern,
    STATE(379), 1,
      sym_limit_clause,
    STATE(380), 1,
      sym_offset_clause,
    STATE(398), 1,
      sym_limit_offset_clauses,
    STATE(451), 1,
      sym_solution_modifier,
    ACTIONS(1029), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    STATE(294), 2,
      sym_dataset_clause,
      aux_sym_select_query_repeat1,
    ACTIONS(1027), 19,
      ts_builtin_sym_end,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_values_clause_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [2381] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1031), 1,
      sym_pn_prefix,
    ACTIONS(1034), 1,
      anon_sym_LPAREN,
    ACTIONS(1037), 1,
      anon_sym_RPAREN,
    ACTIONS(1039), 1,
      anon_sym_LBRACK,
    ACTIONS(1045), 1,
      anon_sym_LT,
    ACTIONS(1051), 1,
      anon_sym_COLON,
    ACTIONS(1054), 1,
      anon_sym__COLON,
    ACTIONS(1060), 1,
      anon_sym_SQUOTE,
    ACTIONS(1063), 1,
      anon_sym_DQUOTE,
    ACTIONS(1066), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(1069), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(384), 1,
      sym_namespace,
    STATE(491), 1,
      sym_string,
    ACTIONS(1048), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1057), 2,
      sym_integer,
      sym_decimal,
    ACTIONS(1042), 4,
      sym_var,
      sym_double,
      sym_nil,
      sym_anon,
    STATE(422), 4,
      sym__string_literal1,
      sym__string_literal2,
      sym__string_literal_long1,
      sym__string_literal_long2,
    STATE(242), 15,
      sym__triples_node_path,
      sym_blank_node_property_list_path,
      sym_collection_path,
      sym__graph_node_path,
      sym__var_or_term,
      sym__graph_term,
      sym_rdf_literal,
      sym__numeric_literal,
      sym_boolean_literal,
      sym__iri,
      sym_prefixed_name,
      sym__blank_node,
      sym_iri_reference,
      sym_blank_node_label,
      aux_sym_collection_path_repeat1,
  [2461] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(780), 1,
      sym_pn_prefix,
    ACTIONS(808), 1,
      anon_sym_LT,
    ACTIONS(812), 1,
      anon_sym_COLON,
    ACTIONS(814), 1,
      anon_sym__COLON,
    ACTIONS(818), 1,
      anon_sym_SQUOTE,
    ACTIONS(820), 1,
      anon_sym_DQUOTE,
    ACTIONS(822), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(824), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(945), 1,
      anon_sym_LPAREN,
    ACTIONS(951), 1,
      anon_sym_LBRACK,
    ACTIONS(1072), 1,
      anon_sym_RBRACE,
    STATE(729), 1,
      sym_string,
    STATE(736), 1,
      sym_namespace,
    STATE(864), 1,
      sym_triples_same_subject,
    STATE(1030), 1,
      sym_triples_template,
    ACTIONS(810), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(955), 2,
      sym_integer,
      sym_decimal,
    STATE(613), 3,
      sym__triples_node,
      sym_blank_node_property_list,
      sym_collection,
    ACTIONS(953), 4,
      sym_var,
      sym_double,
      sym_nil,
      sym_anon,
    STATE(417), 4,
      sym__string_literal1,
      sym__string_literal2,
      sym__string_literal_long1,
      sym__string_literal_long2,
    STATE(694), 10,
      sym__var_or_term,
      sym__graph_term,
      sym_rdf_literal,
      sym__numeric_literal,
      sym_boolean_literal,
      sym__iri,
      sym_prefixed_name,
      sym__blank_node,
      sym_iri_reference,
      sym_blank_node_label,
  [2547] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(780), 1,
      sym_pn_prefix,
    ACTIONS(808), 1,
      anon_sym_LT,
    ACTIONS(812), 1,
      anon_sym_COLON,
    ACTIONS(814), 1,
      anon_sym__COLON,
    ACTIONS(818), 1,
      anon_sym_SQUOTE,
    ACTIONS(820), 1,
      anon_sym_DQUOTE,
    ACTIONS(822), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(824), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(945), 1,
      anon_sym_LPAREN,
    ACTIONS(951), 1,
      anon_sym_LBRACK,
    ACTIONS(1074), 1,
      anon_sym_RBRACE,
    ACTIONS(1076), 1,
      aux_sym_graph_or_default_token2,
    STATE(729), 1,
      sym_string,
    STATE(736), 1,
      sym_namespace,
    STATE(910), 1,
      sym_triples_same_subject,
    ACTIONS(810), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(955), 2,
      sym_integer,
      sym_decimal,
    STATE(613), 3,
      sym__triples_node,
      sym_blank_node_property_list,
      sym_collection,
    ACTIONS(953), 4,
      sym_var,
      sym_double,
      sym_nil,
      sym_anon,
    STATE(417), 4,
      sym__string_literal1,
      sym__string_literal2,
      sym__string_literal_long1,
      sym__string_literal_long2,
    STATE(694), 10,
      sym__var_or_term,
      sym__graph_term,
      sym_rdf_literal,
      sym__numeric_literal,
      sym_boolean_literal,
      sym__iri,
      sym_prefixed_name,
      sym__blank_node,
      sym_iri_reference,
      sym_blank_node_label,
  [2633] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1078), 1,
      sym_pn_prefix,
    ACTIONS(1081), 1,
      anon_sym_LPAREN,
    ACTIONS(1084), 1,
      anon_sym_RPAREN,
    ACTIONS(1086), 1,
      anon_sym_LBRACK,
    ACTIONS(1092), 1,
      anon_sym_LT,
    ACTIONS(1098), 1,
      anon_sym_COLON,
    ACTIONS(1101), 1,
      anon_sym__COLON,
    ACTIONS(1107), 1,
      anon_sym_SQUOTE,
    ACTIONS(1110), 1,
      anon_sym_DQUOTE,
    ACTIONS(1113), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(1116), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(384), 1,
      sym_namespace,
    STATE(491), 1,
      sym_string,
    ACTIONS(1095), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1104), 2,
      sym_integer,
      sym_decimal,
    ACTIONS(1089), 4,
      sym_var,
      sym_double,
      sym_nil,
      sym_anon,
    STATE(422), 4,
      sym__string_literal1,
      sym__string_literal2,
      sym__string_literal_long1,
      sym__string_literal_long2,
    STATE(245), 15,
      sym__triples_node,
      sym_blank_node_property_list,
      sym_collection,
      sym__graph_node,
      sym__var_or_term,
      sym__graph_term,
      sym_rdf_literal,
      sym__numeric_literal,
      sym_boolean_literal,
      sym__iri,
      sym_prefixed_name,
      sym__blank_node,
      sym_iri_reference,
      sym_blank_node_label,
      aux_sym_collection_repeat1,
  [2713] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(969), 1,
      sym_pn_prefix,
    ACTIONS(979), 1,
      anon_sym_LT,
    ACTIONS(983), 1,
      anon_sym_COLON,
    ACTIONS(985), 1,
      anon_sym__COLON,
    ACTIONS(989), 1,
      anon_sym_SQUOTE,
    ACTIONS(991), 1,
      anon_sym_DQUOTE,
    ACTIONS(993), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(995), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(999), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_LBRACK,
    ACTIONS(1119), 1,
      anon_sym_RPAREN,
    STATE(384), 1,
      sym_namespace,
    STATE(491), 1,
      sym_string,
    ACTIONS(981), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1007), 2,
      sym_integer,
      sym_decimal,
    ACTIONS(1005), 4,
      sym_var,
      sym_double,
      sym_nil,
      sym_anon,
    STATE(422), 4,
      sym__string_literal1,
      sym__string_literal2,
      sym__string_literal_long1,
      sym__string_literal_long2,
    STATE(245), 15,
      sym__triples_node,
      sym_blank_node_property_list,
      sym_collection,
      sym__graph_node,
      sym__var_or_term,
      sym__graph_term,
      sym_rdf_literal,
      sym__numeric_literal,
      sym_boolean_literal,
      sym__iri,
      sym_prefixed_name,
      sym__blank_node,
      sym_iri_reference,
      sym_blank_node_label,
      aux_sym_collection_repeat1,
  [2793] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      sym_pn_prefix,
    ACTIONS(57), 1,
      anon_sym_LT,
    ACTIONS(89), 1,
      anon_sym_COLON,
    ACTIONS(206), 1,
      anon_sym_SQUOTE,
    ACTIONS(208), 1,
      anon_sym_DQUOTE,
    ACTIONS(210), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(212), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(814), 1,
      anon_sym__COLON,
    ACTIONS(945), 1,
      anon_sym_LPAREN,
    ACTIONS(951), 1,
      anon_sym_LBRACK,
    STATE(413), 1,
      sym_namespace,
    STATE(623), 1,
      sym_string,
    STATE(815), 1,
      sym_object_list,
    ACTIONS(202), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1123), 2,
      sym_integer,
      sym_decimal,
    ACTIONS(1121), 4,
      sym_var,
      sym_double,
      sym_nil,
      sym_anon,
    STATE(296), 4,
      sym__string_literal1,
      sym__string_literal2,
      sym__string_literal_long1,
      sym__string_literal_long2,
    STATE(688), 14,
      sym__triples_node,
      sym_blank_node_property_list,
      sym_collection,
      sym__graph_node,
      sym__var_or_term,
      sym__graph_term,
      sym_rdf_literal,
      sym__numeric_literal,
      sym_boolean_literal,
      sym__iri,
      sym_prefixed_name,
      sym__blank_node,
      sym_iri_reference,
      sym_blank_node_label,
  [2872] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(969), 1,
      sym_pn_prefix,
    ACTIONS(971), 1,
      anon_sym_LPAREN,
    ACTIONS(975), 1,
      anon_sym_LBRACK,
    ACTIONS(979), 1,
      anon_sym_LT,
    ACTIONS(983), 1,
      anon_sym_COLON,
    ACTIONS(985), 1,
      anon_sym__COLON,
    ACTIONS(989), 1,
      anon_sym_SQUOTE,
    ACTIONS(991), 1,
      anon_sym_DQUOTE,
    ACTIONS(993), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(995), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(384), 1,
      sym_namespace,
    STATE(491), 1,
      sym_string,
    ACTIONS(981), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1127), 2,
      sym_integer,
      sym_decimal,
    ACTIONS(1125), 4,
      sym_var,
      sym_double,
      sym_nil,
      sym_anon,
    STATE(422), 4,
      sym__string_literal1,
      sym__string_literal2,
      sym__string_literal_long1,
      sym__string_literal_long2,
    STATE(237), 15,
      sym__triples_node_path,
      sym_blank_node_property_list_path,
      sym_collection_path,
      sym__graph_node_path,
      sym__var_or_term,
      sym__graph_term,
      sym_rdf_literal,
      sym__numeric_literal,
      sym_boolean_literal,
      sym__iri,
      sym_prefixed_name,
      sym__blank_node,
      sym_iri_reference,
      sym_blank_node_label,
      aux_sym_collection_path_repeat1,
  [2949] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(780), 1,
      sym_pn_prefix,
    ACTIONS(808), 1,
      anon_sym_LT,
    ACTIONS(812), 1,
      anon_sym_COLON,
    ACTIONS(814), 1,
      anon_sym__COLON,
    ACTIONS(818), 1,
      anon_sym_SQUOTE,
    ACTIONS(820), 1,
      anon_sym_DQUOTE,
    ACTIONS(822), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(824), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(945), 1,
      anon_sym_LPAREN,
    ACTIONS(951), 1,
      anon_sym_LBRACK,
    ACTIONS(1129), 1,
      anon_sym_RBRACE,
    STATE(729), 1,
      sym_string,
    STATE(736), 1,
      sym_namespace,
    STATE(910), 1,
      sym_triples_same_subject,
    ACTIONS(810), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(955), 2,
      sym_integer,
      sym_decimal,
    STATE(613), 3,
      sym__triples_node,
      sym_blank_node_property_list,
      sym_collection,
    ACTIONS(953), 4,
      sym_var,
      sym_double,
      sym_nil,
      sym_anon,
    STATE(417), 4,
      sym__string_literal1,
      sym__string_literal2,
      sym__string_literal_long1,
      sym__string_literal_long2,
    STATE(694), 10,
      sym__var_or_term,
      sym__graph_term,
      sym_rdf_literal,
      sym__numeric_literal,
      sym_boolean_literal,
      sym__iri,
      sym_prefixed_name,
      sym__blank_node,
      sym_iri_reference,
      sym_blank_node_label,
  [3032] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(969), 1,
      sym_pn_prefix,
    ACTIONS(979), 1,
      anon_sym_LT,
    ACTIONS(983), 1,
      anon_sym_COLON,
    ACTIONS(985), 1,
      anon_sym__COLON,
    ACTIONS(989), 1,
      anon_sym_SQUOTE,
    ACTIONS(991), 1,
      anon_sym_DQUOTE,
    ACTIONS(993), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(995), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(999), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_LBRACK,
    STATE(384), 1,
      sym_namespace,
    STATE(491), 1,
      sym_string,
    ACTIONS(981), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1133), 2,
      sym_integer,
      sym_decimal,
    ACTIONS(1131), 4,
      sym_var,
      sym_double,
      sym_nil,
      sym_anon,
    STATE(422), 4,
      sym__string_literal1,
      sym__string_literal2,
      sym__string_literal_long1,
      sym__string_literal_long2,
    STATE(238), 15,
      sym__triples_node,
      sym_blank_node_property_list,
      sym_collection,
      sym__graph_node,
      sym__var_or_term,
      sym__graph_term,
      sym_rdf_literal,
      sym__numeric_literal,
      sym_boolean_literal,
      sym__iri,
      sym_prefixed_name,
      sym__blank_node,
      sym_iri_reference,
      sym_blank_node_label,
      aux_sym_collection_repeat1,
  [3109] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(780), 1,
      sym_pn_prefix,
    ACTIONS(808), 1,
      anon_sym_LT,
    ACTIONS(812), 1,
      anon_sym_COLON,
    ACTIONS(814), 1,
      anon_sym__COLON,
    ACTIONS(818), 1,
      anon_sym_SQUOTE,
    ACTIONS(820), 1,
      anon_sym_DQUOTE,
    ACTIONS(822), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(824), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(945), 1,
      anon_sym_LPAREN,
    ACTIONS(951), 1,
      anon_sym_LBRACK,
    ACTIONS(1135), 1,
      anon_sym_RBRACE,
    STATE(729), 1,
      sym_string,
    STATE(736), 1,
      sym_namespace,
    STATE(910), 1,
      sym_triples_same_subject,
    ACTIONS(810), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(955), 2,
      sym_integer,
      sym_decimal,
    STATE(613), 3,
      sym__triples_node,
      sym_blank_node_property_list,
      sym_collection,
    ACTIONS(953), 4,
      sym_var,
      sym_double,
      sym_nil,
      sym_anon,
    STATE(417), 4,
      sym__string_literal1,
      sym__string_literal2,
      sym__string_literal_long1,
      sym__string_literal_long2,
    STATE(694), 10,
      sym__var_or_term,
      sym__graph_term,
      sym_rdf_literal,
      sym__numeric_literal,
      sym_boolean_literal,
      sym__iri,
      sym_prefixed_name,
      sym__blank_node,
      sym_iri_reference,
      sym_blank_node_label,
  [3192] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(780), 1,
      sym_pn_prefix,
    ACTIONS(808), 1,
      anon_sym_LT,
    ACTIONS(812), 1,
      anon_sym_COLON,
    ACTIONS(814), 1,
      anon_sym__COLON,
    ACTIONS(818), 1,
      anon_sym_SQUOTE,
    ACTIONS(820), 1,
      anon_sym_DQUOTE,
    ACTIONS(822), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(824), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(945), 1,
      anon_sym_LPAREN,
    ACTIONS(951), 1,
      anon_sym_LBRACK,
    STATE(729), 1,
      sym_string,
    STATE(736), 1,
      sym_namespace,
    STATE(864), 1,
      sym_triples_same_subject,
    STATE(1036), 1,
      sym_triples_template,
    ACTIONS(810), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(955), 2,
      sym_integer,
      sym_decimal,
    STATE(613), 3,
      sym__triples_node,
      sym_blank_node_property_list,
      sym_collection,
    ACTIONS(953), 4,
      sym_var,
      sym_double,
      sym_nil,
      sym_anon,
    STATE(417), 4,
      sym__string_literal1,
      sym__string_literal2,
      sym__string_literal_long1,
      sym__string_literal_long2,
    STATE(694), 10,
      sym__var_or_term,
      sym__graph_term,
      sym_rdf_literal,
      sym__numeric_literal,
      sym_boolean_literal,
      sym__iri,
      sym_prefixed_name,
      sym__blank_node,
      sym_iri_reference,
      sym_blank_node_label,
  [3275] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1139), 1,
      sym_pn_prefix,
    ACTIONS(1144), 1,
      sym_var,
    ACTIONS(1147), 1,
      anon_sym_LT,
    ACTIONS(1150), 1,
      anon_sym_COLON,
    STATE(274), 1,
      sym_namespace,
    ACTIONS(1137), 5,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
    STATE(253), 5,
      sym__var_or_iri,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
      aux_sym_describe_query_repeat1,
    ACTIONS(1142), 24,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_construct_query_token2,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_dataset_clause_token1,
      aux_sym_group_clause_token1,
      aux_sym_having_clause_token1,
      aux_sym_order_clause_token1,
      aux_sym_limit_clause_token1,
      aux_sym_offset_clause_token1,
      aux_sym_values_clause_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      aux_sym_modify_token1,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
  [3334] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(969), 1,
      sym_pn_prefix,
    ACTIONS(971), 1,
      anon_sym_LPAREN,
    ACTIONS(975), 1,
      anon_sym_LBRACK,
    ACTIONS(979), 1,
      anon_sym_LT,
    ACTIONS(983), 1,
      anon_sym_COLON,
    ACTIONS(985), 1,
      anon_sym__COLON,
    ACTIONS(989), 1,
      anon_sym_SQUOTE,
    ACTIONS(991), 1,
      anon_sym_DQUOTE,
    ACTIONS(993), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(995), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(384), 1,
      sym_namespace,
    STATE(491), 1,
      sym_string,
    ACTIONS(981), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1155), 2,
      sym_integer,
      sym_decimal,
    ACTIONS(1153), 4,
      sym_var,
      sym_double,
      sym_nil,
      sym_anon,
    STATE(422), 4,
      sym__string_literal1,
      sym__string_literal2,
      sym__string_literal_long1,
      sym__string_literal_long2,
    STATE(236), 15,
      sym__triples_node_path,
      sym_blank_node_property_list_path,
      sym_collection_path,
      sym__graph_node_path,
      sym__var_or_term,
      sym__graph_term,
      sym_rdf_literal,
      sym__numeric_literal,
      sym_boolean_literal,
      sym__iri,
      sym_prefixed_name,
      sym__blank_node,
      sym_iri_reference,
      sym_blank_node_label,
      aux_sym_collection_path_repeat1,
  [3411] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1157), 19,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_SLASH,
      anon_sym_RBRACK,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      sym_nil,
      sym_pn_local,
    ACTIONS(1159), 20,
      anon_sym_LPAREN,
      aux_sym_select_clause_token4,
      aux_sym_construct_query_token2,
      aux_sym_dataset_clause_token1,
      aux_sym_values_clause_token1,
      aux_sym_add_token2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
      aux_sym_using_clause_token1,
      aux_sym_graph_or_default_token2,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      aux_sym_binary_expression_token1,
      aux_sym_binary_expression_token2,
  [3458] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      sym_pn_prefix,
    ACTIONS(57), 1,
      anon_sym_LT,
    ACTIONS(89), 1,
      anon_sym_COLON,
    ACTIONS(206), 1,
      anon_sym_SQUOTE,
    ACTIONS(208), 1,
      anon_sym_DQUOTE,
    ACTIONS(210), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(212), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(814), 1,
      anon_sym__COLON,
    ACTIONS(945), 1,
      anon_sym_LPAREN,
    ACTIONS(951), 1,
      anon_sym_LBRACK,
    STATE(413), 1,
      sym_namespace,
    STATE(623), 1,
      sym_string,
    STATE(704), 1,
      sym_object_list,
    ACTIONS(202), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1123), 2,
      sym_integer,
      sym_decimal,
    ACTIONS(1121), 4,
      sym_var,
      sym_double,
      sym_nil,
      sym_anon,
    STATE(296), 4,
      sym__string_literal1,
      sym__string_literal2,
      sym__string_literal_long1,
      sym__string_literal_long2,
    STATE(688), 14,
      sym__triples_node,
      sym_blank_node_property_list,
      sym_collection,
      sym__graph_node,
      sym__var_or_term,
      sym__graph_term,
      sym_rdf_literal,
      sym__numeric_literal,
      sym_boolean_literal,
      sym__iri,
      sym_prefixed_name,
      sym__blank_node,
      sym_iri_reference,
      sym_blank_node_label,
  [3537] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      sym_pn_prefix,
    ACTIONS(57), 1,
      anon_sym_LT,
    ACTIONS(89), 1,
      anon_sym_COLON,
    ACTIONS(206), 1,
      anon_sym_SQUOTE,
    ACTIONS(208), 1,
      anon_sym_DQUOTE,
    ACTIONS(210), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(212), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(784), 1,
      anon_sym_LPAREN,
    ACTIONS(804), 1,
      anon_sym_LBRACK,
    ACTIONS(814), 1,
      anon_sym__COLON,
    STATE(413), 1,
      sym_namespace,
    STATE(623), 1,
      sym_string,
    STATE(703), 1,
      sym_object_list_path,
    ACTIONS(202), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1163), 2,
      sym_integer,
      sym_decimal,
    ACTIONS(1161), 4,
      sym_var,
      sym_double,
      sym_nil,
      sym_anon,
    STATE(296), 4,
      sym__string_literal1,
      sym__string_literal2,
      sym__string_literal_long1,
      sym__string_literal_long2,
    STATE(690), 14,
      sym__triples_node_path,
      sym_blank_node_property_list_path,
      sym_collection_path,
      sym__graph_node_path,
      sym__var_or_term,
      sym__graph_term,
      sym_rdf_literal,
      sym__numeric_literal,
      sym_boolean_literal,
      sym__iri,
      sym_prefixed_name,
      sym__blank_node,
      sym_iri_reference,
      sym_blank_node_label,
  [3616] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      sym_pn_prefix,
    ACTIONS(57), 1,
      anon_sym_LT,
    ACTIONS(89), 1,
      anon_sym_COLON,
    ACTIONS(206), 1,
      anon_sym_SQUOTE,
    ACTIONS(208), 1,
      anon_sym_DQUOTE,
    ACTIONS(210), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(212), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(784), 1,
      anon_sym_LPAREN,
    ACTIONS(804), 1,
      anon_sym_LBRACK,
    ACTIONS(814), 1,
      anon_sym__COLON,
    STATE(413), 1,
      sym_namespace,
    STATE(623), 1,
      sym_string,
    STATE(703), 1,
      sym_object_list_path,
    ACTIONS(202), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1167), 2,
      sym_integer,
      sym_decimal,
    ACTIONS(1165), 4,
      sym_var,
      sym_double,
      sym_nil,
      sym_anon,
    STATE(296), 4,
      sym__string_literal1,
      sym__string_literal2,
      sym__string_literal_long1,
      sym__string_literal_long2,
    STATE(859), 14,
      sym__triples_node_path,
      sym_blank_node_property_list_path,
      sym_collection_path,
      sym__graph_node_path,
      sym__var_or_term,
      sym__graph_term,
      sym_rdf_literal,
      sym__numeric_literal,
      sym_boolean_literal,
      sym__iri,
      sym_prefixed_name,
      sym__blank_node,
      sym_iri_reference,
      sym_blank_node_label,
  [3695] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      sym_pn_prefix,
    ACTIONS(57), 1,
      anon_sym_LT,
    ACTIONS(89), 1,
      anon_sym_COLON,
    ACTIONS(206), 1,
      anon_sym_SQUOTE,
    ACTIONS(208), 1,
      anon_sym_DQUOTE,
    ACTIONS(210), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(212), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(814), 1,
      anon_sym__COLON,
    ACTIONS(945), 1,
      anon_sym_LPAREN,
    ACTIONS(951), 1,
      anon_sym_LBRACK,
    STATE(413), 1,
      sym_namespace,
    STATE(623), 1,
      sym_string,
    STATE(815), 1,
      sym_object_list,
    ACTIONS(202), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1171), 2,
      sym_integer,
      sym_decimal,
    ACTIONS(1169), 4,
      sym_var,
      sym_double,
      sym_nil,
      sym_anon,
    STATE(296), 4,
      sym__string_literal1,
      sym__string_literal2,
      sym__string_literal_long1,
      sym__string_literal_long2,
    STATE(835), 14,
      sym__triples_node,
      sym_blank_node_property_list,
      sym_collection,
      sym__graph_node,
      sym__var_or_term,
      sym__graph_term,
      sym_rdf_literal,
      sym__numeric_literal,
      sym_boolean_literal,
      sym__iri,
      sym_prefixed_name,
      sym__blank_node,
      sym_iri_reference,
      sym_blank_node_label,
  [3774] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      sym_pn_prefix,
    ACTIONS(57), 1,
      anon_sym_LT,
    ACTIONS(89), 1,
      anon_sym_COLON,
    ACTIONS(206), 1,
      anon_sym_SQUOTE,
    ACTIONS(208), 1,
      anon_sym_DQUOTE,
    ACTIONS(210), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(212), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(814), 1,
      anon_sym__COLON,
    ACTIONS(945), 1,
      anon_sym_LPAREN,
    ACTIONS(951), 1,
      anon_sym_LBRACK,
    STATE(413), 1,
      sym_namespace,
    STATE(623), 1,
      sym_string,
    STATE(704), 1,
      sym_object_list,
    ACTIONS(202), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1171), 2,
      sym_integer,
      sym_decimal,
    ACTIONS(1169), 4,
      sym_var,
      sym_double,
      sym_nil,
      sym_anon,
    STATE(296), 4,
      sym__string_literal1,
      sym__string_literal2,
      sym__string_literal_long1,
      sym__string_literal_long2,
    STATE(835), 14,
      sym__triples_node,
      sym_blank_node_property_list,
      sym_collection,
      sym__graph_node,
      sym__var_or_term,
      sym__graph_term,
      sym_rdf_literal,
      sym__numeric_literal,
      sym_boolean_literal,
      sym__iri,
      sym_prefixed_name,
      sym__blank_node,
      sym_iri_reference,
      sym_blank_node_label,
  [3853] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(969), 1,
      sym_pn_prefix,
    ACTIONS(979), 1,
      anon_sym_LT,
    ACTIONS(983), 1,
      anon_sym_COLON,
    ACTIONS(985), 1,
      anon_sym__COLON,
    ACTIONS(989), 1,
      anon_sym_SQUOTE,
    ACTIONS(991), 1,
      anon_sym_DQUOTE,
    ACTIONS(993), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(995), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(999), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_LBRACK,
    STATE(384), 1,
      sym_namespace,
    STATE(491), 1,
      sym_string,
    ACTIONS(981), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 2,
      sym_integer,
      sym_decimal,
    ACTIONS(1173), 4,
      sym_var,
      sym_double,
      sym_nil,
      sym_anon,
    STATE(422), 4,
      sym__string_literal1,
      sym__string_literal2,
      sym__string_literal_long1,
      sym__string_literal_long2,
    STATE(246), 15,
      sym__triples_node,
      sym_blank_node_property_list,
      sym_collection,
      sym__graph_node,
      sym__var_or_term,
      sym__graph_term,
      sym_rdf_literal,
      sym__numeric_literal,
      sym_boolean_literal,
      sym__iri,
      sym_prefixed_name,
      sym__blank_node,
      sym_iri_reference,
      sym_blank_node_label,
      aux_sym_collection_repeat1,
  [3930] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(780), 1,
      sym_pn_prefix,
    ACTIONS(808), 1,
      anon_sym_LT,
    ACTIONS(812), 1,
      anon_sym_COLON,
    ACTIONS(814), 1,
      anon_sym__COLON,
    ACTIONS(818), 1,
      anon_sym_SQUOTE,
    ACTIONS(820), 1,
      anon_sym_DQUOTE,
    ACTIONS(822), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(824), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(945), 1,
      anon_sym_LPAREN,
    ACTIONS(951), 1,
      anon_sym_LBRACK,
    STATE(729), 1,
      sym_string,
    STATE(736), 1,
      sym_namespace,
    STATE(864), 1,
      sym_triples_same_subject,
    STATE(1015), 1,
      sym_triples_template,
    ACTIONS(810), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(955), 2,
      sym_integer,
      sym_decimal,
    STATE(613), 3,
      sym__triples_node,
      sym_blank_node_property_list,
      sym_collection,
    ACTIONS(953), 4,
      sym_var,
      sym_double,
      sym_nil,
      sym_anon,
    STATE(417), 4,
      sym__string_literal1,
      sym__string_literal2,
      sym__string_literal_long1,
      sym__string_literal_long2,
    STATE(694), 10,
      sym__var_or_term,
      sym__graph_term,
      sym_rdf_literal,
      sym__numeric_literal,
      sym_boolean_literal,
      sym__iri,
      sym_prefixed_name,
      sym__blank_node,
      sym_iri_reference,
      sym_blank_node_label,
  [4013] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(780), 1,
      sym_pn_prefix,
    ACTIONS(808), 1,
      anon_sym_LT,
    ACTIONS(812), 1,
      anon_sym_COLON,
    ACTIONS(814), 1,
      anon_sym__COLON,
    ACTIONS(818), 1,
      anon_sym_SQUOTE,
    ACTIONS(820), 1,
      anon_sym_DQUOTE,
    ACTIONS(822), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(824), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(945), 1,
      anon_sym_LPAREN,
    ACTIONS(951), 1,
      anon_sym_LBRACK,
    STATE(729), 1,
      sym_string,
    STATE(736), 1,
      sym_namespace,
    STATE(892), 1,
      sym_triples_same_subject,
    STATE(1104), 1,
      sym_construct_triples,
    ACTIONS(810), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(955), 2,
      sym_integer,
      sym_decimal,
    STATE(613), 3,
      sym__triples_node,
      sym_blank_node_property_list,
      sym_collection,
    ACTIONS(953), 4,
      sym_var,
      sym_double,
      sym_nil,
      sym_anon,
    STATE(417), 4,
      sym__string_literal1,
      sym__string_literal2,
      sym__string_literal_long1,
      sym__string_literal_long2,
    STATE(694), 10,
      sym__var_or_term,
      sym__graph_term,
      sym_rdf_literal,
      sym__numeric_literal,
      sym_boolean_literal,
      sym__iri,
      sym_prefixed_name,
      sym__blank_node,
      sym_iri_reference,
      sym_blank_node_label,
  [4096] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1177), 19,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_SLASH,
      anon_sym_RBRACK,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      sym_nil,
      sym_pn_local,
    ACTIONS(1179), 20,
      anon_sym_LPAREN,
      aux_sym_select_clause_token4,
      aux_sym_construct_query_token2,
      aux_sym_dataset_clause_token1,
      aux_sym_values_clause_token1,
      aux_sym_add_token2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
      aux_sym_using_clause_token1,
      aux_sym_graph_or_default_token2,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      aux_sym_binary_expression_token1,
      aux_sym_binary_expression_token2,
  [4143] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(780), 1,
      sym_pn_prefix,
    ACTIONS(784), 1,
      anon_sym_LPAREN,
    ACTIONS(804), 1,
      anon_sym_LBRACK,
    ACTIONS(808), 1,
      anon_sym_LT,
    ACTIONS(812), 1,
      anon_sym_COLON,
    ACTIONS(814), 1,
      anon_sym__COLON,
    ACTIONS(818), 1,
      anon_sym_SQUOTE,
    ACTIONS(820), 1,
      anon_sym_DQUOTE,
    ACTIONS(822), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(824), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(729), 1,
      sym_string,
    STATE(730), 1,
      sym_triples_same_subject_path,
    STATE(736), 1,
      sym_namespace,
    ACTIONS(810), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(816), 2,
      sym_integer,
      sym_decimal,
    STATE(304), 3,
      sym__triples_node_path,
      sym_blank_node_property_list_path,
      sym_collection_path,
    ACTIONS(806), 4,
      sym_var,
      sym_double,
      sym_nil,
      sym_anon,
    STATE(417), 4,
      sym__string_literal1,
      sym__string_literal2,
      sym__string_literal_long1,
      sym__string_literal_long2,
    STATE(493), 10,
      sym__var_or_term,
      sym__graph_term,
      sym_rdf_literal,
      sym__numeric_literal,
      sym_boolean_literal,
      sym__iri,
      sym_prefixed_name,
      sym__blank_node,
      sym_iri_reference,
      sym_blank_node_label,
  [4223] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      sym_pn_prefix,
    ACTIONS(57), 1,
      anon_sym_LT,
    ACTIONS(89), 1,
      anon_sym_COLON,
    ACTIONS(206), 1,
      anon_sym_SQUOTE,
    ACTIONS(208), 1,
      anon_sym_DQUOTE,
    ACTIONS(210), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(212), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(814), 1,
      anon_sym__COLON,
    ACTIONS(945), 1,
      anon_sym_LPAREN,
    ACTIONS(951), 1,
      anon_sym_LBRACK,
    STATE(413), 1,
      sym_namespace,
    STATE(623), 1,
      sym_string,
    ACTIONS(202), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1183), 2,
      sym_integer,
      sym_decimal,
    ACTIONS(1181), 4,
      sym_var,
      sym_double,
      sym_nil,
      sym_anon,
    STATE(296), 4,
      sym__string_literal1,
      sym__string_literal2,
      sym__string_literal_long1,
      sym__string_literal_long2,
    STATE(687), 14,
      sym__triples_node,
      sym_blank_node_property_list,
      sym_collection,
      sym__graph_node,
      sym__var_or_term,
      sym__graph_term,
      sym_rdf_literal,
      sym__numeric_literal,
      sym_boolean_literal,
      sym__iri,
      sym_prefixed_name,
      sym__blank_node,
      sym_iri_reference,
      sym_blank_node_label,
  [4299] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      sym_pn_prefix,
    ACTIONS(57), 1,
      anon_sym_LT,
    ACTIONS(89), 1,
      anon_sym_COLON,
    ACTIONS(206), 1,
      anon_sym_SQUOTE,
    ACTIONS(208), 1,
      anon_sym_DQUOTE,
    ACTIONS(210), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(212), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(784), 1,
      anon_sym_LPAREN,
    ACTIONS(804), 1,
      anon_sym_LBRACK,
    ACTIONS(814), 1,
      anon_sym__COLON,
    STATE(413), 1,
      sym_namespace,
    STATE(623), 1,
      sym_string,
    ACTIONS(202), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1187), 2,
      sym_integer,
      sym_decimal,
    ACTIONS(1185), 4,
      sym_var,
      sym_double,
      sym_nil,
      sym_anon,
    STATE(296), 4,
      sym__string_literal1,
      sym__string_literal2,
      sym__string_literal_long1,
      sym__string_literal_long2,
    STATE(696), 14,
      sym__triples_node_path,
      sym_blank_node_property_list_path,
      sym_collection_path,
      sym__graph_node_path,
      sym__var_or_term,
      sym__graph_term,
      sym_rdf_literal,
      sym__numeric_literal,
      sym_boolean_literal,
      sym__iri,
      sym_prefixed_name,
      sym__blank_node,
      sym_iri_reference,
      sym_blank_node_label,
  [4375] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      sym_pn_prefix,
    ACTIONS(57), 1,
      anon_sym_LT,
    ACTIONS(89), 1,
      anon_sym_COLON,
    ACTIONS(206), 1,
      anon_sym_SQUOTE,
    ACTIONS(208), 1,
      anon_sym_DQUOTE,
    ACTIONS(210), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(212), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(814), 1,
      anon_sym__COLON,
    ACTIONS(945), 1,
      anon_sym_LPAREN,
    ACTIONS(951), 1,
      anon_sym_LBRACK,
    STATE(413), 1,
      sym_namespace,
    STATE(623), 1,
      sym_string,
    ACTIONS(202), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1183), 2,
      sym_integer,
      sym_decimal,
    ACTIONS(1181), 4,
      sym_var,
      sym_double,
      sym_nil,
      sym_anon,
    STATE(296), 4,
      sym__string_literal1,
      sym__string_literal2,
      sym__string_literal_long1,
      sym__string_literal_long2,
    STATE(687), 14,
      sym__triples_node,
      sym_blank_node_property_list,
      sym_collection,
      sym__graph_node,
      sym__var_or_term,
      sym__graph_term,
      sym_rdf_literal,
      sym__numeric_literal,
      sym_boolean_literal,
      sym__iri,
      sym_prefixed_name,
      sym__blank_node,
      sym_iri_reference,
      sym_blank_node_label,
  [4451] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(780), 1,
      sym_pn_prefix,
    ACTIONS(808), 1,
      anon_sym_LT,
    ACTIONS(812), 1,
      anon_sym_COLON,
    ACTIONS(814), 1,
      anon_sym__COLON,
    ACTIONS(818), 1,
      anon_sym_SQUOTE,
    ACTIONS(820), 1,
      anon_sym_DQUOTE,
    ACTIONS(822), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(824), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(945), 1,
      anon_sym_LPAREN,
    ACTIONS(951), 1,
      anon_sym_LBRACK,
    STATE(729), 1,
      sym_string,
    STATE(736), 1,
      sym_namespace,
    STATE(910), 1,
      sym_triples_same_subject,
    ACTIONS(810), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(955), 2,
      sym_integer,
      sym_decimal,
    STATE(613), 3,
      sym__triples_node,
      sym_blank_node_property_list,
      sym_collection,
    ACTIONS(953), 4,
      sym_var,
      sym_double,
      sym_nil,
      sym_anon,
    STATE(417), 4,
      sym__string_literal1,
      sym__string_literal2,
      sym__string_literal_long1,
      sym__string_literal_long2,
    STATE(694), 10,
      sym__var_or_term,
      sym__graph_term,
      sym_rdf_literal,
      sym__numeric_literal,
      sym_boolean_literal,
      sym__iri,
      sym_prefixed_name,
      sym__blank_node,
      sym_iri_reference,
      sym_blank_node_label,
  [4531] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      sym_pn_prefix,
    ACTIONS(57), 1,
      anon_sym_LT,
    ACTIONS(89), 1,
      anon_sym_COLON,
    ACTIONS(206), 1,
      anon_sym_SQUOTE,
    ACTIONS(208), 1,
      anon_sym_DQUOTE,
    ACTIONS(210), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(212), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(784), 1,
      anon_sym_LPAREN,
    ACTIONS(804), 1,
      anon_sym_LBRACK,
    ACTIONS(814), 1,
      anon_sym__COLON,
    STATE(413), 1,
      sym_namespace,
    STATE(623), 1,
      sym_string,
    ACTIONS(202), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1187), 2,
      sym_integer,
      sym_decimal,
    ACTIONS(1185), 4,
      sym_var,
      sym_double,
      sym_nil,
      sym_anon,
    STATE(296), 4,
      sym__string_literal1,
      sym__string_literal2,
      sym__string_literal_long1,
      sym__string_literal_long2,
    STATE(696), 14,
      sym__triples_node_path,
      sym_blank_node_property_list_path,
      sym_collection_path,
      sym__graph_node_path,
      sym__var_or_term,
      sym__graph_term,
      sym_rdf_literal,
      sym__numeric_literal,
      sym_boolean_literal,
      sym__iri,
      sym_prefixed_name,
      sym__blank_node,
      sym_iri_reference,
      sym_blank_node_label,
  [4607] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11), 1,
      aux_sym_select_clause_token1,
    ACTIONS(13), 1,
      aux_sym_construct_query_token1,
    ACTIONS(15), 1,
      aux_sym_describe_query_token1,
    ACTIONS(17), 1,
      aux_sym_ask_query_token1,
    ACTIONS(19), 1,
      aux_sym_load_token1,
    ACTIONS(21), 1,
      aux_sym_clear_token1,
    ACTIONS(23), 1,
      aux_sym_drop_token1,
    ACTIONS(25), 1,
      aux_sym_create_token1,
    ACTIONS(27), 1,
      aux_sym_add_token1,
    ACTIONS(29), 1,
      aux_sym_move_token1,
    ACTIONS(31), 1,
      aux_sym_copy_token1,
    ACTIONS(33), 1,
      anon_sym_INSERTDATA,
    ACTIONS(35), 1,
      anon_sym_DELETEDATA,
    ACTIONS(37), 1,
      anon_sym_DELETEWHERE,
    ACTIONS(39), 1,
      aux_sym_modify_token1,
    ACTIONS(41), 1,
      aux_sym_delete_clause_token1,
    ACTIONS(43), 1,
      aux_sym_insert_clause_token1,
    STATE(757), 1,
      sym_select_clause,
    STATE(788), 1,
      sym_delete_clause,
    STATE(863), 1,
      sym_insert_clause,
    STATE(401), 4,
      sym_select_query,
      sym_construct_query,
      sym_describe_query,
      sym_ask_query,
    STATE(456), 11,
      sym_load,
      sym_clear,
      sym_drop,
      sym_create,
      sym_add,
      sym_move,
      sym_copy,
      sym_insert_data,
      sym_delete_data,
      sym_delete_where,
      sym_modify,
  [4690] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1157), 7,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      sym_var,
      anon_sym_LT,
    ACTIONS(1159), 27,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_construct_query_token2,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_dataset_clause_token1,
      aux_sym_group_clause_token1,
      aux_sym_having_clause_token1,
      aux_sym_order_clause_token1,
      aux_sym_limit_clause_token1,
      aux_sym_offset_clause_token1,
      aux_sym_values_clause_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      aux_sym_modify_token1,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
      anon_sym_COLON,
      sym_pn_prefix,
      sym_pn_local,
  [4732] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1177), 7,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      sym_var,
      anon_sym_LT,
    ACTIONS(1179), 27,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_construct_query_token2,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_dataset_clause_token1,
      aux_sym_group_clause_token1,
      aux_sym_having_clause_token1,
      aux_sym_order_clause_token1,
      aux_sym_limit_clause_token1,
      aux_sym_offset_clause_token1,
      aux_sym_values_clause_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      aux_sym_modify_token1,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
      anon_sym_COLON,
      sym_pn_prefix,
      sym_pn_local,
  [4774] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1193), 1,
      sym_pn_local,
    ACTIONS(1189), 7,
      ts_builtin_sym_end,
      anon_sym_LBRACE,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      sym_var,
      anon_sym_LT,
    ACTIONS(1191), 26,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_construct_query_token2,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_dataset_clause_token1,
      aux_sym_group_clause_token1,
      aux_sym_having_clause_token1,
      aux_sym_order_clause_token1,
      aux_sym_limit_clause_token1,
      aux_sym_offset_clause_token1,
      aux_sym_values_clause_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      aux_sym_modify_token1,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
      anon_sym_COLON,
      sym_pn_prefix,
  [4818] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7), 1,
      aux_sym_base_declaration_token1,
    ACTIONS(9), 1,
      aux_sym_prefix_declaration_token1,
    ACTIONS(19), 1,
      aux_sym_load_token1,
    ACTIONS(21), 1,
      aux_sym_clear_token1,
    ACTIONS(23), 1,
      aux_sym_drop_token1,
    ACTIONS(25), 1,
      aux_sym_create_token1,
    ACTIONS(27), 1,
      aux_sym_add_token1,
    ACTIONS(29), 1,
      aux_sym_move_token1,
    ACTIONS(31), 1,
      aux_sym_copy_token1,
    ACTIONS(33), 1,
      anon_sym_INSERTDATA,
    ACTIONS(35), 1,
      anon_sym_DELETEDATA,
    ACTIONS(37), 1,
      anon_sym_DELETEWHERE,
    ACTIONS(39), 1,
      aux_sym_modify_token1,
    ACTIONS(41), 1,
      aux_sym_delete_clause_token1,
    ACTIONS(43), 1,
      aux_sym_insert_clause_token1,
    STATE(378), 1,
      sym_prologue,
    STATE(513), 1,
      sym__update,
    STATE(788), 1,
      sym_delete_clause,
    STATE(863), 1,
      sym_insert_clause,
    STATE(404), 3,
      sym_base_declaration,
      sym_prefix_declaration,
      aux_sym_prologue_repeat1,
    STATE(486), 11,
      sym_load,
      sym_clear,
      sym_drop,
      sym_create,
      sym_add,
      sym_move,
      sym_copy,
      sym_insert_data,
      sym_delete_data,
      sym_delete_where,
      sym_modify,
  [4897] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1013), 1,
      aux_sym_group_clause_token1,
    ACTIONS(1015), 1,
      aux_sym_having_clause_token1,
    ACTIONS(1017), 1,
      aux_sym_order_clause_token1,
    ACTIONS(1019), 1,
      aux_sym_limit_clause_token1,
    ACTIONS(1021), 1,
      aux_sym_offset_clause_token1,
    STATE(300), 1,
      sym_group_clause,
    STATE(323), 1,
      sym_having_clause,
    STATE(373), 1,
      sym_order_clause,
    STATE(379), 1,
      sym_limit_clause,
    STATE(380), 1,
      sym_offset_clause,
    STATE(398), 1,
      sym_limit_offset_clauses,
    STATE(447), 1,
      sym_solution_modifier,
    ACTIONS(1197), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1195), 19,
      ts_builtin_sym_end,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_values_clause_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [4962] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1013), 1,
      aux_sym_group_clause_token1,
    ACTIONS(1015), 1,
      aux_sym_having_clause_token1,
    ACTIONS(1017), 1,
      aux_sym_order_clause_token1,
    ACTIONS(1019), 1,
      aux_sym_limit_clause_token1,
    ACTIONS(1021), 1,
      aux_sym_offset_clause_token1,
    STATE(300), 1,
      sym_group_clause,
    STATE(323), 1,
      sym_having_clause,
    STATE(373), 1,
      sym_order_clause,
    STATE(379), 1,
      sym_limit_clause,
    STATE(380), 1,
      sym_offset_clause,
    STATE(398), 1,
      sym_limit_offset_clauses,
    STATE(454), 1,
      sym_solution_modifier,
    ACTIONS(1201), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1199), 19,
      ts_builtin_sym_end,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_values_clause_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [5027] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1013), 1,
      aux_sym_group_clause_token1,
    ACTIONS(1015), 1,
      aux_sym_having_clause_token1,
    ACTIONS(1017), 1,
      aux_sym_order_clause_token1,
    ACTIONS(1019), 1,
      aux_sym_limit_clause_token1,
    ACTIONS(1021), 1,
      aux_sym_offset_clause_token1,
    STATE(300), 1,
      sym_group_clause,
    STATE(323), 1,
      sym_having_clause,
    STATE(373), 1,
      sym_order_clause,
    STATE(379), 1,
      sym_limit_clause,
    STATE(380), 1,
      sym_offset_clause,
    STATE(398), 1,
      sym_limit_offset_clauses,
    STATE(462), 1,
      sym_solution_modifier,
    ACTIONS(1205), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1203), 19,
      ts_builtin_sym_end,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_values_clause_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [5092] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1013), 1,
      aux_sym_group_clause_token1,
    ACTIONS(1015), 1,
      aux_sym_having_clause_token1,
    ACTIONS(1017), 1,
      aux_sym_order_clause_token1,
    ACTIONS(1019), 1,
      aux_sym_limit_clause_token1,
    ACTIONS(1021), 1,
      aux_sym_offset_clause_token1,
    STATE(300), 1,
      sym_group_clause,
    STATE(323), 1,
      sym_having_clause,
    STATE(373), 1,
      sym_order_clause,
    STATE(379), 1,
      sym_limit_clause,
    STATE(380), 1,
      sym_offset_clause,
    STATE(398), 1,
      sym_limit_offset_clauses,
    STATE(483), 1,
      sym_solution_modifier,
    ACTIONS(1209), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1207), 19,
      ts_builtin_sym_end,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_values_clause_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [5157] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7), 1,
      aux_sym_base_declaration_token1,
    ACTIONS(9), 1,
      aux_sym_prefix_declaration_token1,
    ACTIONS(19), 1,
      aux_sym_load_token1,
    ACTIONS(21), 1,
      aux_sym_clear_token1,
    ACTIONS(23), 1,
      aux_sym_drop_token1,
    ACTIONS(25), 1,
      aux_sym_create_token1,
    ACTIONS(27), 1,
      aux_sym_add_token1,
    ACTIONS(29), 1,
      aux_sym_move_token1,
    ACTIONS(31), 1,
      aux_sym_copy_token1,
    ACTIONS(33), 1,
      anon_sym_INSERTDATA,
    ACTIONS(35), 1,
      anon_sym_DELETEDATA,
    ACTIONS(37), 1,
      anon_sym_DELETEWHERE,
    ACTIONS(39), 1,
      aux_sym_modify_token1,
    ACTIONS(41), 1,
      aux_sym_delete_clause_token1,
    ACTIONS(43), 1,
      aux_sym_insert_clause_token1,
    STATE(378), 1,
      sym_prologue,
    STATE(517), 1,
      sym__update,
    STATE(788), 1,
      sym_delete_clause,
    STATE(863), 1,
      sym_insert_clause,
    STATE(404), 3,
      sym_base_declaration,
      sym_prefix_declaration,
      aux_sym_prologue_repeat1,
    STATE(486), 11,
      sym_load,
      sym_clear,
      sym_drop,
      sym_create,
      sym_add,
      sym_move,
      sym_copy,
      sym_insert_data,
      sym_delete_data,
      sym_delete_where,
      sym_modify,
  [5236] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1013), 1,
      aux_sym_group_clause_token1,
    ACTIONS(1015), 1,
      aux_sym_having_clause_token1,
    ACTIONS(1017), 1,
      aux_sym_order_clause_token1,
    ACTIONS(1019), 1,
      aux_sym_limit_clause_token1,
    ACTIONS(1021), 1,
      aux_sym_offset_clause_token1,
    STATE(300), 1,
      sym_group_clause,
    STATE(323), 1,
      sym_having_clause,
    STATE(373), 1,
      sym_order_clause,
    STATE(379), 1,
      sym_limit_clause,
    STATE(380), 1,
      sym_offset_clause,
    STATE(398), 1,
      sym_limit_offset_clauses,
    STATE(435), 1,
      sym_solution_modifier,
    ACTIONS(1213), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1211), 19,
      ts_builtin_sym_end,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_values_clause_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [5301] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1013), 1,
      aux_sym_group_clause_token1,
    ACTIONS(1015), 1,
      aux_sym_having_clause_token1,
    ACTIONS(1017), 1,
      aux_sym_order_clause_token1,
    ACTIONS(1019), 1,
      aux_sym_limit_clause_token1,
    ACTIONS(1021), 1,
      aux_sym_offset_clause_token1,
    STATE(300), 1,
      sym_group_clause,
    STATE(323), 1,
      sym_having_clause,
    STATE(373), 1,
      sym_order_clause,
    STATE(379), 1,
      sym_limit_clause,
    STATE(380), 1,
      sym_offset_clause,
    STATE(398), 1,
      sym_limit_offset_clauses,
    STATE(482), 1,
      sym_solution_modifier,
    ACTIONS(1217), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1215), 19,
      ts_builtin_sym_end,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_values_clause_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [5366] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1013), 1,
      aux_sym_group_clause_token1,
    ACTIONS(1015), 1,
      aux_sym_having_clause_token1,
    ACTIONS(1017), 1,
      aux_sym_order_clause_token1,
    ACTIONS(1019), 1,
      aux_sym_limit_clause_token1,
    ACTIONS(1021), 1,
      aux_sym_offset_clause_token1,
    STATE(300), 1,
      sym_group_clause,
    STATE(323), 1,
      sym_having_clause,
    STATE(373), 1,
      sym_order_clause,
    STATE(379), 1,
      sym_limit_clause,
    STATE(380), 1,
      sym_offset_clause,
    STATE(398), 1,
      sym_limit_offset_clauses,
    STATE(470), 1,
      sym_solution_modifier,
    ACTIONS(1221), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1219), 19,
      ts_builtin_sym_end,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_values_clause_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [5431] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1013), 1,
      aux_sym_group_clause_token1,
    ACTIONS(1015), 1,
      aux_sym_having_clause_token1,
    ACTIONS(1017), 1,
      aux_sym_order_clause_token1,
    ACTIONS(1019), 1,
      aux_sym_limit_clause_token1,
    ACTIONS(1021), 1,
      aux_sym_offset_clause_token1,
    STATE(300), 1,
      sym_group_clause,
    STATE(323), 1,
      sym_having_clause,
    STATE(373), 1,
      sym_order_clause,
    STATE(379), 1,
      sym_limit_clause,
    STATE(380), 1,
      sym_offset_clause,
    STATE(398), 1,
      sym_limit_offset_clauses,
    STATE(451), 1,
      sym_solution_modifier,
    ACTIONS(1029), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1027), 19,
      ts_builtin_sym_end,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_values_clause_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [5496] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1013), 1,
      aux_sym_group_clause_token1,
    ACTIONS(1015), 1,
      aux_sym_having_clause_token1,
    ACTIONS(1017), 1,
      aux_sym_order_clause_token1,
    ACTIONS(1019), 1,
      aux_sym_limit_clause_token1,
    ACTIONS(1021), 1,
      aux_sym_offset_clause_token1,
    STATE(300), 1,
      sym_group_clause,
    STATE(323), 1,
      sym_having_clause,
    STATE(373), 1,
      sym_order_clause,
    STATE(379), 1,
      sym_limit_clause,
    STATE(380), 1,
      sym_offset_clause,
    STATE(398), 1,
      sym_limit_offset_clauses,
    STATE(455), 1,
      sym_solution_modifier,
    ACTIONS(1225), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1223), 19,
      ts_builtin_sym_end,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_values_clause_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [5561] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1013), 1,
      aux_sym_group_clause_token1,
    ACTIONS(1015), 1,
      aux_sym_having_clause_token1,
    ACTIONS(1017), 1,
      aux_sym_order_clause_token1,
    ACTIONS(1019), 1,
      aux_sym_limit_clause_token1,
    ACTIONS(1021), 1,
      aux_sym_offset_clause_token1,
    STATE(300), 1,
      sym_group_clause,
    STATE(323), 1,
      sym_having_clause,
    STATE(373), 1,
      sym_order_clause,
    STATE(379), 1,
      sym_limit_clause,
    STATE(380), 1,
      sym_offset_clause,
    STATE(398), 1,
      sym_limit_offset_clauses,
    STATE(442), 1,
      sym_solution_modifier,
    ACTIONS(1229), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1227), 19,
      ts_builtin_sym_end,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_values_clause_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [5626] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1157), 6,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
    ACTIONS(1159), 26,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_construct_query_token2,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_dataset_clause_token1,
      aux_sym_group_clause_token1,
      aux_sym_having_clause_token1,
      aux_sym_order_clause_token1,
      aux_sym_limit_clause_token1,
      aux_sym_offset_clause_token1,
      aux_sym_values_clause_token1,
      aux_sym_load_token1,
      aux_sym_load_token3,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      aux_sym_modify_token1,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
      sym_pn_local,
  [5666] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1193), 1,
      sym_pn_local,
    ACTIONS(1189), 6,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
    ACTIONS(1191), 25,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_construct_query_token2,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_dataset_clause_token1,
      aux_sym_group_clause_token1,
      aux_sym_having_clause_token1,
      aux_sym_order_clause_token1,
      aux_sym_limit_clause_token1,
      aux_sym_offset_clause_token1,
      aux_sym_values_clause_token1,
      aux_sym_load_token1,
      aux_sym_load_token3,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      aux_sym_modify_token1,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
  [5708] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1177), 6,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
    ACTIONS(1179), 26,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_construct_query_token2,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_dataset_clause_token1,
      aux_sym_group_clause_token1,
      aux_sym_having_clause_token1,
      aux_sym_order_clause_token1,
      aux_sym_limit_clause_token1,
      aux_sym_offset_clause_token1,
      aux_sym_values_clause_token1,
      aux_sym_load_token1,
      aux_sym_load_token3,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      aux_sym_modify_token1,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
      sym_pn_local,
  [5748] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1233), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1231), 29,
      anon_sym_SEMI,
      aux_sym_select_clause_token4,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_COMMA,
      anon_sym_SLASH,
      anon_sym_RBRACK,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      aux_sym_binary_expression_token1,
      aux_sym_binary_expression_token2,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET_CARET,
      sym_lang_tag,
  [5787] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1237), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1235), 29,
      anon_sym_SEMI,
      aux_sym_select_clause_token4,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_COMMA,
      anon_sym_SLASH,
      anon_sym_RBRACK,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      aux_sym_binary_expression_token1,
      aux_sym_binary_expression_token2,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET_CARET,
      sym_lang_tag,
  [5826] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1241), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1239), 29,
      anon_sym_SEMI,
      aux_sym_select_clause_token4,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_COMMA,
      anon_sym_SLASH,
      anon_sym_RBRACK,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      aux_sym_binary_expression_token1,
      aux_sym_binary_expression_token2,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET_CARET,
      sym_lang_tag,
  [5865] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1245), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1243), 29,
      anon_sym_SEMI,
      aux_sym_select_clause_token4,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_COMMA,
      anon_sym_SLASH,
      anon_sym_RBRACK,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      aux_sym_binary_expression_token1,
      aux_sym_binary_expression_token2,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET_CARET,
      sym_lang_tag,
  [5904] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1249), 1,
      aux_sym_dataset_clause_token1,
    ACTIONS(1252), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    STATE(294), 2,
      sym_dataset_clause,
      aux_sym_select_query_repeat1,
    ACTIONS(1247), 26,
      ts_builtin_sym_end,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_construct_query_token2,
      anon_sym_LBRACE,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_group_clause_token1,
      aux_sym_having_clause_token1,
      aux_sym_order_clause_token1,
      aux_sym_limit_clause_token1,
      aux_sym_offset_clause_token1,
      aux_sym_values_clause_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [5947] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1256), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1254), 29,
      anon_sym_SEMI,
      aux_sym_select_clause_token4,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_COMMA,
      anon_sym_SLASH,
      anon_sym_RBRACK,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      aux_sym_binary_expression_token1,
      aux_sym_binary_expression_token2,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET_CARET,
      sym_lang_tag,
  [5986] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1260), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1258), 29,
      anon_sym_SEMI,
      aux_sym_select_clause_token4,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_COMMA,
      anon_sym_SLASH,
      anon_sym_RBRACK,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      aux_sym_binary_expression_token1,
      aux_sym_binary_expression_token2,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET_CARET,
      sym_lang_tag,
  [6025] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1264), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1262), 29,
      anon_sym_SEMI,
      aux_sym_select_clause_token4,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_COMMA,
      anon_sym_SLASH,
      anon_sym_RBRACK,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      aux_sym_binary_expression_token1,
      aux_sym_binary_expression_token2,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET_CARET,
      sym_lang_tag,
  [6064] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1268), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1266), 29,
      anon_sym_SEMI,
      aux_sym_select_clause_token4,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_COMMA,
      anon_sym_SLASH,
      anon_sym_RBRACK,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      aux_sym_binary_expression_token1,
      aux_sym_binary_expression_token2,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET_CARET,
      sym_lang_tag,
  [6103] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1272), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1270), 29,
      anon_sym_SEMI,
      aux_sym_select_clause_token4,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_COMMA,
      anon_sym_SLASH,
      anon_sym_RBRACK,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      aux_sym_binary_expression_token1,
      aux_sym_binary_expression_token2,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_CARET_CARET,
      sym_lang_tag,
  [6142] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1015), 1,
      aux_sym_having_clause_token1,
    ACTIONS(1017), 1,
      aux_sym_order_clause_token1,
    ACTIONS(1019), 1,
      aux_sym_limit_clause_token1,
    ACTIONS(1021), 1,
      aux_sym_offset_clause_token1,
    STATE(326), 1,
      sym_having_clause,
    STATE(376), 1,
      sym_order_clause,
    STATE(379), 1,
      sym_limit_clause,
    STATE(380), 1,
      sym_offset_clause,
    STATE(392), 1,
      sym_limit_offset_clauses,
    ACTIONS(1276), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1274), 19,
      ts_builtin_sym_end,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_values_clause_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [6198] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1282), 1,
      aux_sym_group_or_union_graph_pattern_token1,
    STATE(301), 1,
      aux_sym_group_or_union_graph_pattern_repeat1,
    ACTIONS(1280), 11,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
    ACTIONS(1278), 17,
      anon_sym_LPAREN,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
  [6240] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(969), 1,
      sym_pn_prefix,
    ACTIONS(979), 1,
      anon_sym_LT,
    ACTIONS(983), 1,
      anon_sym_COLON,
    ACTIONS(1287), 1,
      anon_sym_LPAREN,
    ACTIONS(1291), 1,
      anon_sym_a,
    ACTIONS(1293), 1,
      anon_sym_CARET,
    ACTIONS(1295), 1,
      anon_sym_BANG,
    ACTIONS(1297), 1,
      sym_var,
    STATE(256), 1,
      sym__predicate_path,
    STATE(384), 1,
      sym_namespace,
    STATE(698), 1,
      sym_property_path_rest,
    STATE(707), 1,
      sym_path_inverse,
    STATE(502), 3,
      sym__path,
      sym_binary_path,
      sym_path_element,
    ACTIONS(1285), 4,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
    STATE(477), 4,
      sym__primary_path,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
    ACTIONS(1289), 7,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
  [6306] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1303), 1,
      aux_sym_group_or_union_graph_pattern_token1,
    STATE(301), 1,
      aux_sym_group_or_union_graph_pattern_repeat1,
    ACTIONS(1301), 11,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
    ACTIONS(1299), 17,
      anon_sym_LPAREN,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
  [6348] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(969), 1,
      sym_pn_prefix,
    ACTIONS(979), 1,
      anon_sym_LT,
    ACTIONS(983), 1,
      anon_sym_COLON,
    ACTIONS(1287), 1,
      anon_sym_LPAREN,
    ACTIONS(1291), 1,
      anon_sym_a,
    ACTIONS(1293), 1,
      anon_sym_CARET,
    ACTIONS(1295), 1,
      anon_sym_BANG,
    ACTIONS(1309), 1,
      sym_var,
    STATE(257), 1,
      sym__predicate_path,
    STATE(384), 1,
      sym_namespace,
    STATE(700), 1,
      sym_property_path,
    STATE(707), 1,
      sym_path_inverse,
    STATE(722), 1,
      sym_property_list_path,
    ACTIONS(1305), 3,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
    STATE(502), 3,
      sym__path,
      sym_binary_path,
      sym_path_element,
    STATE(477), 4,
      sym__primary_path,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
    ACTIONS(1307), 7,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
  [6416] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1303), 1,
      aux_sym_group_or_union_graph_pattern_token1,
    STATE(303), 1,
      aux_sym_group_or_union_graph_pattern_repeat1,
    ACTIONS(1313), 11,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
    ACTIONS(1311), 17,
      anon_sym_LPAREN,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
  [6458] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(399), 11,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
    ACTIONS(401), 18,
      anon_sym_LPAREN,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_group_or_union_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
  [6495] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1315), 1,
      sym_pn_prefix,
    ACTIONS(1323), 1,
      anon_sym_LT,
    ACTIONS(1329), 1,
      anon_sym_COLON,
    ACTIONS(1332), 1,
      sym_double,
    ACTIONS(1335), 1,
      anon_sym_SQUOTE,
    ACTIONS(1338), 1,
      anon_sym_DQUOTE,
    ACTIONS(1341), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(1344), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(579), 1,
      sym_string,
    STATE(604), 1,
      sym_namespace,
    ACTIONS(1318), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(1326), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1320), 3,
      aux_sym__data_block_value_token1,
      sym_integer,
      sym_decimal,
    STATE(417), 4,
      sym__string_literal1,
      sym__string_literal2,
      sym__string_literal_long1,
      sym__string_literal_long2,
    STATE(307), 8,
      sym__data_block_value,
      sym_rdf_literal,
      sym__numeric_literal,
      sym_boolean_literal,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
      aux_sym__inline_data_one_var_repeat1,
  [6558] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1349), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1347), 27,
      anon_sym_SEMI,
      aux_sym_select_clause_token4,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_COMMA,
      anon_sym_SLASH,
      anon_sym_RBRACK,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      aux_sym_binary_expression_token1,
      aux_sym_binary_expression_token2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [6595] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1353), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1351), 27,
      anon_sym_SEMI,
      aux_sym_select_clause_token4,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_COMMA,
      anon_sym_SLASH,
      anon_sym_RBRACK,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      aux_sym_binary_expression_token1,
      aux_sym_binary_expression_token2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [6632] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(605), 11,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
    ACTIONS(607), 18,
      anon_sym_LPAREN,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_group_or_union_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
  [6669] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1357), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1355), 27,
      ts_builtin_sym_end,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_construct_query_token2,
      anon_sym_LBRACE,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_dataset_clause_token1,
      aux_sym_group_clause_token1,
      aux_sym_having_clause_token1,
      aux_sym_order_clause_token1,
      aux_sym_limit_clause_token1,
      aux_sym_offset_clause_token1,
      aux_sym_values_clause_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [6706] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1361), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1359), 27,
      ts_builtin_sym_end,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_construct_query_token2,
      anon_sym_LBRACE,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_dataset_clause_token1,
      aux_sym_group_clause_token1,
      aux_sym_having_clause_token1,
      aux_sym_order_clause_token1,
      aux_sym_limit_clause_token1,
      aux_sym_offset_clause_token1,
      aux_sym_values_clause_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [6743] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1365), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1363), 27,
      ts_builtin_sym_end,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_construct_query_token2,
      anon_sym_LBRACE,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_dataset_clause_token1,
      aux_sym_group_clause_token1,
      aux_sym_having_clause_token1,
      aux_sym_order_clause_token1,
      aux_sym_limit_clause_token1,
      aux_sym_offset_clause_token1,
      aux_sym_values_clause_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [6780] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(609), 11,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
    ACTIONS(611), 18,
      anon_sym_LPAREN,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_group_or_union_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
  [6817] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1369), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1367), 27,
      anon_sym_SEMI,
      aux_sym_select_clause_token4,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_COMMA,
      anon_sym_SLASH,
      anon_sym_RBRACK,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      aux_sym_binary_expression_token1,
      aux_sym_binary_expression_token2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [6854] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1280), 11,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
    ACTIONS(1278), 18,
      anon_sym_LPAREN,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_group_or_union_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
  [6891] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(435), 11,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
    ACTIONS(437), 17,
      anon_sym_LPAREN,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
  [6927] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1373), 11,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
    ACTIONS(1371), 17,
      anon_sym_LPAREN,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
  [6963] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(808), 1,
      anon_sym_LT,
    ACTIONS(818), 1,
      anon_sym_SQUOTE,
    ACTIONS(820), 1,
      anon_sym_DQUOTE,
    ACTIONS(822), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(824), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(1375), 1,
      sym_pn_prefix,
    ACTIONS(1377), 1,
      anon_sym_RPAREN,
    ACTIONS(1381), 1,
      anon_sym_COLON,
    ACTIONS(1383), 1,
      sym_double,
    STATE(579), 1,
      sym_string,
    STATE(604), 1,
      sym_namespace,
    ACTIONS(810), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1379), 3,
      aux_sym__data_block_value_token1,
      sym_integer,
      sym_decimal,
    STATE(417), 4,
      sym__string_literal1,
      sym__string_literal2,
      sym__string_literal_long1,
      sym__string_literal_long2,
    STATE(307), 8,
      sym__data_block_value,
      sym_rdf_literal,
      sym__numeric_literal,
      sym_boolean_literal,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
      aux_sym__inline_data_one_var_repeat1,
  [7025] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1387), 11,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
    ACTIONS(1385), 17,
      anon_sym_LPAREN,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
  [7061] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1391), 11,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
    ACTIONS(1389), 17,
      anon_sym_LPAREN,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
  [7097] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1395), 11,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
    ACTIONS(1393), 17,
      anon_sym_LPAREN,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
  [7133] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1017), 1,
      aux_sym_order_clause_token1,
    ACTIONS(1019), 1,
      aux_sym_limit_clause_token1,
    ACTIONS(1021), 1,
      aux_sym_offset_clause_token1,
    STATE(376), 1,
      sym_order_clause,
    STATE(379), 1,
      sym_limit_clause,
    STATE(380), 1,
      sym_offset_clause,
    STATE(392), 1,
      sym_limit_offset_clauses,
    ACTIONS(1276), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1274), 19,
      ts_builtin_sym_end,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_values_clause_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [7183] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1399), 11,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
    ACTIONS(1397), 17,
      anon_sym_LPAREN,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
  [7219] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1403), 11,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
    ACTIONS(1401), 17,
      anon_sym_LPAREN,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
  [7255] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1017), 1,
      aux_sym_order_clause_token1,
    ACTIONS(1019), 1,
      aux_sym_limit_clause_token1,
    ACTIONS(1021), 1,
      aux_sym_offset_clause_token1,
    STATE(374), 1,
      sym_order_clause,
    STATE(379), 1,
      sym_limit_clause,
    STATE(380), 1,
      sym_offset_clause,
    STATE(405), 1,
      sym_limit_offset_clauses,
    ACTIONS(1407), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1405), 19,
      ts_builtin_sym_end,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_values_clause_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [7305] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1411), 11,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
    ACTIONS(1409), 17,
      anon_sym_LPAREN,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
  [7341] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1415), 11,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
    ACTIONS(1413), 17,
      anon_sym_LPAREN,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
  [7377] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1419), 11,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
    ACTIONS(1417), 17,
      anon_sym_LPAREN,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
  [7413] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1423), 11,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
    ACTIONS(1421), 17,
      anon_sym_LPAREN,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
  [7449] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1427), 11,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
    ACTIONS(1425), 17,
      anon_sym_LPAREN,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
  [7485] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1431), 11,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
    ACTIONS(1429), 17,
      anon_sym_LPAREN,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
  [7521] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(403), 11,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
    ACTIONS(405), 17,
      anon_sym_LPAREN,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
  [7557] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(403), 11,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
    ACTIONS(405), 17,
      anon_sym_LPAREN,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
  [7593] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(403), 11,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
    ACTIONS(405), 17,
      anon_sym_LPAREN,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
  [7629] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(403), 11,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
    ACTIONS(405), 17,
      anon_sym_LPAREN,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
  [7665] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(407), 11,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
    ACTIONS(409), 17,
      anon_sym_LPAREN,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
  [7701] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(411), 11,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
    ACTIONS(413), 17,
      anon_sym_LPAREN,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
  [7737] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(415), 11,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
    ACTIONS(417), 17,
      anon_sym_LPAREN,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
  [7773] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(419), 11,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
    ACTIONS(421), 17,
      anon_sym_LPAREN,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
  [7809] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(423), 11,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
    ACTIONS(425), 17,
      anon_sym_LPAREN,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
  [7845] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(427), 11,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
    ACTIONS(429), 17,
      anon_sym_LPAREN,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
  [7881] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(431), 11,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
    ACTIONS(433), 17,
      anon_sym_LPAREN,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
  [7917] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(439), 11,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
    ACTIONS(441), 17,
      anon_sym_LPAREN,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
  [7953] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(443), 11,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
    ACTIONS(445), 17,
      anon_sym_LPAREN,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
  [7989] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(483), 11,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
    ACTIONS(485), 17,
      anon_sym_LPAREN,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
  [8025] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(487), 11,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
    ACTIONS(489), 17,
      anon_sym_LPAREN,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
  [8061] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(613), 11,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
    ACTIONS(615), 17,
      anon_sym_LPAREN,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
  [8097] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(491), 11,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
    ACTIONS(493), 17,
      anon_sym_LPAREN,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
  [8133] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(549), 11,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
    ACTIONS(551), 17,
      anon_sym_LPAREN,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
  [8169] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(553), 11,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
    ACTIONS(555), 17,
      anon_sym_LPAREN,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
  [8205] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(557), 11,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
    ACTIONS(559), 17,
      anon_sym_LPAREN,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
  [8241] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(561), 11,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
    ACTIONS(563), 17,
      anon_sym_LPAREN,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
  [8277] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(565), 11,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
    ACTIONS(567), 17,
      anon_sym_LPAREN,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
  [8313] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(569), 11,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
    ACTIONS(571), 17,
      anon_sym_LPAREN,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
  [8349] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(573), 11,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
    ACTIONS(575), 17,
      anon_sym_LPAREN,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
  [8385] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(577), 11,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
    ACTIONS(579), 17,
      anon_sym_LPAREN,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
  [8421] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(581), 11,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
    ACTIONS(583), 17,
      anon_sym_LPAREN,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
  [8457] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(585), 11,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
    ACTIONS(587), 17,
      anon_sym_LPAREN,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
  [8493] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(589), 11,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
    ACTIONS(591), 17,
      anon_sym_LPAREN,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
  [8529] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(593), 11,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
    ACTIONS(595), 17,
      anon_sym_LPAREN,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
  [8565] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(597), 11,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
    ACTIONS(599), 17,
      anon_sym_LPAREN,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
  [8601] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(601), 11,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
    ACTIONS(603), 17,
      anon_sym_LPAREN,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
  [8637] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(808), 1,
      anon_sym_LT,
    ACTIONS(818), 1,
      anon_sym_SQUOTE,
    ACTIONS(820), 1,
      anon_sym_DQUOTE,
    ACTIONS(822), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(824), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(1375), 1,
      sym_pn_prefix,
    ACTIONS(1381), 1,
      anon_sym_COLON,
    ACTIONS(1433), 1,
      anon_sym_RBRACE,
    ACTIONS(1437), 1,
      sym_double,
    STATE(579), 1,
      sym_string,
    STATE(604), 1,
      sym_namespace,
    ACTIONS(810), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1435), 3,
      aux_sym__data_block_value_token1,
      sym_integer,
      sym_decimal,
    STATE(417), 4,
      sym__string_literal1,
      sym__string_literal2,
      sym__string_literal_long1,
      sym__string_literal_long2,
    STATE(370), 8,
      sym__data_block_value,
      sym_rdf_literal,
      sym__numeric_literal,
      sym_boolean_literal,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
      aux_sym__inline_data_one_var_repeat1,
  [8699] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1387), 11,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
    ACTIONS(1385), 17,
      anon_sym_LPAREN,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
  [8735] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(808), 1,
      anon_sym_LT,
    ACTIONS(818), 1,
      anon_sym_SQUOTE,
    ACTIONS(820), 1,
      anon_sym_DQUOTE,
    ACTIONS(822), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(824), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(1375), 1,
      sym_pn_prefix,
    ACTIONS(1381), 1,
      anon_sym_COLON,
    ACTIONS(1439), 1,
      anon_sym_RBRACE,
    ACTIONS(1443), 1,
      sym_double,
    STATE(579), 1,
      sym_string,
    STATE(604), 1,
      sym_namespace,
    ACTIONS(810), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1441), 3,
      aux_sym__data_block_value_token1,
      sym_integer,
      sym_decimal,
    STATE(417), 4,
      sym__string_literal1,
      sym__string_literal2,
      sym__string_literal_long1,
      sym__string_literal_long2,
    STATE(367), 8,
      sym__data_block_value,
      sym_rdf_literal,
      sym__numeric_literal,
      sym_boolean_literal,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
      aux_sym__inline_data_one_var_repeat1,
  [8797] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(808), 1,
      anon_sym_LT,
    ACTIONS(818), 1,
      anon_sym_SQUOTE,
    ACTIONS(820), 1,
      anon_sym_DQUOTE,
    ACTIONS(822), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(824), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(1375), 1,
      sym_pn_prefix,
    ACTIONS(1381), 1,
      anon_sym_COLON,
    ACTIONS(1383), 1,
      sym_double,
    ACTIONS(1445), 1,
      anon_sym_RBRACE,
    STATE(579), 1,
      sym_string,
    STATE(604), 1,
      sym_namespace,
    ACTIONS(810), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1379), 3,
      aux_sym__data_block_value_token1,
      sym_integer,
      sym_decimal,
    STATE(417), 4,
      sym__string_literal1,
      sym__string_literal2,
      sym__string_literal_long1,
      sym__string_literal_long2,
    STATE(307), 8,
      sym__data_block_value,
      sym_rdf_literal,
      sym__numeric_literal,
      sym_boolean_literal,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
      aux_sym__inline_data_one_var_repeat1,
  [8859] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1449), 11,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
    ACTIONS(1447), 17,
      anon_sym_LPAREN,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
  [8895] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1453), 11,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
    ACTIONS(1451), 17,
      anon_sym_LPAREN,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
  [8931] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(808), 1,
      anon_sym_LT,
    ACTIONS(818), 1,
      anon_sym_SQUOTE,
    ACTIONS(820), 1,
      anon_sym_DQUOTE,
    ACTIONS(822), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(824), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(1375), 1,
      sym_pn_prefix,
    ACTIONS(1381), 1,
      anon_sym_COLON,
    ACTIONS(1383), 1,
      sym_double,
    ACTIONS(1455), 1,
      anon_sym_RBRACE,
    STATE(579), 1,
      sym_string,
    STATE(604), 1,
      sym_namespace,
    ACTIONS(810), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1379), 3,
      aux_sym__data_block_value_token1,
      sym_integer,
      sym_decimal,
    STATE(417), 4,
      sym__string_literal1,
      sym__string_literal2,
      sym__string_literal_long1,
      sym__string_literal_long2,
    STATE(307), 8,
      sym__data_block_value,
      sym_rdf_literal,
      sym__numeric_literal,
      sym_boolean_literal,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
      aux_sym__inline_data_one_var_repeat1,
  [8993] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1459), 11,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
    ACTIONS(1457), 17,
      anon_sym_LPAREN,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
  [9029] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1463), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1461), 25,
      ts_builtin_sym_end,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      anon_sym_RBRACE,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_group_clause_token1,
      aux_sym_having_clause_token1,
      aux_sym_order_clause_token1,
      aux_sym_limit_clause_token1,
      aux_sym_offset_clause_token1,
      aux_sym_values_clause_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [9064] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1019), 1,
      aux_sym_limit_clause_token1,
    ACTIONS(1021), 1,
      aux_sym_offset_clause_token1,
    STATE(379), 1,
      sym_limit_clause,
    STATE(380), 1,
      sym_offset_clause,
    STATE(392), 1,
      sym_limit_offset_clauses,
    ACTIONS(1276), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1274), 20,
      ts_builtin_sym_end,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      anon_sym_RBRACE,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_values_clause_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [9109] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1019), 1,
      aux_sym_limit_clause_token1,
    ACTIONS(1021), 1,
      aux_sym_offset_clause_token1,
    STATE(379), 1,
      sym_limit_clause,
    STATE(380), 1,
      sym_offset_clause,
    STATE(416), 1,
      sym_limit_offset_clauses,
    ACTIONS(1467), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1465), 20,
      ts_builtin_sym_end,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      anon_sym_RBRACE,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_values_clause_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [9154] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(808), 1,
      anon_sym_LT,
    ACTIONS(818), 1,
      anon_sym_SQUOTE,
    ACTIONS(820), 1,
      anon_sym_DQUOTE,
    ACTIONS(822), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(824), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(1375), 1,
      sym_pn_prefix,
    ACTIONS(1381), 1,
      anon_sym_COLON,
    ACTIONS(1471), 1,
      sym_double,
    STATE(579), 1,
      sym_string,
    STATE(604), 1,
      sym_namespace,
    ACTIONS(810), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1469), 3,
      aux_sym__data_block_value_token1,
      sym_integer,
      sym_decimal,
    STATE(417), 4,
      sym__string_literal1,
      sym__string_literal2,
      sym__string_literal_long1,
      sym__string_literal_long2,
    STATE(319), 8,
      sym__data_block_value,
      sym_rdf_literal,
      sym__numeric_literal,
      sym_boolean_literal,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
      aux_sym__inline_data_one_var_repeat1,
  [9213] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1019), 1,
      aux_sym_limit_clause_token1,
    ACTIONS(1021), 1,
      aux_sym_offset_clause_token1,
    STATE(379), 1,
      sym_limit_clause,
    STATE(380), 1,
      sym_offset_clause,
    STATE(405), 1,
      sym_limit_offset_clauses,
    ACTIONS(1407), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1405), 20,
      ts_builtin_sym_end,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      anon_sym_RBRACE,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_values_clause_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [9258] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1475), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1473), 25,
      ts_builtin_sym_end,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      anon_sym_RBRACE,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_group_clause_token1,
      aux_sym_having_clause_token1,
      aux_sym_order_clause_token1,
      aux_sym_limit_clause_token1,
      aux_sym_offset_clause_token1,
      aux_sym_values_clause_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [9293] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(19), 1,
      aux_sym_load_token1,
    ACTIONS(21), 1,
      aux_sym_clear_token1,
    ACTIONS(23), 1,
      aux_sym_drop_token1,
    ACTIONS(25), 1,
      aux_sym_create_token1,
    ACTIONS(27), 1,
      aux_sym_add_token1,
    ACTIONS(29), 1,
      aux_sym_move_token1,
    ACTIONS(31), 1,
      aux_sym_copy_token1,
    ACTIONS(33), 1,
      anon_sym_INSERTDATA,
    ACTIONS(35), 1,
      anon_sym_DELETEDATA,
    ACTIONS(37), 1,
      anon_sym_DELETEWHERE,
    ACTIONS(39), 1,
      aux_sym_modify_token1,
    ACTIONS(41), 1,
      aux_sym_delete_clause_token1,
    ACTIONS(43), 1,
      aux_sym_insert_clause_token1,
    STATE(788), 1,
      sym_delete_clause,
    STATE(863), 1,
      sym_insert_clause,
    STATE(456), 11,
      sym_load,
      sym_clear,
      sym_drop,
      sym_create,
      sym_add,
      sym_move,
      sym_copy,
      sym_insert_data,
      sym_delete_data,
      sym_delete_where,
      sym_modify,
  [9355] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1021), 1,
      aux_sym_offset_clause_token1,
    STATE(393), 1,
      sym_offset_clause,
    ACTIONS(1479), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1477), 20,
      ts_builtin_sym_end,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      anon_sym_RBRACE,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_values_clause_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [9391] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1019), 1,
      aux_sym_limit_clause_token1,
    STATE(393), 1,
      sym_limit_clause,
    ACTIONS(1479), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1477), 20,
      ts_builtin_sym_end,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      anon_sym_RBRACE,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_values_clause_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [9427] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1177), 9,
      anon_sym_RPAREN,
      anon_sym_SLASH,
      anon_sym_PIPE,
      sym_var,
      anon_sym_LT,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
    ACTIONS(1179), 14,
      anon_sym_LPAREN,
      sym_path_mod,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_integer,
      sym_decimal,
      sym_double,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
      sym_pn_local,
  [9458] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1483), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1481), 21,
      ts_builtin_sym_end,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      anon_sym_RBRACE,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_limit_clause_token1,
      aux_sym_values_clause_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [9489] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1157), 9,
      anon_sym_RPAREN,
      anon_sym_SLASH,
      anon_sym_PIPE,
      sym_var,
      anon_sym_LT,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
    ACTIONS(1159), 14,
      anon_sym_LPAREN,
      sym_path_mod,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_integer,
      sym_decimal,
      sym_double,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
      sym_pn_local,
  [9520] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1485), 1,
      sym_pn_local,
    ACTIONS(1189), 9,
      anon_sym_RPAREN,
      anon_sym_SLASH,
      anon_sym_PIPE,
      sym_var,
      anon_sym_LT,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
    ACTIONS(1191), 13,
      anon_sym_LPAREN,
      sym_path_mod,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_integer,
      sym_decimal,
      sym_double,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
  [9553] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1489), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1487), 21,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_construct_query_token2,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
      aux_sym_using_clause_token1,
  [9584] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1493), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1491), 21,
      ts_builtin_sym_end,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      anon_sym_RBRACE,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_offset_clause_token1,
      aux_sym_values_clause_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [9615] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1495), 1,
      sym_pn_local,
    ACTIONS(1191), 8,
      anon_sym_LPAREN,
      aux_sym_select_clause_token4,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
      anon_sym_LT,
      anon_sym_GT,
      aux_sym_binary_expression_token1,
      aux_sym_binary_expression_token2,
    ACTIONS(1189), 14,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS,
      anon_sym_DASH,
      sym_nil,
  [9648] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1499), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1497), 21,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_construct_query_token2,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
      aux_sym_using_clause_token1,
  [9679] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1503), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1501), 21,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_construct_query_token2,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
      aux_sym_using_clause_token1,
  [9710] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(832), 11,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_BANG,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(834), 11,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
      aux_sym__data_block_value_token1,
      anon_sym_a,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
  [9740] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1507), 1,
      aux_sym_load_token3,
    ACTIONS(1509), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1505), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [9772] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1407), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1405), 20,
      ts_builtin_sym_end,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      anon_sym_RBRACE,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_values_clause_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [9802] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1513), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1511), 20,
      ts_builtin_sym_end,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      anon_sym_RBRACE,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_values_clause_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [9832] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(838), 4,
      anon_sym_LPAREN,
      anon_sym_LT,
      anon_sym_GT,
      aux_sym_binary_expression_token1,
    ACTIONS(836), 18,
      anon_sym_SEMI,
      aux_sym_select_clause_token4,
      anon_sym_RPAREN,
      anon_sym_STAR,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
      anon_sym_COMMA,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      aux_sym_binary_expression_token2,
      anon_sym_PLUS,
      anon_sym_DASH,
      sym_nil,
  [9862] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(838), 10,
      anon_sym_LPAREN,
      sym_path_mod,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
    ACTIONS(836), 12,
      anon_sym_RPAREN,
      anon_sym_SLASH,
      anon_sym_PIPE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
  [9892] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(834), 10,
      anon_sym_LPAREN,
      sym_path_mod,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
    ACTIONS(832), 12,
      anon_sym_RPAREN,
      anon_sym_SLASH,
      anon_sym_PIPE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
  [9922] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1245), 10,
      aux_sym__data_block_value_token1,
      anon_sym_a,
      anon_sym_CARET,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
    ACTIONS(1243), 12,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_BANG,
      sym_var,
      anon_sym_LT,
      anon_sym_CARET_CARET,
      anon_sym_COLON,
      sym_lang_tag,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
  [9952] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1276), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1274), 20,
      ts_builtin_sym_end,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      anon_sym_RBRACE,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_values_clause_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [9982] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1241), 10,
      aux_sym__data_block_value_token1,
      anon_sym_a,
      anon_sym_CARET,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
    ACTIONS(1239), 12,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_BANG,
      sym_var,
      anon_sym_LT,
      anon_sym_CARET_CARET,
      anon_sym_COLON,
      sym_lang_tag,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
  [10012] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1256), 10,
      aux_sym__data_block_value_token1,
      anon_sym_a,
      anon_sym_CARET,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
    ACTIONS(1254), 12,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_BANG,
      sym_var,
      anon_sym_LT,
      anon_sym_CARET_CARET,
      anon_sym_COLON,
      sym_lang_tag,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
  [10042] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1515), 1,
      aux_sym_values_clause_token1,
    STATE(503), 1,
      sym_values_clause,
    ACTIONS(1517), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(884), 18,
      ts_builtin_sym_end,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [10076] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1521), 1,
      aux_sym_load_token3,
    ACTIONS(1523), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1519), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [10108] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1527), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1525), 20,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_add_token2,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [10138] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7), 1,
      aux_sym_base_declaration_token1,
    ACTIONS(9), 1,
      aux_sym_prefix_declaration_token1,
    ACTIONS(1531), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    STATE(407), 3,
      sym_base_declaration,
      sym_prefix_declaration,
      aux_sym_prologue_repeat1,
    ACTIONS(1529), 15,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [10174] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1467), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1465), 20,
      ts_builtin_sym_end,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      anon_sym_RBRACE,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_values_clause_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [10204] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1264), 10,
      aux_sym__data_block_value_token1,
      anon_sym_a,
      anon_sym_CARET,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
    ACTIONS(1262), 12,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_BANG,
      sym_var,
      anon_sym_LT,
      anon_sym_CARET_CARET,
      anon_sym_COLON,
      sym_lang_tag,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
  [10234] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1533), 1,
      aux_sym_base_declaration_token1,
    ACTIONS(1536), 1,
      aux_sym_prefix_declaration_token1,
    ACTIONS(1541), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    STATE(407), 3,
      sym_base_declaration,
      sym_prefix_declaration,
      aux_sym_prologue_repeat1,
    ACTIONS(1539), 15,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [10270] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1543), 10,
      anon_sym_LPAREN,
      sym_path_mod,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
    ACTIONS(1545), 12,
      anon_sym_RPAREN,
      anon_sym_SLASH,
      anon_sym_PIPE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
  [10300] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1549), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1547), 20,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_add_token2,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [10330] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1272), 10,
      aux_sym__data_block_value_token1,
      anon_sym_a,
      anon_sym_CARET,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
    ACTIONS(1270), 12,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_BANG,
      sym_var,
      anon_sym_LT,
      anon_sym_CARET_CARET,
      anon_sym_COLON,
      sym_lang_tag,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
  [10360] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1268), 10,
      aux_sym__data_block_value_token1,
      anon_sym_a,
      anon_sym_CARET,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
    ACTIONS(1266), 12,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_BANG,
      sym_var,
      anon_sym_LT,
      anon_sym_CARET_CARET,
      anon_sym_COLON,
      sym_lang_tag,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
  [10390] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1233), 10,
      aux_sym__data_block_value_token1,
      anon_sym_a,
      anon_sym_CARET,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
    ACTIONS(1231), 12,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_BANG,
      sym_var,
      anon_sym_LT,
      anon_sym_CARET_CARET,
      anon_sym_COLON,
      sym_lang_tag,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
  [10420] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1551), 1,
      sym_pn_local,
    ACTIONS(1189), 9,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_RBRACK,
      sym_nil,
    ACTIONS(1191), 12,
      anon_sym_LPAREN,
      aux_sym_construct_query_token2,
      aux_sym_dataset_clause_token1,
      aux_sym_values_clause_token1,
      aux_sym_add_token2,
      aux_sym_using_clause_token1,
      aux_sym_graph_or_default_token2,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
  [10452] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1515), 1,
      aux_sym_values_clause_token1,
    STATE(501), 1,
      sym_values_clause,
    ACTIONS(1555), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1553), 18,
      ts_builtin_sym_end,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [10486] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1237), 10,
      aux_sym__data_block_value_token1,
      anon_sym_a,
      anon_sym_CARET,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
    ACTIONS(1235), 12,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_BANG,
      sym_var,
      anon_sym_LT,
      anon_sym_CARET_CARET,
      anon_sym_COLON,
      sym_lang_tag,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
  [10516] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1559), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1557), 20,
      ts_builtin_sym_end,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      anon_sym_RBRACE,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_values_clause_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [10546] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1260), 10,
      aux_sym__data_block_value_token1,
      anon_sym_a,
      anon_sym_CARET,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
    ACTIONS(1258), 12,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_BANG,
      sym_var,
      anon_sym_LT,
      anon_sym_CARET_CARET,
      anon_sym_COLON,
      sym_lang_tag,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
  [10576] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1561), 10,
      anon_sym_LPAREN,
      sym_path_mod,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
    ACTIONS(1563), 12,
      anon_sym_RPAREN,
      anon_sym_SLASH,
      anon_sym_PIPE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
  [10606] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1567), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1565), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [10635] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1569), 9,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
    ACTIONS(1571), 12,
      anon_sym_RPAREN,
      anon_sym_SLASH,
      anon_sym_PIPE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
  [10664] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1575), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1573), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [10693] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1260), 9,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
    ACTIONS(1258), 12,
      anon_sym_RPAREN,
      sym_var,
      anon_sym_LT,
      anon_sym_CARET_CARET,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_lang_tag,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
  [10722] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1256), 9,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
    ACTIONS(1254), 12,
      anon_sym_RPAREN,
      sym_var,
      anon_sym_LT,
      anon_sym_CARET_CARET,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_lang_tag,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
  [10751] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1264), 9,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
    ACTIONS(1262), 12,
      anon_sym_RPAREN,
      sym_var,
      anon_sym_LT,
      anon_sym_CARET_CARET,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_lang_tag,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
  [10780] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1245), 9,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
    ACTIONS(1243), 12,
      anon_sym_RPAREN,
      sym_var,
      anon_sym_LT,
      anon_sym_CARET_CARET,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_lang_tag,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
  [10809] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1241), 9,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
    ACTIONS(1239), 12,
      anon_sym_RPAREN,
      sym_var,
      anon_sym_LT,
      anon_sym_CARET_CARET,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_lang_tag,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
  [10838] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1272), 9,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
    ACTIONS(1270), 12,
      anon_sym_RPAREN,
      sym_var,
      anon_sym_LT,
      anon_sym_CARET_CARET,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_lang_tag,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
  [10867] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1268), 9,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
    ACTIONS(1266), 12,
      anon_sym_RPAREN,
      sym_var,
      anon_sym_LT,
      anon_sym_CARET_CARET,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_lang_tag,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
  [10896] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1233), 9,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
    ACTIONS(1231), 12,
      anon_sym_RPAREN,
      sym_var,
      anon_sym_LT,
      anon_sym_CARET_CARET,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_lang_tag,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
  [10925] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1237), 9,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
    ACTIONS(1235), 12,
      anon_sym_RPAREN,
      sym_var,
      anon_sym_LT,
      anon_sym_CARET_CARET,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_lang_tag,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
  [10954] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1397), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1399), 19,
      ts_builtin_sym_end,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      anon_sym_RBRACE,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [10983] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1577), 9,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_a,
      sym_pn_prefix,
    ACTIONS(1579), 12,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_CARET,
      anon_sym_BANG,
      anon_sym_RBRACK,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
  [11012] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1581), 10,
      anon_sym_LPAREN,
      sym_path_mod,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
    ACTIONS(1583), 11,
      anon_sym_SLASH,
      anon_sym_PIPE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
  [11041] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1421), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1423), 19,
      ts_builtin_sym_end,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      anon_sym_RBRACE,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [11070] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1225), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1223), 19,
      ts_builtin_sym_end,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_values_clause_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [11099] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1587), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1585), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [11128] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1591), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1589), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [11157] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1595), 10,
      anon_sym_RBRACE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
    ACTIONS(1593), 11,
      anon_sym_LPAREN,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
  [11186] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1599), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1597), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [11215] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1029), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1027), 19,
      ts_builtin_sym_end,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_values_clause_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [11244] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1603), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1601), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [11273] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1607), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1605), 19,
      ts_builtin_sym_end,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_values_clause_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [11302] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1611), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1609), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [11331] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1615), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1613), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [11360] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1619), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1617), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [11389] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1623), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1621), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [11418] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1627), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1625), 19,
      ts_builtin_sym_end,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_values_clause_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [11447] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1631), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1629), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [11476] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1635), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1633), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [11505] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1639), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1637), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [11534] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1205), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1203), 19,
      ts_builtin_sym_end,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_values_clause_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [11563] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1643), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1641), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [11592] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1647), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1645), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [11621] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1229), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1227), 19,
      ts_builtin_sym_end,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_values_clause_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [11650] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1209), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1207), 19,
      ts_builtin_sym_end,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_values_clause_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [11679] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1651), 1,
      anon_sym_SEMI,
    ACTIONS(1653), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1649), 18,
      ts_builtin_sym_end,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [11710] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1657), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1655), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [11739] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1661), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1659), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [11768] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1665), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1663), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [11797] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1669), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1667), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [11826] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1401), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1403), 19,
      ts_builtin_sym_end,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      anon_sym_RBRACE,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [11855] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1673), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1671), 19,
      ts_builtin_sym_end,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_values_clause_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [11884] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1675), 9,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_a,
      sym_pn_prefix,
    ACTIONS(1677), 12,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_CARET,
      anon_sym_BANG,
      anon_sym_RBRACK,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
  [11913] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1679), 10,
      anon_sym_LPAREN,
      sym_path_mod,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
    ACTIONS(1681), 11,
      anon_sym_SLASH,
      anon_sym_PIPE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
  [11942] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1683), 10,
      anon_sym_LPAREN,
      sym_path_mod,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
    ACTIONS(1685), 11,
      anon_sym_SLASH,
      anon_sym_PIPE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
  [11971] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1687), 9,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_a,
      sym_pn_prefix,
    ACTIONS(1689), 12,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_CARET,
      anon_sym_BANG,
      anon_sym_RBRACK,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
  [12000] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(969), 1,
      sym_pn_prefix,
    ACTIONS(979), 1,
      anon_sym_LT,
    ACTIONS(983), 1,
      anon_sym_COLON,
    ACTIONS(1287), 1,
      anon_sym_LPAREN,
    ACTIONS(1291), 1,
      anon_sym_a,
    ACTIONS(1293), 1,
      anon_sym_CARET,
    ACTIONS(1295), 1,
      anon_sym_BANG,
    ACTIONS(1691), 1,
      sym_var,
    STATE(260), 1,
      sym__predicate_path,
    STATE(384), 1,
      sym_namespace,
    STATE(698), 1,
      sym_property_path_rest,
    STATE(707), 1,
      sym_path_inverse,
    ACTIONS(1285), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    STATE(502), 3,
      sym__path,
      sym_binary_path,
      sym_path_element,
    STATE(477), 4,
      sym__primary_path,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
  [12055] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1697), 1,
      sym_path_mod,
    ACTIONS(1693), 9,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
    ACTIONS(1695), 11,
      anon_sym_SLASH,
      anon_sym_PIPE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
  [12086] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1693), 9,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
    ACTIONS(1695), 12,
      anon_sym_RPAREN,
      anon_sym_SLASH,
      anon_sym_PIPE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
  [12115] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1701), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1699), 19,
      ts_builtin_sym_end,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_values_clause_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [12144] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1705), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1703), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [12173] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1709), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1707), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [12202] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1713), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1711), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [12231] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1715), 9,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
    ACTIONS(1717), 12,
      anon_sym_RPAREN,
      anon_sym_SLASH,
      anon_sym_PIPE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
  [12260] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1721), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1719), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [12289] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1389), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1391), 19,
      ts_builtin_sym_end,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      anon_sym_RBRACE,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [12318] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1727), 1,
      sym_path_mod,
    ACTIONS(1723), 9,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
    ACTIONS(1725), 11,
      anon_sym_SLASH,
      anon_sym_PIPE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
  [12349] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1393), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1395), 19,
      ts_builtin_sym_end,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      anon_sym_RBRACE,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [12378] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1731), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1729), 19,
      ts_builtin_sym_end,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      anon_sym_RBRACE,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [12407] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1385), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1387), 19,
      ts_builtin_sym_end,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      anon_sym_RBRACE,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [12436] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1385), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1387), 19,
      ts_builtin_sym_end,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      anon_sym_RBRACE,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [12465] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1197), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1195), 19,
      ts_builtin_sym_end,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_values_clause_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [12494] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1221), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1219), 19,
      ts_builtin_sym_end,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_values_clause_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [12523] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1735), 1,
      anon_sym_LPAREN,
    ACTIONS(1739), 1,
      sym_nil,
    STATE(555), 1,
      sym_arg_list,
    ACTIONS(1737), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1733), 16,
      anon_sym_SEMI,
      aux_sym_select_clause_token4,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      aux_sym_binary_expression_token1,
      aux_sym_binary_expression_token2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [12558] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1743), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1741), 19,
      ts_builtin_sym_end,
      anon_sym_SEMI,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [12587] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1747), 1,
      anon_sym_SEMI,
    ACTIONS(1749), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1745), 18,
      ts_builtin_sym_end,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [12618] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1751), 10,
      anon_sym_LPAREN,
      sym_path_mod,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
    ACTIONS(1753), 11,
      anon_sym_SLASH,
      anon_sym_PIPE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
  [12647] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1755), 10,
      anon_sym_LPAREN,
      sym_path_mod,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
    ACTIONS(1757), 11,
      anon_sym_SLASH,
      anon_sym_PIPE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
  [12676] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1759), 10,
      anon_sym_LPAREN,
      sym_path_mod,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
    ACTIONS(1761), 11,
      anon_sym_SLASH,
      anon_sym_PIPE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
  [12705] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1765), 10,
      anon_sym_RBRACE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
    ACTIONS(1763), 11,
      anon_sym_LPAREN,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
  [12734] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1771), 1,
      anon_sym_CARET_CARET,
    ACTIONS(1773), 1,
      sym_lang_tag,
    ACTIONS(1767), 9,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
    ACTIONS(1769), 10,
      anon_sym_RPAREN,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
  [12767] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1409), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1411), 19,
      ts_builtin_sym_end,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      anon_sym_RBRACE,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [12796] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(969), 1,
      sym_pn_prefix,
    ACTIONS(979), 1,
      anon_sym_LT,
    ACTIONS(983), 1,
      anon_sym_COLON,
    ACTIONS(1287), 1,
      anon_sym_LPAREN,
    ACTIONS(1291), 1,
      anon_sym_a,
    ACTIONS(1293), 1,
      anon_sym_CARET,
    ACTIONS(1295), 1,
      anon_sym_BANG,
    ACTIONS(1309), 1,
      sym_var,
    STATE(257), 1,
      sym__predicate_path,
    STATE(384), 1,
      sym_namespace,
    STATE(700), 1,
      sym_property_path,
    STATE(707), 1,
      sym_path_inverse,
    STATE(723), 1,
      sym_property_list_path,
    STATE(502), 3,
      sym__path,
      sym_binary_path,
      sym_path_element,
    STATE(477), 4,
      sym__primary_path,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
  [12850] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(969), 1,
      sym_pn_prefix,
    ACTIONS(979), 1,
      anon_sym_LT,
    ACTIONS(983), 1,
      anon_sym_COLON,
    ACTIONS(1287), 1,
      anon_sym_LPAREN,
    ACTIONS(1291), 1,
      anon_sym_a,
    ACTIONS(1293), 1,
      anon_sym_CARET,
    ACTIONS(1295), 1,
      anon_sym_BANG,
    ACTIONS(1775), 1,
      sym_var,
    STATE(258), 1,
      sym__predicate_path,
    STATE(384), 1,
      sym_namespace,
    STATE(707), 1,
      sym_path_inverse,
    STATE(931), 1,
      sym_property_path,
    STATE(1101), 1,
      sym_property_list_path,
    STATE(502), 3,
      sym__path,
      sym_binary_path,
      sym_path_element,
    STATE(477), 4,
      sym__primary_path,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
  [12904] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1369), 9,
      aux_sym__data_block_value_token1,
      anon_sym_a,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
    ACTIONS(1367), 11,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_BANG,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
  [12932] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(1777), 1,
      anon_sym_RBRACE,
    ACTIONS(1779), 1,
      aux_sym_values_clause_token1,
    ACTIONS(1781), 1,
      aux_sym_graph_or_default_token2,
    ACTIONS(1783), 1,
      aux_sym_optional_graph_pattern_token1,
    ACTIONS(1785), 1,
      aux_sym_service_graph_pattern_token1,
    ACTIONS(1787), 1,
      aux_sym_bind_token1,
    ACTIONS(1789), 1,
      aux_sym_minus_graph_pattern_token1,
    ACTIONS(1791), 1,
      aux_sym_filter_token1,
    STATE(305), 1,
      sym_group_graph_pattern,
    STATE(518), 1,
      aux_sym_group_graph_pattern_repeat1,
    STATE(223), 9,
      sym__graph_pattern_not_triples,
      sym_optional_graph_pattern,
      sym_graph_graph_pattern,
      sym_service_graph_pattern,
      sym_bind,
      sym_inline_data,
      sym_minus_graph_pattern,
      sym_group_or_union_graph_pattern,
      sym_filter,
  [12980] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(1779), 1,
      aux_sym_values_clause_token1,
    ACTIONS(1781), 1,
      aux_sym_graph_or_default_token2,
    ACTIONS(1783), 1,
      aux_sym_optional_graph_pattern_token1,
    ACTIONS(1785), 1,
      aux_sym_service_graph_pattern_token1,
    ACTIONS(1787), 1,
      aux_sym_bind_token1,
    ACTIONS(1789), 1,
      aux_sym_minus_graph_pattern_token1,
    ACTIONS(1791), 1,
      aux_sym_filter_token1,
    ACTIONS(1793), 1,
      anon_sym_RBRACE,
    STATE(305), 1,
      sym_group_graph_pattern,
    STATE(499), 1,
      aux_sym_group_graph_pattern_repeat1,
    STATE(223), 9,
      sym__graph_pattern_not_triples,
      sym_optional_graph_pattern,
      sym_graph_graph_pattern,
      sym_service_graph_pattern,
      sym_bind,
      sym_inline_data,
      sym_minus_graph_pattern,
      sym_group_or_union_graph_pattern,
      sym_filter,
  [13028] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(1779), 1,
      aux_sym_values_clause_token1,
    ACTIONS(1781), 1,
      aux_sym_graph_or_default_token2,
    ACTIONS(1783), 1,
      aux_sym_optional_graph_pattern_token1,
    ACTIONS(1785), 1,
      aux_sym_service_graph_pattern_token1,
    ACTIONS(1787), 1,
      aux_sym_bind_token1,
    ACTIONS(1789), 1,
      aux_sym_minus_graph_pattern_token1,
    ACTIONS(1791), 1,
      aux_sym_filter_token1,
    ACTIONS(1793), 1,
      anon_sym_RBRACE,
    STATE(305), 1,
      sym_group_graph_pattern,
    STATE(512), 1,
      aux_sym_group_graph_pattern_repeat1,
    STATE(223), 9,
      sym__graph_pattern_not_triples,
      sym_optional_graph_pattern,
      sym_graph_graph_pattern,
      sym_service_graph_pattern,
      sym_bind,
      sym_inline_data,
      sym_minus_graph_pattern,
      sym_group_or_union_graph_pattern,
      sym_filter,
  [13076] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(1779), 1,
      aux_sym_values_clause_token1,
    ACTIONS(1781), 1,
      aux_sym_graph_or_default_token2,
    ACTIONS(1783), 1,
      aux_sym_optional_graph_pattern_token1,
    ACTIONS(1785), 1,
      aux_sym_service_graph_pattern_token1,
    ACTIONS(1787), 1,
      aux_sym_bind_token1,
    ACTIONS(1789), 1,
      aux_sym_minus_graph_pattern_token1,
    ACTIONS(1791), 1,
      aux_sym_filter_token1,
    ACTIONS(1795), 1,
      anon_sym_RBRACE,
    STATE(305), 1,
      sym_group_graph_pattern,
    STATE(512), 1,
      aux_sym_group_graph_pattern_repeat1,
    STATE(223), 9,
      sym__graph_pattern_not_triples,
      sym_optional_graph_pattern,
      sym_graph_graph_pattern,
      sym_service_graph_pattern,
      sym_bind,
      sym_inline_data,
      sym_minus_graph_pattern,
      sym_group_or_union_graph_pattern,
      sym_filter,
  [13124] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1349), 9,
      aux_sym__data_block_value_token1,
      anon_sym_a,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
    ACTIONS(1347), 11,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_BANG,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
  [13152] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1517), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(884), 18,
      ts_builtin_sym_end,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [13180] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1799), 1,
      anon_sym_SLASH,
    ACTIONS(1801), 1,
      anon_sym_PIPE,
    ACTIONS(1797), 9,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
    ACTIONS(1803), 9,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
  [13212] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1807), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1805), 18,
      ts_builtin_sym_end,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [13240] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(838), 9,
      aux_sym__data_block_value_token1,
      anon_sym_a,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
    ACTIONS(836), 11,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_BANG,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
  [13268] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(1779), 1,
      aux_sym_values_clause_token1,
    ACTIONS(1781), 1,
      aux_sym_graph_or_default_token2,
    ACTIONS(1783), 1,
      aux_sym_optional_graph_pattern_token1,
    ACTIONS(1785), 1,
      aux_sym_service_graph_pattern_token1,
    ACTIONS(1787), 1,
      aux_sym_bind_token1,
    ACTIONS(1789), 1,
      aux_sym_minus_graph_pattern_token1,
    ACTIONS(1791), 1,
      aux_sym_filter_token1,
    ACTIONS(1809), 1,
      anon_sym_RBRACE,
    STATE(305), 1,
      sym_group_graph_pattern,
    STATE(512), 1,
      aux_sym_group_graph_pattern_repeat1,
    STATE(223), 9,
      sym__graph_pattern_not_triples,
      sym_optional_graph_pattern,
      sym_graph_graph_pattern,
      sym_service_graph_pattern,
      sym_bind,
      sym_inline_data,
      sym_minus_graph_pattern,
      sym_group_or_union_graph_pattern,
      sym_filter,
  [13316] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1811), 1,
      anon_sym_CARET_CARET,
    ACTIONS(1813), 1,
      sym_lang_tag,
    ACTIONS(1767), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1769), 16,
      anon_sym_SEMI,
      aux_sym_select_clause_token4,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      aux_sym_binary_expression_token1,
      aux_sym_binary_expression_token2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [13348] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(1779), 1,
      aux_sym_values_clause_token1,
    ACTIONS(1781), 1,
      aux_sym_graph_or_default_token2,
    ACTIONS(1783), 1,
      aux_sym_optional_graph_pattern_token1,
    ACTIONS(1785), 1,
      aux_sym_service_graph_pattern_token1,
    ACTIONS(1787), 1,
      aux_sym_bind_token1,
    ACTIONS(1789), 1,
      aux_sym_minus_graph_pattern_token1,
    ACTIONS(1791), 1,
      aux_sym_filter_token1,
    ACTIONS(1815), 1,
      anon_sym_RBRACE,
    STATE(305), 1,
      sym_group_graph_pattern,
    STATE(512), 1,
      aux_sym_group_graph_pattern_repeat1,
    STATE(223), 9,
      sym__graph_pattern_not_triples,
      sym_optional_graph_pattern,
      sym_graph_graph_pattern,
      sym_service_graph_pattern,
      sym_bind,
      sym_inline_data,
      sym_minus_graph_pattern,
      sym_group_or_union_graph_pattern,
      sym_filter,
  [13396] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(1777), 1,
      anon_sym_RBRACE,
    ACTIONS(1779), 1,
      aux_sym_values_clause_token1,
    ACTIONS(1781), 1,
      aux_sym_graph_or_default_token2,
    ACTIONS(1783), 1,
      aux_sym_optional_graph_pattern_token1,
    ACTIONS(1785), 1,
      aux_sym_service_graph_pattern_token1,
    ACTIONS(1787), 1,
      aux_sym_bind_token1,
    ACTIONS(1789), 1,
      aux_sym_minus_graph_pattern_token1,
    ACTIONS(1791), 1,
      aux_sym_filter_token1,
    STATE(305), 1,
      sym_group_graph_pattern,
    STATE(512), 1,
      aux_sym_group_graph_pattern_repeat1,
    STATE(223), 9,
      sym__graph_pattern_not_triples,
      sym_optional_graph_pattern,
      sym_graph_graph_pattern,
      sym_service_graph_pattern,
      sym_bind,
      sym_inline_data,
      sym_minus_graph_pattern,
      sym_group_or_union_graph_pattern,
      sym_filter,
  [13444] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(1779), 1,
      aux_sym_values_clause_token1,
    ACTIONS(1781), 1,
      aux_sym_graph_or_default_token2,
    ACTIONS(1783), 1,
      aux_sym_optional_graph_pattern_token1,
    ACTIONS(1785), 1,
      aux_sym_service_graph_pattern_token1,
    ACTIONS(1787), 1,
      aux_sym_bind_token1,
    ACTIONS(1789), 1,
      aux_sym_minus_graph_pattern_token1,
    ACTIONS(1791), 1,
      aux_sym_filter_token1,
    ACTIONS(1817), 1,
      anon_sym_RBRACE,
    STATE(305), 1,
      sym_group_graph_pattern,
    STATE(511), 1,
      aux_sym_group_graph_pattern_repeat1,
    STATE(223), 9,
      sym__graph_pattern_not_triples,
      sym_optional_graph_pattern,
      sym_graph_graph_pattern,
      sym_service_graph_pattern,
      sym_bind,
      sym_inline_data,
      sym_minus_graph_pattern,
      sym_group_or_union_graph_pattern,
      sym_filter,
  [13492] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(1779), 1,
      aux_sym_values_clause_token1,
    ACTIONS(1781), 1,
      aux_sym_graph_or_default_token2,
    ACTIONS(1783), 1,
      aux_sym_optional_graph_pattern_token1,
    ACTIONS(1785), 1,
      aux_sym_service_graph_pattern_token1,
    ACTIONS(1787), 1,
      aux_sym_bind_token1,
    ACTIONS(1789), 1,
      aux_sym_minus_graph_pattern_token1,
    ACTIONS(1791), 1,
      aux_sym_filter_token1,
    ACTIONS(1817), 1,
      anon_sym_RBRACE,
    STATE(305), 1,
      sym_group_graph_pattern,
    STATE(512), 1,
      aux_sym_group_graph_pattern_repeat1,
    STATE(223), 9,
      sym__graph_pattern_not_triples,
      sym_optional_graph_pattern,
      sym_graph_graph_pattern,
      sym_service_graph_pattern,
      sym_bind,
      sym_inline_data,
      sym_minus_graph_pattern,
      sym_group_or_union_graph_pattern,
      sym_filter,
  [13540] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(1779), 1,
      aux_sym_values_clause_token1,
    ACTIONS(1781), 1,
      aux_sym_graph_or_default_token2,
    ACTIONS(1783), 1,
      aux_sym_optional_graph_pattern_token1,
    ACTIONS(1785), 1,
      aux_sym_service_graph_pattern_token1,
    ACTIONS(1787), 1,
      aux_sym_bind_token1,
    ACTIONS(1789), 1,
      aux_sym_minus_graph_pattern_token1,
    ACTIONS(1791), 1,
      aux_sym_filter_token1,
    ACTIONS(1819), 1,
      anon_sym_RBRACE,
    STATE(305), 1,
      sym_group_graph_pattern,
    STATE(512), 1,
      aux_sym_group_graph_pattern_repeat1,
    STATE(223), 9,
      sym__graph_pattern_not_triples,
      sym_optional_graph_pattern,
      sym_graph_graph_pattern,
      sym_service_graph_pattern,
      sym_bind,
      sym_inline_data,
      sym_minus_graph_pattern,
      sym_group_or_union_graph_pattern,
      sym_filter,
  [13588] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(872), 1,
      anon_sym_RBRACE,
    ACTIONS(1821), 1,
      anon_sym_LBRACE,
    ACTIONS(1824), 1,
      aux_sym_values_clause_token1,
    ACTIONS(1827), 1,
      aux_sym_graph_or_default_token2,
    ACTIONS(1830), 1,
      aux_sym_optional_graph_pattern_token1,
    ACTIONS(1833), 1,
      aux_sym_service_graph_pattern_token1,
    ACTIONS(1836), 1,
      aux_sym_bind_token1,
    ACTIONS(1839), 1,
      aux_sym_minus_graph_pattern_token1,
    ACTIONS(1842), 1,
      aux_sym_filter_token1,
    STATE(305), 1,
      sym_group_graph_pattern,
    STATE(512), 1,
      aux_sym_group_graph_pattern_repeat1,
    STATE(223), 9,
      sym__graph_pattern_not_triples,
      sym_optional_graph_pattern,
      sym_graph_graph_pattern,
      sym_service_graph_pattern,
      sym_bind,
      sym_inline_data,
      sym_minus_graph_pattern,
      sym_group_or_union_graph_pattern,
      sym_filter,
  [13636] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1847), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1845), 18,
      ts_builtin_sym_end,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [13664] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(969), 1,
      sym_pn_prefix,
    ACTIONS(979), 1,
      anon_sym_LT,
    ACTIONS(983), 1,
      anon_sym_COLON,
    ACTIONS(1287), 1,
      anon_sym_LPAREN,
    ACTIONS(1291), 1,
      anon_sym_a,
    ACTIONS(1293), 1,
      anon_sym_CARET,
    ACTIONS(1295), 1,
      anon_sym_BANG,
    ACTIONS(1775), 1,
      sym_var,
    STATE(258), 1,
      sym__predicate_path,
    STATE(384), 1,
      sym_namespace,
    STATE(707), 1,
      sym_path_inverse,
    STATE(931), 1,
      sym_property_path,
    STATE(1120), 1,
      sym_property_list_path,
    STATE(502), 3,
      sym__path,
      sym_binary_path,
      sym_path_element,
    STATE(477), 4,
      sym__primary_path,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
  [13718] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1353), 9,
      aux_sym__data_block_value_token1,
      anon_sym_a,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
    ACTIONS(1351), 11,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_BANG,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
  [13746] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(834), 3,
      anon_sym_LPAREN,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(832), 17,
      anon_sym_SEMI,
      aux_sym_select_clause_token4,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      aux_sym_binary_expression_token1,
      aux_sym_binary_expression_token2,
      anon_sym_PLUS,
      anon_sym_DASH,
      sym_nil,
  [13774] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1851), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1849), 18,
      ts_builtin_sym_end,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [13802] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(1779), 1,
      aux_sym_values_clause_token1,
    ACTIONS(1781), 1,
      aux_sym_graph_or_default_token2,
    ACTIONS(1783), 1,
      aux_sym_optional_graph_pattern_token1,
    ACTIONS(1785), 1,
      aux_sym_service_graph_pattern_token1,
    ACTIONS(1787), 1,
      aux_sym_bind_token1,
    ACTIONS(1789), 1,
      aux_sym_minus_graph_pattern_token1,
    ACTIONS(1791), 1,
      aux_sym_filter_token1,
    ACTIONS(1853), 1,
      anon_sym_RBRACE,
    STATE(305), 1,
      sym_group_graph_pattern,
    STATE(512), 1,
      aux_sym_group_graph_pattern_repeat1,
    STATE(223), 9,
      sym__graph_pattern_not_triples,
      sym_optional_graph_pattern,
      sym_graph_graph_pattern,
      sym_service_graph_pattern,
      sym_bind,
      sym_inline_data,
      sym_minus_graph_pattern,
      sym_group_or_union_graph_pattern,
      sym_filter,
  [13850] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1799), 1,
      anon_sym_SLASH,
    ACTIONS(1569), 9,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
    ACTIONS(1571), 10,
      anon_sym_PIPE,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
  [13880] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    ACTIONS(1779), 1,
      aux_sym_values_clause_token1,
    ACTIONS(1781), 1,
      aux_sym_graph_or_default_token2,
    ACTIONS(1783), 1,
      aux_sym_optional_graph_pattern_token1,
    ACTIONS(1785), 1,
      aux_sym_service_graph_pattern_token1,
    ACTIONS(1787), 1,
      aux_sym_bind_token1,
    ACTIONS(1789), 1,
      aux_sym_minus_graph_pattern_token1,
    ACTIONS(1791), 1,
      aux_sym_filter_token1,
    ACTIONS(1809), 1,
      anon_sym_RBRACE,
    STATE(305), 1,
      sym_group_graph_pattern,
    STATE(507), 1,
      aux_sym_group_graph_pattern_repeat1,
    STATE(223), 9,
      sym__graph_pattern_not_triples,
      sym_optional_graph_pattern,
      sym_graph_graph_pattern,
      sym_service_graph_pattern,
      sym_bind,
      sym_inline_data,
      sym_minus_graph_pattern,
      sym_group_or_union_graph_pattern,
      sym_filter,
  [13928] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1857), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1855), 17,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [13955] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1687), 9,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
    ACTIONS(1689), 10,
      anon_sym_RPAREN,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
  [13982] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1577), 9,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
    ACTIONS(1579), 10,
      anon_sym_RPAREN,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
  [14009] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1861), 2,
      aux_sym_delete_clause_token1,
      aux_sym_insert_clause_token1,
    ACTIONS(1859), 17,
      aux_sym_base_declaration_token1,
      aux_sym_prefix_declaration_token1,
      aux_sym_select_clause_token1,
      aux_sym_construct_query_token1,
      aux_sym_describe_query_token1,
      aux_sym_ask_query_token1,
      aux_sym_load_token1,
      aux_sym_clear_token1,
      aux_sym_drop_token1,
      aux_sym_create_token1,
      aux_sym_add_token1,
      aux_sym_move_token1,
      aux_sym_copy_token1,
      anon_sym_INSERTDATA,
      anon_sym_DELETEDATA,
      anon_sym_DELETEWHERE,
      aux_sym_modify_token1,
  [14036] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1353), 9,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
    ACTIONS(1351), 10,
      anon_sym_RPAREN,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
  [14063] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1369), 9,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
    ACTIONS(1367), 10,
      anon_sym_RPAREN,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
  [14090] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1863), 9,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
    ACTIONS(1865), 10,
      anon_sym_RPAREN,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
  [14117] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1867), 9,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
    ACTIONS(1869), 10,
      anon_sym_RPAREN,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
  [14144] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1675), 9,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
    ACTIONS(1677), 10,
      anon_sym_RPAREN,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
  [14171] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1349), 9,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
    ACTIONS(1347), 10,
      anon_sym_RPAREN,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym__COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      sym_nil,
      sym_anon,
  [14198] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(427), 16,
      anon_sym_SEMI,
      aux_sym_select_clause_token4,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      aux_sym_binary_expression_token1,
      aux_sym_binary_expression_token2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [14224] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(405), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(403), 16,
      anon_sym_SEMI,
      aux_sym_select_clause_token4,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      aux_sym_binary_expression_token1,
      aux_sym_binary_expression_token2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [14250] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(1871), 5,
      anon_sym_SEMI,
      aux_sym_select_clause_token4,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
  [14288] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
    ACTIONS(1871), 6,
      anon_sym_SEMI,
      aux_sym_select_clause_token4,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
  [14324] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1887), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1871), 12,
      anon_sym_SEMI,
      aux_sym_select_clause_token4,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      aux_sym_binary_expression_token1,
      aux_sym_binary_expression_token2,
  [14354] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(551), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(549), 16,
      anon_sym_SEMI,
      aux_sym_select_clause_token4,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      aux_sym_binary_expression_token1,
      aux_sym_binary_expression_token2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [14380] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(405), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(403), 16,
      anon_sym_SEMI,
      aux_sym_select_clause_token4,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      aux_sym_binary_expression_token1,
      aux_sym_binary_expression_token2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [14406] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(555), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(553), 16,
      anon_sym_SEMI,
      aux_sym_select_clause_token4,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      aux_sym_binary_expression_token1,
      aux_sym_binary_expression_token2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [14432] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1887), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1871), 16,
      anon_sym_SEMI,
      aux_sym_select_clause_token4,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      aux_sym_binary_expression_token1,
      aux_sym_binary_expression_token2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [14458] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1887), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1871), 14,
      anon_sym_SEMI,
      aux_sym_select_clause_token4,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      aux_sym_binary_expression_token1,
      aux_sym_binary_expression_token2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [14486] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(591), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(589), 16,
      anon_sym_SEMI,
      aux_sym_select_clause_token4,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      aux_sym_binary_expression_token1,
      aux_sym_binary_expression_token2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [14512] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(421), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(419), 16,
      anon_sym_SEMI,
      aux_sym_select_clause_token4,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      aux_sym_binary_expression_token1,
      aux_sym_binary_expression_token2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [14538] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(413), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(411), 16,
      anon_sym_SEMI,
      aux_sym_select_clause_token4,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      aux_sym_binary_expression_token1,
      aux_sym_binary_expression_token2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [14564] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(559), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(557), 16,
      anon_sym_SEMI,
      aux_sym_select_clause_token4,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      aux_sym_binary_expression_token1,
      aux_sym_binary_expression_token2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [14590] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(425), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(423), 16,
      anon_sym_SEMI,
      aux_sym_select_clause_token4,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      aux_sym_binary_expression_token1,
      aux_sym_binary_expression_token2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [14616] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1891), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1889), 16,
      anon_sym_SEMI,
      aux_sym_select_clause_token4,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      aux_sym_binary_expression_token1,
      aux_sym_binary_expression_token2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [14642] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(441), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(439), 16,
      anon_sym_SEMI,
      aux_sym_select_clause_token4,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      aux_sym_binary_expression_token1,
      aux_sym_binary_expression_token2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [14668] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1867), 9,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_a,
      sym_pn_prefix,
    ACTIONS(1869), 9,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
  [14694] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(443), 16,
      anon_sym_SEMI,
      aux_sym_select_clause_token4,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      aux_sym_binary_expression_token1,
      aux_sym_binary_expression_token2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [14720] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(575), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(573), 16,
      anon_sym_SEMI,
      aux_sym_select_clause_token4,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      aux_sym_binary_expression_token1,
      aux_sym_binary_expression_token2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [14746] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(485), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(483), 16,
      anon_sym_SEMI,
      aux_sym_select_clause_token4,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      aux_sym_binary_expression_token1,
      aux_sym_binary_expression_token2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [14772] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(567), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(565), 16,
      anon_sym_SEMI,
      aux_sym_select_clause_token4,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      aux_sym_binary_expression_token1,
      aux_sym_binary_expression_token2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [14798] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(433), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(431), 16,
      anon_sym_SEMI,
      aux_sym_select_clause_token4,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      aux_sym_binary_expression_token1,
      aux_sym_binary_expression_token2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [14824] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(489), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(487), 16,
      anon_sym_SEMI,
      aux_sym_select_clause_token4,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      aux_sym_binary_expression_token1,
      aux_sym_binary_expression_token2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [14850] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(437), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(435), 16,
      anon_sym_SEMI,
      aux_sym_select_clause_token4,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      aux_sym_binary_expression_token1,
      aux_sym_binary_expression_token2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [14876] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(563), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(561), 16,
      anon_sym_SEMI,
      aux_sym_select_clause_token4,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      aux_sym_binary_expression_token1,
      aux_sym_binary_expression_token2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [14902] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(615), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(613), 16,
      anon_sym_SEMI,
      aux_sym_select_clause_token4,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      aux_sym_binary_expression_token1,
      aux_sym_binary_expression_token2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [14928] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1895), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1893), 16,
      anon_sym_SEMI,
      aux_sym_select_clause_token4,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      aux_sym_binary_expression_token1,
      aux_sym_binary_expression_token2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [14954] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(493), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(491), 16,
      anon_sym_SEMI,
      aux_sym_select_clause_token4,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      aux_sym_binary_expression_token1,
      aux_sym_binary_expression_token2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [14980] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1863), 9,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_a,
      sym_pn_prefix,
    ACTIONS(1865), 9,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
  [15006] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(595), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(593), 16,
      anon_sym_SEMI,
      aux_sym_select_clause_token4,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      aux_sym_binary_expression_token1,
      aux_sym_binary_expression_token2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [15032] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(599), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(597), 16,
      anon_sym_SEMI,
      aux_sym_select_clause_token4,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      aux_sym_binary_expression_token1,
      aux_sym_binary_expression_token2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [15058] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1899), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1897), 16,
      anon_sym_SEMI,
      aux_sym_select_clause_token4,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      aux_sym_binary_expression_token1,
      aux_sym_binary_expression_token2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [15084] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(417), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(415), 16,
      anon_sym_SEMI,
      aux_sym_select_clause_token4,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      aux_sym_binary_expression_token1,
      aux_sym_binary_expression_token2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [15110] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(603), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(601), 16,
      anon_sym_SEMI,
      aux_sym_select_clause_token4,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      aux_sym_binary_expression_token1,
      aux_sym_binary_expression_token2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [15136] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(571), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(569), 16,
      anon_sym_SEMI,
      aux_sym_select_clause_token4,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      aux_sym_binary_expression_token1,
      aux_sym_binary_expression_token2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [15162] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(405), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(403), 16,
      anon_sym_SEMI,
      aux_sym_select_clause_token4,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      aux_sym_binary_expression_token1,
      aux_sym_binary_expression_token2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [15188] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(579), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(577), 16,
      anon_sym_SEMI,
      aux_sym_select_clause_token4,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      aux_sym_binary_expression_token1,
      aux_sym_binary_expression_token2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [15214] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(409), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(407), 16,
      anon_sym_SEMI,
      aux_sym_select_clause_token4,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      aux_sym_binary_expression_token1,
      aux_sym_binary_expression_token2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [15240] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1887), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1871), 16,
      anon_sym_SEMI,
      aux_sym_select_clause_token4,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      aux_sym_binary_expression_token1,
      aux_sym_binary_expression_token2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [15266] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(587), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(585), 16,
      anon_sym_SEMI,
      aux_sym_select_clause_token4,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      aux_sym_binary_expression_token1,
      aux_sym_binary_expression_token2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [15292] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(583), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(581), 16,
      anon_sym_SEMI,
      aux_sym_select_clause_token4,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      aux_sym_binary_expression_token1,
      aux_sym_binary_expression_token2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [15318] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(405), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(403), 16,
      anon_sym_SEMI,
      aux_sym_select_clause_token4,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_COMMA,
      anon_sym_SLASH,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      aux_sym_binary_expression_token1,
      aux_sym_binary_expression_token2,
      anon_sym_PLUS,
      anon_sym_DASH,
  [15344] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1901), 1,
      anon_sym_RPAREN,
    ACTIONS(1903), 1,
      anon_sym_COMMA,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    STATE(923), 1,
      aux_sym_arg_list_repeat1,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [15387] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1903), 1,
      anon_sym_COMMA,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1907), 1,
      anon_sym_RPAREN,
    STATE(929), 1,
      aux_sym_arg_list_repeat1,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [15430] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1903), 1,
      anon_sym_COMMA,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1909), 1,
      anon_sym_RPAREN,
    STATE(927), 1,
      aux_sym_arg_list_repeat1,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [15473] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1903), 1,
      anon_sym_COMMA,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1911), 1,
      anon_sym_RPAREN,
    STATE(936), 1,
      aux_sym_arg_list_repeat1,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [15516] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1903), 1,
      anon_sym_COMMA,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1913), 1,
      anon_sym_RPAREN,
    STATE(915), 1,
      aux_sym_arg_list_repeat1,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [15559] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1915), 1,
      anon_sym_CARET_CARET,
    ACTIONS(1917), 1,
      sym_lang_tag,
    ACTIONS(1769), 7,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_LT,
      anon_sym_COLON,
      sym_double,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(1767), 8,
      aux_sym__data_block_value_token1,
      anon_sym_true,
      anon_sym_false,
      sym_integer,
      sym_decimal,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
  [15588] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1903), 1,
      anon_sym_COMMA,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1919), 1,
      anon_sym_RPAREN,
    STATE(924), 1,
      aux_sym_arg_list_repeat1,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [15631] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1903), 1,
      anon_sym_COMMA,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1921), 1,
      anon_sym_RPAREN,
    STATE(887), 1,
      aux_sym_arg_list_repeat1,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [15674] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1903), 1,
      anon_sym_COMMA,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1923), 1,
      anon_sym_RPAREN,
    STATE(889), 1,
      aux_sym_arg_list_repeat1,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [15717] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1903), 1,
      anon_sym_COMMA,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1925), 1,
      anon_sym_RPAREN,
    STATE(893), 1,
      aux_sym_arg_list_repeat1,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [15760] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1903), 1,
      anon_sym_COMMA,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1927), 1,
      anon_sym_RPAREN,
    STATE(894), 1,
      aux_sym_arg_list_repeat1,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [15803] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1903), 1,
      anon_sym_COMMA,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1929), 1,
      anon_sym_RPAREN,
    STATE(932), 1,
      aux_sym_arg_list_repeat1,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [15846] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1903), 1,
      anon_sym_COMMA,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1931), 1,
      anon_sym_RPAREN,
    STATE(937), 1,
      aux_sym_arg_list_repeat1,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [15889] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(969), 1,
      sym_pn_prefix,
    ACTIONS(979), 1,
      anon_sym_LT,
    ACTIONS(983), 1,
      anon_sym_COLON,
    ACTIONS(1935), 1,
      aux_sym_graph_or_default_token2,
    ACTIONS(1937), 1,
      anon_sym_a,
    ACTIONS(1939), 1,
      sym_var,
    STATE(384), 1,
      sym_namespace,
    STATE(804), 1,
      sym_property,
    ACTIONS(1933), 3,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_DOT,
    STATE(247), 5,
      sym__predicate,
      sym__var_or_iri,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
  [15929] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1941), 1,
      anon_sym_SEMI,
    ACTIONS(1943), 1,
      anon_sym_RPAREN,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [15969] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1945), 1,
      anon_sym_SEMI,
    ACTIONS(1947), 1,
      anon_sym_RPAREN,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [16009] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1949), 1,
      anon_sym_RPAREN,
    ACTIONS(1951), 1,
      anon_sym_COMMA,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [16049] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1953), 1,
      anon_sym_RPAREN,
    ACTIONS(1955), 1,
      anon_sym_COMMA,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [16089] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1957), 1,
      anon_sym_RPAREN,
    ACTIONS(1959), 1,
      anon_sym_COMMA,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [16129] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1961), 1,
      anon_sym_RPAREN,
    ACTIONS(1963), 1,
      anon_sym_COMMA,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [16169] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1965), 1,
      anon_sym_RPAREN,
    ACTIONS(1967), 1,
      anon_sym_COMMA,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [16209] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1969), 1,
      anon_sym_SEMI,
    ACTIONS(1971), 1,
      anon_sym_RPAREN,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [16249] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1973), 1,
      anon_sym_SEMI,
    ACTIONS(1975), 1,
      anon_sym_RPAREN,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [16289] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1977), 1,
      anon_sym_RPAREN,
    ACTIONS(1979), 1,
      anon_sym_COMMA,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [16329] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1981), 1,
      anon_sym_RPAREN,
    ACTIONS(1983), 1,
      anon_sym_COMMA,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [16369] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1985), 1,
      anon_sym_RPAREN,
    ACTIONS(1987), 1,
      anon_sym_COMMA,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [16409] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1989), 1,
      anon_sym_SEMI,
    ACTIONS(1991), 1,
      anon_sym_RPAREN,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [16449] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1293), 1,
      anon_sym_CARET,
    ACTIONS(1993), 1,
      sym_pn_prefix,
    ACTIONS(1995), 1,
      anon_sym_LPAREN,
    ACTIONS(1997), 1,
      anon_sym_a,
    ACTIONS(1999), 1,
      anon_sym_BANG,
    ACTIONS(2001), 1,
      anon_sym_LT,
    ACTIONS(2003), 1,
      anon_sym_COLON,
    STATE(710), 1,
      sym_path_inverse,
    STATE(809), 1,
      sym_namespace,
    STATE(920), 3,
      sym__path,
      sym_binary_path,
      sym_path_element,
    STATE(837), 4,
      sym__primary_path,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
  [16491] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1177), 5,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_LT,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(1179), 11,
      aux_sym__data_block_value_token1,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON,
      sym_integer,
      sym_decimal,
      sym_double,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
      sym_pn_local,
  [16515] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2005), 1,
      anon_sym_RPAREN,
    ACTIONS(2007), 1,
      anon_sym_COMMA,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [16555] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2009), 1,
      sym_pn_local,
    ACTIONS(1189), 5,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_LT,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(1191), 10,
      aux_sym__data_block_value_token1,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON,
      sym_integer,
      sym_decimal,
      sym_double,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
  [16581] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2011), 2,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [16619] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(969), 1,
      sym_pn_prefix,
    ACTIONS(979), 1,
      anon_sym_LT,
    ACTIONS(983), 1,
      anon_sym_COLON,
    ACTIONS(1287), 1,
      anon_sym_LPAREN,
    ACTIONS(1291), 1,
      anon_sym_a,
    ACTIONS(1293), 1,
      anon_sym_CARET,
    ACTIONS(1295), 1,
      anon_sym_BANG,
    STATE(384), 1,
      sym_namespace,
    STATE(707), 1,
      sym_path_inverse,
    STATE(420), 3,
      sym__path,
      sym_binary_path,
      sym_path_element,
    STATE(477), 4,
      sym__primary_path,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
  [16661] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(969), 1,
      sym_pn_prefix,
    ACTIONS(979), 1,
      anon_sym_LT,
    ACTIONS(983), 1,
      anon_sym_COLON,
    ACTIONS(1287), 1,
      anon_sym_LPAREN,
    ACTIONS(1291), 1,
      anon_sym_a,
    ACTIONS(1293), 1,
      anon_sym_CARET,
    ACTIONS(1295), 1,
      anon_sym_BANG,
    STATE(384), 1,
      sym_namespace,
    STATE(707), 1,
      sym_path_inverse,
    STATE(519), 3,
      sym__path,
      sym_binary_path,
      sym_path_element,
    STATE(477), 4,
      sym__primary_path,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
  [16703] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2013), 1,
      anon_sym_RPAREN,
    ACTIONS(2015), 1,
      anon_sym_COMMA,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [16743] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1293), 1,
      anon_sym_CARET,
    ACTIONS(1993), 1,
      sym_pn_prefix,
    ACTIONS(1995), 1,
      anon_sym_LPAREN,
    ACTIONS(1997), 1,
      anon_sym_a,
    ACTIONS(1999), 1,
      anon_sym_BANG,
    ACTIONS(2001), 1,
      anon_sym_LT,
    ACTIONS(2003), 1,
      anon_sym_COLON,
    STATE(710), 1,
      sym_path_inverse,
    STATE(809), 1,
      sym_namespace,
    STATE(420), 3,
      sym__path,
      sym_binary_path,
      sym_path_element,
    STATE(837), 4,
      sym__primary_path,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
  [16785] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1293), 1,
      anon_sym_CARET,
    ACTIONS(1993), 1,
      sym_pn_prefix,
    ACTIONS(1995), 1,
      anon_sym_LPAREN,
    ACTIONS(1997), 1,
      anon_sym_a,
    ACTIONS(1999), 1,
      anon_sym_BANG,
    ACTIONS(2001), 1,
      anon_sym_LT,
    ACTIONS(2003), 1,
      anon_sym_COLON,
    STATE(710), 1,
      sym_path_inverse,
    STATE(809), 1,
      sym_namespace,
    STATE(899), 3,
      sym__path,
      sym_binary_path,
      sym_path_element,
    STATE(837), 4,
      sym__primary_path,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
  [16827] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1293), 1,
      anon_sym_CARET,
    ACTIONS(1993), 1,
      sym_pn_prefix,
    ACTIONS(1995), 1,
      anon_sym_LPAREN,
    ACTIONS(1997), 1,
      anon_sym_a,
    ACTIONS(1999), 1,
      anon_sym_BANG,
    ACTIONS(2001), 1,
      anon_sym_LT,
    ACTIONS(2003), 1,
      anon_sym_COLON,
    STATE(710), 1,
      sym_path_inverse,
    STATE(809), 1,
      sym_namespace,
    STATE(891), 3,
      sym__path,
      sym_binary_path,
      sym_path_element,
    STATE(837), 4,
      sym__primary_path,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
  [16869] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2017), 1,
      anon_sym_SEMI,
    ACTIONS(2019), 1,
      anon_sym_RPAREN,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [16909] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(969), 1,
      sym_pn_prefix,
    ACTIONS(979), 1,
      anon_sym_LT,
    ACTIONS(983), 1,
      anon_sym_COLON,
    ACTIONS(1937), 1,
      anon_sym_a,
    ACTIONS(1939), 1,
      sym_var,
    ACTIONS(2023), 1,
      aux_sym_graph_or_default_token2,
    STATE(384), 1,
      sym_namespace,
    STATE(811), 1,
      sym_property,
    STATE(909), 1,
      sym_property_list,
    ACTIONS(2021), 2,
      anon_sym_RBRACE,
      anon_sym_DOT,
    STATE(247), 5,
      sym__predicate,
      sym__var_or_iri,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
  [16951] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2025), 1,
      anon_sym_SEMI,
    ACTIONS(2027), 1,
      anon_sym_RPAREN,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [16991] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2029), 1,
      aux_sym_select_clause_token4,
    ACTIONS(2031), 1,
      anon_sym_RPAREN,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [17031] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2033), 1,
      anon_sym_SEMI,
    ACTIONS(2035), 1,
      anon_sym_RPAREN,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [17071] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2037), 1,
      anon_sym_RPAREN,
    ACTIONS(2039), 1,
      anon_sym_COMMA,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [17111] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2041), 1,
      anon_sym_RPAREN,
    ACTIONS(2043), 1,
      anon_sym_COMMA,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [17151] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2045), 1,
      aux_sym_select_clause_token4,
    ACTIONS(2047), 1,
      anon_sym_RPAREN,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [17191] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1157), 5,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_LT,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(1159), 11,
      aux_sym__data_block_value_token1,
      anon_sym_true,
      anon_sym_false,
      anon_sym_COLON,
      sym_integer,
      sym_decimal,
      sym_double,
      anon_sym_SQUOTE,
      anon_sym_DQUOTE,
      sym_pn_prefix,
      sym_pn_local,
  [17215] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2049), 1,
      anon_sym_RPAREN,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [17252] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2051), 1,
      anon_sym_COMMA,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [17289] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1813), 1,
      sym_lang_tag,
    ACTIONS(2053), 1,
      anon_sym_CARET_CARET,
    ACTIONS(1769), 13,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [17314] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2055), 1,
      anon_sym_COMMA,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [17351] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1991), 1,
      anon_sym_RPAREN,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [17388] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2057), 1,
      anon_sym_RPAREN,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [17425] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2059), 1,
      anon_sym_RPAREN,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [17462] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1019), 1,
      aux_sym_limit_clause_token1,
    ACTIONS(1021), 1,
      aux_sym_offset_clause_token1,
    ACTIONS(1515), 1,
      aux_sym_values_clause_token1,
    ACTIONS(2061), 1,
      anon_sym_RBRACE,
    ACTIONS(2063), 1,
      aux_sym_group_clause_token1,
    ACTIONS(2065), 1,
      aux_sym_having_clause_token1,
    ACTIONS(2067), 1,
      aux_sym_order_clause_token1,
    STATE(373), 1,
      sym_order_clause,
    STATE(379), 1,
      sym_limit_clause,
    STATE(380), 1,
      sym_offset_clause,
    STATE(398), 1,
      sym_limit_offset_clauses,
    STATE(706), 1,
      sym_group_clause,
    STATE(740), 1,
      sym_having_clause,
    STATE(903), 1,
      sym_solution_modifier,
    STATE(1008), 1,
      sym_values_clause,
  [17511] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2069), 1,
      anon_sym_COMMA,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [17548] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2071), 1,
      anon_sym_RPAREN,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [17585] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2073), 1,
      anon_sym_RPAREN,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [17622] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1947), 1,
      anon_sym_RPAREN,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [17659] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2075), 1,
      anon_sym_RPAREN,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [17696] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2077), 1,
      aux_sym_select_clause_token4,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [17733] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2079), 1,
      anon_sym_COMMA,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [17770] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2081), 1,
      aux_sym_select_clause_token4,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [17807] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2083), 1,
      anon_sym_RPAREN,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [17844] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2085), 1,
      anon_sym_RPAREN,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [17881] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2087), 1,
      anon_sym_COMMA,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [17918] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1971), 1,
      anon_sym_RPAREN,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [17955] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2089), 1,
      anon_sym_RPAREN,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [17992] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1975), 1,
      anon_sym_RPAREN,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [18029] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2091), 1,
      anon_sym_RPAREN,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [18066] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2019), 1,
      anon_sym_RPAREN,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [18103] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2093), 1,
      anon_sym_COMMA,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [18140] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1943), 1,
      anon_sym_RPAREN,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [18177] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2027), 1,
      anon_sym_RPAREN,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [18214] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2095), 1,
      anon_sym_RPAREN,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [18251] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2035), 1,
      anon_sym_RPAREN,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [18288] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2097), 1,
      anon_sym_RPAREN,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [18325] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2099), 1,
      anon_sym_RPAREN,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [18362] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2101), 1,
      anon_sym_COMMA,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [18399] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2103), 1,
      anon_sym_COMMA,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [18436] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2105), 1,
      anon_sym_COMMA,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [18473] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2107), 1,
      anon_sym_COMMA,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [18510] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2109), 1,
      anon_sym_COMMA,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [18547] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2111), 1,
      anon_sym_COMMA,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [18584] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2113), 1,
      anon_sym_COMMA,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [18621] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2115), 1,
      anon_sym_COMMA,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [18658] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2117), 1,
      anon_sym_COMMA,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [18695] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2119), 1,
      anon_sym_COMMA,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [18732] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2121), 1,
      anon_sym_COMMA,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [18769] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2123), 1,
      anon_sym_COMMA,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [18806] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2125), 1,
      anon_sym_COMMA,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [18843] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2127), 1,
      anon_sym_COMMA,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [18880] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2129), 1,
      anon_sym_COMMA,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [18917] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2131), 1,
      anon_sym_RPAREN,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [18954] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2133), 1,
      anon_sym_RPAREN,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [18991] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2135), 1,
      anon_sym_RPAREN,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [19028] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2137), 1,
      anon_sym_COMMA,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [19065] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2139), 1,
      anon_sym_RPAREN,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [19102] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2141), 1,
      anon_sym_RPAREN,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [19139] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2143), 1,
      anon_sym_RPAREN,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [19176] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2145), 1,
      anon_sym_RPAREN,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [19213] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2147), 1,
      anon_sym_RPAREN,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [19250] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2149), 1,
      anon_sym_RPAREN,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [19287] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2151), 1,
      anon_sym_COMMA,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [19324] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2153), 1,
      anon_sym_COMMA,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [19361] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2155), 1,
      anon_sym_COMMA,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [19398] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2157), 1,
      anon_sym_COMMA,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [19435] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2159), 1,
      anon_sym_COMMA,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [19472] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2161), 1,
      anon_sym_COMMA,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [19509] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2163), 1,
      anon_sym_RPAREN,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [19546] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1875), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1881), 1,
      aux_sym_binary_expression_token1,
    ACTIONS(1883), 1,
      aux_sym_binary_expression_token2,
    ACTIONS(1905), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(2165), 1,
      anon_sym_RPAREN,
    ACTIONS(1873), 2,
      anon_sym_STAR,
      anon_sym_SLASH,
    ACTIONS(1879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1885), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1877), 4,
      anon_sym_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
  [19583] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(969), 1,
      sym_pn_prefix,
    ACTIONS(979), 1,
      anon_sym_LT,
    ACTIONS(983), 1,
      anon_sym_COLON,
    ACTIONS(2167), 1,
      anon_sym_a,
    ACTIONS(2169), 1,
      sym_var,
    STATE(384), 1,
      sym_namespace,
    STATE(804), 1,
      sym_property,
    ACTIONS(1933), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
    STATE(259), 5,
      sym__predicate,
      sym__var_or_iri,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
  [19619] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2173), 1,
      anon_sym_COMMA,
    STATE(692), 1,
      aux_sym_object_list_path_repeat1,
    ACTIONS(2171), 11,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
  [19642] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2175), 13,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [19661] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2179), 1,
      anon_sym_COMMA,
    STATE(695), 1,
      aux_sym_object_list_repeat1,
    ACTIONS(2177), 11,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
  [19684] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(969), 1,
      sym_pn_prefix,
    ACTIONS(979), 1,
      anon_sym_LT,
    ACTIONS(983), 1,
      anon_sym_COLON,
    ACTIONS(2167), 1,
      anon_sym_a,
    ACTIONS(2169), 1,
      sym_var,
    STATE(384), 1,
      sym_namespace,
    STATE(906), 1,
      sym_property,
    STATE(1017), 1,
      sym_property_list,
    STATE(259), 5,
      sym__predicate,
      sym__var_or_iri,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
  [19719] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2173), 1,
      anon_sym_COMMA,
    STATE(686), 1,
      aux_sym_object_list_path_repeat1,
    ACTIONS(2181), 11,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
  [19742] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2183), 1,
      anon_sym_COMMA,
    STATE(691), 1,
      aux_sym_object_list_repeat1,
    ACTIONS(2175), 11,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
  [19765] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2188), 1,
      anon_sym_COMMA,
    STATE(692), 1,
      aux_sym_object_list_path_repeat1,
    ACTIONS(2186), 11,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
  [19788] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(969), 1,
      sym_pn_prefix,
    ACTIONS(979), 1,
      anon_sym_LT,
    ACTIONS(983), 1,
      anon_sym_COLON,
    ACTIONS(2167), 1,
      anon_sym_a,
    ACTIONS(2169), 1,
      sym_var,
    STATE(384), 1,
      sym_namespace,
    STATE(906), 1,
      sym_property,
    STATE(1046), 1,
      sym_property_list,
    STATE(259), 5,
      sym__predicate,
      sym__var_or_iri,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
  [19823] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(969), 1,
      sym_pn_prefix,
    ACTIONS(979), 1,
      anon_sym_LT,
    ACTIONS(983), 1,
      anon_sym_COLON,
    ACTIONS(1937), 1,
      anon_sym_a,
    ACTIONS(1939), 1,
      sym_var,
    STATE(384), 1,
      sym_namespace,
    STATE(811), 1,
      sym_property,
    STATE(909), 1,
      sym_property_list,
    STATE(247), 5,
      sym__predicate,
      sym__var_or_iri,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
  [19858] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2179), 1,
      anon_sym_COMMA,
    STATE(691), 1,
      aux_sym_object_list_repeat1,
    ACTIONS(2191), 11,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
  [19881] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2186), 13,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [19900] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2193), 1,
      anon_sym_SEMI,
    STATE(697), 1,
      aux_sym_property_list_path_repeat1,
    ACTIONS(2196), 10,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
  [19922] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2196), 12,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_RBRACK,
  [19940] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2198), 1,
      anon_sym_SEMI,
    STATE(697), 1,
      aux_sym_property_list_path_repeat1,
    ACTIONS(2200), 10,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
  [19962] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2198), 1,
      anon_sym_SEMI,
    STATE(699), 1,
      aux_sym_property_list_path_repeat1,
    ACTIONS(2202), 10,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
  [19984] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1993), 1,
      sym_pn_prefix,
    ACTIONS(2001), 1,
      anon_sym_LT,
    ACTIONS(2003), 1,
      anon_sym_COLON,
    ACTIONS(2204), 1,
      anon_sym_LPAREN,
    ACTIONS(2206), 1,
      anon_sym_a,
    ACTIONS(2208), 1,
      anon_sym_CARET,
    STATE(809), 1,
      sym_namespace,
    STATE(848), 1,
      sym_path_negated_property_set,
    STATE(849), 1,
      sym_path_one_in_property_set,
    STATE(847), 3,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
  [20020] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(969), 1,
      sym_pn_prefix,
    ACTIONS(979), 1,
      anon_sym_LT,
    ACTIONS(983), 1,
      anon_sym_COLON,
    ACTIONS(2210), 1,
      anon_sym_LPAREN,
    ACTIONS(2212), 1,
      anon_sym_a,
    ACTIONS(2214), 1,
      anon_sym_CARET,
    STATE(384), 1,
      sym_namespace,
    STATE(464), 1,
      sym_path_negated_property_set,
    STATE(465), 1,
      sym_path_one_in_property_set,
    STATE(408), 3,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
  [20056] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2216), 12,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_RBRACK,
  [20074] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2218), 12,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
      anon_sym_RBRACK,
  [20092] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      sym_pn_prefix,
    ACTIONS(57), 1,
      anon_sym_LT,
    ACTIONS(89), 1,
      anon_sym_COLON,
    ACTIONS(2212), 1,
      anon_sym_a,
    ACTIONS(2220), 1,
      anon_sym_RPAREN,
    ACTIONS(2222), 1,
      anon_sym_CARET,
    STATE(413), 1,
      sym_namespace,
    STATE(930), 1,
      sym_path_one_in_property_set,
    STATE(408), 3,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
  [20125] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1019), 1,
      aux_sym_limit_clause_token1,
    ACTIONS(1021), 1,
      aux_sym_offset_clause_token1,
    ACTIONS(2065), 1,
      aux_sym_having_clause_token1,
    ACTIONS(2067), 1,
      aux_sym_order_clause_token1,
    STATE(376), 1,
      sym_order_clause,
    STATE(379), 1,
      sym_limit_clause,
    STATE(380), 1,
      sym_offset_clause,
    STATE(392), 1,
      sym_limit_offset_clauses,
    STATE(741), 1,
      sym_having_clause,
    ACTIONS(1274), 2,
      anon_sym_RBRACE,
      aux_sym_values_clause_token1,
  [20160] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(969), 1,
      sym_pn_prefix,
    ACTIONS(979), 1,
      anon_sym_LT,
    ACTIONS(983), 1,
      anon_sym_COLON,
    ACTIONS(1287), 1,
      anon_sym_LPAREN,
    ACTIONS(1295), 1,
      anon_sym_BANG,
    ACTIONS(2224), 1,
      anon_sym_a,
    STATE(384), 1,
      sym_namespace,
    STATE(468), 4,
      sym__primary_path,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
  [20191] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2228), 1,
      anon_sym_DOT,
    STATE(709), 1,
      aux_sym_triples_block_repeat1,
    ACTIONS(2226), 9,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
  [20212] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2230), 1,
      anon_sym_DOT,
    STATE(713), 1,
      aux_sym_triples_block_repeat1,
    ACTIONS(876), 9,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
  [20233] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1993), 1,
      sym_pn_prefix,
    ACTIONS(1995), 1,
      anon_sym_LPAREN,
    ACTIONS(1999), 1,
      anon_sym_BANG,
    ACTIONS(2001), 1,
      anon_sym_LT,
    ACTIONS(2003), 1,
      anon_sym_COLON,
    ACTIONS(2232), 1,
      anon_sym_a,
    STATE(809), 1,
      sym_namespace,
    STATE(851), 4,
      sym__primary_path,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
  [20264] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      sym_pn_prefix,
    ACTIONS(57), 1,
      anon_sym_LT,
    ACTIONS(89), 1,
      anon_sym_COLON,
    ACTIONS(2234), 1,
      aux_sym_load_token2,
    ACTIONS(2236), 1,
      aux_sym_graph_or_default_token1,
    ACTIONS(2238), 1,
      aux_sym_graph_or_default_token2,
    STATE(413), 1,
      sym_namespace,
    STATE(1040), 1,
      sym_graph_or_default,
    STATE(409), 3,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
  [20297] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      sym_pn_prefix,
    ACTIONS(57), 1,
      anon_sym_LT,
    ACTIONS(89), 1,
      anon_sym_COLON,
    ACTIONS(2236), 1,
      aux_sym_graph_or_default_token1,
    ACTIONS(2238), 1,
      aux_sym_graph_or_default_token2,
    ACTIONS(2240), 1,
      aux_sym_load_token2,
    STATE(413), 1,
      sym_namespace,
    STATE(1043), 1,
      sym_graph_or_default,
    STATE(409), 3,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
  [20330] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2244), 1,
      anon_sym_DOT,
    STATE(713), 1,
      aux_sym_triples_block_repeat1,
    ACTIONS(2242), 9,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
  [20351] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(57), 1,
      anon_sym_LT,
    ACTIONS(864), 1,
      anon_sym_COLON,
    ACTIONS(2247), 1,
      sym_pn_prefix,
    ACTIONS(2249), 1,
      anon_sym_STAR,
    ACTIONS(2251), 1,
      sym_var,
    STATE(274), 1,
      sym_namespace,
    STATE(222), 5,
      sym__var_or_iri,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
      aux_sym_describe_query_repeat1,
  [20380] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      sym_pn_prefix,
    ACTIONS(57), 1,
      anon_sym_LT,
    ACTIONS(89), 1,
      anon_sym_COLON,
    ACTIONS(2212), 1,
      anon_sym_a,
    ACTIONS(2222), 1,
      anon_sym_CARET,
    ACTIONS(2253), 1,
      anon_sym_RPAREN,
    STATE(413), 1,
      sym_namespace,
    STATE(934), 1,
      sym_path_one_in_property_set,
    STATE(408), 3,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
  [20413] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      sym_pn_prefix,
    ACTIONS(57), 1,
      anon_sym_LT,
    ACTIONS(89), 1,
      anon_sym_COLON,
    ACTIONS(2236), 1,
      aux_sym_graph_or_default_token1,
    ACTIONS(2238), 1,
      aux_sym_graph_or_default_token2,
    ACTIONS(2255), 1,
      aux_sym_load_token2,
    STATE(413), 1,
      sym_namespace,
    STATE(1037), 1,
      sym_graph_or_default,
    STATE(409), 3,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
  [20446] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      sym_pn_prefix,
    ACTIONS(57), 1,
      anon_sym_LT,
    ACTIONS(89), 1,
      anon_sym_COLON,
    ACTIONS(2236), 1,
      aux_sym_graph_or_default_token1,
    ACTIONS(2238), 1,
      aux_sym_graph_or_default_token2,
    STATE(413), 1,
      sym_namespace,
    STATE(1038), 1,
      sym_graph_or_default,
    STATE(409), 3,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
  [20476] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(57), 1,
      anon_sym_LT,
    ACTIONS(2236), 1,
      aux_sym_graph_or_default_token1,
    ACTIONS(2257), 1,
      sym_pn_prefix,
    ACTIONS(2259), 1,
      aux_sym_graph_or_default_token2,
    ACTIONS(2261), 1,
      anon_sym_COLON,
    STATE(288), 1,
      sym_namespace,
    STATE(419), 1,
      sym_graph_or_default,
    STATE(409), 3,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
  [20506] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(57), 1,
      anon_sym_LT,
    ACTIONS(2236), 1,
      aux_sym_graph_or_default_token1,
    ACTIONS(2257), 1,
      sym_pn_prefix,
    ACTIONS(2259), 1,
      aux_sym_graph_or_default_token2,
    ACTIONS(2261), 1,
      anon_sym_COLON,
    STATE(288), 1,
      sym_namespace,
    STATE(473), 1,
      sym_graph_or_default,
    STATE(409), 3,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
  [20536] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(57), 1,
      anon_sym_LT,
    ACTIONS(2236), 1,
      aux_sym_graph_or_default_token1,
    ACTIONS(2257), 1,
      sym_pn_prefix,
    ACTIONS(2259), 1,
      aux_sym_graph_or_default_token2,
    ACTIONS(2261), 1,
      anon_sym_COLON,
    STATE(288), 1,
      sym_namespace,
    STATE(445), 1,
      sym_graph_or_default,
    STATE(409), 3,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
  [20566] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      sym_pn_prefix,
    ACTIONS(57), 1,
      anon_sym_LT,
    ACTIONS(89), 1,
      anon_sym_COLON,
    ACTIONS(2263), 1,
      aux_sym_named_graph_clause_token1,
    STATE(413), 1,
      sym_namespace,
    STATE(311), 2,
      sym_default_graph_clause,
      sym_named_graph_clause,
    STATE(312), 3,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
  [20594] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2265), 10,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
  [20610] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2267), 10,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
  [20626] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      sym_pn_prefix,
    ACTIONS(57), 1,
      anon_sym_LT,
    ACTIONS(89), 1,
      anon_sym_COLON,
    ACTIONS(2236), 1,
      aux_sym_graph_or_default_token1,
    ACTIONS(2238), 1,
      aux_sym_graph_or_default_token2,
    STATE(413), 1,
      sym_namespace,
    STATE(1039), 1,
      sym_graph_or_default,
    STATE(409), 3,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
  [20656] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(57), 1,
      anon_sym_LT,
    ACTIONS(2236), 1,
      aux_sym_graph_or_default_token1,
    ACTIONS(2257), 1,
      sym_pn_prefix,
    ACTIONS(2259), 1,
      aux_sym_graph_or_default_token2,
    ACTIONS(2261), 1,
      anon_sym_COLON,
    STATE(288), 1,
      sym_namespace,
    STATE(446), 1,
      sym_graph_or_default,
    STATE(409), 3,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
  [20686] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(57), 1,
      anon_sym_LT,
    ACTIONS(2236), 1,
      aux_sym_graph_or_default_token1,
    ACTIONS(2257), 1,
      sym_pn_prefix,
    ACTIONS(2259), 1,
      aux_sym_graph_or_default_token2,
    ACTIONS(2261), 1,
      anon_sym_COLON,
    STATE(288), 1,
      sym_namespace,
    STATE(472), 1,
      sym_graph_or_default,
    STATE(409), 3,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
  [20716] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(57), 1,
      anon_sym_LT,
    ACTIONS(2257), 1,
      sym_pn_prefix,
    ACTIONS(2261), 1,
      anon_sym_COLON,
    ACTIONS(2269), 1,
      aux_sym_named_graph_clause_token1,
    STATE(288), 1,
      sym_namespace,
    STATE(311), 2,
      sym_default_graph_clause,
      sym_named_graph_clause,
    STATE(312), 3,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
  [20744] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      sym_pn_prefix,
    ACTIONS(57), 1,
      anon_sym_LT,
    ACTIONS(89), 1,
      anon_sym_COLON,
    ACTIONS(2212), 1,
      anon_sym_a,
    ACTIONS(2222), 1,
      anon_sym_CARET,
    STATE(413), 1,
      sym_namespace,
    STATE(950), 1,
      sym_path_one_in_property_set,
    STATE(408), 3,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
  [20774] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1917), 1,
      sym_lang_tag,
    ACTIONS(2271), 1,
      anon_sym_CARET_CARET,
    ACTIONS(1767), 3,
      anon_sym_a,
      anon_sym_CARET,
      sym_pn_prefix,
    ACTIONS(1769), 5,
      anon_sym_LPAREN,
      anon_sym_BANG,
      sym_var,
      anon_sym_LT,
      anon_sym_COLON,
  [20796] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2242), 10,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
  [20812] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      sym_pn_prefix,
    ACTIONS(57), 1,
      anon_sym_LT,
    ACTIONS(89), 1,
      anon_sym_COLON,
    ACTIONS(2236), 1,
      aux_sym_graph_or_default_token1,
    ACTIONS(2238), 1,
      aux_sym_graph_or_default_token2,
    STATE(413), 1,
      sym_namespace,
    STATE(1070), 1,
      sym_graph_or_default,
    STATE(409), 3,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
  [20842] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      sym_pn_prefix,
    ACTIONS(57), 1,
      anon_sym_LT,
    ACTIONS(89), 1,
      anon_sym_COLON,
    ACTIONS(2273), 1,
      aux_sym_load_token2,
    ACTIONS(2275), 1,
      sym_var,
    STATE(413), 1,
      sym_namespace,
    STATE(965), 4,
      sym__var_or_iri,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
  [20870] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(57), 1,
      anon_sym_LT,
    ACTIONS(2236), 1,
      aux_sym_graph_or_default_token1,
    ACTIONS(2257), 1,
      sym_pn_prefix,
    ACTIONS(2259), 1,
      aux_sym_graph_or_default_token2,
    ACTIONS(2261), 1,
      anon_sym_COLON,
    STATE(288), 1,
      sym_namespace,
    STATE(444), 1,
      sym_graph_or_default,
    STATE(409), 3,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
  [20900] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(206), 1,
      anon_sym_SQUOTE,
    ACTIONS(208), 1,
      anon_sym_DQUOTE,
    ACTIONS(210), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(212), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(1007), 1,
      sym_string,
    STATE(296), 4,
      sym__string_literal1,
      sym__string_literal2,
      sym__string_literal_long1,
      sym__string_literal_long2,
  [20925] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1159), 4,
      anon_sym_a,
      anon_sym_COLON,
      sym_pn_prefix,
      sym_pn_local,
    ACTIONS(1157), 5,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_BANG,
      sym_var,
      anon_sym_LT,
  [20942] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2009), 1,
      sym_pn_local,
    ACTIONS(1191), 3,
      anon_sym_a,
      anon_sym_COLON,
      sym_pn_prefix,
    ACTIONS(1189), 5,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_BANG,
      sym_var,
      anon_sym_LT,
  [20961] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(57), 1,
      anon_sym_LT,
    ACTIONS(89), 1,
      anon_sym_COLON,
    ACTIONS(2277), 1,
      sym_pn_prefix,
    ACTIONS(2279), 1,
      sym_var,
    STATE(413), 1,
      sym_namespace,
    STATE(1066), 4,
      sym__var_or_iri,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
  [20986] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(206), 1,
      anon_sym_SQUOTE,
    ACTIONS(208), 1,
      anon_sym_DQUOTE,
    ACTIONS(210), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(212), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(1044), 1,
      sym_string,
    STATE(296), 4,
      sym__string_literal1,
      sym__string_literal2,
      sym__string_literal_long1,
      sym__string_literal_long2,
  [21011] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(206), 1,
      anon_sym_SQUOTE,
    ACTIONS(208), 1,
      anon_sym_DQUOTE,
    ACTIONS(210), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(212), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(1108), 1,
      sym_string,
    STATE(296), 4,
      sym__string_literal1,
      sym__string_literal2,
      sym__string_literal_long1,
      sym__string_literal_long2,
  [21036] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1019), 1,
      aux_sym_limit_clause_token1,
    ACTIONS(1021), 1,
      aux_sym_offset_clause_token1,
    ACTIONS(2067), 1,
      aux_sym_order_clause_token1,
    STATE(376), 1,
      sym_order_clause,
    STATE(379), 1,
      sym_limit_clause,
    STATE(380), 1,
      sym_offset_clause,
    STATE(392), 1,
      sym_limit_offset_clauses,
    ACTIONS(1274), 2,
      anon_sym_RBRACE,
      aux_sym_values_clause_token1,
  [21065] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1019), 1,
      aux_sym_limit_clause_token1,
    ACTIONS(1021), 1,
      aux_sym_offset_clause_token1,
    ACTIONS(2067), 1,
      aux_sym_order_clause_token1,
    STATE(374), 1,
      sym_order_clause,
    STATE(379), 1,
      sym_limit_clause,
    STATE(380), 1,
      sym_offset_clause,
    STATE(405), 1,
      sym_limit_offset_clauses,
    ACTIONS(1405), 2,
      anon_sym_RBRACE,
      aux_sym_values_clause_token1,
  [21094] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(206), 1,
      anon_sym_SQUOTE,
    ACTIONS(208), 1,
      anon_sym_DQUOTE,
    ACTIONS(210), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(212), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(1004), 1,
      sym_string,
    STATE(296), 4,
      sym__string_literal1,
      sym__string_literal2,
      sym__string_literal_long1,
      sym__string_literal_long2,
  [21119] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2281), 9,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
  [21134] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(206), 1,
      anon_sym_SQUOTE,
    ACTIONS(208), 1,
      anon_sym_DQUOTE,
    ACTIONS(210), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(212), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(992), 1,
      sym_string,
    STATE(296), 4,
      sym__string_literal1,
      sym__string_literal2,
      sym__string_literal_long1,
      sym__string_literal_long2,
  [21159] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(206), 1,
      anon_sym_SQUOTE,
    ACTIONS(208), 1,
      anon_sym_DQUOTE,
    ACTIONS(210), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(212), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(993), 1,
      sym_string,
    STATE(296), 4,
      sym__string_literal1,
      sym__string_literal2,
      sym__string_literal_long1,
      sym__string_literal_long2,
  [21184] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(206), 1,
      anon_sym_SQUOTE,
    ACTIONS(208), 1,
      anon_sym_DQUOTE,
    ACTIONS(210), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(212), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(1058), 1,
      sym_string,
    STATE(296), 4,
      sym__string_literal1,
      sym__string_literal2,
      sym__string_literal_long1,
      sym__string_literal_long2,
  [21209] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(206), 1,
      anon_sym_SQUOTE,
    ACTIONS(208), 1,
      anon_sym_DQUOTE,
    ACTIONS(210), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(212), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(1059), 1,
      sym_string,
    STATE(296), 4,
      sym__string_literal1,
      sym__string_literal2,
      sym__string_literal_long1,
      sym__string_literal_long2,
  [21234] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(57), 1,
      anon_sym_LT,
    ACTIONS(89), 1,
      anon_sym_COLON,
    ACTIONS(2277), 1,
      sym_pn_prefix,
    ACTIONS(2283), 1,
      sym_var,
    STATE(413), 1,
      sym_namespace,
    STATE(960), 4,
      sym__var_or_iri,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
  [21259] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(57), 1,
      anon_sym_LT,
    ACTIONS(89), 1,
      anon_sym_COLON,
    ACTIONS(2277), 1,
      sym_pn_prefix,
    ACTIONS(2285), 1,
      sym_var,
    STATE(413), 1,
      sym_namespace,
    STATE(963), 4,
      sym__var_or_iri,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
  [21284] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1179), 4,
      anon_sym_a,
      anon_sym_COLON,
      sym_pn_prefix,
      sym_pn_local,
    ACTIONS(1177), 5,
      anon_sym_LPAREN,
      anon_sym_CARET,
      anon_sym_BANG,
      sym_var,
      anon_sym_LT,
  [21301] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(872), 9,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      aux_sym_values_clause_token1,
      aux_sym_graph_or_default_token2,
      aux_sym_optional_graph_pattern_token1,
      aux_sym_service_graph_pattern_token1,
      aux_sym_bind_token1,
      aux_sym_minus_graph_pattern_token1,
      aux_sym_filter_token1,
  [21316] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1993), 1,
      sym_pn_prefix,
    ACTIONS(2001), 1,
      anon_sym_LT,
    ACTIONS(2003), 1,
      anon_sym_COLON,
    ACTIONS(2287), 1,
      anon_sym_a,
    STATE(809), 1,
      sym_namespace,
    STATE(858), 3,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
  [21340] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(969), 1,
      sym_pn_prefix,
    ACTIONS(979), 1,
      anon_sym_LT,
    ACTIONS(983), 1,
      anon_sym_COLON,
    ACTIONS(2289), 1,
      anon_sym_a,
    STATE(384), 1,
      sym_namespace,
    STATE(418), 3,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
  [21364] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(57), 1,
      anon_sym_LT,
    ACTIONS(2257), 1,
      sym_pn_prefix,
    ACTIONS(2261), 1,
      anon_sym_COLON,
    ACTIONS(2291), 1,
      aux_sym_load_token2,
    STATE(288), 1,
      sym_namespace,
    STATE(391), 3,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
  [21388] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      sym_pn_prefix,
    ACTIONS(57), 1,
      anon_sym_LT,
    ACTIONS(89), 1,
      anon_sym_COLON,
    ACTIONS(2289), 1,
      anon_sym_a,
    STATE(413), 1,
      sym_namespace,
    STATE(418), 3,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
  [21412] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      sym_pn_prefix,
    ACTIONS(57), 1,
      anon_sym_LT,
    ACTIONS(89), 1,
      anon_sym_COLON,
    ACTIONS(2293), 1,
      aux_sym_named_graph_clause_token1,
    STATE(413), 1,
      sym_namespace,
    STATE(980), 3,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
  [21436] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(848), 1,
      anon_sym_LBRACE,
    ACTIONS(1009), 1,
      aux_sym_construct_query_token2,
    ACTIONS(2295), 1,
      aux_sym_dataset_clause_token1,
    STATE(282), 1,
      sym_where_clause,
    STATE(377), 1,
      sym_group_graph_pattern,
    STATE(776), 2,
      sym_dataset_clause,
      aux_sym_select_query_repeat1,
  [21459] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(808), 1,
      anon_sym_LT,
    ACTIONS(812), 1,
      anon_sym_COLON,
    ACTIONS(2297), 1,
      sym_pn_prefix,
    STATE(736), 1,
      sym_namespace,
    STATE(495), 3,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
  [21480] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(57), 1,
      anon_sym_LT,
    ACTIONS(2261), 1,
      anon_sym_COLON,
    ACTIONS(2299), 1,
      sym_pn_prefix,
    STATE(288), 1,
      sym_namespace,
    STATE(403), 3,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
  [21501] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(57), 1,
      anon_sym_LT,
    ACTIONS(2261), 1,
      anon_sym_COLON,
    ACTIONS(2299), 1,
      sym_pn_prefix,
    STATE(288), 1,
      sym_namespace,
    STATE(458), 3,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
  [21522] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(808), 1,
      anon_sym_LT,
    ACTIONS(1381), 1,
      anon_sym_COLON,
    ACTIONS(2301), 1,
      sym_pn_prefix,
    STATE(604), 1,
      sym_namespace,
    STATE(495), 3,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
  [21543] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(57), 1,
      anon_sym_LT,
    ACTIONS(89), 1,
      anon_sym_COLON,
    ACTIONS(2277), 1,
      sym_pn_prefix,
    STATE(413), 1,
      sym_namespace,
    STATE(313), 3,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
  [21564] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(57), 1,
      anon_sym_LT,
    ACTIONS(2261), 1,
      anon_sym_COLON,
    ACTIONS(2299), 1,
      sym_pn_prefix,
    STATE(288), 1,
      sym_namespace,
    STATE(313), 3,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
  [21585] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(89), 1,
      anon_sym_COLON,
    ACTIONS(168), 1,
      anon_sym_LT,
    ACTIONS(2277), 1,
      sym_pn_prefix,
    STATE(387), 1,
      sym_namespace,
    STATE(315), 3,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
  [21606] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(848), 1,
      anon_sym_LBRACE,
    ACTIONS(1009), 1,
      aux_sym_construct_query_token2,
    ACTIONS(2295), 1,
      aux_sym_dataset_clause_token1,
    STATE(285), 1,
      sym_where_clause,
    STATE(377), 1,
      sym_group_graph_pattern,
    STATE(814), 2,
      sym_dataset_clause,
      aux_sym_select_query_repeat1,
  [21629] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(848), 1,
      anon_sym_LBRACE,
    ACTIONS(1009), 1,
      aux_sym_construct_query_token2,
    ACTIONS(2295), 1,
      aux_sym_dataset_clause_token1,
    STATE(281), 1,
      sym_where_clause,
    STATE(377), 1,
      sym_group_graph_pattern,
    STATE(765), 2,
      sym_dataset_clause,
      aux_sym_select_query_repeat1,
  [21652] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(57), 1,
      anon_sym_LT,
    ACTIONS(89), 1,
      anon_sym_COLON,
    ACTIONS(2277), 1,
      sym_pn_prefix,
    STATE(413), 1,
      sym_namespace,
    STATE(971), 3,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
  [21673] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(979), 1,
      anon_sym_LT,
    ACTIONS(983), 1,
      anon_sym_COLON,
    ACTIONS(2303), 1,
      sym_pn_prefix,
    STATE(384), 1,
      sym_namespace,
    STATE(526), 3,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
  [21694] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2307), 1,
      aux_sym_load_token2,
    ACTIONS(2309), 1,
      aux_sym_graph_or_default_token2,
    STATE(436), 1,
      sym_graph_ref,
    STATE(439), 1,
      sym_graph_ref_all,
    ACTIONS(2305), 3,
      aux_sym_named_graph_clause_token1,
      aux_sym_graph_or_default_token1,
      aux_sym_graph_ref_all_token1,
  [21715] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2309), 1,
      aux_sym_graph_or_default_token2,
    ACTIONS(2311), 1,
      aux_sym_load_token2,
    STATE(436), 1,
      sym_graph_ref,
    STATE(437), 1,
      sym_graph_ref_all,
    ACTIONS(2305), 3,
      aux_sym_named_graph_clause_token1,
      aux_sym_graph_or_default_token1,
      aux_sym_graph_ref_all_token1,
  [21736] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(89), 1,
      anon_sym_COLON,
    ACTIONS(808), 1,
      anon_sym_LT,
    ACTIONS(2277), 1,
      sym_pn_prefix,
    STATE(387), 1,
      sym_namespace,
    STATE(872), 3,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
  [21757] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(57), 1,
      anon_sym_LT,
    ACTIONS(89), 1,
      anon_sym_COLON,
    ACTIONS(2277), 1,
      sym_pn_prefix,
    STATE(413), 1,
      sym_namespace,
    STATE(403), 3,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
  [21778] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(57), 1,
      anon_sym_LT,
    ACTIONS(89), 1,
      anon_sym_COLON,
    ACTIONS(2277), 1,
      sym_pn_prefix,
    STATE(413), 1,
      sym_namespace,
    STATE(315), 3,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
  [21799] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(848), 1,
      anon_sym_LBRACE,
    ACTIONS(1009), 1,
      aux_sym_construct_query_token2,
    ACTIONS(2295), 1,
      aux_sym_dataset_clause_token1,
    STATE(286), 1,
      sym_where_clause,
    STATE(377), 1,
      sym_group_graph_pattern,
    STATE(814), 2,
      sym_dataset_clause,
      aux_sym_select_query_repeat1,
  [21822] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(57), 1,
      anon_sym_LT,
    ACTIONS(2261), 1,
      anon_sym_COLON,
    ACTIONS(2299), 1,
      sym_pn_prefix,
    STATE(288), 1,
      sym_namespace,
    STATE(402), 3,
      sym__iri,
      sym_prefixed_name,
      sym_iri_reference,
  [21843] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(848), 1,
      anon_sym_LBRACE,
    ACTIONS(1009), 1,
      aux_sym_construct_query_token2,
    ACTIONS(2295), 1,
      aux_sym_dataset_clause_token1,
    STATE(276), 1,
      sym_where_clause,
    STATE(377), 1,
      sym_group_graph_pattern,
    STATE(814), 2,
      sym_dataset_clause,
      aux_sym_select_query_repeat1,
  [21866] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(848), 1,
      anon_sym_LBRACE,
    ACTIONS(1009), 1,
      aux_sym_construct_query_token2,
    ACTIONS(2295), 1,
      aux_sym_dataset_clause_token1,
    STATE(277), 1,
      sym_where_clause,
    STATE(377), 1,
      sym_group_graph_pattern,
    STATE(774), 2,
      sym_dataset_clause,
      aux_sym_select_query_repeat1,
  [21889] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2313), 1,
      anon_sym_LPAREN,
    ACTIONS(2315), 1,
      sym_var,
    ACTIONS(2317), 1,
      sym_nil,
    STATE(320), 1,
      sym__inline_data_one_var,
    STATE(328), 1,
      sym_data_block,
    STATE(365), 1,
      sym__inline_data_full,
  [21911] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2319), 1,
      anon_sym_LPAREN,
    ACTIONS(2323), 1,
      sym_var,
    STATE(801), 1,
      aux_sym_select_clause_repeat1,
    ACTIONS(2321), 3,
      aux_sym_construct_query_token2,
      anon_sym_LBRACE,
      aux_sym_dataset_clause_token1,
  [21929] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2295), 1,
      aux_sym_dataset_clause_token1,
    ACTIONS(2325), 1,
      aux_sym_construct_query_token2,
    ACTIONS(2327), 1,
      anon_sym_LBRACE,
    STATE(766), 1,
      sym_construct_template,
    STATE(839), 2,
      sym_dataset_clause,
      aux_sym_select_query_repeat1,
  [21949] = 6,
    ACTIONS(2329), 1,
      sym_comment,
    ACTIONS(2333), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(2335), 1,
      aux_sym__string_literal_long1_token1,
    ACTIONS(2337), 1,
      sym_echar,
    STATE(785), 1,
      aux_sym__string_literal_long1_repeat1,
    ACTIONS(2331), 2,
      anon_sym_SQUOTE,
      anon_sym_SQUOTE_SQUOTE,
  [21969] = 6,
    ACTIONS(2329), 1,
      sym_comment,
    ACTIONS(2341), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(2343), 1,
      aux_sym__string_literal_long2_token1,
    ACTIONS(2345), 1,
      sym_echar,
    STATE(789), 1,
      aux_sym__string_literal_long2_repeat1,
    ACTIONS(2339), 2,
      anon_sym_DQUOTE,
      anon_sym_DQUOTE_DQUOTE,
  [21989] = 6,
    ACTIONS(2329), 1,
      sym_comment,
    ACTIONS(2347), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(2349), 1,
      aux_sym__string_literal_long1_token1,
    ACTIONS(2351), 1,
      sym_echar,
    STATE(795), 1,
      aux_sym__string_literal_long1_repeat1,
    ACTIONS(2331), 2,
      anon_sym_SQUOTE,
      anon_sym_SQUOTE_SQUOTE,
  [22009] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2309), 1,
      aux_sym_graph_or_default_token2,
    STATE(436), 1,
      sym_graph_ref,
    STATE(459), 1,
      sym_graph_ref_all,
    ACTIONS(2305), 3,
      aux_sym_named_graph_clause_token1,
      aux_sym_graph_or_default_token1,
      aux_sym_graph_ref_all_token1,
  [22027] = 6,
    ACTIONS(2329), 1,
      sym_comment,
    ACTIONS(2356), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(2358), 1,
      aux_sym__string_literal_long1_token1,
    ACTIONS(2361), 1,
      sym_echar,
    STATE(785), 1,
      aux_sym__string_literal_long1_repeat1,
    ACTIONS(2353), 2,
      anon_sym_SQUOTE,
      anon_sym_SQUOTE_SQUOTE,
  [22047] = 6,
    ACTIONS(2329), 1,
      sym_comment,
    ACTIONS(2364), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(2366), 1,
      aux_sym__string_literal_long1_token1,
    ACTIONS(2368), 1,
      sym_echar,
    STATE(790), 1,
      aux_sym__string_literal_long1_repeat1,
    ACTIONS(2331), 2,
      anon_sym_SQUOTE,
      anon_sym_SQUOTE_SQUOTE,
  [22067] = 6,
    ACTIONS(2329), 1,
      sym_comment,
    ACTIONS(2370), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(2372), 1,
      aux_sym__string_literal_long2_token1,
    ACTIONS(2374), 1,
      sym_echar,
    STATE(791), 1,
      aux_sym__string_literal_long2_repeat1,
    ACTIONS(2339), 2,
      anon_sym_DQUOTE,
      anon_sym_DQUOTE_DQUOTE,
  [22087] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2376), 1,
      aux_sym_construct_query_token2,
    ACTIONS(2378), 1,
      aux_sym_insert_clause_token1,
    ACTIONS(2380), 1,
      aux_sym_using_clause_token1,
    STATE(817), 1,
      sym_insert_clause,
    STATE(855), 2,
      sym_using_clause,
      aux_sym_modify_repeat1,
  [22107] = 6,
    ACTIONS(2329), 1,
      sym_comment,
    ACTIONS(2385), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(2387), 1,
      aux_sym__string_literal_long2_token1,
    ACTIONS(2390), 1,
      sym_echar,
    STATE(789), 1,
      aux_sym__string_literal_long2_repeat1,
    ACTIONS(2382), 2,
      anon_sym_DQUOTE,
      anon_sym_DQUOTE_DQUOTE,
  [22127] = 6,
    ACTIONS(2329), 1,
      sym_comment,
    ACTIONS(2335), 1,
      aux_sym__string_literal_long1_token1,
    ACTIONS(2337), 1,
      sym_echar,
    ACTIONS(2393), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    STATE(785), 1,
      aux_sym__string_literal_long1_repeat1,
    ACTIONS(2331), 2,
      anon_sym_SQUOTE,
      anon_sym_SQUOTE_SQUOTE,
  [22147] = 6,
    ACTIONS(2329), 1,
      sym_comment,
    ACTIONS(2343), 1,
      aux_sym__string_literal_long2_token1,
    ACTIONS(2345), 1,
      sym_echar,
    ACTIONS(2395), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(789), 1,
      aux_sym__string_literal_long2_repeat1,
    ACTIONS(2339), 2,
      anon_sym_DQUOTE,
      anon_sym_DQUOTE_DQUOTE,
  [22167] = 6,
    ACTIONS(2329), 1,
      sym_comment,
    ACTIONS(2397), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(2399), 1,
      aux_sym__string_literal_long2_token1,
    ACTIONS(2401), 1,
      sym_echar,
    STATE(796), 1,
      aux_sym__string_literal_long2_repeat1,
    ACTIONS(2339), 2,
      anon_sym_DQUOTE,
      anon_sym_DQUOTE_DQUOTE,
  [22187] = 6,
    ACTIONS(2329), 1,
      sym_comment,
    ACTIONS(2403), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    ACTIONS(2405), 1,
      aux_sym__string_literal_long1_token1,
    ACTIONS(2407), 1,
      sym_echar,
    STATE(781), 1,
      aux_sym__string_literal_long1_repeat1,
    ACTIONS(2331), 2,
      anon_sym_SQUOTE,
      anon_sym_SQUOTE_SQUOTE,
  [22207] = 6,
    ACTIONS(2329), 1,
      sym_comment,
    ACTIONS(2409), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    ACTIONS(2411), 1,
      aux_sym__string_literal_long2_token1,
    ACTIONS(2413), 1,
      sym_echar,
    STATE(782), 1,
      aux_sym__string_literal_long2_repeat1,
    ACTIONS(2339), 2,
      anon_sym_DQUOTE,
      anon_sym_DQUOTE_DQUOTE,
  [22227] = 6,
    ACTIONS(2329), 1,
      sym_comment,
    ACTIONS(2335), 1,
      aux_sym__string_literal_long1_token1,
    ACTIONS(2337), 1,
      sym_echar,
    ACTIONS(2415), 1,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
    STATE(785), 1,
      aux_sym__string_literal_long1_repeat1,
    ACTIONS(2331), 2,
      anon_sym_SQUOTE,
      anon_sym_SQUOTE_SQUOTE,
  [22247] = 6,
    ACTIONS(2329), 1,
      sym_comment,
    ACTIONS(2343), 1,
      aux_sym__string_literal_long2_token1,
    ACTIONS(2345), 1,
      sym_echar,
    ACTIONS(2417), 1,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
    STATE(789), 1,
      aux_sym__string_literal_long2_repeat1,
    ACTIONS(2339), 2,
      anon_sym_DQUOTE,
      anon_sym_DQUOTE_DQUOTE,
  [22267] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2319), 1,
      anon_sym_LPAREN,
    ACTIONS(2323), 1,
      sym_var,
    ACTIONS(2421), 1,
      anon_sym_STAR,
    STATE(803), 1,
      aux_sym_select_clause_repeat1,
    ACTIONS(2419), 2,
      aux_sym_select_clause_token2,
      aux_sym_select_clause_token3,
  [22287] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2423), 1,
      anon_sym_LPAREN,
    ACTIONS(2425), 1,
      sym_var,
    ACTIONS(2427), 1,
      sym_nil,
    STATE(479), 1,
      sym_data_block,
    STATE(480), 1,
      sym__inline_data_one_var,
    STATE(481), 1,
      sym__inline_data_full,
  [22309] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2429), 2,
      anon_sym_a,
      sym_pn_prefix,
    ACTIONS(2431), 4,
      anon_sym_LPAREN,
      anon_sym_BANG,
      anon_sym_LT,
      anon_sym_COLON,
  [22323] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2378), 1,
      aux_sym_insert_clause_token1,
    ACTIONS(2380), 1,
      aux_sym_using_clause_token1,
    ACTIONS(2433), 1,
      aux_sym_construct_query_token2,
    STATE(841), 1,
      sym_insert_clause,
    STATE(842), 2,
      sym_using_clause,
      aux_sym_modify_repeat1,
  [22343] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2435), 1,
      anon_sym_LPAREN,
    ACTIONS(2440), 1,
      sym_var,
    STATE(801), 1,
      aux_sym_select_clause_repeat1,
    ACTIONS(2438), 3,
      aux_sym_construct_query_token2,
      anon_sym_LBRACE,
      aux_sym_dataset_clause_token1,
  [22361] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2309), 1,
      aux_sym_graph_or_default_token2,
    STATE(436), 1,
      sym_graph_ref,
    STATE(457), 1,
      sym_graph_ref_all,
    ACTIONS(2305), 3,
      aux_sym_named_graph_clause_token1,
      aux_sym_graph_or_default_token1,
      aux_sym_graph_ref_all_token1,
  [22379] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2319), 1,
      anon_sym_LPAREN,
    ACTIONS(2323), 1,
      sym_var,
    STATE(801), 1,
      aux_sym_select_clause_repeat1,
    ACTIONS(2443), 3,
      aux_sym_construct_query_token2,
      anon_sym_LBRACE,
      aux_sym_dataset_clause_token1,
  [22397] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2445), 5,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      anon_sym_RBRACK,
  [22408] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2447), 1,
      anon_sym_SEMI,
    STATE(805), 1,
      aux_sym_property_list_repeat1,
    ACTIONS(2445), 3,
      anon_sym_RBRACE,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
  [22423] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1157), 5,
      anon_sym_RPAREN,
      anon_sym_SLASH,
      anon_sym_PIPE,
      sym_path_mod,
      sym_pn_local,
  [22434] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2450), 1,
      anon_sym_SEMI,
    STATE(805), 1,
      aux_sym_property_list_repeat1,
    ACTIONS(2452), 3,
      anon_sym_RBRACE,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
  [22449] = 3,
    ACTIONS(2329), 1,
      sym_comment,
    ACTIONS(2454), 1,
      aux_sym__string_literal_long2_token1,
    ACTIONS(2385), 4,
      anon_sym_DQUOTE,
      anon_sym_DQUOTE_DQUOTE_DQUOTE,
      anon_sym_DQUOTE_DQUOTE,
      sym_echar,
  [22462] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2456), 1,
      sym_pn_local,
    ACTIONS(1189), 4,
      anon_sym_RPAREN,
      anon_sym_SLASH,
      anon_sym_PIPE,
      sym_path_mod,
  [22475] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1177), 5,
      anon_sym_RPAREN,
      anon_sym_SLASH,
      anon_sym_PIPE,
      sym_path_mod,
      sym_pn_local,
  [22486] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2450), 1,
      anon_sym_SEMI,
    STATE(807), 1,
      aux_sym_property_list_repeat1,
    ACTIONS(2458), 3,
      anon_sym_RBRACE,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
  [22501] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2460), 5,
      anon_sym_LPAREN,
      aux_sym_construct_query_token2,
      anon_sym_LBRACE,
      aux_sym_dataset_clause_token1,
      sym_var,
  [22512] = 3,
    ACTIONS(2329), 1,
      sym_comment,
    ACTIONS(2462), 1,
      aux_sym__string_literal_long1_token1,
    ACTIONS(2356), 4,
      anon_sym_SQUOTE,
      anon_sym_SQUOTE_SQUOTE_SQUOTE,
      anon_sym_SQUOTE_SQUOTE,
      sym_echar,
  [22525] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2464), 1,
      aux_sym_dataset_clause_token1,
    ACTIONS(1247), 2,
      aux_sym_construct_query_token2,
      anon_sym_LBRACE,
    STATE(814), 2,
      sym_dataset_clause,
      aux_sym_select_query_repeat1,
  [22540] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2467), 5,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
      anon_sym_RBRACK,
  [22551] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2469), 5,
      anon_sym_LPAREN,
      aux_sym_construct_query_token2,
      anon_sym_LBRACE,
      aux_sym_dataset_clause_token1,
      sym_var,
  [22562] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2380), 1,
      aux_sym_using_clause_token1,
    ACTIONS(2471), 1,
      aux_sym_construct_query_token2,
    STATE(829), 2,
      sym_using_clause,
      aux_sym_modify_repeat1,
  [22576] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2473), 1,
      anon_sym_LPAREN,
    ACTIONS(2475), 1,
      anon_sym_RBRACE,
    ACTIONS(2477), 1,
      sym_nil,
    STATE(854), 1,
      aux_sym__inline_data_full_repeat2,
  [22592] = 5,
    ACTIONS(2329), 1,
      sym_comment,
    ACTIONS(2479), 1,
      anon_sym_SQUOTE,
    ACTIONS(2481), 1,
      aux_sym__string_literal1_token1,
    ACTIONS(2484), 1,
      sym_echar,
    STATE(819), 1,
      aux_sym__string_literal1_repeat1,
  [22608] = 5,
    ACTIONS(2329), 1,
      sym_comment,
    ACTIONS(2487), 1,
      anon_sym_DQUOTE,
    ACTIONS(2489), 1,
      aux_sym__string_literal2_token1,
    ACTIONS(2492), 1,
      sym_echar,
    STATE(820), 1,
      aux_sym__string_literal2_repeat1,
  [22624] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2495), 1,
      anon_sym_COMMA,
    STATE(821), 1,
      aux_sym_object_list_path_repeat1,
    ACTIONS(2186), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
  [22638] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2498), 1,
      anon_sym_RBRACE,
    ACTIONS(2500), 1,
      aux_sym_graph_or_default_token2,
    STATE(234), 1,
      sym_quads_not_triples,
    STATE(840), 1,
      aux_sym_quads_repeat1,
  [22654] = 5,
    ACTIONS(2329), 1,
      sym_comment,
    ACTIONS(2502), 1,
      anon_sym_SQUOTE,
    ACTIONS(2504), 1,
      aux_sym__string_literal1_token1,
    ACTIONS(2506), 1,
      sym_echar,
    STATE(827), 1,
      aux_sym__string_literal1_repeat1,
  [22670] = 5,
    ACTIONS(2329), 1,
      sym_comment,
    ACTIONS(2508), 1,
      anon_sym_DQUOTE,
    ACTIONS(2510), 1,
      aux_sym__string_literal2_token1,
    ACTIONS(2512), 1,
      sym_echar,
    STATE(828), 1,
      aux_sym__string_literal2_repeat1,
  [22686] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2514), 1,
      anon_sym_DOT,
    STATE(838), 1,
      aux_sym_triples_template_repeat1,
    ACTIONS(1023), 2,
      anon_sym_RBRACE,
      aux_sym_graph_or_default_token2,
  [22700] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2473), 1,
      anon_sym_LPAREN,
    ACTIONS(2477), 1,
      sym_nil,
    ACTIONS(2516), 1,
      anon_sym_RBRACE,
    STATE(854), 1,
      aux_sym__inline_data_full_repeat2,
  [22716] = 5,
    ACTIONS(2329), 1,
      sym_comment,
    ACTIONS(2518), 1,
      anon_sym_SQUOTE,
    ACTIONS(2520), 1,
      aux_sym__string_literal1_token1,
    ACTIONS(2522), 1,
      sym_echar,
    STATE(819), 1,
      aux_sym__string_literal1_repeat1,
  [22732] = 5,
    ACTIONS(2329), 1,
      sym_comment,
    ACTIONS(2524), 1,
      anon_sym_DQUOTE,
    ACTIONS(2526), 1,
      aux_sym__string_literal2_token1,
    ACTIONS(2528), 1,
      sym_echar,
    STATE(820), 1,
      aux_sym__string_literal2_repeat1,
  [22748] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2380), 1,
      aux_sym_using_clause_token1,
    ACTIONS(2433), 1,
      aux_sym_construct_query_token2,
    STATE(830), 2,
      sym_using_clause,
      aux_sym_modify_repeat1,
  [22762] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2530), 1,
      aux_sym_construct_query_token2,
    ACTIONS(2532), 1,
      aux_sym_using_clause_token1,
    STATE(830), 2,
      sym_using_clause,
      aux_sym_modify_repeat1,
  [22776] = 5,
    ACTIONS(2329), 1,
      sym_comment,
    ACTIONS(2535), 1,
      anon_sym_SQUOTE,
    ACTIONS(2537), 1,
      aux_sym__string_literal1_token1,
    ACTIONS(2539), 1,
      sym_echar,
    STATE(880), 1,
      aux_sym__string_literal1_repeat1,
  [22792] = 5,
    ACTIONS(2329), 1,
      sym_comment,
    ACTIONS(2541), 1,
      anon_sym_DQUOTE,
    ACTIONS(2543), 1,
      aux_sym__string_literal2_token1,
    ACTIONS(2545), 1,
      sym_echar,
    STATE(846), 1,
      aux_sym__string_literal2_repeat1,
  [22808] = 5,
    ACTIONS(2329), 1,
      sym_comment,
    ACTIONS(2547), 1,
      anon_sym_SQUOTE,
    ACTIONS(2549), 1,
      aux_sym__string_literal1_token1,
    ACTIONS(2551), 1,
      sym_echar,
    STATE(850), 1,
      aux_sym__string_literal1_repeat1,
  [22824] = 5,
    ACTIONS(2329), 1,
      sym_comment,
    ACTIONS(2553), 1,
      anon_sym_DQUOTE,
    ACTIONS(2555), 1,
      aux_sym__string_literal2_token1,
    ACTIONS(2557), 1,
      sym_echar,
    STATE(852), 1,
      aux_sym__string_literal2_repeat1,
  [22840] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2559), 1,
      anon_sym_COMMA,
    STATE(875), 1,
      aux_sym_object_list_repeat1,
    ACTIONS(2177), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
  [22854] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2473), 1,
      anon_sym_LPAREN,
    ACTIONS(2561), 1,
      anon_sym_RBRACE,
    ACTIONS(2563), 1,
      sym_nil,
    STATE(826), 1,
      aux_sym__inline_data_full_repeat2,
  [22870] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2565), 1,
      sym_path_mod,
    ACTIONS(1725), 3,
      anon_sym_RPAREN,
      anon_sym_SLASH,
      anon_sym_PIPE,
  [22882] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2569), 1,
      anon_sym_DOT,
    STATE(838), 1,
      aux_sym_triples_template_repeat1,
    ACTIONS(2567), 2,
      anon_sym_RBRACE,
      aux_sym_graph_or_default_token2,
  [22896] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2295), 1,
      aux_sym_dataset_clause_token1,
    ACTIONS(2572), 1,
      aux_sym_construct_query_token2,
    STATE(814), 2,
      sym_dataset_clause,
      aux_sym_select_query_repeat1,
  [22910] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(965), 1,
      anon_sym_RBRACE,
    ACTIONS(2574), 1,
      aux_sym_graph_or_default_token2,
    STATE(234), 1,
      sym_quads_not_triples,
    STATE(840), 1,
      aux_sym_quads_repeat1,
  [22926] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2380), 1,
      aux_sym_using_clause_token1,
    ACTIONS(2577), 1,
      aux_sym_construct_query_token2,
    STATE(869), 2,
      sym_using_clause,
      aux_sym_modify_repeat1,
  [22940] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2380), 1,
      aux_sym_using_clause_token1,
    ACTIONS(2577), 1,
      aux_sym_construct_query_token2,
    STATE(830), 2,
      sym_using_clause,
      aux_sym_modify_repeat1,
  [22954] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2500), 1,
      aux_sym_graph_or_default_token2,
    ACTIONS(2579), 1,
      anon_sym_RBRACE,
    STATE(234), 1,
      sym_quads_not_triples,
    STATE(866), 1,
      aux_sym_quads_repeat1,
  [22970] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2500), 1,
      aux_sym_graph_or_default_token2,
    ACTIONS(2579), 1,
      anon_sym_RBRACE,
    STATE(234), 1,
      sym_quads_not_triples,
    STATE(840), 1,
      aux_sym_quads_repeat1,
  [22986] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(832), 4,
      anon_sym_RPAREN,
      anon_sym_SLASH,
      anon_sym_PIPE,
      sym_path_mod,
  [22996] = 5,
    ACTIONS(2329), 1,
      sym_comment,
    ACTIONS(2526), 1,
      aux_sym__string_literal2_token1,
    ACTIONS(2528), 1,
      sym_echar,
    ACTIONS(2581), 1,
      anon_sym_DQUOTE,
    STATE(820), 1,
      aux_sym__string_literal2_repeat1,
  [23012] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1545), 4,
      anon_sym_RPAREN,
      anon_sym_SLASH,
      anon_sym_PIPE,
      sym_path_mod,
  [23022] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1681), 4,
      anon_sym_RPAREN,
      anon_sym_SLASH,
      anon_sym_PIPE,
      sym_path_mod,
  [23032] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1685), 4,
      anon_sym_RPAREN,
      anon_sym_SLASH,
      anon_sym_PIPE,
      sym_path_mod,
  [23042] = 5,
    ACTIONS(2329), 1,
      sym_comment,
    ACTIONS(2520), 1,
      aux_sym__string_literal1_token1,
    ACTIONS(2522), 1,
      sym_echar,
    ACTIONS(2583), 1,
      anon_sym_SQUOTE,
    STATE(819), 1,
      aux_sym__string_literal1_repeat1,
  [23058] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2585), 1,
      sym_path_mod,
    ACTIONS(1695), 3,
      anon_sym_RPAREN,
      anon_sym_SLASH,
      anon_sym_PIPE,
  [23070] = 5,
    ACTIONS(2329), 1,
      sym_comment,
    ACTIONS(2526), 1,
      aux_sym__string_literal2_token1,
    ACTIONS(2528), 1,
      sym_echar,
    ACTIONS(2587), 1,
      anon_sym_DQUOTE,
    STATE(820), 1,
      aux_sym__string_literal2_repeat1,
  [23086] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2589), 1,
      anon_sym_COMMA,
    STATE(853), 1,
      aux_sym_object_list_repeat1,
    ACTIONS(2175), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
  [23100] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2592), 1,
      anon_sym_LPAREN,
    ACTIONS(2595), 1,
      anon_sym_RBRACE,
    ACTIONS(2597), 1,
      sym_nil,
    STATE(854), 1,
      aux_sym__inline_data_full_repeat2,
  [23116] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2380), 1,
      aux_sym_using_clause_token1,
    ACTIONS(2471), 1,
      aux_sym_construct_query_token2,
    STATE(830), 2,
      sym_using_clause,
      aux_sym_modify_repeat1,
  [23130] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1757), 4,
      anon_sym_RPAREN,
      anon_sym_SLASH,
      anon_sym_PIPE,
      sym_path_mod,
  [23140] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1761), 4,
      anon_sym_RPAREN,
      anon_sym_SLASH,
      anon_sym_PIPE,
      sym_path_mod,
  [23150] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1563), 4,
      anon_sym_RPAREN,
      anon_sym_SLASH,
      anon_sym_PIPE,
      sym_path_mod,
  [23160] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2600), 1,
      anon_sym_COMMA,
    STATE(878), 1,
      aux_sym_object_list_path_repeat1,
    ACTIONS(2181), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
  [23174] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2500), 1,
      aux_sym_graph_or_default_token2,
    ACTIONS(2602), 1,
      anon_sym_RBRACE,
    STATE(234), 1,
      sym_quads_not_triples,
    STATE(822), 1,
      aux_sym_quads_repeat1,
  [23190] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2473), 1,
      anon_sym_LPAREN,
    ACTIONS(2604), 1,
      anon_sym_RBRACE,
    ACTIONS(2606), 1,
      sym_nil,
    STATE(871), 1,
      aux_sym__inline_data_full_repeat2,
  [23206] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1753), 4,
      anon_sym_RPAREN,
      anon_sym_SLASH,
      anon_sym_PIPE,
      sym_path_mod,
  [23216] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2376), 1,
      aux_sym_construct_query_token2,
    ACTIONS(2380), 1,
      aux_sym_using_clause_token1,
    STATE(855), 2,
      sym_using_clause,
      aux_sym_modify_repeat1,
  [23230] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2610), 1,
      anon_sym_DOT,
    STATE(825), 1,
      aux_sym_triples_template_repeat1,
    ACTIONS(2608), 2,
      anon_sym_RBRACE,
      aux_sym_graph_or_default_token2,
  [23244] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1583), 4,
      anon_sym_RPAREN,
      anon_sym_SLASH,
      anon_sym_PIPE,
      sym_path_mod,
  [23254] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2500), 1,
      aux_sym_graph_or_default_token2,
    ACTIONS(2612), 1,
      anon_sym_RBRACE,
    STATE(234), 1,
      sym_quads_not_triples,
    STATE(840), 1,
      aux_sym_quads_repeat1,
  [23270] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2473), 1,
      anon_sym_LPAREN,
    ACTIONS(2614), 1,
      anon_sym_RBRACE,
    ACTIONS(2616), 1,
      sym_nil,
    STATE(874), 1,
      aux_sym__inline_data_full_repeat2,
  [23286] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2500), 1,
      aux_sym_graph_or_default_token2,
    ACTIONS(2602), 1,
      anon_sym_RBRACE,
    STATE(234), 1,
      sym_quads_not_triples,
    STATE(840), 1,
      aux_sym_quads_repeat1,
  [23302] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2380), 1,
      aux_sym_using_clause_token1,
    ACTIONS(2618), 1,
      aux_sym_construct_query_token2,
    STATE(830), 2,
      sym_using_clause,
      aux_sym_modify_repeat1,
  [23316] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2380), 1,
      aux_sym_using_clause_token1,
    ACTIONS(2433), 1,
      aux_sym_construct_query_token2,
    STATE(842), 2,
      sym_using_clause,
      aux_sym_modify_repeat1,
  [23330] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2473), 1,
      anon_sym_LPAREN,
    ACTIONS(2477), 1,
      sym_nil,
    ACTIONS(2620), 1,
      anon_sym_RBRACE,
    STATE(854), 1,
      aux_sym__inline_data_full_repeat2,
  [23346] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2378), 1,
      aux_sym_insert_clause_token1,
    ACTIONS(2622), 1,
      aux_sym_delete_clause_token1,
    STATE(800), 1,
      sym_delete_clause,
    STATE(870), 1,
      sym_insert_clause,
  [23362] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2319), 1,
      anon_sym_LPAREN,
    ACTIONS(2323), 1,
      sym_var,
    ACTIONS(2624), 1,
      anon_sym_STAR,
    STATE(779), 1,
      aux_sym_select_clause_repeat1,
  [23378] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2473), 1,
      anon_sym_LPAREN,
    ACTIONS(2477), 1,
      sym_nil,
    ACTIONS(2626), 1,
      anon_sym_RBRACE,
    STATE(854), 1,
      aux_sym__inline_data_full_repeat2,
  [23394] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2559), 1,
      anon_sym_COMMA,
    STATE(853), 1,
      aux_sym_object_list_repeat1,
    ACTIONS(2191), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
  [23408] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(848), 1,
      anon_sym_LBRACE,
    ACTIONS(1009), 1,
      aux_sym_construct_query_token2,
    STATE(377), 1,
      sym_group_graph_pattern,
    STATE(628), 1,
      sym_where_clause,
  [23424] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2473), 1,
      anon_sym_LPAREN,
    ACTIONS(2628), 1,
      anon_sym_RBRACE,
    ACTIONS(2630), 1,
      sym_nil,
    STATE(818), 1,
      aux_sym__inline_data_full_repeat2,
  [23440] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2600), 1,
      anon_sym_COMMA,
    STATE(821), 1,
      aux_sym_object_list_path_repeat1,
    ACTIONS(2171), 2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
  [23454] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(836), 4,
      anon_sym_RPAREN,
      anon_sym_SLASH,
      anon_sym_PIPE,
      sym_path_mod,
  [23464] = 5,
    ACTIONS(2329), 1,
      sym_comment,
    ACTIONS(2520), 1,
      aux_sym__string_literal1_token1,
    ACTIONS(2522), 1,
      sym_echar,
    ACTIONS(2632), 1,
      anon_sym_SQUOTE,
    STATE(819), 1,
      aux_sym__string_literal1_repeat1,
  [23480] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2200), 1,
      anon_sym_RBRACK,
    ACTIONS(2634), 1,
      anon_sym_SEMI,
    STATE(933), 1,
      aux_sym_property_list_path_repeat1,
  [23493] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2636), 1,
      anon_sym_LPAREN,
    ACTIONS(2638), 1,
      sym_nil,
    STATE(179), 1,
      sym_arg_list,
  [23506] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1501), 3,
      aux_sym_construct_query_token2,
      aux_sym_insert_clause_token1,
      aux_sym_using_clause_token1,
  [23515] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2640), 1,
      anon_sym_LPAREN,
    ACTIONS(2642), 1,
      sym_nil,
    STATE(337), 1,
      sym_bracketted_expression,
  [23528] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2644), 3,
      aux_sym_construct_query_token2,
      anon_sym_LBRACE,
      aux_sym_dataset_clause_token1,
  [23537] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2646), 1,
      anon_sym_LPAREN,
    ACTIONS(2648), 1,
      sym_nil,
    STATE(127), 1,
      sym_expression_list,
  [23550] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1903), 1,
      anon_sym_COMMA,
    ACTIONS(2650), 1,
      anon_sym_RPAREN,
    STATE(898), 1,
      aux_sym_arg_list_repeat1,
  [23563] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2652), 1,
      anon_sym_LPAREN,
    ACTIONS(2654), 1,
      sym_nil,
    STATE(558), 1,
      sym_expression_list,
  [23576] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1903), 1,
      anon_sym_COMMA,
    ACTIONS(1927), 1,
      anon_sym_RPAREN,
    STATE(898), 1,
      aux_sym_arg_list_repeat1,
  [23589] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1497), 3,
      aux_sym_construct_query_token2,
      aux_sym_insert_clause_token1,
      aux_sym_using_clause_token1,
  [23598] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2656), 1,
      anon_sym_RPAREN,
    ACTIONS(2658), 1,
      anon_sym_SLASH,
    ACTIONS(2660), 1,
      anon_sym_PIPE,
  [23611] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2662), 1,
      anon_sym_RBRACE,
    ACTIONS(2664), 1,
      anon_sym_DOT,
    STATE(938), 1,
      aux_sym_triples_template_repeat1,
  [23624] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1903), 1,
      anon_sym_COMMA,
    ACTIONS(2666), 1,
      anon_sym_RPAREN,
    STATE(898), 1,
      aux_sym_arg_list_repeat1,
  [23637] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1903), 1,
      anon_sym_COMMA,
    ACTIONS(2668), 1,
      anon_sym_RPAREN,
    STATE(898), 1,
      aux_sym_arg_list_repeat1,
  [23650] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2670), 1,
      anon_sym_RPAREN,
    ACTIONS(2672), 1,
      sym_var,
    STATE(911), 1,
      aux_sym__inline_data_full_repeat1,
  [23663] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2674), 1,
      anon_sym_LPAREN,
    ACTIONS(2676), 1,
      sym_nil,
    STATE(341), 1,
      sym_expression_list,
  [23676] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2678), 1,
      anon_sym_LPAREN,
    ACTIONS(2680), 1,
      sym_nil,
    STATE(317), 1,
      sym_arg_list,
  [23689] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2011), 1,
      anon_sym_RPAREN,
    ACTIONS(2682), 1,
      anon_sym_COMMA,
    STATE(898), 1,
      aux_sym_arg_list_repeat1,
  [23702] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2658), 1,
      anon_sym_SLASH,
    ACTIONS(1571), 2,
      anon_sym_RPAREN,
      anon_sym_PIPE,
  [23713] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2652), 1,
      anon_sym_LPAREN,
    ACTIONS(2654), 1,
      sym_nil,
    STATE(539), 1,
      sym_expression_list,
  [23726] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2685), 1,
      anon_sym_LPAREN,
    ACTIONS(2687), 1,
      sym_nil,
    STATE(204), 1,
      sym_bracketted_expression,
  [23739] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2689), 1,
      anon_sym_LPAREN,
    ACTIONS(2691), 1,
      sym_nil,
    STATE(176), 1,
      sym_expression_list,
  [23752] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1515), 1,
      aux_sym_values_clause_token1,
    ACTIONS(2693), 1,
      anon_sym_RBRACE,
    STATE(1126), 1,
      sym_values_clause,
  [23765] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2452), 1,
      anon_sym_RBRACK,
    ACTIONS(2695), 1,
      anon_sym_SEMI,
    STATE(925), 1,
      aux_sym_property_list_repeat1,
  [23778] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2697), 1,
      anon_sym_RPAREN,
    ACTIONS(2699), 1,
      anon_sym_PIPE,
    STATE(905), 1,
      aux_sym_path_negated_property_set_repeat1,
  [23791] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2458), 1,
      anon_sym_RBRACK,
    ACTIONS(2695), 1,
      anon_sym_SEMI,
    STATE(904), 1,
      aux_sym_property_list_repeat1,
  [23804] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2702), 3,
      aux_sym_construct_query_token2,
      anon_sym_LBRACE,
      aux_sym_dataset_clause_token1,
  [23813] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2704), 1,
      anon_sym_RPAREN,
    ACTIONS(2706), 1,
      anon_sym_PIPE,
    STATE(905), 1,
      aux_sym_path_negated_property_set_repeat1,
  [23826] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2708), 3,
      anon_sym_RBRACE,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
  [23835] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2567), 3,
      anon_sym_RBRACE,
      aux_sym_graph_or_default_token2,
      anon_sym_DOT,
  [23844] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2710), 1,
      anon_sym_RPAREN,
    ACTIONS(2712), 1,
      sym_var,
    STATE(911), 1,
      aux_sym__inline_data_full_repeat1,
  [23857] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2706), 1,
      anon_sym_PIPE,
    ACTIONS(2715), 1,
      anon_sym_RPAREN,
    STATE(905), 1,
      aux_sym_path_negated_property_set_repeat1,
  [23870] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2717), 1,
      anon_sym_LPAREN,
    ACTIONS(2719), 1,
      sym_nil,
    STATE(130), 1,
      sym_arg_list,
  [23883] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2309), 1,
      aux_sym_graph_or_default_token2,
    ACTIONS(2721), 1,
      aux_sym_load_token2,
    STATE(441), 1,
      sym_graph_ref,
  [23896] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1903), 1,
      anon_sym_COMMA,
    ACTIONS(2723), 1,
      anon_sym_RPAREN,
    STATE(898), 1,
      aux_sym_arg_list_repeat1,
  [23909] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(864), 1,
      anon_sym_COLON,
    ACTIONS(2247), 1,
      sym_pn_prefix,
    STATE(948), 1,
      sym_namespace,
  [23922] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2672), 1,
      sym_var,
    ACTIONS(2725), 1,
      anon_sym_RPAREN,
    STATE(911), 1,
      aux_sym__inline_data_full_repeat1,
  [23935] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1487), 3,
      aux_sym_construct_query_token2,
      aux_sym_insert_clause_token1,
      aux_sym_using_clause_token1,
  [23944] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2727), 3,
      aux_sym_construct_query_token2,
      aux_sym_insert_clause_token1,
      aux_sym_using_clause_token1,
  [23953] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2658), 1,
      anon_sym_SLASH,
    ACTIONS(2660), 1,
      anon_sym_PIPE,
    ACTIONS(2729), 1,
      anon_sym_RPAREN,
  [23966] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2731), 1,
      anon_sym_LPAREN,
    ACTIONS(2733), 2,
      anon_sym_RBRACE,
      sym_nil,
  [23977] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2735), 1,
      anon_sym_LPAREN,
    ACTIONS(2737), 1,
      sym_nil,
    STATE(569), 1,
      sym_bracketted_expression,
  [23990] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1903), 1,
      anon_sym_COMMA,
    ACTIONS(1925), 1,
      anon_sym_RPAREN,
    STATE(898), 1,
      aux_sym_arg_list_repeat1,
  [24003] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1903), 1,
      anon_sym_COMMA,
    ACTIONS(2739), 1,
      anon_sym_RPAREN,
    STATE(898), 1,
      aux_sym_arg_list_repeat1,
  [24016] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2445), 1,
      anon_sym_RBRACK,
    ACTIONS(2741), 1,
      anon_sym_SEMI,
    STATE(925), 1,
      aux_sym_property_list_repeat1,
  [24029] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2744), 1,
      anon_sym_LPAREN,
    ACTIONS(2746), 1,
      sym_nil,
    STATE(123), 1,
      sym_bracketted_expression,
  [24042] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1903), 1,
      anon_sym_COMMA,
    ACTIONS(2748), 1,
      anon_sym_RPAREN,
    STATE(898), 1,
      aux_sym_arg_list_repeat1,
  [24055] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2750), 3,
      aux_sym_construct_query_token2,
      anon_sym_LBRACE,
      aux_sym_dataset_clause_token1,
  [24064] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1903), 1,
      anon_sym_COMMA,
    ACTIONS(1911), 1,
      anon_sym_RPAREN,
    STATE(898), 1,
      aux_sym_arg_list_repeat1,
  [24077] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2706), 1,
      anon_sym_PIPE,
    ACTIONS(2752), 1,
      anon_sym_RPAREN,
    STATE(912), 1,
      aux_sym_path_negated_property_set_repeat1,
  [24090] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2202), 1,
      anon_sym_RBRACK,
    ACTIONS(2634), 1,
      anon_sym_SEMI,
    STATE(881), 1,
      aux_sym_property_list_path_repeat1,
  [24103] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1903), 1,
      anon_sym_COMMA,
    ACTIONS(1931), 1,
      anon_sym_RPAREN,
    STATE(898), 1,
      aux_sym_arg_list_repeat1,
  [24116] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2196), 1,
      anon_sym_RBRACK,
    ACTIONS(2754), 1,
      anon_sym_SEMI,
    STATE(933), 1,
      aux_sym_property_list_path_repeat1,
  [24129] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2706), 1,
      anon_sym_PIPE,
    ACTIONS(2757), 1,
      anon_sym_RPAREN,
    STATE(908), 1,
      aux_sym_path_negated_property_set_repeat1,
  [24142] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2652), 1,
      anon_sym_LPAREN,
    ACTIONS(2654), 1,
      sym_nil,
    STATE(545), 1,
      sym_expression_list,
  [24155] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1903), 1,
      anon_sym_COMMA,
    ACTIONS(2759), 1,
      anon_sym_RPAREN,
    STATE(898), 1,
      aux_sym_arg_list_repeat1,
  [24168] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1903), 1,
      anon_sym_COMMA,
    ACTIONS(2761), 1,
      anon_sym_RPAREN,
    STATE(898), 1,
      aux_sym_arg_list_repeat1,
  [24181] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1129), 1,
      anon_sym_RBRACE,
    ACTIONS(2763), 1,
      anon_sym_DOT,
    STATE(838), 1,
      aux_sym_triples_template_repeat1,
  [24194] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2309), 1,
      aux_sym_graph_or_default_token2,
    STATE(471), 1,
      sym_graph_ref,
  [24204] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2765), 1,
      anon_sym_LBRACE,
    STATE(951), 1,
      sym_quads,
  [24214] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2765), 1,
      anon_sym_LBRACE,
    STATE(450), 1,
      sym_quads,
  [24224] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2309), 1,
      aux_sym_graph_or_default_token2,
    STATE(460), 1,
      sym_graph_ref,
  [24234] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2767), 1,
      anon_sym_LBRACE,
    STATE(919), 1,
      sym_quads,
  [24244] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(965), 2,
      anon_sym_RBRACE,
      aux_sym_graph_or_default_token2,
  [24252] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(447), 1,
      anon_sym_LPAREN,
    STATE(214), 1,
      sym_bracketted_expression,
  [24262] = 3,
    ACTIONS(2329), 1,
      sym_comment,
    ACTIONS(2769), 1,
      aux_sym__string_literal_long2_token1,
    ACTIONS(2771), 1,
      sym_echar,
  [24272] = 3,
    ACTIONS(2329), 1,
      sym_comment,
    ACTIONS(2773), 1,
      aux_sym__string_literal_long1_token1,
    ACTIONS(2775), 1,
      sym_echar,
  [24282] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(57), 1,
      anon_sym_LT,
    STATE(521), 1,
      sym_iri_reference,
  [24292] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(447), 1,
      anon_sym_LPAREN,
    STATE(206), 1,
      sym_bracketted_expression,
  [24302] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2697), 2,
      anon_sym_RPAREN,
      anon_sym_PIPE,
  [24310] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2777), 2,
      aux_sym_construct_query_token2,
      aux_sym_using_clause_token1,
  [24318] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2779), 1,
      anon_sym_LBRACE,
    STATE(132), 1,
      sym_group_graph_pattern,
  [24328] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2781), 2,
      anon_sym_RPAREN,
      sym_var,
  [24336] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2309), 1,
      aux_sym_graph_or_default_token2,
    STATE(443), 1,
      sym_graph_ref,
  [24346] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2783), 1,
      anon_sym_LBRACE,
    STATE(177), 1,
      sym_group_graph_pattern,
  [24356] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2765), 1,
      anon_sym_LBRACE,
    STATE(452), 1,
      sym_quads,
  [24366] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    STATE(329), 1,
      sym_group_graph_pattern,
  [24376] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(848), 1,
      anon_sym_LBRACE,
    STATE(372), 1,
      sym_group_graph_pattern,
  [24386] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(848), 1,
      anon_sym_LBRACE,
    STATE(421), 1,
      sym_group_graph_pattern,
  [24396] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    STATE(368), 1,
      sym_group_graph_pattern,
  [24406] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2672), 1,
      sym_var,
    STATE(917), 1,
      aux_sym__inline_data_full_repeat1,
  [24416] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(848), 1,
      anon_sym_LBRACE,
    STATE(448), 1,
      sym_group_graph_pattern,
  [24426] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    STATE(371), 1,
      sym_group_graph_pattern,
  [24436] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(160), 1,
      anon_sym_LPAREN,
    STATE(564), 1,
      sym_bracketted_expression,
  [24446] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    STATE(369), 1,
      sym_group_graph_pattern,
  [24456] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    STATE(331), 1,
      sym_group_graph_pattern,
  [24466] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2672), 1,
      sym_var,
    STATE(895), 1,
      aux_sym__inline_data_full_repeat1,
  [24476] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2783), 1,
      anon_sym_LBRACE,
    STATE(181), 1,
      sym_group_graph_pattern,
  [24486] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym_LPAREN,
    STATE(164), 1,
      sym_bracketted_expression,
  [24496] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2785), 2,
      anon_sym_RBRACE,
      aux_sym_graph_or_default_token2,
  [24504] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2787), 2,
      aux_sym_construct_query_token2,
      aux_sym_using_clause_token1,
  [24512] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    STATE(342), 1,
      sym_group_graph_pattern,
  [24522] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    STATE(316), 1,
      sym_group_graph_pattern,
  [24532] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2765), 1,
      anon_sym_LBRACE,
    STATE(449), 1,
      sym_quads,
  [24542] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(748), 1,
      anon_sym_LPAREN,
    STATE(339), 1,
      sym_bracketted_expression,
  [24552] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2779), 1,
      anon_sym_LBRACE,
    STATE(128), 1,
      sym_group_graph_pattern,
  [24562] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(848), 1,
      anon_sym_LBRACE,
    STATE(453), 1,
      sym_group_graph_pattern,
  [24572] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(51), 1,
      anon_sym_LPAREN,
    STATE(125), 1,
      sym_bracketted_expression,
  [24582] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(57), 1,
      anon_sym_LT,
    STATE(524), 1,
      sym_iri_reference,
  [24592] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2789), 2,
      aux_sym_construct_query_token2,
      aux_sym_using_clause_token1,
  [24600] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(848), 1,
      anon_sym_LBRACE,
    STATE(485), 1,
      sym_group_graph_pattern,
  [24610] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(848), 1,
      anon_sym_LBRACE,
    STATE(531), 1,
      sym_group_graph_pattern,
  [24620] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(848), 1,
      anon_sym_LBRACE,
    STATE(475), 1,
      sym_group_graph_pattern,
  [24630] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(848), 1,
      anon_sym_LBRACE,
    STATE(549), 1,
      sym_group_graph_pattern,
  [24640] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(786), 1,
      anon_sym_LBRACE,
    STATE(345), 1,
      sym_group_graph_pattern,
  [24650] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2791), 1,
      anon_sym_LPAREN,
  [24657] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1793), 1,
      anon_sym_RBRACE,
  [24664] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2793), 1,
      anon_sym_LPAREN,
  [24671] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2795), 1,
      anon_sym_LBRACE,
  [24678] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2797), 1,
      anon_sym_GT2,
  [24685] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2799), 1,
      anon_sym_RPAREN,
  [24692] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2801), 1,
      anon_sym_RPAREN,
  [24699] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2803), 1,
      anon_sym_RPAREN,
  [24706] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2805), 1,
      sym_var,
  [24713] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2807), 1,
      anon_sym_LPAREN,
  [24720] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2809), 1,
      anon_sym_COLON,
  [24727] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2811), 1,
      anon_sym_LPAREN,
  [24734] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2813), 1,
      anon_sym_GT2,
  [24741] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2815), 1,
      anon_sym_RPAREN,
  [24748] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2817), 1,
      aux_sym_binary_expression_token1,
  [24755] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2819), 1,
      sym_nil,
  [24762] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2821), 1,
      anon_sym_LPAREN,
  [24769] = 2,
    ACTIONS(2329), 1,
      sym_comment,
    ACTIONS(2823), 1,
      aux_sym_iri_reference_token1,
  [24776] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2825), 1,
      anon_sym_RPAREN,
  [24783] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2827), 1,
      aux_sym_exists_func_token1,
  [24790] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2829), 1,
      sym_var,
  [24797] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2831), 1,
      anon_sym_RPAREN,
  [24804] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2693), 1,
      anon_sym_RBRACE,
  [24811] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1817), 1,
      anon_sym_RBRACE,
  [24818] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2019), 1,
      anon_sym_RPAREN,
  [24825] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2833), 1,
      anon_sym_LBRACE,
  [24832] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2835), 1,
      anon_sym_COLON,
  [24839] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2837), 1,
      anon_sym_GT2,
  [24846] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2839), 1,
      anon_sym_GT2,
  [24853] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2841), 1,
      anon_sym_RBRACE,
  [24860] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2843), 1,
      aux_sym_group_clause_token2,
  [24867] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2845), 1,
      anon_sym_RBRACK,
  [24874] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2847), 1,
      aux_sym_aggregate_token7,
  [24881] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2849), 1,
      sym_nil,
  [24888] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2851), 1,
      aux_sym_group_clause_token2,
  [24895] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2853), 1,
      anon_sym_RPAREN,
  [24902] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2855), 1,
      sym_nil,
  [24909] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1971), 1,
      anon_sym_RPAREN,
  [24916] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2857), 1,
      anon_sym_RPAREN,
  [24923] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2859), 1,
      sym_integer,
  [24930] = 2,
    ACTIONS(2329), 1,
      sym_comment,
    ACTIONS(2861), 1,
      aux_sym_iri_reference_token1,
  [24937] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2863), 1,
      anon_sym_EQ,
  [24944] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2865), 1,
      aux_sym_exists_func_token1,
  [24951] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2867), 1,
      sym_var,
  [24958] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2869), 1,
      anon_sym_RBRACE,
  [24965] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2871), 1,
      anon_sym_LBRACE,
  [24972] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1975), 1,
      anon_sym_RPAREN,
  [24979] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2873), 1,
      anon_sym_LBRACE,
  [24986] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2875), 1,
      ts_builtin_sym_end,
  [24993] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2877), 1,
      sym_integer,
  [25000] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2879), 1,
      anon_sym_RBRACE,
  [25007] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2881), 1,
      aux_sym_add_token2,
  [25014] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2883), 1,
      aux_sym_add_token2,
  [25021] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2885), 1,
      aux_sym_add_token2,
  [25028] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2887), 1,
      aux_sym_add_token2,
  [25035] = 2,
    ACTIONS(2329), 1,
      sym_comment,
    ACTIONS(2889), 1,
      aux_sym_iri_reference_token1,
  [25042] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1809), 1,
      anon_sym_RBRACE,
  [25049] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2891), 1,
      aux_sym_add_token2,
  [25056] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2893), 1,
      anon_sym_RPAREN,
  [25063] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2895), 1,
      aux_sym_exists_func_token1,
  [25070] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2897), 1,
      anon_sym_RBRACK,
  [25077] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2027), 1,
      anon_sym_RPAREN,
  [25084] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2899), 1,
      sym_nil,
  [25091] = 2,
    ACTIONS(2329), 1,
      sym_comment,
    ACTIONS(2901), 1,
      aux_sym_iri_reference_token1,
  [25098] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2903), 1,
      anon_sym_LPAREN,
  [25105] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2905), 1,
      anon_sym_LPAREN,
  [25112] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2907), 1,
      anon_sym_LPAREN,
  [25119] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2909), 1,
      anon_sym_LPAREN,
  [25126] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2911), 1,
      anon_sym_COLON,
  [25133] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2913), 1,
      anon_sym_EQ,
  [25140] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2915), 1,
      sym_var,
  [25147] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2035), 1,
      anon_sym_RPAREN,
  [25154] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2917), 1,
      anon_sym_RPAREN,
  [25161] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2919), 1,
      anon_sym_RPAREN,
  [25168] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2921), 1,
      aux_sym_blank_node_label_token1,
  [25175] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2923), 1,
      anon_sym_EQ,
  [25182] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2925), 1,
      anon_sym_EQ,
  [25189] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2927), 1,
      anon_sym_LPAREN,
  [25196] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2929), 1,
      anon_sym_LPAREN,
  [25203] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2931), 1,
      anon_sym_LPAREN,
  [25210] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2933), 1,
      anon_sym_LBRACE,
  [25217] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2935), 1,
      aux_sym_aggregate_token7,
  [25224] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2937), 1,
      anon_sym_COLON,
  [25231] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2939), 1,
      anon_sym_GT2,
  [25238] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2941), 1,
      aux_sym_add_token2,
  [25245] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2943), 1,
      anon_sym_COLON,
  [25252] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2945), 1,
      anon_sym_EQ,
  [25259] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2947), 1,
      anon_sym_EQ,
  [25266] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2949), 1,
      anon_sym_LPAREN,
  [25273] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2951), 1,
      anon_sym_LPAREN,
  [25280] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2953), 1,
      anon_sym_LPAREN,
  [25287] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2955), 1,
      anon_sym_LPAREN,
  [25294] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2957), 1,
      anon_sym_COLON,
  [25301] = 2,
    ACTIONS(2329), 1,
      sym_comment,
    ACTIONS(2959), 1,
      aux_sym_iri_reference_token1,
  [25308] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2961), 1,
      anon_sym_LBRACE,
  [25315] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2963), 1,
      aux_sym_exists_func_token1,
  [25322] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2965), 1,
      aux_sym_blank_node_label_token1,
  [25329] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2967), 1,
      anon_sym_EQ,
  [25336] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2969), 1,
      anon_sym_EQ,
  [25343] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2971), 1,
      anon_sym_LBRACE,
  [25350] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2973), 1,
      anon_sym_RPAREN,
  [25357] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2975), 1,
      aux_sym_group_clause_token2,
  [25364] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2977), 1,
      aux_sym_group_clause_token2,
  [25371] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2979), 1,
      anon_sym_RPAREN,
  [25378] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2981), 1,
      anon_sym_LPAREN,
  [25385] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2983), 1,
      aux_sym_aggregate_token7,
  [25392] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2985), 1,
      aux_sym_aggregate_token7,
  [25399] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1943), 1,
      anon_sym_RPAREN,
  [25406] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2987), 1,
      anon_sym_LPAREN,
  [25413] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2989), 1,
      anon_sym_LBRACE,
  [25420] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2991), 1,
      anon_sym_LBRACE,
  [25427] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2993), 1,
      sym_var,
  [25434] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2995), 1,
      aux_sym_aggregate_token7,
  [25441] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2997), 1,
      aux_sym_aggregate_token7,
  [25448] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1777), 1,
      anon_sym_RBRACE,
  [25455] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2999), 1,
      anon_sym_RBRACK,
  [25462] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3001), 1,
      sym_var,
  [25469] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3003), 1,
      anon_sym_RPAREN,
  [25476] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3005), 1,
      anon_sym_RBRACE,
  [25483] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3007), 1,
      aux_sym_aggregate_token7,
  [25490] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3009), 1,
      aux_sym_aggregate_token7,
  [25497] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3011), 1,
      anon_sym_LPAREN,
  [25504] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3013), 1,
      anon_sym_RPAREN,
  [25511] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3015), 1,
      anon_sym_LPAREN,
  [25518] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3017), 1,
      anon_sym_COLON,
  [25525] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1991), 1,
      anon_sym_RPAREN,
  [25532] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3019), 1,
      anon_sym_LPAREN,
  [25539] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3021), 1,
      anon_sym_LPAREN,
  [25546] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3023), 1,
      anon_sym_LPAREN,
  [25553] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1947), 1,
      anon_sym_RPAREN,
  [25560] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3025), 1,
      anon_sym_LPAREN,
  [25567] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3027), 1,
      anon_sym_LPAREN,
  [25574] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      anon_sym_LPAREN,
  [25581] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3031), 1,
      anon_sym_LPAREN,
  [25588] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3033), 1,
      anon_sym_RBRACK,
  [25595] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3035), 1,
      anon_sym_LPAREN,
  [25602] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3037), 1,
      anon_sym_LPAREN,
  [25609] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3039), 1,
      anon_sym_LPAREN,
  [25616] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3041), 1,
      anon_sym_RPAREN,
  [25623] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3043), 1,
      sym_var,
  [25630] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3045), 1,
      anon_sym_RBRACE,
  [25637] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3047), 1,
      sym_var,
  [25644] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3049), 1,
      anon_sym_LPAREN,
  [25651] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3051), 1,
      anon_sym_LPAREN,
  [25658] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3053), 1,
      anon_sym_LPAREN,
  [25665] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3055), 1,
      anon_sym_LPAREN,
  [25672] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3057), 1,
      anon_sym_LPAREN,
  [25679] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3059), 1,
      anon_sym_LPAREN,
  [25686] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3061), 1,
      anon_sym_LPAREN,
};

static const uint32_t ts_small_parse_table_map[] = {
  [SMALL_STATE(216)] = 0,
  [SMALL_STATE(217)] = 136,
  [SMALL_STATE(218)] = 272,
  [SMALL_STATE(219)] = 408,
  [SMALL_STATE(220)] = 544,
  [SMALL_STATE(221)] = 603,
  [SMALL_STATE(222)] = 662,
  [SMALL_STATE(223)] = 768,
  [SMALL_STATE(224)] = 867,
  [SMALL_STATE(225)] = 963,
  [SMALL_STATE(226)] = 1056,
  [SMALL_STATE(227)] = 1149,
  [SMALL_STATE(228)] = 1202,
  [SMALL_STATE(229)] = 1255,
  [SMALL_STATE(230)] = 1308,
  [SMALL_STATE(231)] = 1412,
  [SMALL_STATE(232)] = 1516,
  [SMALL_STATE(233)] = 1611,
  [SMALL_STATE(234)] = 1706,
  [SMALL_STATE(235)] = 1798,
  [SMALL_STATE(236)] = 1887,
  [SMALL_STATE(237)] = 1967,
  [SMALL_STATE(238)] = 2047,
  [SMALL_STATE(239)] = 2127,
  [SMALL_STATE(240)] = 2211,
  [SMALL_STATE(241)] = 2297,
  [SMALL_STATE(242)] = 2381,
  [SMALL_STATE(243)] = 2461,
  [SMALL_STATE(244)] = 2547,
  [SMALL_STATE(245)] = 2633,
  [SMALL_STATE(246)] = 2713,
  [SMALL_STATE(247)] = 2793,
  [SMALL_STATE(248)] = 2872,
  [SMALL_STATE(249)] = 2949,
  [SMALL_STATE(250)] = 3032,
  [SMALL_STATE(251)] = 3109,
  [SMALL_STATE(252)] = 3192,
  [SMALL_STATE(253)] = 3275,
  [SMALL_STATE(254)] = 3334,
  [SMALL_STATE(255)] = 3411,
  [SMALL_STATE(256)] = 3458,
  [SMALL_STATE(257)] = 3537,
  [SMALL_STATE(258)] = 3616,
  [SMALL_STATE(259)] = 3695,
  [SMALL_STATE(260)] = 3774,
  [SMALL_STATE(261)] = 3853,
  [SMALL_STATE(262)] = 3930,
  [SMALL_STATE(263)] = 4013,
  [SMALL_STATE(264)] = 4096,
  [SMALL_STATE(265)] = 4143,
  [SMALL_STATE(266)] = 4223,
  [SMALL_STATE(267)] = 4299,
  [SMALL_STATE(268)] = 4375,
  [SMALL_STATE(269)] = 4451,
  [SMALL_STATE(270)] = 4531,
  [SMALL_STATE(271)] = 4607,
  [SMALL_STATE(272)] = 4690,
  [SMALL_STATE(273)] = 4732,
  [SMALL_STATE(274)] = 4774,
  [SMALL_STATE(275)] = 4818,
  [SMALL_STATE(276)] = 4897,
  [SMALL_STATE(277)] = 4962,
  [SMALL_STATE(278)] = 5027,
  [SMALL_STATE(279)] = 5092,
  [SMALL_STATE(280)] = 5157,
  [SMALL_STATE(281)] = 5236,
  [SMALL_STATE(282)] = 5301,
  [SMALL_STATE(283)] = 5366,
  [SMALL_STATE(284)] = 5431,
  [SMALL_STATE(285)] = 5496,
  [SMALL_STATE(286)] = 5561,
  [SMALL_STATE(287)] = 5626,
  [SMALL_STATE(288)] = 5666,
  [SMALL_STATE(289)] = 5708,
  [SMALL_STATE(290)] = 5748,
  [SMALL_STATE(291)] = 5787,
  [SMALL_STATE(292)] = 5826,
  [SMALL_STATE(293)] = 5865,
  [SMALL_STATE(294)] = 5904,
  [SMALL_STATE(295)] = 5947,
  [SMALL_STATE(296)] = 5986,
  [SMALL_STATE(297)] = 6025,
  [SMALL_STATE(298)] = 6064,
  [SMALL_STATE(299)] = 6103,
  [SMALL_STATE(300)] = 6142,
  [SMALL_STATE(301)] = 6198,
  [SMALL_STATE(302)] = 6240,
  [SMALL_STATE(303)] = 6306,
  [SMALL_STATE(304)] = 6348,
  [SMALL_STATE(305)] = 6416,
  [SMALL_STATE(306)] = 6458,
  [SMALL_STATE(307)] = 6495,
  [SMALL_STATE(308)] = 6558,
  [SMALL_STATE(309)] = 6595,
  [SMALL_STATE(310)] = 6632,
  [SMALL_STATE(311)] = 6669,
  [SMALL_STATE(312)] = 6706,
  [SMALL_STATE(313)] = 6743,
  [SMALL_STATE(314)] = 6780,
  [SMALL_STATE(315)] = 6817,
  [SMALL_STATE(316)] = 6854,
  [SMALL_STATE(317)] = 6891,
  [SMALL_STATE(318)] = 6927,
  [SMALL_STATE(319)] = 6963,
  [SMALL_STATE(320)] = 7025,
  [SMALL_STATE(321)] = 7061,
  [SMALL_STATE(322)] = 7097,
  [SMALL_STATE(323)] = 7133,
  [SMALL_STATE(324)] = 7183,
  [SMALL_STATE(325)] = 7219,
  [SMALL_STATE(326)] = 7255,
  [SMALL_STATE(327)] = 7305,
  [SMALL_STATE(328)] = 7341,
  [SMALL_STATE(329)] = 7377,
  [SMALL_STATE(330)] = 7413,
  [SMALL_STATE(331)] = 7449,
  [SMALL_STATE(332)] = 7485,
  [SMALL_STATE(333)] = 7521,
  [SMALL_STATE(334)] = 7557,
  [SMALL_STATE(335)] = 7593,
  [SMALL_STATE(336)] = 7629,
  [SMALL_STATE(337)] = 7665,
  [SMALL_STATE(338)] = 7701,
  [SMALL_STATE(339)] = 7737,
  [SMALL_STATE(340)] = 7773,
  [SMALL_STATE(341)] = 7809,
  [SMALL_STATE(342)] = 7845,
  [SMALL_STATE(343)] = 7881,
  [SMALL_STATE(344)] = 7917,
  [SMALL_STATE(345)] = 7953,
  [SMALL_STATE(346)] = 7989,
  [SMALL_STATE(347)] = 8025,
  [SMALL_STATE(348)] = 8061,
  [SMALL_STATE(349)] = 8097,
  [SMALL_STATE(350)] = 8133,
  [SMALL_STATE(351)] = 8169,
  [SMALL_STATE(352)] = 8205,
  [SMALL_STATE(353)] = 8241,
  [SMALL_STATE(354)] = 8277,
  [SMALL_STATE(355)] = 8313,
  [SMALL_STATE(356)] = 8349,
  [SMALL_STATE(357)] = 8385,
  [SMALL_STATE(358)] = 8421,
  [SMALL_STATE(359)] = 8457,
  [SMALL_STATE(360)] = 8493,
  [SMALL_STATE(361)] = 8529,
  [SMALL_STATE(362)] = 8565,
  [SMALL_STATE(363)] = 8601,
  [SMALL_STATE(364)] = 8637,
  [SMALL_STATE(365)] = 8699,
  [SMALL_STATE(366)] = 8735,
  [SMALL_STATE(367)] = 8797,
  [SMALL_STATE(368)] = 8859,
  [SMALL_STATE(369)] = 8895,
  [SMALL_STATE(370)] = 8931,
  [SMALL_STATE(371)] = 8993,
  [SMALL_STATE(372)] = 9029,
  [SMALL_STATE(373)] = 9064,
  [SMALL_STATE(374)] = 9109,
  [SMALL_STATE(375)] = 9154,
  [SMALL_STATE(376)] = 9213,
  [SMALL_STATE(377)] = 9258,
  [SMALL_STATE(378)] = 9293,
  [SMALL_STATE(379)] = 9355,
  [SMALL_STATE(380)] = 9391,
  [SMALL_STATE(381)] = 9427,
  [SMALL_STATE(382)] = 9458,
  [SMALL_STATE(383)] = 9489,
  [SMALL_STATE(384)] = 9520,
  [SMALL_STATE(385)] = 9553,
  [SMALL_STATE(386)] = 9584,
  [SMALL_STATE(387)] = 9615,
  [SMALL_STATE(388)] = 9648,
  [SMALL_STATE(389)] = 9679,
  [SMALL_STATE(390)] = 9710,
  [SMALL_STATE(391)] = 9740,
  [SMALL_STATE(392)] = 9772,
  [SMALL_STATE(393)] = 9802,
  [SMALL_STATE(394)] = 9832,
  [SMALL_STATE(395)] = 9862,
  [SMALL_STATE(396)] = 9892,
  [SMALL_STATE(397)] = 9922,
  [SMALL_STATE(398)] = 9952,
  [SMALL_STATE(399)] = 9982,
  [SMALL_STATE(400)] = 10012,
  [SMALL_STATE(401)] = 10042,
  [SMALL_STATE(402)] = 10076,
  [SMALL_STATE(403)] = 10108,
  [SMALL_STATE(404)] = 10138,
  [SMALL_STATE(405)] = 10174,
  [SMALL_STATE(406)] = 10204,
  [SMALL_STATE(407)] = 10234,
  [SMALL_STATE(408)] = 10270,
  [SMALL_STATE(409)] = 10300,
  [SMALL_STATE(410)] = 10330,
  [SMALL_STATE(411)] = 10360,
  [SMALL_STATE(412)] = 10390,
  [SMALL_STATE(413)] = 10420,
  [SMALL_STATE(414)] = 10452,
  [SMALL_STATE(415)] = 10486,
  [SMALL_STATE(416)] = 10516,
  [SMALL_STATE(417)] = 10546,
  [SMALL_STATE(418)] = 10576,
  [SMALL_STATE(419)] = 10606,
  [SMALL_STATE(420)] = 10635,
  [SMALL_STATE(421)] = 10664,
  [SMALL_STATE(422)] = 10693,
  [SMALL_STATE(423)] = 10722,
  [SMALL_STATE(424)] = 10751,
  [SMALL_STATE(425)] = 10780,
  [SMALL_STATE(426)] = 10809,
  [SMALL_STATE(427)] = 10838,
  [SMALL_STATE(428)] = 10867,
  [SMALL_STATE(429)] = 10896,
  [SMALL_STATE(430)] = 10925,
  [SMALL_STATE(431)] = 10954,
  [SMALL_STATE(432)] = 10983,
  [SMALL_STATE(433)] = 11012,
  [SMALL_STATE(434)] = 11041,
  [SMALL_STATE(435)] = 11070,
  [SMALL_STATE(436)] = 11099,
  [SMALL_STATE(437)] = 11128,
  [SMALL_STATE(438)] = 11157,
  [SMALL_STATE(439)] = 11186,
  [SMALL_STATE(440)] = 11215,
  [SMALL_STATE(441)] = 11244,
  [SMALL_STATE(442)] = 11273,
  [SMALL_STATE(443)] = 11302,
  [SMALL_STATE(444)] = 11331,
  [SMALL_STATE(445)] = 11360,
  [SMALL_STATE(446)] = 11389,
  [SMALL_STATE(447)] = 11418,
  [SMALL_STATE(448)] = 11447,
  [SMALL_STATE(449)] = 11476,
  [SMALL_STATE(450)] = 11505,
  [SMALL_STATE(451)] = 11534,
  [SMALL_STATE(452)] = 11563,
  [SMALL_STATE(453)] = 11592,
  [SMALL_STATE(454)] = 11621,
  [SMALL_STATE(455)] = 11650,
  [SMALL_STATE(456)] = 11679,
  [SMALL_STATE(457)] = 11710,
  [SMALL_STATE(458)] = 11739,
  [SMALL_STATE(459)] = 11768,
  [SMALL_STATE(460)] = 11797,
  [SMALL_STATE(461)] = 11826,
  [SMALL_STATE(462)] = 11855,
  [SMALL_STATE(463)] = 11884,
  [SMALL_STATE(464)] = 11913,
  [SMALL_STATE(465)] = 11942,
  [SMALL_STATE(466)] = 11971,
  [SMALL_STATE(467)] = 12000,
  [SMALL_STATE(468)] = 12055,
  [SMALL_STATE(469)] = 12086,
  [SMALL_STATE(470)] = 12115,
  [SMALL_STATE(471)] = 12144,
  [SMALL_STATE(472)] = 12173,
  [SMALL_STATE(473)] = 12202,
  [SMALL_STATE(474)] = 12231,
  [SMALL_STATE(475)] = 12260,
  [SMALL_STATE(476)] = 12289,
  [SMALL_STATE(477)] = 12318,
  [SMALL_STATE(478)] = 12349,
  [SMALL_STATE(479)] = 12378,
  [SMALL_STATE(480)] = 12407,
  [SMALL_STATE(481)] = 12436,
  [SMALL_STATE(482)] = 12465,
  [SMALL_STATE(483)] = 12494,
  [SMALL_STATE(484)] = 12523,
  [SMALL_STATE(485)] = 12558,
  [SMALL_STATE(486)] = 12587,
  [SMALL_STATE(487)] = 12618,
  [SMALL_STATE(488)] = 12647,
  [SMALL_STATE(489)] = 12676,
  [SMALL_STATE(490)] = 12705,
  [SMALL_STATE(491)] = 12734,
  [SMALL_STATE(492)] = 12767,
  [SMALL_STATE(493)] = 12796,
  [SMALL_STATE(494)] = 12850,
  [SMALL_STATE(495)] = 12904,
  [SMALL_STATE(496)] = 12932,
  [SMALL_STATE(497)] = 12980,
  [SMALL_STATE(498)] = 13028,
  [SMALL_STATE(499)] = 13076,
  [SMALL_STATE(500)] = 13124,
  [SMALL_STATE(501)] = 13152,
  [SMALL_STATE(502)] = 13180,
  [SMALL_STATE(503)] = 13212,
  [SMALL_STATE(504)] = 13240,
  [SMALL_STATE(505)] = 13268,
  [SMALL_STATE(506)] = 13316,
  [SMALL_STATE(507)] = 13348,
  [SMALL_STATE(508)] = 13396,
  [SMALL_STATE(509)] = 13444,
  [SMALL_STATE(510)] = 13492,
  [SMALL_STATE(511)] = 13540,
  [SMALL_STATE(512)] = 13588,
  [SMALL_STATE(513)] = 13636,
  [SMALL_STATE(514)] = 13664,
  [SMALL_STATE(515)] = 13718,
  [SMALL_STATE(516)] = 13746,
  [SMALL_STATE(517)] = 13774,
  [SMALL_STATE(518)] = 13802,
  [SMALL_STATE(519)] = 13850,
  [SMALL_STATE(520)] = 13880,
  [SMALL_STATE(521)] = 13928,
  [SMALL_STATE(522)] = 13955,
  [SMALL_STATE(523)] = 13982,
  [SMALL_STATE(524)] = 14009,
  [SMALL_STATE(525)] = 14036,
  [SMALL_STATE(526)] = 14063,
  [SMALL_STATE(527)] = 14090,
  [SMALL_STATE(528)] = 14117,
  [SMALL_STATE(529)] = 14144,
  [SMALL_STATE(530)] = 14171,
  [SMALL_STATE(531)] = 14198,
  [SMALL_STATE(532)] = 14224,
  [SMALL_STATE(533)] = 14250,
  [SMALL_STATE(534)] = 14288,
  [SMALL_STATE(535)] = 14324,
  [SMALL_STATE(536)] = 14354,
  [SMALL_STATE(537)] = 14380,
  [SMALL_STATE(538)] = 14406,
  [SMALL_STATE(539)] = 14432,
  [SMALL_STATE(540)] = 14458,
  [SMALL_STATE(541)] = 14486,
  [SMALL_STATE(542)] = 14512,
  [SMALL_STATE(543)] = 14538,
  [SMALL_STATE(544)] = 14564,
  [SMALL_STATE(545)] = 14590,
  [SMALL_STATE(546)] = 14616,
  [SMALL_STATE(547)] = 14642,
  [SMALL_STATE(548)] = 14668,
  [SMALL_STATE(549)] = 14694,
  [SMALL_STATE(550)] = 14720,
  [SMALL_STATE(551)] = 14746,
  [SMALL_STATE(552)] = 14772,
  [SMALL_STATE(553)] = 14798,
  [SMALL_STATE(554)] = 14824,
  [SMALL_STATE(555)] = 14850,
  [SMALL_STATE(556)] = 14876,
  [SMALL_STATE(557)] = 14902,
  [SMALL_STATE(558)] = 14928,
  [SMALL_STATE(559)] = 14954,
  [SMALL_STATE(560)] = 14980,
  [SMALL_STATE(561)] = 15006,
  [SMALL_STATE(562)] = 15032,
  [SMALL_STATE(563)] = 15058,
  [SMALL_STATE(564)] = 15084,
  [SMALL_STATE(565)] = 15110,
  [SMALL_STATE(566)] = 15136,
  [SMALL_STATE(567)] = 15162,
  [SMALL_STATE(568)] = 15188,
  [SMALL_STATE(569)] = 15214,
  [SMALL_STATE(570)] = 15240,
  [SMALL_STATE(571)] = 15266,
  [SMALL_STATE(572)] = 15292,
  [SMALL_STATE(573)] = 15318,
  [SMALL_STATE(574)] = 15344,
  [SMALL_STATE(575)] = 15387,
  [SMALL_STATE(576)] = 15430,
  [SMALL_STATE(577)] = 15473,
  [SMALL_STATE(578)] = 15516,
  [SMALL_STATE(579)] = 15559,
  [SMALL_STATE(580)] = 15588,
  [SMALL_STATE(581)] = 15631,
  [SMALL_STATE(582)] = 15674,
  [SMALL_STATE(583)] = 15717,
  [SMALL_STATE(584)] = 15760,
  [SMALL_STATE(585)] = 15803,
  [SMALL_STATE(586)] = 15846,
  [SMALL_STATE(587)] = 15889,
  [SMALL_STATE(588)] = 15929,
  [SMALL_STATE(589)] = 15969,
  [SMALL_STATE(590)] = 16009,
  [SMALL_STATE(591)] = 16049,
  [SMALL_STATE(592)] = 16089,
  [SMALL_STATE(593)] = 16129,
  [SMALL_STATE(594)] = 16169,
  [SMALL_STATE(595)] = 16209,
  [SMALL_STATE(596)] = 16249,
  [SMALL_STATE(597)] = 16289,
  [SMALL_STATE(598)] = 16329,
  [SMALL_STATE(599)] = 16369,
  [SMALL_STATE(600)] = 16409,
  [SMALL_STATE(601)] = 16449,
  [SMALL_STATE(602)] = 16491,
  [SMALL_STATE(603)] = 16515,
  [SMALL_STATE(604)] = 16555,
  [SMALL_STATE(605)] = 16581,
  [SMALL_STATE(606)] = 16619,
  [SMALL_STATE(607)] = 16661,
  [SMALL_STATE(608)] = 16703,
  [SMALL_STATE(609)] = 16743,
  [SMALL_STATE(610)] = 16785,
  [SMALL_STATE(611)] = 16827,
  [SMALL_STATE(612)] = 16869,
  [SMALL_STATE(613)] = 16909,
  [SMALL_STATE(614)] = 16951,
  [SMALL_STATE(615)] = 16991,
  [SMALL_STATE(616)] = 17031,
  [SMALL_STATE(617)] = 17071,
  [SMALL_STATE(618)] = 17111,
  [SMALL_STATE(619)] = 17151,
  [SMALL_STATE(620)] = 17191,
  [SMALL_STATE(621)] = 17215,
  [SMALL_STATE(622)] = 17252,
  [SMALL_STATE(623)] = 17289,
  [SMALL_STATE(624)] = 17314,
  [SMALL_STATE(625)] = 17351,
  [SMALL_STATE(626)] = 17388,
  [SMALL_STATE(627)] = 17425,
  [SMALL_STATE(628)] = 17462,
  [SMALL_STATE(629)] = 17511,
  [SMALL_STATE(630)] = 17548,
  [SMALL_STATE(631)] = 17585,
  [SMALL_STATE(632)] = 17622,
  [SMALL_STATE(633)] = 17659,
  [SMALL_STATE(634)] = 17696,
  [SMALL_STATE(635)] = 17733,
  [SMALL_STATE(636)] = 17770,
  [SMALL_STATE(637)] = 17807,
  [SMALL_STATE(638)] = 17844,
  [SMALL_STATE(639)] = 17881,
  [SMALL_STATE(640)] = 17918,
  [SMALL_STATE(641)] = 17955,
  [SMALL_STATE(642)] = 17992,
  [SMALL_STATE(643)] = 18029,
  [SMALL_STATE(644)] = 18066,
  [SMALL_STATE(645)] = 18103,
  [SMALL_STATE(646)] = 18140,
  [SMALL_STATE(647)] = 18177,
  [SMALL_STATE(648)] = 18214,
  [SMALL_STATE(649)] = 18251,
  [SMALL_STATE(650)] = 18288,
  [SMALL_STATE(651)] = 18325,
  [SMALL_STATE(652)] = 18362,
  [SMALL_STATE(653)] = 18399,
  [SMALL_STATE(654)] = 18436,
  [SMALL_STATE(655)] = 18473,
  [SMALL_STATE(656)] = 18510,
  [SMALL_STATE(657)] = 18547,
  [SMALL_STATE(658)] = 18584,
  [SMALL_STATE(659)] = 18621,
  [SMALL_STATE(660)] = 18658,
  [SMALL_STATE(661)] = 18695,
  [SMALL_STATE(662)] = 18732,
  [SMALL_STATE(663)] = 18769,
  [SMALL_STATE(664)] = 18806,
  [SMALL_STATE(665)] = 18843,
  [SMALL_STATE(666)] = 18880,
  [SMALL_STATE(667)] = 18917,
  [SMALL_STATE(668)] = 18954,
  [SMALL_STATE(669)] = 18991,
  [SMALL_STATE(670)] = 19028,
  [SMALL_STATE(671)] = 19065,
  [SMALL_STATE(672)] = 19102,
  [SMALL_STATE(673)] = 19139,
  [SMALL_STATE(674)] = 19176,
  [SMALL_STATE(675)] = 19213,
  [SMALL_STATE(676)] = 19250,
  [SMALL_STATE(677)] = 19287,
  [SMALL_STATE(678)] = 19324,
  [SMALL_STATE(679)] = 19361,
  [SMALL_STATE(680)] = 19398,
  [SMALL_STATE(681)] = 19435,
  [SMALL_STATE(682)] = 19472,
  [SMALL_STATE(683)] = 19509,
  [SMALL_STATE(684)] = 19546,
  [SMALL_STATE(685)] = 19583,
  [SMALL_STATE(686)] = 19619,
  [SMALL_STATE(687)] = 19642,
  [SMALL_STATE(688)] = 19661,
  [SMALL_STATE(689)] = 19684,
  [SMALL_STATE(690)] = 19719,
  [SMALL_STATE(691)] = 19742,
  [SMALL_STATE(692)] = 19765,
  [SMALL_STATE(693)] = 19788,
  [SMALL_STATE(694)] = 19823,
  [SMALL_STATE(695)] = 19858,
  [SMALL_STATE(696)] = 19881,
  [SMALL_STATE(697)] = 19900,
  [SMALL_STATE(698)] = 19922,
  [SMALL_STATE(699)] = 19940,
  [SMALL_STATE(700)] = 19962,
  [SMALL_STATE(701)] = 19984,
  [SMALL_STATE(702)] = 20020,
  [SMALL_STATE(703)] = 20056,
  [SMALL_STATE(704)] = 20074,
  [SMALL_STATE(705)] = 20092,
  [SMALL_STATE(706)] = 20125,
  [SMALL_STATE(707)] = 20160,
  [SMALL_STATE(708)] = 20191,
  [SMALL_STATE(709)] = 20212,
  [SMALL_STATE(710)] = 20233,
  [SMALL_STATE(711)] = 20264,
  [SMALL_STATE(712)] = 20297,
  [SMALL_STATE(713)] = 20330,
  [SMALL_STATE(714)] = 20351,
  [SMALL_STATE(715)] = 20380,
  [SMALL_STATE(716)] = 20413,
  [SMALL_STATE(717)] = 20446,
  [SMALL_STATE(718)] = 20476,
  [SMALL_STATE(719)] = 20506,
  [SMALL_STATE(720)] = 20536,
  [SMALL_STATE(721)] = 20566,
  [SMALL_STATE(722)] = 20594,
  [SMALL_STATE(723)] = 20610,
  [SMALL_STATE(724)] = 20626,
  [SMALL_STATE(725)] = 20656,
  [SMALL_STATE(726)] = 20686,
  [SMALL_STATE(727)] = 20716,
  [SMALL_STATE(728)] = 20744,
  [SMALL_STATE(729)] = 20774,
  [SMALL_STATE(730)] = 20796,
  [SMALL_STATE(731)] = 20812,
  [SMALL_STATE(732)] = 20842,
  [SMALL_STATE(733)] = 20870,
  [SMALL_STATE(734)] = 20900,
  [SMALL_STATE(735)] = 20925,
  [SMALL_STATE(736)] = 20942,
  [SMALL_STATE(737)] = 20961,
  [SMALL_STATE(738)] = 20986,
  [SMALL_STATE(739)] = 21011,
  [SMALL_STATE(740)] = 21036,
  [SMALL_STATE(741)] = 21065,
  [SMALL_STATE(742)] = 21094,
  [SMALL_STATE(743)] = 21119,
  [SMALL_STATE(744)] = 21134,
  [SMALL_STATE(745)] = 21159,
  [SMALL_STATE(746)] = 21184,
  [SMALL_STATE(747)] = 21209,
  [SMALL_STATE(748)] = 21234,
  [SMALL_STATE(749)] = 21259,
  [SMALL_STATE(750)] = 21284,
  [SMALL_STATE(751)] = 21301,
  [SMALL_STATE(752)] = 21316,
  [SMALL_STATE(753)] = 21340,
  [SMALL_STATE(754)] = 21364,
  [SMALL_STATE(755)] = 21388,
  [SMALL_STATE(756)] = 21412,
  [SMALL_STATE(757)] = 21436,
  [SMALL_STATE(758)] = 21459,
  [SMALL_STATE(759)] = 21480,
  [SMALL_STATE(760)] = 21501,
  [SMALL_STATE(761)] = 21522,
  [SMALL_STATE(762)] = 21543,
  [SMALL_STATE(763)] = 21564,
  [SMALL_STATE(764)] = 21585,
  [SMALL_STATE(765)] = 21606,
  [SMALL_STATE(766)] = 21629,
  [SMALL_STATE(767)] = 21652,
  [SMALL_STATE(768)] = 21673,
  [SMALL_STATE(769)] = 21694,
  [SMALL_STATE(770)] = 21715,
  [SMALL_STATE(771)] = 21736,
  [SMALL_STATE(772)] = 21757,
  [SMALL_STATE(773)] = 21778,
  [SMALL_STATE(774)] = 21799,
  [SMALL_STATE(775)] = 21822,
  [SMALL_STATE(776)] = 21843,
  [SMALL_STATE(777)] = 21866,
  [SMALL_STATE(778)] = 21889,
  [SMALL_STATE(779)] = 21911,
  [SMALL_STATE(780)] = 21929,
  [SMALL_STATE(781)] = 21949,
  [SMALL_STATE(782)] = 21969,
  [SMALL_STATE(783)] = 21989,
  [SMALL_STATE(784)] = 22009,
  [SMALL_STATE(785)] = 22027,
  [SMALL_STATE(786)] = 22047,
  [SMALL_STATE(787)] = 22067,
  [SMALL_STATE(788)] = 22087,
  [SMALL_STATE(789)] = 22107,
  [SMALL_STATE(790)] = 22127,
  [SMALL_STATE(791)] = 22147,
  [SMALL_STATE(792)] = 22167,
  [SMALL_STATE(793)] = 22187,
  [SMALL_STATE(794)] = 22207,
  [SMALL_STATE(795)] = 22227,
  [SMALL_STATE(796)] = 22247,
  [SMALL_STATE(797)] = 22267,
  [SMALL_STATE(798)] = 22287,
  [SMALL_STATE(799)] = 22309,
  [SMALL_STATE(800)] = 22323,
  [SMALL_STATE(801)] = 22343,
  [SMALL_STATE(802)] = 22361,
  [SMALL_STATE(803)] = 22379,
  [SMALL_STATE(804)] = 22397,
  [SMALL_STATE(805)] = 22408,
  [SMALL_STATE(806)] = 22423,
  [SMALL_STATE(807)] = 22434,
  [SMALL_STATE(808)] = 22449,
  [SMALL_STATE(809)] = 22462,
  [SMALL_STATE(810)] = 22475,
  [SMALL_STATE(811)] = 22486,
  [SMALL_STATE(812)] = 22501,
  [SMALL_STATE(813)] = 22512,
  [SMALL_STATE(814)] = 22525,
  [SMALL_STATE(815)] = 22540,
  [SMALL_STATE(816)] = 22551,
  [SMALL_STATE(817)] = 22562,
  [SMALL_STATE(818)] = 22576,
  [SMALL_STATE(819)] = 22592,
  [SMALL_STATE(820)] = 22608,
  [SMALL_STATE(821)] = 22624,
  [SMALL_STATE(822)] = 22638,
  [SMALL_STATE(823)] = 22654,
  [SMALL_STATE(824)] = 22670,
  [SMALL_STATE(825)] = 22686,
  [SMALL_STATE(826)] = 22700,
  [SMALL_STATE(827)] = 22716,
  [SMALL_STATE(828)] = 22732,
  [SMALL_STATE(829)] = 22748,
  [SMALL_STATE(830)] = 22762,
  [SMALL_STATE(831)] = 22776,
  [SMALL_STATE(832)] = 22792,
  [SMALL_STATE(833)] = 22808,
  [SMALL_STATE(834)] = 22824,
  [SMALL_STATE(835)] = 22840,
  [SMALL_STATE(836)] = 22854,
  [SMALL_STATE(837)] = 22870,
  [SMALL_STATE(838)] = 22882,
  [SMALL_STATE(839)] = 22896,
  [SMALL_STATE(840)] = 22910,
  [SMALL_STATE(841)] = 22926,
  [SMALL_STATE(842)] = 22940,
  [SMALL_STATE(843)] = 22954,
  [SMALL_STATE(844)] = 22970,
  [SMALL_STATE(845)] = 22986,
  [SMALL_STATE(846)] = 22996,
  [SMALL_STATE(847)] = 23012,
  [SMALL_STATE(848)] = 23022,
  [SMALL_STATE(849)] = 23032,
  [SMALL_STATE(850)] = 23042,
  [SMALL_STATE(851)] = 23058,
  [SMALL_STATE(852)] = 23070,
  [SMALL_STATE(853)] = 23086,
  [SMALL_STATE(854)] = 23100,
  [SMALL_STATE(855)] = 23116,
  [SMALL_STATE(856)] = 23130,
  [SMALL_STATE(857)] = 23140,
  [SMALL_STATE(858)] = 23150,
  [SMALL_STATE(859)] = 23160,
  [SMALL_STATE(860)] = 23174,
  [SMALL_STATE(861)] = 23190,
  [SMALL_STATE(862)] = 23206,
  [SMALL_STATE(863)] = 23216,
  [SMALL_STATE(864)] = 23230,
  [SMALL_STATE(865)] = 23244,
  [SMALL_STATE(866)] = 23254,
  [SMALL_STATE(867)] = 23270,
  [SMALL_STATE(868)] = 23286,
  [SMALL_STATE(869)] = 23302,
  [SMALL_STATE(870)] = 23316,
  [SMALL_STATE(871)] = 23330,
  [SMALL_STATE(872)] = 23346,
  [SMALL_STATE(873)] = 23362,
  [SMALL_STATE(874)] = 23378,
  [SMALL_STATE(875)] = 23394,
  [SMALL_STATE(876)] = 23408,
  [SMALL_STATE(877)] = 23424,
  [SMALL_STATE(878)] = 23440,
  [SMALL_STATE(879)] = 23454,
  [SMALL_STATE(880)] = 23464,
  [SMALL_STATE(881)] = 23480,
  [SMALL_STATE(882)] = 23493,
  [SMALL_STATE(883)] = 23506,
  [SMALL_STATE(884)] = 23515,
  [SMALL_STATE(885)] = 23528,
  [SMALL_STATE(886)] = 23537,
  [SMALL_STATE(887)] = 23550,
  [SMALL_STATE(888)] = 23563,
  [SMALL_STATE(889)] = 23576,
  [SMALL_STATE(890)] = 23589,
  [SMALL_STATE(891)] = 23598,
  [SMALL_STATE(892)] = 23611,
  [SMALL_STATE(893)] = 23624,
  [SMALL_STATE(894)] = 23637,
  [SMALL_STATE(895)] = 23650,
  [SMALL_STATE(896)] = 23663,
  [SMALL_STATE(897)] = 23676,
  [SMALL_STATE(898)] = 23689,
  [SMALL_STATE(899)] = 23702,
  [SMALL_STATE(900)] = 23713,
  [SMALL_STATE(901)] = 23726,
  [SMALL_STATE(902)] = 23739,
  [SMALL_STATE(903)] = 23752,
  [SMALL_STATE(904)] = 23765,
  [SMALL_STATE(905)] = 23778,
  [SMALL_STATE(906)] = 23791,
  [SMALL_STATE(907)] = 23804,
  [SMALL_STATE(908)] = 23813,
  [SMALL_STATE(909)] = 23826,
  [SMALL_STATE(910)] = 23835,
  [SMALL_STATE(911)] = 23844,
  [SMALL_STATE(912)] = 23857,
  [SMALL_STATE(913)] = 23870,
  [SMALL_STATE(914)] = 23883,
  [SMALL_STATE(915)] = 23896,
  [SMALL_STATE(916)] = 23909,
  [SMALL_STATE(917)] = 23922,
  [SMALL_STATE(918)] = 23935,
  [SMALL_STATE(919)] = 23944,
  [SMALL_STATE(920)] = 23953,
  [SMALL_STATE(921)] = 23966,
  [SMALL_STATE(922)] = 23977,
  [SMALL_STATE(923)] = 23990,
  [SMALL_STATE(924)] = 24003,
  [SMALL_STATE(925)] = 24016,
  [SMALL_STATE(926)] = 24029,
  [SMALL_STATE(927)] = 24042,
  [SMALL_STATE(928)] = 24055,
  [SMALL_STATE(929)] = 24064,
  [SMALL_STATE(930)] = 24077,
  [SMALL_STATE(931)] = 24090,
  [SMALL_STATE(932)] = 24103,
  [SMALL_STATE(933)] = 24116,
  [SMALL_STATE(934)] = 24129,
  [SMALL_STATE(935)] = 24142,
  [SMALL_STATE(936)] = 24155,
  [SMALL_STATE(937)] = 24168,
  [SMALL_STATE(938)] = 24181,
  [SMALL_STATE(939)] = 24194,
  [SMALL_STATE(940)] = 24204,
  [SMALL_STATE(941)] = 24214,
  [SMALL_STATE(942)] = 24224,
  [SMALL_STATE(943)] = 24234,
  [SMALL_STATE(944)] = 24244,
  [SMALL_STATE(945)] = 24252,
  [SMALL_STATE(946)] = 24262,
  [SMALL_STATE(947)] = 24272,
  [SMALL_STATE(948)] = 24282,
  [SMALL_STATE(949)] = 24292,
  [SMALL_STATE(950)] = 24302,
  [SMALL_STATE(951)] = 24310,
  [SMALL_STATE(952)] = 24318,
  [SMALL_STATE(953)] = 24328,
  [SMALL_STATE(954)] = 24336,
  [SMALL_STATE(955)] = 24346,
  [SMALL_STATE(956)] = 24356,
  [SMALL_STATE(957)] = 24366,
  [SMALL_STATE(958)] = 24376,
  [SMALL_STATE(959)] = 24386,
  [SMALL_STATE(960)] = 24396,
  [SMALL_STATE(961)] = 24406,
  [SMALL_STATE(962)] = 24416,
  [SMALL_STATE(963)] = 24426,
  [SMALL_STATE(964)] = 24436,
  [SMALL_STATE(965)] = 24446,
  [SMALL_STATE(966)] = 24456,
  [SMALL_STATE(967)] = 24466,
  [SMALL_STATE(968)] = 24476,
  [SMALL_STATE(969)] = 24486,
  [SMALL_STATE(970)] = 24496,
  [SMALL_STATE(971)] = 24504,
  [SMALL_STATE(972)] = 24512,
  [SMALL_STATE(973)] = 24522,
  [SMALL_STATE(974)] = 24532,
  [SMALL_STATE(975)] = 24542,
  [SMALL_STATE(976)] = 24552,
  [SMALL_STATE(977)] = 24562,
  [SMALL_STATE(978)] = 24572,
  [SMALL_STATE(979)] = 24582,
  [SMALL_STATE(980)] = 24592,
  [SMALL_STATE(981)] = 24600,
  [SMALL_STATE(982)] = 24610,
  [SMALL_STATE(983)] = 24620,
  [SMALL_STATE(984)] = 24630,
  [SMALL_STATE(985)] = 24640,
  [SMALL_STATE(986)] = 24650,
  [SMALL_STATE(987)] = 24657,
  [SMALL_STATE(988)] = 24664,
  [SMALL_STATE(989)] = 24671,
  [SMALL_STATE(990)] = 24678,
  [SMALL_STATE(991)] = 24685,
  [SMALL_STATE(992)] = 24692,
  [SMALL_STATE(993)] = 24699,
  [SMALL_STATE(994)] = 24706,
  [SMALL_STATE(995)] = 24713,
  [SMALL_STATE(996)] = 24720,
  [SMALL_STATE(997)] = 24727,
  [SMALL_STATE(998)] = 24734,
  [SMALL_STATE(999)] = 24741,
  [SMALL_STATE(1000)] = 24748,
  [SMALL_STATE(1001)] = 24755,
  [SMALL_STATE(1002)] = 24762,
  [SMALL_STATE(1003)] = 24769,
  [SMALL_STATE(1004)] = 24776,
  [SMALL_STATE(1005)] = 24783,
  [SMALL_STATE(1006)] = 24790,
  [SMALL_STATE(1007)] = 24797,
  [SMALL_STATE(1008)] = 24804,
  [SMALL_STATE(1009)] = 24811,
  [SMALL_STATE(1010)] = 24818,
  [SMALL_STATE(1011)] = 24825,
  [SMALL_STATE(1012)] = 24832,
  [SMALL_STATE(1013)] = 24839,
  [SMALL_STATE(1014)] = 24846,
  [SMALL_STATE(1015)] = 24853,
  [SMALL_STATE(1016)] = 24860,
  [SMALL_STATE(1017)] = 24867,
  [SMALL_STATE(1018)] = 24874,
  [SMALL_STATE(1019)] = 24881,
  [SMALL_STATE(1020)] = 24888,
  [SMALL_STATE(1021)] = 24895,
  [SMALL_STATE(1022)] = 24902,
  [SMALL_STATE(1023)] = 24909,
  [SMALL_STATE(1024)] = 24916,
  [SMALL_STATE(1025)] = 24923,
  [SMALL_STATE(1026)] = 24930,
  [SMALL_STATE(1027)] = 24937,
  [SMALL_STATE(1028)] = 24944,
  [SMALL_STATE(1029)] = 24951,
  [SMALL_STATE(1030)] = 24958,
  [SMALL_STATE(1031)] = 24965,
  [SMALL_STATE(1032)] = 24972,
  [SMALL_STATE(1033)] = 24979,
  [SMALL_STATE(1034)] = 24986,
  [SMALL_STATE(1035)] = 24993,
  [SMALL_STATE(1036)] = 25000,
  [SMALL_STATE(1037)] = 25007,
  [SMALL_STATE(1038)] = 25014,
  [SMALL_STATE(1039)] = 25021,
  [SMALL_STATE(1040)] = 25028,
  [SMALL_STATE(1041)] = 25035,
  [SMALL_STATE(1042)] = 25042,
  [SMALL_STATE(1043)] = 25049,
  [SMALL_STATE(1044)] = 25056,
  [SMALL_STATE(1045)] = 25063,
  [SMALL_STATE(1046)] = 25070,
  [SMALL_STATE(1047)] = 25077,
  [SMALL_STATE(1048)] = 25084,
  [SMALL_STATE(1049)] = 25091,
  [SMALL_STATE(1050)] = 25098,
  [SMALL_STATE(1051)] = 25105,
  [SMALL_STATE(1052)] = 25112,
  [SMALL_STATE(1053)] = 25119,
  [SMALL_STATE(1054)] = 25126,
  [SMALL_STATE(1055)] = 25133,
  [SMALL_STATE(1056)] = 25140,
  [SMALL_STATE(1057)] = 25147,
  [SMALL_STATE(1058)] = 25154,
  [SMALL_STATE(1059)] = 25161,
  [SMALL_STATE(1060)] = 25168,
  [SMALL_STATE(1061)] = 25175,
  [SMALL_STATE(1062)] = 25182,
  [SMALL_STATE(1063)] = 25189,
  [SMALL_STATE(1064)] = 25196,
  [SMALL_STATE(1065)] = 25203,
  [SMALL_STATE(1066)] = 25210,
  [SMALL_STATE(1067)] = 25217,
  [SMALL_STATE(1068)] = 25224,
  [SMALL_STATE(1069)] = 25231,
  [SMALL_STATE(1070)] = 25238,
  [SMALL_STATE(1071)] = 25245,
  [SMALL_STATE(1072)] = 25252,
  [SMALL_STATE(1073)] = 25259,
  [SMALL_STATE(1074)] = 25266,
  [SMALL_STATE(1075)] = 25273,
  [SMALL_STATE(1076)] = 25280,
  [SMALL_STATE(1077)] = 25287,
  [SMALL_STATE(1078)] = 25294,
  [SMALL_STATE(1079)] = 25301,
  [SMALL_STATE(1080)] = 25308,
  [SMALL_STATE(1081)] = 25315,
  [SMALL_STATE(1082)] = 25322,
  [SMALL_STATE(1083)] = 25329,
  [SMALL_STATE(1084)] = 25336,
  [SMALL_STATE(1085)] = 25343,
  [SMALL_STATE(1086)] = 25350,
  [SMALL_STATE(1087)] = 25357,
  [SMALL_STATE(1088)] = 25364,
  [SMALL_STATE(1089)] = 25371,
  [SMALL_STATE(1090)] = 25378,
  [SMALL_STATE(1091)] = 25385,
  [SMALL_STATE(1092)] = 25392,
  [SMALL_STATE(1093)] = 25399,
  [SMALL_STATE(1094)] = 25406,
  [SMALL_STATE(1095)] = 25413,
  [SMALL_STATE(1096)] = 25420,
  [SMALL_STATE(1097)] = 25427,
  [SMALL_STATE(1098)] = 25434,
  [SMALL_STATE(1099)] = 25441,
  [SMALL_STATE(1100)] = 25448,
  [SMALL_STATE(1101)] = 25455,
  [SMALL_STATE(1102)] = 25462,
  [SMALL_STATE(1103)] = 25469,
  [SMALL_STATE(1104)] = 25476,
  [SMALL_STATE(1105)] = 25483,
  [SMALL_STATE(1106)] = 25490,
  [SMALL_STATE(1107)] = 25497,
  [SMALL_STATE(1108)] = 25504,
  [SMALL_STATE(1109)] = 25511,
  [SMALL_STATE(1110)] = 25518,
  [SMALL_STATE(1111)] = 25525,
  [SMALL_STATE(1112)] = 25532,
  [SMALL_STATE(1113)] = 25539,
  [SMALL_STATE(1114)] = 25546,
  [SMALL_STATE(1115)] = 25553,
  [SMALL_STATE(1116)] = 25560,
  [SMALL_STATE(1117)] = 25567,
  [SMALL_STATE(1118)] = 25574,
  [SMALL_STATE(1119)] = 25581,
  [SMALL_STATE(1120)] = 25588,
  [SMALL_STATE(1121)] = 25595,
  [SMALL_STATE(1122)] = 25602,
  [SMALL_STATE(1123)] = 25609,
  [SMALL_STATE(1124)] = 25616,
  [SMALL_STATE(1125)] = 25623,
  [SMALL_STATE(1126)] = 25630,
  [SMALL_STATE(1127)] = 25637,
  [SMALL_STATE(1128)] = 25644,
  [SMALL_STATE(1129)] = 25651,
  [SMALL_STATE(1130)] = 25658,
  [SMALL_STATE(1131)] = 25665,
  [SMALL_STATE(1132)] = 25672,
  [SMALL_STATE(1133)] = 25679,
  [SMALL_STATE(1134)] = 25686,
};

static const TSParseActionEntry ts_parse_actions[] = {
  [0] = {.entry = {.count = 0, .reusable = false}},
  [1] = {.entry = {.count = 1, .reusable = false}}, RECOVER(),
  [3] = {.entry = {.count = 1, .reusable = true}}, SHIFT_EXTRA(),
  [5] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unit, 0, 0, 0),
  [7] = {.entry = {.count = 1, .reusable = true}}, SHIFT(979),
  [9] = {.entry = {.count = 1, .reusable = true}}, SHIFT(916),
  [11] = {.entry = {.count = 1, .reusable = true}}, SHIFT(797),
  [13] = {.entry = {.count = 1, .reusable = true}}, SHIFT(780),
  [15] = {.entry = {.count = 1, .reusable = true}}, SHIFT(714),
  [17] = {.entry = {.count = 1, .reusable = true}}, SHIFT(777),
  [19] = {.entry = {.count = 1, .reusable = true}}, SHIFT(754),
  [21] = {.entry = {.count = 1, .reusable = true}}, SHIFT(770),
  [23] = {.entry = {.count = 1, .reusable = true}}, SHIFT(769),
  [25] = {.entry = {.count = 1, .reusable = true}}, SHIFT(914),
  [27] = {.entry = {.count = 1, .reusable = true}}, SHIFT(716),
  [29] = {.entry = {.count = 1, .reusable = true}}, SHIFT(711),
  [31] = {.entry = {.count = 1, .reusable = true}}, SHIFT(712),
  [33] = {.entry = {.count = 1, .reusable = true}}, SHIFT(974),
  [35] = {.entry = {.count = 1, .reusable = true}}, SHIFT(941),
  [37] = {.entry = {.count = 1, .reusable = true}}, SHIFT(956),
  [39] = {.entry = {.count = 1, .reusable = true}}, SHIFT(771),
  [41] = {.entry = {.count = 1, .reusable = false}}, SHIFT(943),
  [43] = {.entry = {.count = 1, .reusable = false}}, SHIFT(940),
  [45] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_order_clause, 3, 0, 0),
  [47] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1012),
  [49] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_order_clause, 3, 0, 0),
  [51] = {.entry = {.count = 1, .reusable = true}}, SHIFT(57),
  [53] = {.entry = {.count = 1, .reusable = false}}, SHIFT(969),
  [55] = {.entry = {.count = 1, .reusable = true}}, SHIFT(163),
  [57] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1041),
  [59] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1081),
  [61] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1050),
  [63] = {.entry = {.count = 1, .reusable = false}}, SHIFT(926),
  [65] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1128),
  [67] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1022),
  [69] = {.entry = {.count = 1, .reusable = false}}, SHIFT(978),
  [71] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1107),
  [73] = {.entry = {.count = 1, .reusable = false}}, SHIFT(886),
  [75] = {.entry = {.count = 1, .reusable = false}}, SHIFT(986),
  [77] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1109),
  [79] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1129),
  [81] = {.entry = {.count = 1, .reusable = false}}, SHIFT(976),
  [83] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1051),
  [85] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1052),
  [87] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1053),
  [89] = {.entry = {.count = 1, .reusable = true}}, SHIFT(264),
  [91] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_order_clause_repeat1, 2, 0, 0),
  [93] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_order_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1012),
  [96] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_order_clause_repeat1, 2, 0, 0),
  [98] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_order_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(57),
  [101] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_order_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(969),
  [104] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_order_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(163),
  [107] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_order_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1041),
  [110] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_order_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1081),
  [113] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_order_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1050),
  [116] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_order_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(926),
  [119] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_order_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1128),
  [122] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_order_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1022),
  [125] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_order_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(978),
  [128] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_order_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1107),
  [131] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_order_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(886),
  [134] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_order_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(986),
  [137] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_order_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1109),
  [140] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_order_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1129),
  [143] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_order_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(976),
  [146] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_order_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1051),
  [149] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_order_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1052),
  [152] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_order_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1053),
  [155] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_order_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(264),
  [158] = {.entry = {.count = 1, .reusable = false}}, SHIFT(10),
  [160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(59),
  [162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1111),
  [164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(118),
  [166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(546),
  [168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1003),
  [170] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1045),
  [172] = {.entry = {.count = 1, .reusable = false}}, SHIFT(118),
  [174] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1002),
  [176] = {.entry = {.count = 1, .reusable = false}}, SHIFT(922),
  [178] = {.entry = {.count = 1, .reusable = false}}, SHIFT(995),
  [180] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1048),
  [182] = {.entry = {.count = 1, .reusable = false}}, SHIFT(964),
  [184] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1094),
  [186] = {.entry = {.count = 1, .reusable = false}}, SHIFT(935),
  [188] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1121),
  [190] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1122),
  [192] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1123),
  [194] = {.entry = {.count = 1, .reusable = false}}, SHIFT(982),
  [196] = {.entry = {.count = 1, .reusable = false}}, SHIFT(988),
  [198] = {.entry = {.count = 1, .reusable = false}}, SHIFT(997),
  [200] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1116),
  [202] = {.entry = {.count = 1, .reusable = false}}, SHIFT(308),
  [204] = {.entry = {.count = 1, .reusable = false}}, SHIFT(546),
  [206] = {.entry = {.count = 1, .reusable = false}}, SHIFT(831),
  [208] = {.entry = {.count = 1, .reusable = false}}, SHIFT(832),
  [210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(793),
  [212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(794),
  [214] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17),
  [216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1010),
  [218] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16),
  [220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1023),
  [222] = {.entry = {.count = 1, .reusable = false}}, SHIFT(23),
  [224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1093),
  [226] = {.entry = {.count = 1, .reusable = false}}, SHIFT(43),
  [228] = {.entry = {.count = 1, .reusable = false}}, SHIFT(44),
  [230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1057),
  [232] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_group_clause, 3, 0, 0),
  [234] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_group_clause, 3, 0, 0),
  [236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(45),
  [238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(161),
  [240] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_having_clause_repeat1, 2, 0, 0),
  [242] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_having_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1012),
  [245] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_having_clause_repeat1, 2, 0, 0),
  [247] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_having_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(57),
  [250] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_having_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1041),
  [253] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_having_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1081),
  [256] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_having_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1050),
  [259] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_having_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(926),
  [262] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_having_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1128),
  [265] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_having_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1022),
  [268] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_having_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(978),
  [271] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_having_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1107),
  [274] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_having_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(886),
  [277] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_having_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(986),
  [280] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_having_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1109),
  [283] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_having_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1129),
  [286] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_having_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(976),
  [289] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_having_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1051),
  [292] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_having_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1052),
  [295] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_having_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1053),
  [298] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_having_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(264),
  [301] = {.entry = {.count = 1, .reusable = false}}, SHIFT(42),
  [303] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_group_clause_repeat1, 2, 0, 0),
  [305] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_group_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1012),
  [308] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_group_clause_repeat1, 2, 0, 0),
  [310] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_group_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(45),
  [313] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_group_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(161),
  [316] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_group_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1041),
  [319] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_group_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1081),
  [322] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_group_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1050),
  [325] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_group_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(926),
  [328] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_group_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1128),
  [331] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_group_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1022),
  [334] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_group_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(978),
  [337] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_group_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1107),
  [340] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_group_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(886),
  [343] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_group_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(986),
  [346] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_group_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1109),
  [349] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_group_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1129),
  [352] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_group_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(976),
  [355] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_group_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1051),
  [358] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_group_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1052),
  [361] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_group_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1053),
  [364] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_group_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(264),
  [367] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_having_clause, 2, 0, 0),
  [369] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_having_clause, 2, 0, 0),
  [371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1032),
  [373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1047),
  [375] = {.entry = {.count = 1, .reusable = false}}, SHIFT(60),
  [377] = {.entry = {.count = 1, .reusable = false}}, SHIFT(62),
  [379] = {.entry = {.count = 1, .reusable = false}}, SHIFT(74),
  [381] = {.entry = {.count = 1, .reusable = false}}, SHIFT(117),
  [383] = {.entry = {.count = 1, .reusable = false}}, SHIFT(76),
  [385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1115),
  [387] = {.entry = {.count = 1, .reusable = false}}, SHIFT(61),
  [389] = {.entry = {.count = 1, .reusable = false}}, SHIFT(87),
  [391] = {.entry = {.count = 1, .reusable = false}}, SHIFT(88),
  [393] = {.entry = {.count = 1, .reusable = false}}, SHIFT(89),
  [395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(563),
  [397] = {.entry = {.count = 1, .reusable = false}}, SHIFT(563),
  [399] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_group_graph_pattern, 2, 0, 0),
  [401] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_group_graph_pattern, 2, 0, 0),
  [403] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_build_in_function, 1, 0, 4),
  [405] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_build_in_function, 1, 0, 4),
  [407] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_build_in_function, 2, 0, 9),
  [409] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_build_in_function, 2, 0, 9),
  [411] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__nullary_build_in_function, 2, 0, 9),
  [413] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__nullary_build_in_function, 2, 0, 9),
  [415] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__unary_build_in_function, 2, 0, 9),
  [417] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__unary_build_in_function, 2, 0, 9),
  [419] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression_list, 1, 0, 0),
  [421] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expression_list, 1, 0, 0),
  [423] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__variadic_build_in_function, 2, 0, 9),
  [425] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__variadic_build_in_function, 2, 0, 9),
  [427] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_exists_func, 2, 0, 0),
  [429] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_exists_func, 2, 0, 0),
  [431] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arg_list, 1, 0, 0),
  [433] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arg_list, 1, 0, 0),
  [435] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_call, 2, 0, 10),
  [437] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_call, 2, 0, 10),
  [439] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bracketted_expression, 3, 0, 0),
  [441] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_bracketted_expression, 3, 0, 0),
  [443] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_not_exists_func, 3, 0, 0),
  [445] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_not_exists_func, 3, 0, 0),
  [447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(85),
  [449] = {.entry = {.count = 1, .reusable = false}}, SHIFT(945),
  [451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(211),
  [453] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1028),
  [455] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1074),
  [457] = {.entry = {.count = 1, .reusable = false}}, SHIFT(901),
  [459] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1132),
  [461] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1001),
  [463] = {.entry = {.count = 1, .reusable = false}}, SHIFT(949),
  [465] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1117),
  [467] = {.entry = {.count = 1, .reusable = false}}, SHIFT(902),
  [469] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1118),
  [471] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1119),
  [473] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1133),
  [475] = {.entry = {.count = 1, .reusable = false}}, SHIFT(955),
  [477] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1075),
  [479] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1076),
  [481] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1077),
  [483] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_build_in_function, 4, 0, 14),
  [485] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_build_in_function, 4, 0, 14),
  [487] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression_list, 3, 0, 0),
  [489] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expression_list, 3, 0, 0),
  [491] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arg_list, 3, 0, 0),
  [493] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arg_list, 3, 0, 0),
  [495] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_order_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(85),
  [498] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_order_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(945),
  [501] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_order_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(211),
  [504] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_order_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1028),
  [507] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_order_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1074),
  [510] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_order_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(901),
  [513] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_order_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1132),
  [516] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_order_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1001),
  [519] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_order_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(949),
  [522] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_order_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1117),
  [525] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_order_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(902),
  [528] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_order_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1118),
  [531] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_order_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1119),
  [534] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_order_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1133),
  [537] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_order_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(955),
  [540] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_order_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1075),
  [543] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_order_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1076),
  [546] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_order_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1077),
  [549] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression_list, 4, 0, 0),
  [551] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expression_list, 4, 0, 0),
  [553] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_aggregate, 5, 0, 0),
  [555] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_aggregate, 5, 0, 0),
  [557] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arg_list, 4, 0, 0),
  [559] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arg_list, 4, 0, 0),
  [561] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__binary_build_in_function, 6, 0, 16),
  [563] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__binary_build_in_function, 6, 0, 16),
  [565] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_regex_expression, 6, 0, 17),
  [567] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_regex_expression, 6, 0, 17),
  [569] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_substring_expression, 6, 0, 0),
  [571] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_substring_expression, 6, 0, 0),
  [573] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arg_list, 5, 0, 0),
  [575] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arg_list, 5, 0, 0),
  [577] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_build_in_function, 8, 0, 19),
  [579] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_build_in_function, 8, 0, 19),
  [581] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_regex_expression, 8, 0, 20),
  [583] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_regex_expression, 8, 0, 20),
  [585] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_substring_expression, 8, 0, 0),
  [587] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_substring_expression, 8, 0, 0),
  [589] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string_replace_expression, 8, 0, 0),
  [591] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string_replace_expression, 8, 0, 0),
  [593] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_aggregate, 8, 0, 0),
  [595] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_aggregate, 8, 0, 0),
  [597] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_aggregate, 9, 0, 0),
  [599] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_aggregate, 9, 0, 0),
  [601] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string_replace_expression, 10, 0, 0),
  [603] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string_replace_expression, 10, 0, 0),
  [605] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_group_graph_pattern, 3, 0, 0),
  [607] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_group_graph_pattern, 3, 0, 0),
  [609] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_group_graph_pattern, 4, 0, 0),
  [611] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_group_graph_pattern, 4, 0, 0),
  [613] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_aggregate, 4, 0, 0),
  [615] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_aggregate, 4, 0, 0),
  [617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(63),
  [619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(210),
  [621] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_group_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(63),
  [624] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_group_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(210),
  [627] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_group_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1028),
  [630] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_group_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1074),
  [633] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_group_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(901),
  [636] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_group_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1132),
  [639] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_group_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1001),
  [642] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_group_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(949),
  [645] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_group_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1117),
  [648] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_group_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(902),
  [651] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_group_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1118),
  [654] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_group_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1119),
  [657] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_group_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1133),
  [660] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_group_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(955),
  [663] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_group_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1075),
  [666] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_group_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1076),
  [669] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_group_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1077),
  [672] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_having_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(85),
  [675] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_having_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1028),
  [678] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_having_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1074),
  [681] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_having_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(901),
  [684] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_having_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1132),
  [687] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_having_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1001),
  [690] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_having_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(949),
  [693] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_having_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1117),
  [696] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_having_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(902),
  [699] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_having_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1118),
  [702] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_having_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1119),
  [705] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_having_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1133),
  [708] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_having_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(955),
  [711] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_having_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1075),
  [714] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_having_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1076),
  [717] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_having_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1077),
  [720] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_group_condition, 5, 0, 15),
  [722] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_group_condition, 5, 0, 15),
  [724] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_group_condition, 1, 0, 1),
  [726] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_group_condition, 1, 0, 1),
  [728] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_group_condition, 1, 0, 0),
  [730] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_group_condition, 1, 0, 0),
  [732] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_order_condition, 1, 0, 0),
  [734] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_order_condition, 1, 0, 0),
  [736] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_order_condition, 2, 0, 0),
  [738] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_order_condition, 2, 0, 0),
  [740] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_group_condition, 3, 0, 0),
  [742] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_group_condition, 3, 0, 0),
  [744] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_having_condition, 1, 0, 0),
  [746] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_having_condition, 1, 0, 0),
  [748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(72),
  [750] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1005),
  [752] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1063),
  [754] = {.entry = {.count = 1, .reusable = false}}, SHIFT(884),
  [756] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1130),
  [758] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1019),
  [760] = {.entry = {.count = 1, .reusable = false}}, SHIFT(975),
  [762] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1112),
  [764] = {.entry = {.count = 1, .reusable = false}}, SHIFT(896),
  [766] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1113),
  [768] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1114),
  [770] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1131),
  [772] = {.entry = {.count = 1, .reusable = false}}, SHIFT(972),
  [774] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1064),
  [776] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1065),
  [778] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1134),
  [780] = {.entry = {.count = 1, .reusable = false}}, SHIFT(996),
  [782] = {.entry = {.count = 1, .reusable = false}}, SHIFT(797),
  [784] = {.entry = {.count = 1, .reusable = false}}, SHIFT(254),
  [786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(216),
  [788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(306),
  [790] = {.entry = {.count = 1, .reusable = false}}, SHIFT(778),
  [792] = {.entry = {.count = 1, .reusable = false}}, SHIFT(748),
  [794] = {.entry = {.count = 1, .reusable = false}}, SHIFT(957),
  [796] = {.entry = {.count = 1, .reusable = false}}, SHIFT(732),
  [798] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1090),
  [800] = {.entry = {.count = 1, .reusable = false}}, SHIFT(966),
  [802] = {.entry = {.count = 1, .reusable = false}}, SHIFT(173),
  [804] = {.entry = {.count = 1, .reusable = false}}, SHIFT(494),
  [806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(493),
  [808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1079),
  [810] = {.entry = {.count = 1, .reusable = false}}, SHIFT(500),
  [812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(750),
  [814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1082),
  [816] = {.entry = {.count = 1, .reusable = false}}, SHIFT(493),
  [818] = {.entry = {.count = 1, .reusable = false}}, SHIFT(833),
  [820] = {.entry = {.count = 1, .reusable = false}}, SHIFT(834),
  [822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(783),
  [824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(792),
  [826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(119),
  [828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(207),
  [830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(228),
  [832] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_iri_reference, 3, 0, 0),
  [834] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_iri_reference, 3, 0, 0),
  [836] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_prefixed_name, 2, 0, 0),
  [838] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_prefixed_name, 2, 0, 0),
  [840] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_describe_query, 2, 0, 0),
  [842] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1054),
  [844] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_describe_query, 2, 0, 0),
  [846] = {.entry = {.count = 1, .reusable = false}}, SHIFT(958),
  [848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(219),
  [850] = {.entry = {.count = 1, .reusable = false}}, SHIFT(727),
  [852] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1016),
  [854] = {.entry = {.count = 1, .reusable = false}}, SHIFT(169),
  [856] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1020),
  [858] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1025),
  [860] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1035),
  [862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(253),
  [864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(273),
  [866] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_group_graph_pattern_repeat1, 1, 0, 0),
  [868] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_group_graph_pattern_repeat1, 1, 0, 0),
  [870] = {.entry = {.count = 1, .reusable = false}}, SHIFT(224),
  [872] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_group_graph_pattern_repeat1, 2, 0, 0),
  [874] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_group_graph_pattern_repeat1, 2, 0, 0),
  [876] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_triples_block, 2, 0, 0),
  [878] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_triples_block, 2, 0, 0),
  [880] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_triples_block, 3, 0, 0),
  [882] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_triples_block, 3, 0, 0),
  [884] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_unit_repeat1, 2, 0, 0),
  [886] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(979),
  [889] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(916),
  [892] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(797),
  [895] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(780),
  [898] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(714),
  [901] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(777),
  [904] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(754),
  [907] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(770),
  [910] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(769),
  [913] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(914),
  [916] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(716),
  [919] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(711),
  [922] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(712),
  [925] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(974),
  [928] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(941),
  [931] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(956),
  [934] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(771),
  [937] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(943),
  [940] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(940),
  [943] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unit, 1, 0, 0),
  [945] = {.entry = {.count = 1, .reusable = false}}, SHIFT(250),
  [947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(883),
  [949] = {.entry = {.count = 1, .reusable = false}}, SHIFT(737),
  [951] = {.entry = {.count = 1, .reusable = false}}, SHIFT(689),
  [953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(694),
  [955] = {.entry = {.count = 1, .reusable = false}}, SHIFT(694),
  [957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(389),
  [959] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_quads_repeat1, 1, 0, 0),
  [961] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_quads_repeat1, 1, 0, 0),
  [963] = {.entry = {.count = 1, .reusable = false}}, SHIFT(235),
  [965] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_quads_repeat1, 2, 0, 0),
  [967] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_quads_repeat1, 2, 0, 0),
  [969] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1068),
  [971] = {.entry = {.count = 1, .reusable = false}}, SHIFT(248),
  [973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(463),
  [975] = {.entry = {.count = 1, .reusable = false}}, SHIFT(514),
  [977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(242),
  [979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1026),
  [981] = {.entry = {.count = 1, .reusable = false}}, SHIFT(530),
  [983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(381),
  [985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1060),
  [987] = {.entry = {.count = 1, .reusable = false}}, SHIFT(242),
  [989] = {.entry = {.count = 1, .reusable = false}}, SHIFT(823),
  [991] = {.entry = {.count = 1, .reusable = false}}, SHIFT(824),
  [993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(786),
  [995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(787),
  [997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(529),
  [999] = {.entry = {.count = 1, .reusable = false}}, SHIFT(261),
  [1001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(548),
  [1003] = {.entry = {.count = 1, .reusable = false}}, SHIFT(693),
  [1005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(245),
  [1007] = {.entry = {.count = 1, .reusable = false}}, SHIFT(245),
  [1009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(958),
  [1011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(727),
  [1013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1016),
  [1015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(169),
  [1017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1020),
  [1019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1025),
  [1021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1035),
  [1023] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_triples_template, 2, 0, 0),
  [1025] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_triples_template, 2, 0, 0),
  [1027] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_describe_query, 3, 0, 0),
  [1029] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_describe_query, 3, 0, 0),
  [1031] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_collection_path_repeat1, 2, 0, 0), SHIFT_REPEAT(1068),
  [1034] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_collection_path_repeat1, 2, 0, 0), SHIFT_REPEAT(248),
  [1037] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_collection_path_repeat1, 2, 0, 0),
  [1039] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_collection_path_repeat1, 2, 0, 0), SHIFT_REPEAT(514),
  [1042] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_collection_path_repeat1, 2, 0, 0), SHIFT_REPEAT(242),
  [1045] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_collection_path_repeat1, 2, 0, 0), SHIFT_REPEAT(1026),
  [1048] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_collection_path_repeat1, 2, 0, 0), SHIFT_REPEAT(530),
  [1051] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_collection_path_repeat1, 2, 0, 0), SHIFT_REPEAT(381),
  [1054] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_collection_path_repeat1, 2, 0, 0), SHIFT_REPEAT(1060),
  [1057] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_collection_path_repeat1, 2, 0, 0), SHIFT_REPEAT(242),
  [1060] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_collection_path_repeat1, 2, 0, 0), SHIFT_REPEAT(823),
  [1063] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_collection_path_repeat1, 2, 0, 0), SHIFT_REPEAT(824),
  [1066] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_collection_path_repeat1, 2, 0, 0), SHIFT_REPEAT(786),
  [1069] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_collection_path_repeat1, 2, 0, 0), SHIFT_REPEAT(787),
  [1072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(438),
  [1074] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_triples_template, 3, 0, 0),
  [1076] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_triples_template, 3, 0, 0),
  [1078] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_collection_repeat1, 2, 0, 0), SHIFT_REPEAT(1068),
  [1081] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_collection_repeat1, 2, 0, 0), SHIFT_REPEAT(261),
  [1084] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_collection_repeat1, 2, 0, 0),
  [1086] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_collection_repeat1, 2, 0, 0), SHIFT_REPEAT(693),
  [1089] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_collection_repeat1, 2, 0, 0), SHIFT_REPEAT(245),
  [1092] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_collection_repeat1, 2, 0, 0), SHIFT_REPEAT(1026),
  [1095] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_collection_repeat1, 2, 0, 0), SHIFT_REPEAT(530),
  [1098] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_collection_repeat1, 2, 0, 0), SHIFT_REPEAT(381),
  [1101] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_collection_repeat1, 2, 0, 0), SHIFT_REPEAT(1060),
  [1104] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_collection_repeat1, 2, 0, 0), SHIFT_REPEAT(245),
  [1107] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_collection_repeat1, 2, 0, 0), SHIFT_REPEAT(823),
  [1110] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_collection_repeat1, 2, 0, 0), SHIFT_REPEAT(824),
  [1113] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_collection_repeat1, 2, 0, 0), SHIFT_REPEAT(786),
  [1116] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_collection_repeat1, 2, 0, 0), SHIFT_REPEAT(787),
  [1119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(528),
  [1121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(688),
  [1123] = {.entry = {.count = 1, .reusable = false}}, SHIFT(688),
  [1125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(237),
  [1127] = {.entry = {.count = 1, .reusable = false}}, SHIFT(237),
  [1129] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_construct_triples, 2, 0, 0),
  [1131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(238),
  [1133] = {.entry = {.count = 1, .reusable = false}}, SHIFT(238),
  [1135] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_construct_triples, 3, 0, 0),
  [1137] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_describe_query_repeat1, 2, 0, 0),
  [1139] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_describe_query_repeat1, 2, 0, 0), SHIFT_REPEAT(1054),
  [1142] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_describe_query_repeat1, 2, 0, 0),
  [1144] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_describe_query_repeat1, 2, 0, 0), SHIFT_REPEAT(253),
  [1147] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_describe_query_repeat1, 2, 0, 0), SHIFT_REPEAT(1041),
  [1150] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_describe_query_repeat1, 2, 0, 0), SHIFT_REPEAT(273),
  [1153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(236),
  [1155] = {.entry = {.count = 1, .reusable = false}}, SHIFT(236),
  [1157] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_namespace, 2, 0, 0),
  [1159] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_namespace, 2, 0, 0),
  [1161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(690),
  [1163] = {.entry = {.count = 1, .reusable = false}}, SHIFT(690),
  [1165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(859),
  [1167] = {.entry = {.count = 1, .reusable = false}}, SHIFT(859),
  [1169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(835),
  [1171] = {.entry = {.count = 1, .reusable = false}}, SHIFT(835),
  [1173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(246),
  [1175] = {.entry = {.count = 1, .reusable = false}}, SHIFT(246),
  [1177] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_namespace, 1, 0, 0),
  [1179] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_namespace, 1, 0, 0),
  [1181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(687),
  [1183] = {.entry = {.count = 1, .reusable = false}}, SHIFT(687),
  [1185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(696),
  [1187] = {.entry = {.count = 1, .reusable = false}}, SHIFT(696),
  [1189] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_prefixed_name, 1, 0, 0),
  [1191] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_prefixed_name, 1, 0, 0),
  [1193] = {.entry = {.count = 1, .reusable = false}}, SHIFT(221),
  [1195] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_select_query, 3, 0, 0),
  [1197] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_select_query, 3, 0, 0),
  [1199] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ask_query, 2, 0, 0),
  [1201] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_ask_query, 2, 0, 0),
  [1203] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_describe_query, 4, 0, 0),
  [1205] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_describe_query, 4, 0, 0),
  [1207] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_construct_query, 5, 0, 0),
  [1209] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_construct_query, 5, 0, 0),
  [1211] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_construct_query, 3, 0, 0),
  [1213] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_construct_query, 3, 0, 0),
  [1215] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_select_query, 2, 0, 0),
  [1217] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_select_query, 2, 0, 0),
  [1219] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_construct_query, 6, 0, 0),
  [1221] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_construct_query, 6, 0, 0),
  [1223] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_construct_query, 4, 0, 0),
  [1225] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_construct_query, 4, 0, 0),
  [1227] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ask_query, 3, 0, 0),
  [1229] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_ask_query, 3, 0, 0),
  [1231] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__string_literal_long1, 3, 0, 0),
  [1233] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__string_literal_long1, 3, 0, 0),
  [1235] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__string_literal_long2, 3, 0, 0),
  [1237] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__string_literal_long2, 3, 0, 0),
  [1239] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__string_literal_long2, 2, 0, 0),
  [1241] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__string_literal_long2, 2, 0, 0),
  [1243] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__string_literal_long1, 2, 0, 0),
  [1245] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__string_literal_long1, 2, 0, 0),
  [1247] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_select_query_repeat1, 2, 0, 0),
  [1249] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_select_query_repeat1, 2, 0, 0), SHIFT_REPEAT(727),
  [1252] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_select_query_repeat1, 2, 0, 0),
  [1254] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__string_literal1, 2, 0, 0),
  [1256] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__string_literal1, 2, 0, 0),
  [1258] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string, 1, 0, 0),
  [1260] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string, 1, 0, 0),
  [1262] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__string_literal2, 2, 0, 0),
  [1264] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__string_literal2, 2, 0, 0),
  [1266] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__string_literal2, 3, 0, 0),
  [1268] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__string_literal2, 3, 0, 0),
  [1270] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__string_literal1, 3, 0, 0),
  [1272] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__string_literal1, 3, 0, 0),
  [1274] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_solution_modifier, 1, 0, 0),
  [1276] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_solution_modifier, 1, 0, 0),
  [1278] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_group_or_union_graph_pattern_repeat1, 2, 0, 0),
  [1280] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_group_or_union_graph_pattern_repeat1, 2, 0, 0),
  [1282] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_group_or_union_graph_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(973),
  [1285] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_property_list_path_repeat1, 1, 0, 0),
  [1287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(611),
  [1289] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_property_list_path_repeat1, 1, 0, 0),
  [1291] = {.entry = {.count = 1, .reusable = false}}, SHIFT(477),
  [1293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(799),
  [1295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(702),
  [1297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(256),
  [1299] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_group_or_union_graph_pattern, 2, 0, 0),
  [1301] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_group_or_union_graph_pattern, 2, 0, 0),
  [1303] = {.entry = {.count = 1, .reusable = false}}, SHIFT(973),
  [1305] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_triples_same_subject_path, 1, 0, 0),
  [1307] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_triples_same_subject_path, 1, 0, 0),
  [1309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(257),
  [1311] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_group_or_union_graph_pattern, 1, 0, 0),
  [1313] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_group_or_union_graph_pattern, 1, 0, 0),
  [1315] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__inline_data_one_var_repeat1, 2, 0, 0), SHIFT_REPEAT(1078),
  [1318] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__inline_data_one_var_repeat1, 2, 0, 0),
  [1320] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__inline_data_one_var_repeat1, 2, 0, 0), SHIFT_REPEAT(307),
  [1323] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__inline_data_one_var_repeat1, 2, 0, 0), SHIFT_REPEAT(1079),
  [1326] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__inline_data_one_var_repeat1, 2, 0, 0), SHIFT_REPEAT(500),
  [1329] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__inline_data_one_var_repeat1, 2, 0, 0), SHIFT_REPEAT(602),
  [1332] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__inline_data_one_var_repeat1, 2, 0, 0), SHIFT_REPEAT(307),
  [1335] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__inline_data_one_var_repeat1, 2, 0, 0), SHIFT_REPEAT(833),
  [1338] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__inline_data_one_var_repeat1, 2, 0, 0), SHIFT_REPEAT(834),
  [1341] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__inline_data_one_var_repeat1, 2, 0, 0), SHIFT_REPEAT(783),
  [1344] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__inline_data_one_var_repeat1, 2, 0, 0), SHIFT_REPEAT(792),
  [1347] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_boolean_literal, 1, 0, 0),
  [1349] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_boolean_literal, 1, 0, 0),
  [1351] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_rdf_literal, 2, 0, 5),
  [1353] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_rdf_literal, 2, 0, 5),
  [1355] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dataset_clause, 2, 0, 0),
  [1357] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_dataset_clause, 2, 0, 0),
  [1359] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_default_graph_clause, 1, 0, 7),
  [1361] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_default_graph_clause, 1, 0, 7),
  [1363] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_named_graph_clause, 2, 0, 11),
  [1365] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_named_graph_clause, 2, 0, 11),
  [1367] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_rdf_literal, 3, 0, 13),
  [1369] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_rdf_literal, 3, 0, 13),
  [1371] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_bind, 6, 0, 18),
  [1373] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bind, 6, 0, 18),
  [1375] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1078),
  [1377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(921),
  [1379] = {.entry = {.count = 1, .reusable = false}}, SHIFT(307),
  [1381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(602),
  [1383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(307),
  [1385] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_data_block, 1, 0, 8),
  [1387] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_data_block, 1, 0, 8),
  [1389] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__inline_data_one_var, 3, 0, 1),
  [1391] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__inline_data_one_var, 3, 0, 1),
  [1393] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__inline_data_full, 3, 0, 0),
  [1395] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__inline_data_full, 3, 0, 0),
  [1397] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__inline_data_one_var, 4, 0, 1),
  [1399] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__inline_data_one_var, 4, 0, 1),
  [1401] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__inline_data_full, 4, 0, 0),
  [1403] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__inline_data_full, 4, 0, 0),
  [1405] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_solution_modifier, 2, 0, 0),
  [1407] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_solution_modifier, 2, 0, 0),
  [1409] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__inline_data_full, 5, 0, 2),
  [1411] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__inline_data_full, 5, 0, 2),
  [1413] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_inline_data, 2, 0, 0),
  [1415] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inline_data, 2, 0, 0),
  [1417] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_optional_graph_pattern, 2, 0, 0),
  [1419] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_optional_graph_pattern, 2, 0, 0),
  [1421] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__inline_data_full, 6, 0, 2),
  [1423] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__inline_data_full, 6, 0, 2),
  [1425] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_minus_graph_pattern, 2, 0, 0),
  [1427] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_minus_graph_pattern, 2, 0, 0),
  [1429] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_filter, 2, 0, 0),
  [1431] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_filter, 2, 0, 0),
  [1433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(476),
  [1435] = {.entry = {.count = 1, .reusable = false}}, SHIFT(370),
  [1437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(370),
  [1439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(321),
  [1441] = {.entry = {.count = 1, .reusable = false}}, SHIFT(367),
  [1443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(367),
  [1445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(324),
  [1447] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_graph_graph_pattern, 3, 0, 0),
  [1449] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_graph_graph_pattern, 3, 0, 0),
  [1451] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_service_graph_pattern, 3, 0, 0),
  [1453] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_service_graph_pattern, 3, 0, 0),
  [1455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(431),
  [1457] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_service_graph_pattern, 4, 0, 0),
  [1459] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_service_graph_pattern, 4, 0, 0),
  [1461] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_where_clause, 2, 0, 0),
  [1463] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_where_clause, 2, 0, 0),
  [1465] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_solution_modifier, 3, 0, 0),
  [1467] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_solution_modifier, 3, 0, 0),
  [1469] = {.entry = {.count = 1, .reusable = false}}, SHIFT(319),
  [1471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(319),
  [1473] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_where_clause, 1, 0, 0),
  [1475] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_where_clause, 1, 0, 0),
  [1477] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_limit_offset_clauses, 1, 0, 0),
  [1479] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_limit_offset_clauses, 1, 0, 0),
  [1481] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_offset_clause, 2, 0, 0),
  [1483] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_offset_clause, 2, 0, 0),
  [1485] = {.entry = {.count = 1, .reusable = false}}, SHIFT(395),
  [1487] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_quads, 3, 0, 0),
  [1489] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_quads, 3, 0, 0),
  [1491] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_limit_clause, 2, 0, 0),
  [1493] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_limit_clause, 2, 0, 0),
  [1495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(394),
  [1497] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_quads, 4, 0, 0),
  [1499] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_quads, 4, 0, 0),
  [1501] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_quads, 2, 0, 0),
  [1503] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_quads, 2, 0, 0),
  [1505] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_load, 2, 0, 0),
  [1507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(954),
  [1509] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_load, 2, 0, 0),
  [1511] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_limit_offset_clauses, 2, 0, 0),
  [1513] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_limit_offset_clauses, 2, 0, 0),
  [1515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(798),
  [1517] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_unit_repeat1, 2, 0, 0),
  [1519] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_load, 3, 0, 0),
  [1521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(939),
  [1523] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_load, 3, 0, 0),
  [1525] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_graph_or_default, 2, 0, 0),
  [1527] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_graph_or_default, 2, 0, 0),
  [1529] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_prologue, 1, 0, 0),
  [1531] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_prologue, 1, 0, 0),
  [1533] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_prologue_repeat1, 2, 0, 0), SHIFT_REPEAT(979),
  [1536] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_prologue_repeat1, 2, 0, 0), SHIFT_REPEAT(916),
  [1539] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_prologue_repeat1, 2, 0, 0),
  [1541] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_prologue_repeat1, 2, 0, 0),
  [1543] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_path_one_in_property_set, 1, 0, 0),
  [1545] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_path_one_in_property_set, 1, 0, 0),
  [1547] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_graph_or_default, 1, 0, 0),
  [1549] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_graph_or_default, 1, 0, 0),
  [1551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(221),
  [1553] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_unit_repeat1, 1, 0, 0),
  [1555] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_unit_repeat1, 1, 0, 0),
  [1557] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_solution_modifier, 4, 0, 0),
  [1559] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_solution_modifier, 4, 0, 0),
  [1561] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_path_one_in_property_set, 2, 0, 0),
  [1563] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_path_one_in_property_set, 2, 0, 0),
  [1565] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_copy, 5, 0, 0),
  [1567] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_copy, 5, 0, 0),
  [1569] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_binary_path, 3, 0, 0),
  [1571] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_binary_path, 3, 0, 0),
  [1573] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_modify, 7, 0, 0),
  [1575] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_modify, 7, 0, 0),
  [1577] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_blank_node_label, 2, 0, 0),
  [1579] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_blank_node_label, 2, 0, 0),
  [1581] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_path_negated_property_set, 4, 0, 0),
  [1583] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_path_negated_property_set, 4, 0, 0),
  [1585] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_graph_ref_all, 1, 0, 0),
  [1587] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_graph_ref_all, 1, 0, 0),
  [1589] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_clear, 2, 0, 0),
  [1591] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_clear, 2, 0, 0),
  [1593] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_quads_not_triples, 4, 0, 0),
  [1595] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_quads_not_triples, 4, 0, 0),
  [1597] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_drop, 2, 0, 0),
  [1599] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_drop, 2, 0, 0),
  [1601] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_create, 2, 0, 0),
  [1603] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_create, 2, 0, 0),
  [1605] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ask_query, 4, 0, 0),
  [1607] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_ask_query, 4, 0, 0),
  [1609] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_load, 4, 0, 0),
  [1611] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_load, 4, 0, 0),
  [1613] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_add, 4, 0, 0),
  [1615] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_add, 4, 0, 0),
  [1617] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_move, 4, 0, 0),
  [1619] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_move, 4, 0, 0),
  [1621] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_copy, 4, 0, 0),
  [1623] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_copy, 4, 0, 0),
  [1625] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_select_query, 4, 0, 0),
  [1627] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_select_query, 4, 0, 0),
  [1629] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_modify, 4, 0, 0),
  [1631] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_modify, 4, 0, 0),
  [1633] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_insert_data, 2, 0, 0),
  [1635] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_insert_data, 2, 0, 0),
  [1637] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_delete_data, 2, 0, 0),
  [1639] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_delete_data, 2, 0, 0),
  [1641] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_delete_where, 2, 0, 0),
  [1643] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_delete_where, 2, 0, 0),
  [1645] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_modify, 6, 0, 0),
  [1647] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_modify, 6, 0, 0),
  [1649] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__update, 2, 0, 0),
  [1651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(280),
  [1653] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__update, 2, 0, 0),
  [1655] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_clear, 3, 0, 0),
  [1657] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_clear, 3, 0, 0),
  [1659] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_graph_ref, 2, 0, 0),
  [1661] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_graph_ref, 2, 0, 0),
  [1663] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_drop, 3, 0, 0),
  [1665] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_drop, 3, 0, 0),
  [1667] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_create, 3, 0, 0),
  [1669] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_create, 3, 0, 0),
  [1671] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_describe_query, 5, 0, 0),
  [1673] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_describe_query, 5, 0, 0),
  [1675] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_collection_path, 3, 0, 0),
  [1677] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_collection_path, 3, 0, 0),
  [1679] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__primary_path, 2, 0, 0),
  [1681] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__primary_path, 2, 0, 0),
  [1683] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_path_negated_property_set, 1, 0, 0),
  [1685] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_path_negated_property_set, 1, 0, 0),
  [1687] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_blank_node_property_list_path, 3, 0, 0),
  [1689] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_blank_node_property_list_path, 3, 0, 0),
  [1691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(260),
  [1693] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_path_element, 2, 0, 0),
  [1695] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_path_element, 2, 0, 0),
  [1697] = {.entry = {.count = 1, .reusable = false}}, SHIFT(474),
  [1699] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_construct_query, 7, 0, 0),
  [1701] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_construct_query, 7, 0, 0),
  [1703] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_load, 5, 0, 0),
  [1705] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_load, 5, 0, 0),
  [1707] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_add, 5, 0, 0),
  [1709] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_add, 5, 0, 0),
  [1711] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_move, 5, 0, 0),
  [1713] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_move, 5, 0, 0),
  [1715] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_path_element, 3, 0, 0),
  [1717] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_path_element, 3, 0, 0),
  [1719] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_modify, 5, 0, 0),
  [1721] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_modify, 5, 0, 0),
  [1723] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_path_element, 1, 0, 0),
  [1725] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_path_element, 1, 0, 0),
  [1727] = {.entry = {.count = 1, .reusable = false}}, SHIFT(469),
  [1729] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_values_clause, 2, 0, 0),
  [1731] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_values_clause, 2, 0, 0),
  [1733] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__iri_or_function, 1, 0, 0),
  [1735] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9),
  [1737] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__iri_or_function, 1, 0, 0),
  [1739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(553),
  [1741] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_modify, 3, 0, 0),
  [1743] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_modify, 3, 0, 0),
  [1745] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__update, 1, 0, 0),
  [1747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(275),
  [1749] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__update, 1, 0, 0),
  [1751] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_path_negated_property_set, 3, 0, 0),
  [1753] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_path_negated_property_set, 3, 0, 0),
  [1755] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__primary_path, 3, 0, 0),
  [1757] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__primary_path, 3, 0, 0),
  [1759] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_path_negated_property_set, 2, 0, 0),
  [1761] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_path_negated_property_set, 2, 0, 0),
  [1763] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_quads_not_triples, 5, 0, 0),
  [1765] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_quads_not_triples, 5, 0, 0),
  [1767] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_rdf_literal, 1, 0, 5),
  [1769] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_rdf_literal, 1, 0, 5),
  [1771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(768),
  [1773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(525),
  [1775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(258),
  [1777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(227),
  [1779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(778),
  [1781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(748),
  [1783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(957),
  [1785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(732),
  [1787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1090),
  [1789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(966),
  [1791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(173),
  [1793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(310),
  [1795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(314),
  [1797] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__predicate_path, 1, 0, 0),
  [1799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(606),
  [1801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(607),
  [1803] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__predicate_path, 1, 0, 0),
  [1805] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_unit_repeat1, 3, 0, 0),
  [1807] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_unit_repeat1, 3, 0, 0),
  [1809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(153),
  [1811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(764),
  [1813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(309),
  [1815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(154),
  [1817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(188),
  [1819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(192),
  [1821] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_group_graph_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(216),
  [1824] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_group_graph_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(778),
  [1827] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_group_graph_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(748),
  [1830] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_group_graph_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(957),
  [1833] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_group_graph_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(732),
  [1836] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_group_graph_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(1090),
  [1839] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_group_graph_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(966),
  [1842] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_group_graph_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(173),
  [1845] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__update, 3, 0, 0),
  [1847] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__update, 3, 0, 0),
  [1849] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__update, 4, 0, 0),
  [1851] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__update, 4, 0, 0),
  [1853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(229),
  [1855] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_prefix_declaration, 3, 0, 0),
  [1857] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_prefix_declaration, 3, 0, 0),
  [1859] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_base_declaration, 2, 0, 0),
  [1861] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_base_declaration, 2, 0, 0),
  [1863] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_blank_node_property_list, 3, 0, 0),
  [1865] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_blank_node_property_list, 3, 0, 0),
  [1867] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_collection, 3, 0, 0),
  [1869] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_collection, 3, 0, 0),
  [1871] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_binary_expression, 3, 0, 0),
  [1873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(36),
  [1875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(38),
  [1877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(39),
  [1879] = {.entry = {.count = 1, .reusable = false}}, SHIFT(39),
  [1881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(900),
  [1883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1000),
  [1885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(40),
  [1887] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_binary_expression, 3, 0, 0),
  [1889] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expression, 1, 0, 0),
  [1891] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__expression, 1, 0, 0),
  [1893] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_binary_expression, 4, 0, 0),
  [1895] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_binary_expression, 4, 0, 0),
  [1897] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unary_expression, 2, 0, 0),
  [1899] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_unary_expression, 2, 0, 0),
  [1901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(559),
  [1903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(48),
  [1905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(37),
  [1907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(137),
  [1909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(135),
  [1911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(141),
  [1913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(554),
  [1915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(761),
  [1917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(515),
  [1919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(183),
  [1921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(347),
  [1923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(349),
  [1925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(544),
  [1927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(352),
  [1929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(185),
  [1931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(174),
  [1933] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_property_list_repeat1, 1, 0, 0),
  [1935] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_property_list_repeat1, 1, 0, 0),
  [1937] = {.entry = {.count = 1, .reusable = false}}, SHIFT(247),
  [1939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(247),
  [1941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1098),
  [1943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(348),
  [1945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1099),
  [1947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(351),
  [1949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(354),
  [1951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(81),
  [1953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(355),
  [1955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(82),
  [1957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(360),
  [1959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(84),
  [1961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(552),
  [1963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(53),
  [1965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(566),
  [1967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(54),
  [1969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1105),
  [1971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(184),
  [1973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1106),
  [1975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(187),
  [1977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(190),
  [1979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(94),
  [1981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(191),
  [1983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(95),
  [1985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(196),
  [1987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(97),
  [1989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1067),
  [1991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(557),
  [1993] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1071),
  [1995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(601),
  [1997] = {.entry = {.count = 1, .reusable = false}}, SHIFT(837),
  [1999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(701),
  [2001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1049),
  [2003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(810),
  [2005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(149),
  [2007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(71),
  [2009] = {.entry = {.count = 1, .reusable = false}}, SHIFT(504),
  [2011] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_arg_list_repeat1, 2, 0, 0),
  [2013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(541),
  [2015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(56),
  [2017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1091),
  [2019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(155),
  [2021] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_triples_same_subject, 1, 0, 0),
  [2023] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_triples_same_subject, 1, 0, 0),
  [2025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1092),
  [2027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(140),
  [2029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(994),
  [2031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(209),
  [2033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1018),
  [2035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(538),
  [2037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(143),
  [2039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(68),
  [2041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(144),
  [2043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(69),
  [2045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1056),
  [2047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(165),
  [2049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(571),
  [2051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(50),
  [2053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(773),
  [2055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(51),
  [2057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(565),
  [2059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(363),
  [2061] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sub_select, 2, 0, 0),
  [2063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1087),
  [2065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(170),
  [2067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1088),
  [2069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(55),
  [2071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(556),
  [2073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(353),
  [2075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(180),
  [2077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1097),
  [2079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(46),
  [2081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1127),
  [2083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(568),
  [2085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(572),
  [2087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(47),
  [2089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(131),
  [2091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(357),
  [2093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(49),
  [2095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(358),
  [2097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(359),
  [2099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(193),
  [2101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(64),
  [2103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(65),
  [2105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(66),
  [2107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(67),
  [2109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(70),
  [2111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(77),
  [2113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(78),
  [2115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(79),
  [2117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(80),
  [2119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(83),
  [2121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(90),
  [2123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(91),
  [2125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(92),
  [2127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(93),
  [2129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(96),
  [2131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(142),
  [2133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(194),
  [2135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(195),
  [2137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(52),
  [2139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(547),
  [2141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(146),
  [2143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(147),
  [2145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(148),
  [2147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(199),
  [2149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(152),
  [2151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(101),
  [2153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(102),
  [2155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(106),
  [2157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(107),
  [2159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(111),
  [2161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(112),
  [2163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(344),
  [2165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(189),
  [2167] = {.entry = {.count = 1, .reusable = false}}, SHIFT(259),
  [2169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(259),
  [2171] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_list_path, 2, 0, 0),
  [2173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(267),
  [2175] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_object_list_repeat1, 2, 0, 0),
  [2177] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_list, 1, 0, 0),
  [2179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(266),
  [2181] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_list_path, 1, 0, 0),
  [2183] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_object_list_repeat1, 2, 0, 0), SHIFT_REPEAT(266),
  [2186] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_object_list_path_repeat1, 2, 0, 0),
  [2188] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_object_list_path_repeat1, 2, 0, 0), SHIFT_REPEAT(267),
  [2191] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_list, 2, 0, 0),
  [2193] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_property_list_path_repeat1, 2, 0, 0), SHIFT_REPEAT(302),
  [2196] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_property_list_path_repeat1, 2, 0, 0),
  [2198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(302),
  [2200] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_list_path, 2, 0, 0),
  [2202] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_list_path, 1, 0, 0),
  [2204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(715),
  [2206] = {.entry = {.count = 1, .reusable = false}}, SHIFT(847),
  [2208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(752),
  [2210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(705),
  [2212] = {.entry = {.count = 1, .reusable = false}}, SHIFT(408),
  [2214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(753),
  [2216] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_path, 2, 0, 0),
  [2218] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_path_rest, 2, 0, 0),
  [2220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(489),
  [2222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(755),
  [2224] = {.entry = {.count = 1, .reusable = false}}, SHIFT(468),
  [2226] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_triples_block, 1, 0, 0),
  [2228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(225),
  [2230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(226),
  [2232] = {.entry = {.count = 1, .reusable = false}}, SHIFT(851),
  [2234] = {.entry = {.count = 1, .reusable = false}}, SHIFT(717),
  [2236] = {.entry = {.count = 1, .reusable = false}}, SHIFT(409),
  [2238] = {.entry = {.count = 1, .reusable = false}}, SHIFT(772),
  [2240] = {.entry = {.count = 1, .reusable = false}}, SHIFT(731),
  [2242] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_triples_block_repeat1, 2, 0, 0),
  [2244] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_triples_block_repeat1, 2, 0, 0), SHIFT_REPEAT(265),
  [2247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1054),
  [2249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(239),
  [2251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(222),
  [2253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(857),
  [2255] = {.entry = {.count = 1, .reusable = false}}, SHIFT(724),
  [2257] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1110),
  [2259] = {.entry = {.count = 1, .reusable = false}}, SHIFT(759),
  [2261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(289),
  [2263] = {.entry = {.count = 1, .reusable = false}}, SHIFT(762),
  [2265] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_triples_same_subject_path, 2, 0, 0),
  [2267] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_triples_same_subject_path, 2, 0, 12),
  [2269] = {.entry = {.count = 1, .reusable = false}}, SHIFT(763),
  [2271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(758),
  [2273] = {.entry = {.count = 1, .reusable = false}}, SHIFT(749),
  [2275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(965),
  [2277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1012),
  [2279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1066),
  [2281] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_group_graph_pattern_repeat1, 3, 0, 0),
  [2283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(960),
  [2285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(963),
  [2287] = {.entry = {.count = 1, .reusable = false}}, SHIFT(858),
  [2289] = {.entry = {.count = 1, .reusable = false}}, SHIFT(418),
  [2291] = {.entry = {.count = 1, .reusable = false}}, SHIFT(775),
  [2293] = {.entry = {.count = 1, .reusable = false}}, SHIFT(767),
  [2295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(721),
  [2297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(996),
  [2299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1110),
  [2301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1078),
  [2303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1068),
  [2305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(436),
  [2307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(784),
  [2309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(760),
  [2311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(802),
  [2313] = {.entry = {.count = 1, .reusable = false}}, SHIFT(961),
  [2315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1095),
  [2317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1096),
  [2319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(35),
  [2321] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_select_clause, 3, 0, 3),
  [2323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(812),
  [2325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1031),
  [2327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(263),
  [2329] = {.entry = {.count = 1, .reusable = false}}, SHIFT_EXTRA(),
  [2331] = {.entry = {.count = 1, .reusable = false}}, SHIFT(947),
  [2333] = {.entry = {.count = 1, .reusable = false}}, SHIFT(290),
  [2335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(785),
  [2337] = {.entry = {.count = 1, .reusable = false}}, SHIFT(785),
  [2339] = {.entry = {.count = 1, .reusable = false}}, SHIFT(946),
  [2341] = {.entry = {.count = 1, .reusable = false}}, SHIFT(291),
  [2343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(789),
  [2345] = {.entry = {.count = 1, .reusable = false}}, SHIFT(789),
  [2347] = {.entry = {.count = 1, .reusable = false}}, SHIFT(397),
  [2349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(795),
  [2351] = {.entry = {.count = 1, .reusable = false}}, SHIFT(795),
  [2353] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__string_literal_long1_repeat1, 2, 0, 0), SHIFT_REPEAT(947),
  [2356] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__string_literal_long1_repeat1, 2, 0, 0),
  [2358] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__string_literal_long1_repeat1, 2, 0, 0), SHIFT_REPEAT(785),
  [2361] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__string_literal_long1_repeat1, 2, 0, 0), SHIFT_REPEAT(785),
  [2364] = {.entry = {.count = 1, .reusable = false}}, SHIFT(425),
  [2366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(790),
  [2368] = {.entry = {.count = 1, .reusable = false}}, SHIFT(790),
  [2370] = {.entry = {.count = 1, .reusable = false}}, SHIFT(426),
  [2372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(791),
  [2374] = {.entry = {.count = 1, .reusable = false}}, SHIFT(791),
  [2376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(981),
  [2378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(940),
  [2380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(756),
  [2382] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__string_literal_long2_repeat1, 2, 0, 0), SHIFT_REPEAT(946),
  [2385] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__string_literal_long2_repeat1, 2, 0, 0),
  [2387] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__string_literal_long2_repeat1, 2, 0, 0), SHIFT_REPEAT(789),
  [2390] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__string_literal_long2_repeat1, 2, 0, 0), SHIFT_REPEAT(789),
  [2393] = {.entry = {.count = 1, .reusable = false}}, SHIFT(429),
  [2395] = {.entry = {.count = 1, .reusable = false}}, SHIFT(430),
  [2397] = {.entry = {.count = 1, .reusable = false}}, SHIFT(399),
  [2399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(796),
  [2401] = {.entry = {.count = 1, .reusable = false}}, SHIFT(796),
  [2403] = {.entry = {.count = 1, .reusable = false}}, SHIFT(293),
  [2405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(781),
  [2407] = {.entry = {.count = 1, .reusable = false}}, SHIFT(781),
  [2409] = {.entry = {.count = 1, .reusable = false}}, SHIFT(292),
  [2411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(782),
  [2413] = {.entry = {.count = 1, .reusable = false}}, SHIFT(782),
  [2415] = {.entry = {.count = 1, .reusable = false}}, SHIFT(412),
  [2417] = {.entry = {.count = 1, .reusable = false}}, SHIFT(415),
  [2419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(873),
  [2421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(928),
  [2423] = {.entry = {.count = 1, .reusable = false}}, SHIFT(967),
  [2425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1080),
  [2427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1085),
  [2429] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_path_inverse, 1, 0, 0),
  [2431] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_path_inverse, 1, 0, 0),
  [2433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(983),
  [2435] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_select_clause_repeat1, 2, 0, 6), SHIFT_REPEAT(35),
  [2438] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_select_clause_repeat1, 2, 0, 6),
  [2440] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_select_clause_repeat1, 2, 0, 6), SHIFT_REPEAT(812),
  [2443] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_select_clause, 2, 0, 2),
  [2445] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_property_list_repeat1, 2, 0, 0),
  [2447] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_property_list_repeat1, 2, 0, 0), SHIFT_REPEAT(587),
  [2450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(587),
  [2452] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_list, 2, 0, 0),
  [2454] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__string_literal_long2_repeat1, 2, 0, 0),
  [2456] = {.entry = {.count = 1, .reusable = true}}, SHIFT(879),
  [2458] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_list, 1, 0, 0),
  [2460] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_select_clause_repeat1, 1, 0, 1),
  [2462] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__string_literal_long1_repeat1, 2, 0, 0),
  [2464] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_select_query_repeat1, 2, 0, 0), SHIFT_REPEAT(721),
  [2467] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property, 2, 0, 0),
  [2469] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_select_clause_repeat1, 5, 0, 15),
  [2471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(962),
  [2473] = {.entry = {.count = 1, .reusable = false}}, SHIFT(375),
  [2475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(330),
  [2477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(854),
  [2479] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__string_literal1_repeat1, 2, 0, 0),
  [2481] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__string_literal1_repeat1, 2, 0, 0), SHIFT_REPEAT(819),
  [2484] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__string_literal1_repeat1, 2, 0, 0), SHIFT_REPEAT(819),
  [2487] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__string_literal2_repeat1, 2, 0, 0),
  [2489] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__string_literal2_repeat1, 2, 0, 0), SHIFT_REPEAT(820),
  [2492] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__string_literal2_repeat1, 2, 0, 0), SHIFT_REPEAT(820),
  [2495] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_object_list_path_repeat1, 2, 0, 0), SHIFT_REPEAT(270),
  [2498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(388),
  [2500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(737),
  [2502] = {.entry = {.count = 1, .reusable = false}}, SHIFT(423),
  [2504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(827),
  [2506] = {.entry = {.count = 1, .reusable = false}}, SHIFT(827),
  [2508] = {.entry = {.count = 1, .reusable = false}}, SHIFT(424),
  [2510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(828),
  [2512] = {.entry = {.count = 1, .reusable = false}}, SHIFT(828),
  [2514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(244),
  [2516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(434),
  [2518] = {.entry = {.count = 1, .reusable = false}}, SHIFT(427),
  [2520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(819),
  [2522] = {.entry = {.count = 1, .reusable = false}}, SHIFT(819),
  [2524] = {.entry = {.count = 1, .reusable = false}}, SHIFT(428),
  [2526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(820),
  [2528] = {.entry = {.count = 1, .reusable = false}}, SHIFT(820),
  [2530] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_modify_repeat1, 2, 0, 0),
  [2532] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_modify_repeat1, 2, 0, 0), SHIFT_REPEAT(756),
  [2535] = {.entry = {.count = 1, .reusable = false}}, SHIFT(295),
  [2537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(880),
  [2539] = {.entry = {.count = 1, .reusable = false}}, SHIFT(880),
  [2541] = {.entry = {.count = 1, .reusable = false}}, SHIFT(297),
  [2543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(846),
  [2545] = {.entry = {.count = 1, .reusable = false}}, SHIFT(846),
  [2547] = {.entry = {.count = 1, .reusable = false}}, SHIFT(400),
  [2549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(850),
  [2551] = {.entry = {.count = 1, .reusable = false}}, SHIFT(850),
  [2553] = {.entry = {.count = 1, .reusable = false}}, SHIFT(406),
  [2555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(852),
  [2557] = {.entry = {.count = 1, .reusable = false}}, SHIFT(852),
  [2559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(268),
  [2561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(492),
  [2563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(826),
  [2565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(469),
  [2567] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_triples_template_repeat1, 2, 0, 0),
  [2569] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_triples_template_repeat1, 2, 0, 0), SHIFT_REPEAT(269),
  [2572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1011),
  [2574] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_quads_repeat1, 2, 0, 0), SHIFT_REPEAT(737),
  [2577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(977),
  [2579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(918),
  [2581] = {.entry = {.count = 1, .reusable = false}}, SHIFT(298),
  [2583] = {.entry = {.count = 1, .reusable = false}}, SHIFT(410),
  [2585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(474),
  [2587] = {.entry = {.count = 1, .reusable = false}}, SHIFT(411),
  [2589] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_object_list_repeat1, 2, 0, 0), SHIFT_REPEAT(268),
  [2592] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__inline_data_full_repeat2, 2, 0, 0), SHIFT_REPEAT(375),
  [2595] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__inline_data_full_repeat2, 2, 0, 0),
  [2597] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__inline_data_full_repeat2, 2, 0, 0), SHIFT_REPEAT(854),
  [2600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(270),
  [2602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(385),
  [2604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(478),
  [2606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(871),
  [2608] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_triples_template, 1, 0, 0),
  [2610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(240),
  [2612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(890),
  [2614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(322),
  [2616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(874),
  [2618] = {.entry = {.count = 1, .reusable = true}}, SHIFT(959),
  [2620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(461),
  [2622] = {.entry = {.count = 1, .reusable = true}}, SHIFT(943),
  [2624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(885),
  [2626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(325),
  [2628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(327),
  [2630] = {.entry = {.count = 1, .reusable = true}}, SHIFT(818),
  [2632] = {.entry = {.count = 1, .reusable = false}}, SHIFT(299),
  [2634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(467),
  [2636] = {.entry = {.count = 1, .reusable = false}}, SHIFT(27),
  [2638] = {.entry = {.count = 1, .reusable = true}}, SHIFT(178),
  [2640] = {.entry = {.count = 1, .reusable = false}}, SHIFT(72),
  [2642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(337),
  [2644] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_select_clause, 3, 0, 0),
  [2646] = {.entry = {.count = 1, .reusable = false}}, SHIFT(58),
  [2648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(126),
  [2650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(350),
  [2652] = {.entry = {.count = 1, .reusable = false}}, SHIFT(31),
  [2654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(542),
  [2656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(488),
  [2658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(609),
  [2660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(610),
  [2662] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_construct_triples, 1, 0, 0),
  [2664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(249),
  [2666] = {.entry = {.count = 1, .reusable = true}}, SHIFT(550),
  [2668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(356),
  [2670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1033),
  [2672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(953),
  [2674] = {.entry = {.count = 1, .reusable = false}}, SHIFT(73),
  [2676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(340),
  [2678] = {.entry = {.count = 1, .reusable = false}}, SHIFT(22),
  [2680] = {.entry = {.count = 1, .reusable = true}}, SHIFT(343),
  [2682] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_arg_list_repeat1, 2, 0, 0), SHIFT_REPEAT(48),
  [2685] = {.entry = {.count = 1, .reusable = false}}, SHIFT(85),
  [2687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(204),
  [2689] = {.entry = {.count = 1, .reusable = false}}, SHIFT(86),
  [2691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(175),
  [2693] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sub_select, 3, 0, 0),
  [2695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(685),
  [2697] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_path_negated_property_set_repeat1, 2, 0, 0),
  [2699] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_path_negated_property_set_repeat1, 2, 0, 0), SHIFT_REPEAT(728),
  [2702] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_construct_template, 3, 0, 0),
  [2704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(865),
  [2706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(728),
  [2708] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_triples_same_subject, 2, 0, 0),
  [2710] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__inline_data_full_repeat1, 2, 0, 6),
  [2712] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__inline_data_full_repeat1, 2, 0, 6), SHIFT_REPEAT(953),
  [2715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(433),
  [2717] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19),
  [2719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(129),
  [2721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(942),
  [2723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(536),
  [2725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(989),
  [2727] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_delete_clause, 2, 0, 0),
  [2729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(856),
  [2731] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__inline_data_full_repeat2, 3, 0, 0),
  [2733] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__inline_data_full_repeat2, 3, 0, 0),
  [2735] = {.entry = {.count = 1, .reusable = false}}, SHIFT(59),
  [2737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(569),
  [2739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(186),
  [2741] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_property_list_repeat1, 2, 0, 0), SHIFT_REPEAT(685),
  [2744] = {.entry = {.count = 1, .reusable = false}}, SHIFT(57),
  [2746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(123),
  [2748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(139),
  [2750] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_select_clause, 2, 0, 0),
  [2752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(487),
  [2754] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_property_list_path_repeat1, 2, 0, 0), SHIFT_REPEAT(467),
  [2757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(862),
  [2759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(145),
  [2761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(208),
  [2763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(251),
  [2765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(233),
  [2767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(232),
  [2769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(808),
  [2771] = {.entry = {.count = 1, .reusable = false}}, SHIFT(808),
  [2773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(813),
  [2775] = {.entry = {.count = 1, .reusable = false}}, SHIFT(813),
  [2777] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_insert_clause, 2, 0, 0),
  [2779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(217),
  [2781] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__inline_data_full_repeat1, 1, 0, 1),
  [2783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(218),
  [2785] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_quads_repeat1, 3, 0, 0),
  [2787] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_using_clause, 3, 0, 0),
  [2789] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_using_clause, 2, 0, 0),
  [2791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(99),
  [2793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4),
  [2795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(877),
  [2797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(220),
  [2799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(213),
  [2801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(361),
  [2803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(362),
  [2805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(991),
  [2807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(29),
  [2809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(735),
  [2811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13),
  [2813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(396),
  [2815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(134),
  [2817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(888),
  [2819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(205),
  [2821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1125),
  [2823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1014),
  [2825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(150),
  [2827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(985),
  [2829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1086),
  [2831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(151),
  [2833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(252),
  [2835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(255),
  [2837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(390),
  [2839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(516),
  [2841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(279),
  [2843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(172),
  [2845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(560),
  [2847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1055),
  [2849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(338),
  [2851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(168),
  [2853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(182),
  [2855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(124),
  [2857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(551),
  [2859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(386),
  [2861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(998),
  [2863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(738),
  [2865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(968),
  [2867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1021),
  [2869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(490),
  [2871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(262),
  [2873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(836),
  [2875] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
  [2877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(382),
  [2879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(283),
  [2881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(733),
  [2883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(719),
  [2885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(726),
  [2887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(720),
  [2889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(990),
  [2891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(725),
  [2893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(561),
  [2895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(984),
  [2897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(527),
  [2899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(543),
  [2901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1069),
  [2903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1102),
  [2905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5),
  [2907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18),
  [2909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(24),
  [2911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(272),
  [2913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(739),
  [2915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1103),
  [2917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(197),
  [2919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(198),
  [2921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(523),
  [2923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(742),
  [2925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(734),
  [2927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1006),
  [2929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7),
  [2931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20),
  [2933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(243),
  [2935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1027),
  [2937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(383),
  [2939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(845),
  [2941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(718),
  [2943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(806),
  [2945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(744),
  [2947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(745),
  [2949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1029),
  [2951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6),
  [2953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(25),
  [2955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(26),
  [2957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(620),
  [2959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1013),
  [2961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(364),
  [2963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(952),
  [2965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(432),
  [2967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(746),
  [2969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(747),
  [2971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(861),
  [2973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(346),
  [2975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(171),
  [2977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(167),
  [2979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(816),
  [2981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(41),
  [2983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1061),
  [2985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1062),
  [2987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(30),
  [2989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(366),
  [2991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(867),
  [2993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1124),
  [2995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1072),
  [2997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1073),
  [2999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(466),
  [3001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(999),
  [3003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(160),
  [3005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(907),
  [3007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1083),
  [3009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1084),
  [3011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(98),
  [3013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(562),
  [3015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(100),
  [3017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(287),
  [3019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(103),
  [3021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(104),
  [3023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(105),
  [3025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8),
  [3027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(108),
  [3029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(109),
  [3031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(110),
  [3033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(522),
  [3035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(32),
  [3037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(33),
  [3039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(34),
  [3041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(318),
  [3043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1024),
  [3045] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sub_select, 4, 0, 0),
  [3047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1089),
  [3049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(113),
  [3051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(114),
  [3053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(115),
  [3055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(116),
  [3057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(75),
  [3059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(28),
  [3061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21),
};

#ifdef __cplusplus
extern "C" {
#endif
#ifdef TREE_SITTER_HIDE_SYMBOLS
#define TS_PUBLIC
#elif defined(_WIN32)
#define TS_PUBLIC __declspec(dllexport)
#else
#define TS_PUBLIC __attribute__((visibility("default")))
#endif

TS_PUBLIC const TSLanguage *tree_sitter_sparql(void) {
  static const TSLanguage language = {
    .version = LANGUAGE_VERSION,
    .symbol_count = SYMBOL_COUNT,
    .alias_count = ALIAS_COUNT,
    .token_count = TOKEN_COUNT,
    .external_token_count = EXTERNAL_TOKEN_COUNT,
    .state_count = STATE_COUNT,
    .large_state_count = LARGE_STATE_COUNT,
    .production_id_count = PRODUCTION_ID_COUNT,
    .field_count = FIELD_COUNT,
    .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
    .parse_table = &ts_parse_table[0][0],
    .small_parse_table = ts_small_parse_table,
    .small_parse_table_map = ts_small_parse_table_map,
    .parse_actions = ts_parse_actions,
    .symbol_names = ts_symbol_names,
    .field_names = ts_field_names,
    .field_map_slices = ts_field_map_slices,
    .field_map_entries = ts_field_map_entries,
    .symbol_metadata = ts_symbol_metadata,
    .public_symbol_map = ts_symbol_map,
    .alias_map = ts_non_terminal_alias_map,
    .alias_sequences = &ts_alias_sequences[0][0],
    .lex_modes = ts_lex_modes,
    .lex_fn = ts_lex,
    .keyword_lex_fn = ts_lex_keywords,
    .keyword_capture_token = sym_pn_prefix,
    .primary_state_ids = ts_primary_state_ids,
  };
  return &language;
}
#ifdef __cplusplus
}
#endif
